(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[    511037,      13602]
NotebookOptionsPosition[    473112,      13026]
NotebookOutlinePosition[    473574,      13044]
CellTagsIndexPosition[    473531,      13041]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[BoxData[
 RowBox[{
  RowBox[{"SetDirectory", "[", 
   RowBox[{"NotebookDirectory", "[", "]"}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.781786761328034*^9, 3.781786769223647*^9}, {
  3.7971915793849573`*^9, 
  3.7971915838999634`*^9}},ExpressionUUID->"dc453752-83d2-4d0d-9f4c-\
1a179aba4247"],

Cell[BoxData[
 RowBox[{"<<", " ", "TripleK`"}]], "Input",
 CellChangeTimes->{{3.781711824066417*^9, 
  3.7817118319345713`*^9}},ExpressionUUID->"319af3f1-fcf4-44fc-93fe-\
2d882d3e0a38"],

Cell[CellGroupData[{

Cell["Evaluation of triple-K integrals", "Section",
 CellChangeTimes->{{3.781787475680848*^9, 
  3.781787486456489*^9}},ExpressionUUID->"49a7a544-43e6-4966-a5b7-\
afcc2fd40efe"],

Cell[TextData[{
 "The main object of the package is the ",
 StyleBox["triple-K",
  FontSlant->"Italic"],
 " integral defined in (6.1) of [",
 ButtonBox["1304.7760",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://arxiv.org/pdf/1304.7760.pdf"], None},
  ButtonNote->"https://arxiv.org/pdf/1304.7760.pdf"],
 "] as\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["I", 
      RowBox[{"\[Alpha]", 
       RowBox[{"{", 
        RowBox[{
         SubscriptBox["\[Beta]", "1"], 
         SubscriptBox["\[Beta]", "2"], 
         SubscriptBox["\[Beta]", "3"]}], "}"}]}]], "(", 
     RowBox[{
      SubscriptBox["p", "1"], ",", 
      SubscriptBox["p", "2"], ",", 
      SubscriptBox["p", "3"]}], ")"}], "=", 
    RowBox[{
     SuperscriptBox[
      SubscriptBox["p", "1"], 
      SubscriptBox["\[Beta]", "1"]], 
     SuperscriptBox[
      SubscriptBox["p", "2"], 
      SubscriptBox["\[Beta]", "2"]], 
     SuperscriptBox[
      SubscriptBox["p", "3"], 
      SubscriptBox["\[Beta]", "3"]], 
     RowBox[{
      SuperscriptBox[
       SubscriptBox["\[Integral]", "0"], "\[Infinity]"], 
      RowBox[{"dx", " ", 
       SuperscriptBox["x", "\[Alpha]"], 
       RowBox[{
        SubscriptBox["K", 
         SubscriptBox["\[Beta]", "1"]], "(", 
        RowBox[{
         SubscriptBox["p", "1"], "x"}], ")"}], 
       RowBox[{
        SubscriptBox["K", 
         SubscriptBox["\[Beta]", "2"]], "(", 
        RowBox[{
         SubscriptBox["p", "2"], "x"}], ")"}], 
       RowBox[{
        SubscriptBox["K", 
         SubscriptBox["\[Beta]", "3"]], "(", 
        RowBox[{
         SubscriptBox["p", "3"], "x"}], ")"}], " "}]}]}]}], TraditionalForm]],
  ExpressionUUID->"8ce3cf4a-5a35-4df4-87ba-d61f3c01e057"],
 ",\nwhere ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["K", "\[Nu]"], TraditionalForm]],ExpressionUUID->
  "a7894135-ce55-4c56-baaf-ded5ee5570c0"],
 " denotes the modified Bessel function of the third kind."
}], "Text",
 CellChangeTimes->{{3.781787514944394*^9, 3.7817875307839003`*^9}, {
  3.7971916628260746`*^9, 3.7971919464224763`*^9}, {3.7979269490491457`*^9, 
  3.797926950000276*^9}, {3.797927005647272*^9, 
  3.7979270255278463`*^9}},ExpressionUUID->"d93abd0d-e2db-410d-8942-\
00f2873a61dd"],

Cell[TextData[{
 "Analogously the double-",
 StyleBox["K",
  FontSlant->"Italic"],
 " integral is\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["I", 
      RowBox[{"\[Alpha]", 
       RowBox[{"{", 
        RowBox[{
         SubscriptBox["\[Beta]", "1"], 
         SubscriptBox["\[Beta]", "2"]}], "}"}]}]], "(", "p", ")"}], "=", 
    RowBox[{
     SuperscriptBox["p", 
      RowBox[{
       SubscriptBox["\[Beta]", "1"], "+", 
       SubscriptBox["\[Beta]", "2"]}]], 
     RowBox[{
      SuperscriptBox[
       SubscriptBox["\[Integral]", "0"], "\[Infinity]"], 
      RowBox[{"dx", " ", 
       SuperscriptBox["x", "\[Alpha]"], 
       RowBox[{
        SubscriptBox["K", 
         SubscriptBox["\[Beta]", "1"]], "(", 
        RowBox[{"p", " ", "x"}], ")"}], 
       RowBox[{
        SubscriptBox["K", 
         SubscriptBox["\[Beta]", "2"]], "(", 
        RowBox[{"p", " ", "x"}], ")"}], " "}]}]}]}], TraditionalForm]],
  ExpressionUUID->"bb088613-21b2-462a-a5cb-1688dec7b276"],
 ".\nHere only a single momentum ",
 StyleBox["p",
  FontSlant->"Italic"],
 " appears in both Bessel functions."
}], "Text",
 CellChangeTimes->{{3.797191949312481*^9, 
  3.797191980157524*^9}},ExpressionUUID->"b69c35ca-eda3-4f49-8b78-\
ebf46ba617f0"],

Cell[TextData[{
 "Double- and triple-",
 StyleBox["K",
  FontSlant->"Italic"],
 " integrals are represented as:"
}], "Text",
 CellChangeTimes->{{3.797191986613533*^9, 3.797191998133549*^9}, 
   3.797927098447754*^9},ExpressionUUID->"f5d4e600-9632-4427-ae03-\
1f545dfc61e4"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"i", "[", 
   RowBox[{"\[Alpha]", ",", 
    RowBox[{"{", 
     RowBox[{"\[Beta]1", ",", "\[Beta]2", ",", "\[Beta]3"}], "}"}]}], "]"}], 
  "[", 
  RowBox[{
   RowBox[{"p", "[", "1", "]"}], ",", 
   RowBox[{"p", "[", "2", "]"}], ",", 
   RowBox[{"p", "[", "3", "]"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"i", "[", 
   RowBox[{"\[Alpha]", ",", 
    RowBox[{"{", 
     RowBox[{"\[Beta]1", ",", "\[Beta]2"}], "}"}]}], "]"}], "[", "p", 
  "]"}]}], "Input",
 CellChangeTimes->{{3.781787532956182*^9, 3.781787580994137*^9}, {
  3.797191647619053*^9, 
  3.7971916497040563`*^9}},ExpressionUUID->"acd878a6-993e-4d4d-ab29-\
f3aa0dd216e5"],

Cell[BoxData[
 SubscriptBox["i", 
  RowBox[{"\[Alpha]", ",", 
   RowBox[{"{", 
    RowBox[{"\[Beta]1", ",", "\[Beta]2", ",", "\[Beta]3"}], 
    "}"}]}]]], "Output",
 CellChangeTimes->{3.7817875508992147`*^9, 3.781787581318968*^9, 
  3.7971919993295507`*^9, 3.7974423142490377`*^9, 3.7979269569978237`*^9, 
  3.7979270468405323`*^9, 3.79824826598517*^9, 3.7986857520171413`*^9, 
  3.7986858021569777`*^9, 
  3.799037617331834*^9},ExpressionUUID->"e3944857-09a3-435c-a6c4-\
e2af9470b32e"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["i", 
   RowBox[{"\[Alpha]", ",", 
    RowBox[{"{", 
     RowBox[{"\[Beta]1", ",", "\[Beta]2"}], "}"}]}]], "[", "p", 
  "]"}]], "Output",
 CellChangeTimes->{3.7817875508992147`*^9, 3.781787581318968*^9, 
  3.7971919993295507`*^9, 3.7974423142490377`*^9, 3.7979269569978237`*^9, 
  3.7979270468405323`*^9, 3.79824826598517*^9, 3.7986857520171413`*^9, 
  3.7986858021569777`*^9, 
  3.79903761733366*^9},ExpressionUUID->"48e907f3-842f-40a2-80c2-b00410db6c65"]
}, Open  ]],

Cell[TextData[{
 "In triple-",
 StyleBox["K",
  FontSlant->"Italic"],
 " integrals (but ",
 StyleBox["not",
  FontSlant->"Italic"],
 " double-",
 StyleBox["K",
  FontSlant->"Italic"],
 ") momenta can be omitted. The standard momenta magnitudes ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["p", "1"], ",", " ", 
    SubscriptBox["p", "2"], ",", " ", 
    SubscriptBox["p", "3"]}], TraditionalForm]],ExpressionUUID->
  "a1c884d5-eb96-4aff-b6b2-01976499230e"],
 " are then assumed as arguments. Parameters can also be inputted as \
subscripts:"
}], "Text",
 CellChangeTimes->{{3.78178760129624*^9, 3.7817876411768093`*^9}, {
  3.794887453569615*^9, 3.794887474569602*^9}, {3.797192060129637*^9, 
  3.7971920910846806`*^9}, {3.797927076304063*^9, 
  3.7979270957364197`*^9}},ExpressionUUID->"247985cb-d475-4788-b74c-\
5191783784d8"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"i", "[", 
    RowBox[{"\[Alpha]", ",", 
     RowBox[{"{", 
      RowBox[{"\[Beta]1", ",", "\[Beta]2", ",", "\[Beta]3"}], "}"}]}], "]"}], 
   "-", 
   RowBox[{
    SubscriptBox["i", 
     RowBox[{"\[Alpha]", ",", 
      RowBox[{"{", 
       RowBox[{"\[Beta]1", ",", "\[Beta]2", ",", "\[Beta]3"}], "}"}]}]], "[", 
    RowBox[{
     SubscriptBox["p", "1"], ",", 
     SubscriptBox["p", "2"], ",", 
     SubscriptBox["p", "3"]}], "]"}]}], "//", "KExpand"}]], "Input",
 CellChangeTimes->{{3.7979271023678493`*^9, 3.7979271249277687`*^9}, {
  3.797927579757101*^9, 3.797927596496648*^9}, {3.797935862292218*^9, 
  3.79793586293546*^9}},ExpressionUUID->"67200ffc-9223-4cef-8986-\
5d12adfe9904"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.797927125644553*^9, 3.7979275967663507`*^9, 
  3.79793586330826*^9, 3.798248275814546*^9, 3.7986857520311418`*^9, 
  3.798685802167979*^9, 
  3.799037617375333*^9},ExpressionUUID->"1f84b12d-e519-48ea-8afb-\
055e3f041eff"]
}, Open  ]],

Cell[TextData[{
 "To evaluate multiple-",
 StyleBox["K",
  FontSlant->"Italic"],
 " integrals explicitly, use ",
 StyleBox["KEvaluate",
  FontSlant->"Italic"],
 ".  ",
 StyleBox["KEvaluate",
  FontSlant->"Italic"],
 " can be applied to any expression and replaces all double- and triple-",
 StyleBox["K",
  FontSlant->"Italic"],
 " integrals with explicit expressions, if these are known. The package \
implements the reduction scheme introduced in [",
 ButtonBox["1511.02357",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://arxiv.org/pdf/1511.02357.pdf"], None},
  ButtonNote->"https://arxiv.org/pdf/1511.02357.pdf"],
 "]. It provides evaluation of the multiple-",
 StyleBox["K",
  FontSlant->"Italic"],
 " integrals in the following cases:"
}], "Text",
 CellChangeTimes->{{3.797927151535733*^9, 3.797927172088361*^9}, {
  3.79792721870348*^9, 3.797927272792275*^9}, {3.7979273181041403`*^9, 
  3.797927386737391*^9}, {3.798248305988546*^9, 3.798248329732109*^9}, {
  3.798248368291429*^9, 
  3.798248383812748*^9}},ExpressionUUID->"c50a115c-ec58-4fca-9718-\
4fa58b9f53ef"],

Cell[CellGroupData[{

Cell[TextData[{
 "All double-",
 StyleBox["K",
  FontSlant->"Italic"],
 " integrals have analytic expressions."
}], "Item",
 CellChangeTimes->{{3.797927395703156*^9, 3.797927409319684*^9}, {
  3.7979276294877443`*^9, 
  3.797927639999776*^9}},ExpressionUUID->"9a21bc91-1ec3-4b84-b6fa-\
219db6be256f"],

Cell[TextData[{
 "Triple-",
 StyleBox["K",
  FontSlant->"Italic"],
 " integrals with half-integral \[Beta]-indices are expressible in terms of \
elementary functions and Gamma function."
}], "Item",
 CellChangeTimes->{{3.797927395703156*^9, 
  3.7979274643038673`*^9}},ExpressionUUID->"274637e8-5dd3-41ff-bfc4-\
9240e48c6577"],

Cell[TextData[{
 "Triple-",
 StyleBox["K",
  FontSlant->"Italic"],
 " integrals with two half-integral \[Beta]-indices are expressible in terms \
of Hypergeometric2F1."
}], "Item",
 CellChangeTimes->{{3.797927395703156*^9, 
  3.797927490704995*^9}},ExpressionUUID->"adbb3bff-24da-42bc-b179-\
28c7107848f9"],

Cell[TextData[{
 "Certain class of triple-",
 StyleBox["K",
  FontSlant->"Italic"],
 " integrals with integral \[Alpha]- and \[Beta]-indices defined as follows. \
Let ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["n", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Sigma]", "1"], 
       SubscriptBox["\[Sigma]", "2"], 
       SubscriptBox["\[Sigma]", "3"]}], ")"}]], "=", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["1", "2"]}], 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Sigma]", "1"], "|", 
       SubscriptBox["\[Beta]", "1"], "|", 
       RowBox[{"+", 
        SubscriptBox["\[Sigma]", "2"]}], "|", 
       SubscriptBox["\[Beta]", "2"], "|", 
       RowBox[{"+", 
        SubscriptBox["\[Sigma]", "3"]}], "|", 
       SubscriptBox["\[Beta]", "3"], "|", 
       RowBox[{
        RowBox[{"+", "\[Alpha]"}], "+", "1"}]}], ")"}]}]}], TraditionalForm]],
  ExpressionUUID->"938d1976-ebcf-47cc-8069-b70d6cc9e5b0"],
 ", where ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[Sigma]", "j"], "=", 
    RowBox[{"\[PlusMinus]", "1"}]}], TraditionalForm]],ExpressionUUID->
  "98fdc8d2-4ca9-456d-991a-d951ec8df8ec"],
 ". If ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["n", 
     RowBox[{"(", 
      RowBox[{"-", "++"}], ")"}]], ",", 
    SubscriptBox["n", 
     RowBox[{"(", 
      RowBox[{"+", 
       RowBox[{"-", "+"}]}], ")"}]], ",", 
    RowBox[{
     SubscriptBox["n", 
      RowBox[{"(", 
       RowBox[{"++", "-"}], ")"}]], "<", "0"}]}], TraditionalForm]],
  ExpressionUUID->"4c3b48fc-c568-4aec-8316-4cca68af261e"],
 ", then the (regulated) triple-",
 StyleBox["K",
  FontSlant->"Italic"],
 " integral is expressible in terms of dilogarithm ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["Li", "2"], TraditionalForm]],ExpressionUUID->
  "3892693f-0167-4763-a900-da824dd0081a"],
 " and elementary functions."
}], "Item",
 CellChangeTimes->{{3.797927395703156*^9, 3.797927526528173*^9}, {
   3.797927657031619*^9, 3.797927657416875*^9}, {3.797927818296541*^9, 
   3.797927823088812*^9}, {3.797928735585561*^9, 3.797928854105352*^9}, {
   3.7979290032182827`*^9, 3.797929005641367*^9}, {3.797933080238048*^9, 
   3.797933224493533*^9}, 3.797933333910076*^9, {3.797935877504438*^9, 
   3.797935981854083*^9}, {3.798248406572526*^9, 3.798248406939909*^9}, {
   3.79861131496354*^9, 
   3.7986113310756273`*^9}},ExpressionUUID->"7058b4cb-e823-45ed-96f3-\
653534c410dd"]
}, Open  ]],

Cell["\<\
To check if an integral can be reduced to an analytic expression use \
IsSolvable:\
\>", "Text",
 CellChangeTimes->{{3.797935989279368*^9, 3.797936020383236*^9}, {
   3.7982484154845057`*^9, 3.798248415587781*^9}, 
   3.798685784098956*^9},ExpressionUUID->"5c5729b2-fc5a-4431-891f-\
fc44dbf87dc6"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"IsSolvable", "[", 
  RowBox[{"i", "[", 
   RowBox[{"1", ",", 
    RowBox[{"{", 
     RowBox[{"2", ",", "2", ",", "2"}], "}"}]}], "]"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"IsSolvable", "[", 
  RowBox[{"i", "[", 
   RowBox[{"0", ",", 
    RowBox[{"{", 
     RowBox[{"2", ",", "2", ",", "2"}], "}"}]}], "]"}], "]"}]}], "Input",
 CellChangeTimes->{{3.797927876210473*^9, 3.797927883032804*^9}, {
   3.797927919811922*^9, 3.797927924257918*^9}, 3.7979284521637278`*^9, {
   3.797928482379817*^9, 3.797928487808124*^9}, {3.797928592019891*^9, 
   3.7979286032490187`*^9}, {3.797936027251505*^9, 3.797936038839711*^9}, {
   3.798248423509081*^9, 3.798248425780197*^9}, {3.7986857849780045`*^9, 
   3.7986857858000517`*^9}},ExpressionUUID->"66608a6c-4b9c-4db2-a659-\
2d179210c9bc"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{
  3.797927884337764*^9, {3.797928449804287*^9, 3.797928452657929*^9}, {
   3.797928483203471*^9, 3.79792848820331*^9}, 3.7979285592449903`*^9, {
   3.797928593260993*^9, 3.7979286036679792`*^9}, 3.797936039271028*^9, {
   3.798248420102783*^9, 3.798248426023471*^9}, 3.7986857520421424`*^9, 
   3.7986858021779795`*^9, 
   3.799037617396923*^9},ExpressionUUID->"4d0d0bc1-587b-4f9a-b2ce-\
c92e8d4d5db8"],

Cell[BoxData["False"], "Output",
 CellChangeTimes->{
  3.797927884337764*^9, {3.797928449804287*^9, 3.797928452657929*^9}, {
   3.797928483203471*^9, 3.79792848820331*^9}, 3.7979285592449903`*^9, {
   3.797928593260993*^9, 3.7979286036679792`*^9}, 3.797936039271028*^9, {
   3.798248420102783*^9, 3.798248426023471*^9}, 3.7986857520421424`*^9, 
   3.7986858021779795`*^9, 
   3.799037617398693*^9},ExpressionUUID->"8182fe33-c710-40a2-9536-\
1d19cd3a371c"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Basic evaluations", "Subsection",
 CellChangeTimes->{{3.781787699192595*^9, 
  3.781787704209251*^9}},ExpressionUUID->"3226fdf5-c858-4709-af01-\
0a2e1aafa4b3"],

Cell[TextData[{
 "Double-",
 StyleBox["K",
  FontSlant->"Italic"],
 " integrals can always be evaluated:"
}], "Text",
 CellChangeTimes->{{3.781787760567605*^9, 3.7817878135297117`*^9}, {
  3.7971920217825823`*^9, 3.797192024263586*^9}, {3.797192192972824*^9, 
  3.797192212095851*^9}, {3.797192561532343*^9, 3.797192561947344*^9}, {
  3.797927210183447*^9, 
  3.797927210703779*^9}},ExpressionUUID->"55a0cdbb-e785-4fca-9712-\
d3f52244f2a9"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"KEvaluate", "[", 
  RowBox[{
   RowBox[{"i", "[", 
    RowBox[{"\[Alpha]", ",", 
     RowBox[{"{", 
      RowBox[{"\[Beta]1", ",", "\[Beta]2"}], "}"}]}], "]"}], "[", "p", "]"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.781787735739447*^9, 3.781787785367161*^9}, {
  3.797192029304593*^9, 3.7971920296395936`*^9}, {3.797192228574874*^9, 
  3.797192228869875*^9}, {3.7971925512753286`*^9, 
  3.7971925519013295`*^9}},ExpressionUUID->"70a893ee-87f6-4783-94b5-\
f94e657edd5f"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{"Gamma", "[", 
    RowBox[{"1", "+", "\[Alpha]"}], "]"}]], 
  RowBox[{
   SuperscriptBox["2", 
    RowBox[{
     RowBox[{"-", "2"}], "+", "\[Alpha]"}]], " ", 
   SuperscriptBox["p", 
    RowBox[{
     RowBox[{"-", "1"}], "-", "\[Alpha]", "+", "\[Beta]1", "+", "\[Beta]2"}]],
    " ", 
   RowBox[{"Gamma", "[", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", "\[Alpha]", "-", "\[Beta]1", "-", "\[Beta]2"}], 
      ")"}]}], "]"}], " ", 
   RowBox[{"Gamma", "[", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", "\[Alpha]", "+", "\[Beta]1", "-", "\[Beta]2"}], 
      ")"}]}], "]"}], " ", 
   RowBox[{"Gamma", "[", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", "\[Alpha]", "-", "\[Beta]1", "+", "\[Beta]2"}], 
      ")"}]}], "]"}], " ", 
   RowBox[{"Gamma", "[", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", "\[Alpha]", "+", "\[Beta]1", "+", "\[Beta]2"}], 
      ")"}]}], "]"}]}]}]], "Output",
 CellChangeTimes->{{3.7817877546557503`*^9, 3.7817877877016973`*^9}, 
   3.781787817885397*^9, 3.794552125495715*^9, {3.7971920255285883`*^9, 
   3.797192030184594*^9}, 3.797192229329875*^9, 3.797193326265432*^9, 
   3.7974423175490417`*^9, 3.79793605980613*^9, 3.798248435585658*^9, 
   3.798685752298157*^9, 3.798685802423993*^9, 
   3.799037617709976*^9},ExpressionUUID->"953a2304-fa28-4090-8d22-\
e60c27bdb543"]
}, Open  ]],

Cell[TextData[{
 "Most triple-",
 StyleBox["K",
  FontSlant->"Italic"],
 " integrals do not have a decent representation, so nothing happens:"
}], "Text",
 CellChangeTimes->{{3.797193344162457*^9, 3.797193362874483*^9}, {
  3.79719340347054*^9, 3.797193406686545*^9}, {3.7979361137504673`*^9, 
  3.797936114463464*^9}},ExpressionUUID->"8651df40-a0de-4128-9bc5-\
5a88c10ab305"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"IsSolvable", "[", 
  RowBox[{"i", "[", 
   RowBox[{"1", ",", 
    RowBox[{"{", 
     RowBox[{"1", ",", "1", ",", "1"}], "}"}]}], "]"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"KEvaluate", "[", 
  RowBox[{"i", "[", 
   RowBox[{"1", ",", 
    RowBox[{"{", 
     RowBox[{"1", ",", "1", ",", "1"}], "}"}]}], "]"}], "]"}]}], "Input",
 CellChangeTimes->{{3.797193368915492*^9, 3.7971933727354975`*^9}, {
   3.7979360756913643`*^9, 3.797936081585958*^9}, 
   3.798685790337308*^9},ExpressionUUID->"e8ff13db-0330-4019-bbc6-\
96af4b63dfb6"],

Cell[BoxData["False"], "Output",
 CellChangeTimes->{{3.7971933749555*^9, 3.797193387369518*^9}, 
   3.797442320475046*^9, {3.797936065865519*^9, 3.797936082109864*^9}, 
   3.79824844132023*^9, 3.798685752315158*^9, 3.7986858024339943`*^9, 
   3.799037617719755*^9},ExpressionUUID->"1769ed37-e2b2-49e1-8360-\
36da356550c1"],

Cell[BoxData[
 SubscriptBox["i", 
  RowBox[{"1", ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1", ",", "1"}], "}"}]}]]], "Output",
 CellChangeTimes->{{3.7971933749555*^9, 3.797193387369518*^9}, 
   3.797442320475046*^9, {3.797936065865519*^9, 3.797936082109864*^9}, 
   3.79824844132023*^9, 3.798685752315158*^9, 3.7986858024339943`*^9, 
   3.799037617721428*^9},ExpressionUUID->"6092f6a2-7e7d-4aa9-a615-\
51b10b0bb7c9"]
}, Open  ]],

Cell[TextData[{
 "Triple-",
 StyleBox["K",
  FontSlant->"Italic"],
 " integrals with half-integral indices lead to elementary expressions:"
}], "Text",
 CellChangeTimes->{{3.781787710688759*^9, 3.781787734520319*^9}, {
  3.79793611584727*^9, 
  3.79793611715942*^9}},ExpressionUUID->"af344a54-a977-4cc3-b332-\
4702c7b0936e"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"KEvaluate", "[", 
  RowBox[{"i", "[", 
   RowBox[{
    RowBox[{"3", "/", "2"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"1", "/", "2"}], ",", 
      RowBox[{"1", "/", "2"}], ",", 
      RowBox[{"1", "/", "2"}]}], "}"}]}], "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"int", "=", 
  RowBox[{
   RowBox[{"KEvaluate", "[", 
    RowBox[{"i", "[", 
     RowBox[{"a", ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"3", "/", "2"}], ",", 
        RowBox[{"1", "/", "2"}], ",", 
        RowBox[{"1", "/", "2"}]}], "}"}]}], "]"}], "]"}], "//", 
   "FullSimplify"}]}]}], "Input",
 CellChangeTimes->{{3.7817120074120464`*^9, 3.7817120091070485`*^9}, {
  3.781712104740596*^9, 3.7817121086526566`*^9}, {3.7817123143578143`*^9, 
  3.7817123149168324`*^9}, {3.781787840315826*^9, 3.781787871841647*^9}, {
  3.7971922465399*^9, 3.797192300541976*^9}, {3.797192395055109*^9, 
  3.797192395220109*^9}},ExpressionUUID->"1bdd0eae-3834-48e0-8cd3-\
aa00995272c0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   FractionBox[
    SuperscriptBox["\[Pi]", 
     RowBox[{"3", "/", "2"}]], 
    RowBox[{"2", " ", 
     SqrtBox["2"], " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["p", "1"], "+", 
       SubscriptBox["p", "2"], "+", 
       SubscriptBox["p", "3"]}], ")"}]}]], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "\[Epsilon]", "]"}], "1"],
    SeriesData[TripleK`\[Epsilon], 0, {}, 0, 1, 1],
    Editable->False]}],
  SeriesData[
  TripleK`\[Epsilon], 0, {
   Rational[1, 2] 2^Rational[-1, 2] Pi^Rational[3, 2]/(TripleK`p[1] + 
    TripleK`p[2] + TripleK`p[3])}, 0, 1, 1],
  Editable->False]], "Output",
 CellChangeTimes->{
  3.7817121134537106`*^9, 3.7817121576113377`*^9, 3.7817123153068547`*^9, 
   3.7817130081454515`*^9, 3.781717597698595*^9, 3.781787708033741*^9, {
   3.781787820575585*^9, 3.781787841188363*^9}, 3.781787872151086*^9, 
   3.794552130030341*^9, 3.7945553514535913`*^9, 3.7945554229305162`*^9, {
   3.797192257440915*^9, 3.7971923010019765`*^9}, {3.7971923849130945`*^9, 
   3.7971923977551126`*^9}, 3.797193330655438*^9, 3.7971933906545224`*^9, 
   3.7974423243910513`*^9, 3.797936093798512*^9, 3.798248446029327*^9, 
   3.798685752337159*^9, 3.798685802444995*^9, 
   3.799037617754045*^9},ExpressionUUID->"90d90bd0-e41b-460f-b698-\
7f32eb099982"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   FractionBox[
    RowBox[{
     SuperscriptBox["\[Pi]", 
      RowBox[{"3", "/", "2"}]], " ", 
     RowBox[{"Gamma", "[", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["3", "2"]}], "+", "a"}], "]"}], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["p", "1"], "+", 
        SubscriptBox["p", "2"], "+", 
        SubscriptBox["p", "3"]}], ")"}], 
      RowBox[{
       FractionBox["1", "2"], "-", "a"}]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"2", " ", "a"}]}], ")"}], " ", 
        SubscriptBox["p", "1"]}], "+", 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["p", "2"], "+", 
          SubscriptBox["p", "3"]}], ")"}]}]}], ")"}]}], 
    RowBox[{"4", " ", 
     SqrtBox["2"]}]], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "\[Epsilon]", "]"}], "1"],
    SeriesData[TripleK`\[Epsilon], 0, {}, 0, 1, 1],
    Editable->False]}],
  SeriesData[
  TripleK`\[Epsilon], 0, {
   Rational[1, 4] 2^Rational[-1, 2] Pi^Rational[3, 2] 
    Gamma[Rational[-3, 2] + $CellContext`a] (TripleK`p[1] + TripleK`p[2] + 
      TripleK`p[3])^(
      Rational[1, 2] - $CellContext`a) ((-1 + 2 $CellContext`a) TripleK`p[1] + 
     2 (TripleK`p[2] + TripleK`p[3]))}, 0, 1, 1],
  Editable->False]], "Output",
 CellChangeTimes->{
  3.7817121134537106`*^9, 3.7817121576113377`*^9, 3.7817123153068547`*^9, 
   3.7817130081454515`*^9, 3.781717597698595*^9, 3.781787708033741*^9, {
   3.781787820575585*^9, 3.781787841188363*^9}, 3.781787872151086*^9, 
   3.794552130030341*^9, 3.7945553514535913`*^9, 3.7945554229305162`*^9, {
   3.797192257440915*^9, 3.7971923010019765`*^9}, {3.7971923849130945`*^9, 
   3.7971923977551126`*^9}, 3.797193330655438*^9, 3.7971933906545224`*^9, 
   3.7974423243910513`*^9, 3.797936093798512*^9, 3.798248446029327*^9, 
   3.798685752337159*^9, 3.798685802444995*^9, 
   3.799037618884927*^9},ExpressionUUID->"11502647-f1a5-41d6-beae-\
b3fa86a50032"]
}, Open  ]],

Cell["We can check that the expression is conformal:", "Text",
 CellChangeTimes->{{3.781787877632333*^9, 3.7817878937616568`*^9}, 
   3.79719230362198*^9, {3.797936111199362*^9, 
   3.797936111615052*^9}},ExpressionUUID->"5604e229-ab24-453e-a9bf-\
f2c14db3937e"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"ScalarKKOp", "[", 
   RowBox[{"int", ",", " ", 
    RowBox[{"p", "[", "1", "]"}], ",", " ", 
    RowBox[{"p", "[", "2", "]"}], ",", 
    RowBox[{"3", "/", "2"}], ",", " ", 
    RowBox[{"1", "/", "2"}]}], "]"}], "//", "FullSimplify"}]], "Input",
 CellChangeTimes->{{3.7817121793237214`*^9, 3.7817121794287214`*^9}, {
  3.781712213547187*^9, 3.7817122217653556`*^9}, {3.781712320692994*^9, 
  3.781712322645*^9}, {3.781712369253448*^9, 3.78171238344458*^9}, {
  3.781712467201071*^9, 3.781712497611518*^9}, {3.781712565697626*^9, 
  3.7817125658026266`*^9}, {3.781787896792782*^9, 3.781787911009264*^9}, {
  3.794555338390315*^9, 3.7945553435014763`*^9}, {3.797192405422124*^9, 
  3.7971924226191473`*^9}, {3.797936107166286*^9, 
  3.797936107983658*^9}},ExpressionUUID->"6bb4e652-0333-4e6a-b8c5-\
4c1fe5ba6c24"],

Cell[BoxData[
 InterpretationBox[
  SuperscriptBox[
   RowBox[{"O", "[", "\[Epsilon]", "]"}], "1"],
  SeriesData[TripleK`\[Epsilon], 0, {}, 1, 1, 1],
  Editable->False]], "Output",
 CellChangeTimes->{
  3.781712180753723*^9, {3.781712216858285*^9, 3.7817122220943747`*^9}, 
   3.78171232317003*^9, {3.7817123716454573`*^9, 3.781712384169581*^9}, {
   3.781712469142129*^9, 3.7817124983705215`*^9}, 3.781712566042627*^9, 
   3.7817130102404547`*^9, 3.78178791123498*^9, {3.794555343857168*^9, 
   3.7945553530351343`*^9}, 3.794555424207711*^9, {3.7971924066571255`*^9, 
   3.7971924230991488`*^9}, 3.7971933346364436`*^9, 3.7971933924845247`*^9, 
   3.797442333788065*^9, 3.797936194116631*^9, 3.798248451386633*^9, 
   3.7986857542062645`*^9, 3.7986858040250835`*^9, 
   3.7990376204990187`*^9},ExpressionUUID->"2551632f-0241-4839-bd4c-\
dfc4d807b556"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Regularization", "Subsection",
 CellChangeTimes->{{3.781787699192595*^9, 3.781787704209251*^9}, {
  3.797192454673193*^9, 3.7971924601292005`*^9}, {3.797192927023858*^9, 
  3.7971929292538614`*^9}, {3.7971929712309203`*^9, 
  3.7971929991849594`*^9}},ExpressionUUID->"90b8d251-9ada-468e-be76-\
e75e3b8eac05"],

Cell[TextData[{
 "With fixed arguments ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["p", "j"], ">", "0"}], TraditionalForm]],ExpressionUUID->
  "bdd29fcb-0a64-4ad2-a104-0a1d2204175c"],
 " the multiple-",
 StyleBox["K",
  FontSlant->"Italic"],
 " integrals are meromorphic functions of the parameters ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Alpha]", ",", 
    SubscriptBox["\[Beta]", "j"]}], TraditionalForm]],ExpressionUUID->
  "7c6ad318-c1c6-4f1e-a6ee-810aa8abc067"],
 ". If, for a given set of parameters the integral is divergent, a regulator, \
\[Epsilon], can be used, and the result Laurent-expanded in \[Epsilon]. \
\[Epsilon] is a special symbol used by the package:"
}], "Text",
 CellChangeTimes->{{3.797192044757615*^9, 3.7971921870958157`*^9}, {
   3.7971929451218834`*^9, 3.7971929468468857`*^9}, {3.7971929831779375`*^9, 
   3.797192986592942*^9}, {3.7979362121835127`*^9, 3.797936212613793*^9}, 
   3.798248459204307*^9},ExpressionUUID->"b8622019-d078-4df3-bb3a-\
57c7e730de1a"],

Cell[CellGroupData[{

Cell[BoxData["\[Epsilon]"], "Input",
 CellChangeTimes->{{3.797192188040817*^9, 
  3.7971921883858175`*^9}},ExpressionUUID->"4c6d8e0d-a74e-47e1-806f-\
8f7b3a9f8e2c"],

Cell[BoxData["\[Epsilon]"], "Output",
 CellChangeTimes->{3.7971921888108177`*^9, 3.7971929885279446`*^9, 
  3.797442336518069*^9, 3.797936210289178*^9, 3.798248473772663*^9, 
  3.798685754217265*^9, 3.798685804033084*^9, 
  3.799037620529797*^9},ExpressionUUID->"8d2d2c10-8f56-4bf5-b36e-\
41b0777ad0f1"]
}, Open  ]],

Cell["\<\
If the regulator \[Epsilon] is used in the expression, the integral evaluates \
to a power series:\
\>", "Text",
 CellChangeTimes->{
  3.797192565613349*^9, {3.797936216479632*^9, 
   3.797936217007654*^9}},ExpressionUUID->"9c8d247a-1517-49fd-bb7f-\
a0fe574daf5c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"KEvaluate", "[", 
  RowBox[{
   RowBox[{"i", "[", 
    RowBox[{
     RowBox[{"1", "+", "\[Epsilon]"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "1"}], "}"}]}], "]"}], "[", "p", "]"}], 
  "]"}]], "Input",ExpressionUUID->"014eed7f-76a5-4f39-b968-ee56fe5d09d8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   FractionBox["1", "\[Epsilon]"], "+", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["1", "2"]}], "-", "EulerGamma", "+", 
     RowBox[{"Log", "[", "2", "]"}], "-", 
     RowBox[{"Log", "[", "p", "]"}]}], ")"}], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "\[Epsilon]", "]"}], "1"],
    SeriesData[TripleK`\[Epsilon], 0, {}, -1, 1, 1],
    Editable->False]}],
  SeriesData[
  TripleK`\[Epsilon], 0, {
   1, Rational[-1, 2] - EulerGamma + Log[2] - Log[TripleK`p]}, -1, 1, 1],
  Editable->False]], "Output",
 CellChangeTimes->{3.7971925687483535`*^9, 3.7974423397590733`*^9, 
  3.79793621836651*^9, 3.7979363555450993`*^9, 3.798248479472456*^9, 
  3.7986857543222713`*^9, 3.7986858041170883`*^9, 
  3.7990376206361027`*^9},ExpressionUUID->"ec44afa4-7aa3-41ff-97d3-\
99589a2191c4"]
}, Open  ]],

Cell[TextData[{
 "If the integral diverges, but no regulator is specified, the default \
regularization ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Alpha]", "\[Rule]", 
    RowBox[{"\[Alpha]", "+", 
     RowBox[{"u", " ", "\[Epsilon]"}]}]}], TraditionalForm]],ExpressionUUID->
  "ece413b3-fd8d-49b3-8d13-befc240fbb3b"],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[Beta]", "j"], "\[Rule]", 
    RowBox[{
     SubscriptBox["\[Beta]", "j"], "+", 
     RowBox[{"v", " ", "\[Epsilon]"}]}]}], TraditionalForm]],ExpressionUUID->
  "582de868-448d-45c5-a150-7a9ab2511cd5"],
 " is used, where ",
 StyleBox["u",
  FontSlant->"Italic"],
 " and ",
 StyleBox["v",
  FontSlant->"Italic"],
 " are arbitrary parameters:"
}], "Text",
 CellChangeTimes->{{3.781787916761024*^9, 3.781787968001458*^9}, {
  3.7945504282600603`*^9, 3.794550428721702*^9}, {3.797192464875207*^9, 
  3.7971924777962255`*^9}, {3.797192596778393*^9, 3.7971926333714447`*^9}, {
  3.797936364695725*^9, 
  3.79793639932839*^9}},ExpressionUUID->"a83b1238-8775-4355-8bb4-\
04977d9a2f2b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"KEvaluate", "[", 
   RowBox[{
    RowBox[{"i", "[", 
     RowBox[{"1", ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", "1"}], "}"}]}], "]"}], "[", "p", "]"}], "]"}], "//", 
  "FullSimplify"}]], "Input",
 CellChangeTimes->{{3.7817122307174764`*^9, 3.781712276540303*^9}, {
  3.781712397581875*^9, 3.7817124300045757`*^9}, {3.781712501844595*^9, 
  3.7817125021716137`*^9}, {3.7817125683566723`*^9, 3.781712568443677*^9}, {
  3.781787972008787*^9, 3.781787972129777*^9}, {3.7982484972367287`*^9, 
  3.798248500355671*^9}, {3.798248744844281*^9, 3.798248772267973*^9}, {
  3.798248841861209*^9, 
  3.798248843470187*^9}},ExpressionUUID->"254452d4-34e5-47f6-90cc-\
88c9b9e0d5b7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   FractionBox["1", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"u", "-", 
       RowBox[{"2", " ", "v"}]}], ")"}], " ", "\[Epsilon]"}]], "+", 
   RowBox[{"(", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"2", " ", "v"}], "+", 
       RowBox[{"u", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "-", 
          RowBox[{"2", " ", "EulerGamma"}], "+", 
          RowBox[{"Log", "[", "4", "]"}]}], ")"}]}]}], 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{"u", "-", 
         RowBox[{"2", " ", "v"}]}], ")"}]}]], "-", 
     RowBox[{"Log", "[", "p", "]"}]}], ")"}], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "\[Epsilon]", "]"}], "1"],
    SeriesData[TripleK`\[Epsilon], 0, {}, -1, 1, 1],
    Editable->False]}],
  SeriesData[
  TripleK`\[Epsilon], 
   0, {(TripleK`u - 2 TripleK`v)^(-1), 
    Rational[1, 2] (TripleK`u - 2 TripleK`v)^(-1) (2 TripleK`v + 
      TripleK`u (-1 - 2 EulerGamma + Log[4])) - Log[TripleK`p]}, -1, 1, 1],
  Editable->False]], "Output",
 CellChangeTimes->{{3.7982487675320473`*^9, 3.798248772566942*^9}, 
   3.798248843860182*^9, 3.7986857545882864`*^9, 3.798685804372103*^9, 
   3.799037620899094*^9},ExpressionUUID->"790fe2bd-73bf-46df-ad3c-\
0a3c5c91009a"]
}, Open  ]],

Cell[TextData[{
 "The default regularization scheme can be adjusted by the option ",
 StyleBox["uParameter",
  FontSlant->"Italic"],
 " and ",
 StyleBox["vParameters",
  FontSlant->"Italic"],
 ". Note, however, that some combinations of the regulating parameters may \
still yield a divergent integral. If the regulator \[Epsilon] is already \
present in the expression, the default parameters are ignored:"
}], "Text",
 CellChangeTimes->{{3.7971926589624805`*^9, 3.797192710607553*^9}, {
  3.7971928200187073`*^9, 3.7971928218147097`*^9}, {3.797192858250761*^9, 
  3.797192895690814*^9}, {3.797936407064107*^9, 
  3.797936407743917*^9}},ExpressionUUID->"20882784-813f-4493-b7b7-\
780e283703af"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"KEvaluate", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"i", "[", 
       RowBox[{"1", ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1"}], "}"}]}], "]"}], "[", "p", "]"}], ",", " ", 
     RowBox[{"uParameter", "\[Rule]", "1"}], ",", 
     RowBox[{"vParameters", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", "0"}], "}"}]}]}], "]"}], "//", 
   "FullSimplify"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"This", " ", 
    RowBox[{"diverges", ":"}]}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"KEvaluate", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"i", "[", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}]}], "]"}], "[", "p", "]"}], ",", " ", 
    RowBox[{"uParameter", "\[Rule]", 
     RowBox[{"2", "v"}]}], ",", 
    RowBox[{"vParameters", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"v", ",", "v", ",", "v"}], "}"}]}]}], "]"}], "//", 
  "FullSimplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"KEvaluate", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"i", "[", 
      RowBox[{
       RowBox[{"1", "+", "\[Epsilon]"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}]}], "]"}], "[", "p", "]"}], ",", " ", 
    RowBox[{"uParameter", "\[Rule]", 
     RowBox[{"2", "v"}]}], ",", 
    RowBox[{"vParameters", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"v", ",", "v", ",", "v"}], "}"}]}]}], "]"}], "//", 
  "FullSimplify"}]}], "Input",
 CellChangeTimes->{{3.7971927178735633`*^9, 3.79719273003658*^9}, {
  3.797192780907652*^9, 3.7971928551007566`*^9}, {3.7971928912358074`*^9, 
  3.797192892395809*^9}, {3.797936420906179*^9, 3.797936431704372*^9}, {
  3.7982488011889477`*^9, 
  3.79824883808436*^9}},ExpressionUUID->"dd471db2-0423-41c7-aa78-\
1288ad5ecb43"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   FractionBox["1", "\[Epsilon]"], "+", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["1", "2"]}], "-", "EulerGamma", "+", 
     RowBox[{"Log", "[", "2", "]"}], "-", 
     RowBox[{"Log", "[", "p", "]"}]}], ")"}], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "\[Epsilon]", "]"}], "1"],
    SeriesData[TripleK`\[Epsilon], 0, {}, -1, 1, 1],
    Editable->False]}],
  SeriesData[
  TripleK`\[Epsilon], 0, {
   1, Rational[-1, 2] - EulerGamma + Log[2] - Log[TripleK`p]}, -1, 1, 1],
  Editable->False]], "Output",
 CellChangeTimes->{
  3.7971927305115814`*^9, {3.7971927713126383`*^9, 3.7971927958496733`*^9}, {
   3.7971928375407314`*^9, 3.797192855775758*^9}, 3.797192897260816*^9, 
   3.797442460495244*^9, {3.797936416248568*^9, 3.797936432997788*^9}, {
   3.798248834157755*^9, 3.798248847422792*^9}, 3.7986857546382885`*^9, 
   3.7986858043981047`*^9, 
   3.799037620926812*^9},ExpressionUUID->"8c8a31f8-f9b3-4107-88e8-\
d2feace9ce68"],

Cell[BoxData["ComplexInfinity"], "Output",
 CellChangeTimes->{
  3.7971927305115814`*^9, {3.7971927713126383`*^9, 3.7971927958496733`*^9}, {
   3.7971928375407314`*^9, 3.797192855775758*^9}, 3.797192897260816*^9, 
   3.797442460495244*^9, {3.797936416248568*^9, 3.797936432997788*^9}, {
   3.798248834157755*^9, 3.798248847422792*^9}, 3.7986857546382885`*^9, 
   3.7986858043981047`*^9, 
   3.799037620928022*^9},ExpressionUUID->"bb4d27e1-608d-47c8-a9e4-\
95e317931d2a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   FractionBox["1", "\[Epsilon]"], "+", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["1", "2"]}], "-", "EulerGamma", "+", 
     RowBox[{"Log", "[", "2", "]"}], "-", 
     RowBox[{"Log", "[", "p", "]"}]}], ")"}], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "\[Epsilon]", "]"}], "1"],
    SeriesData[TripleK`\[Epsilon], 0, {}, -1, 1, 1],
    Editable->False]}],
  SeriesData[
  TripleK`\[Epsilon], 0, {
   1, Rational[-1, 2] - EulerGamma + Log[2] - Log[TripleK`p]}, -1, 1, 1],
  Editable->False]], "Output",
 CellChangeTimes->{
  3.7971927305115814`*^9, {3.7971927713126383`*^9, 3.7971927958496733`*^9}, {
   3.7971928375407314`*^9, 3.797192855775758*^9}, 3.797192897260816*^9, 
   3.797442460495244*^9, {3.797936416248568*^9, 3.797936432997788*^9}, {
   3.798248834157755*^9, 3.798248847422792*^9}, 3.7986857546382885`*^9, 
   3.7986858043981047`*^9, 
   3.799037620932006*^9},ExpressionUUID->"15cabe2d-8bf8-4bae-9643-\
ee87fc40785e"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Calculating divergences", "Subsection",
 CellChangeTimes->{{3.781787699192595*^9, 3.781787704209251*^9}, {
  3.797192454673193*^9, 3.7971924601292005`*^9}, {3.797192927023858*^9, 
  3.7971929292538614`*^9}, {3.7971929712309203`*^9, 3.7971930106569757`*^9}, {
  3.797193302796399*^9, 
  3.7971933057974033`*^9}},ExpressionUUID->"2ce07684-bb5a-4f02-b428-\
2cea82fec864"],

Cell[TextData[{
 "One can use ",
 StyleBox["IsDivergent",
  FontSlant->"Italic"],
 " to check if a multiple-K integral is divergent:"
}], "Text",
 CellChangeTimes->{{3.797193015156982*^9, 3.797193037726014*^9}, 
   3.797193086333082*^9, {3.7979364487513733`*^9, 
   3.797936449127782*^9}},ExpressionUUID->"bac7b8f5-4470-4d34-865b-\
12bfbe083725"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"IsDivergent", "[", 
  RowBox[{"i", "[", 
   RowBox[{
    RowBox[{"1", "/", "2"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"1", "/", "2"}], ",", 
      RowBox[{"1", "/", "2"}], ",", 
      RowBox[{"1", "/", "2"}]}], "}"}]}], "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"IsDivergent", "[", 
  RowBox[{"i", "[", 
   RowBox[{"1", ",", 
    RowBox[{"{", 
     RowBox[{"1", ",", "1"}], "}"}]}], "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"IsDivergent", "[", 
  RowBox[{"i", "[", 
   RowBox[{"1", ",", 
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "]"}], "]"}]}], "Input",
 CellChangeTimes->{{3.797193044397023*^9, 
  3.7971930697100587`*^9}},ExpressionUUID->"0ae17e62-314e-4dc0-85d5-\
7b356f04df97"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{{3.7971930516320333`*^9, 3.797193070000059*^9}, 
   3.797442472667261*^9, 3.797936441160471*^9, 3.798248854833543*^9, 
   3.7986857546612887`*^9, 3.7986858044411073`*^9, 
   3.7990376209457617`*^9},ExpressionUUID->"65851794-8ab5-4d4e-94a3-\
cc24ada058e0"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{{3.7971930516320333`*^9, 3.797193070000059*^9}, 
   3.797442472667261*^9, 3.797936441160471*^9, 3.798248854833543*^9, 
   3.7986857546612887`*^9, 3.7986858044411073`*^9, 
   3.7990376209467363`*^9},ExpressionUUID->"710f4ce1-7d80-47c8-b5e8-\
55d515450024"],

Cell[BoxData["False"], "Output",
 CellChangeTimes->{{3.7971930516320333`*^9, 3.797193070000059*^9}, 
   3.797442472667261*^9, 3.797936441160471*^9, 3.798248854833543*^9, 
   3.7986857546612887`*^9, 3.7986858044411073`*^9, 
   3.7990376209477253`*^9},ExpressionUUID->"92274afe-c524-406f-af2c-\
85cb3c4419d1"]
}, Open  ]],

Cell[TextData[{
 "The parameters of the triple-",
 StyleBox["K",
  FontSlant->"Italic"],
 " integral can be symbolic as well.",
 StyleBox[" IsDivergent",
  FontSlant->"Italic"],
 " returns then a set of conditions for the integral to be divergent. Option ",
 StyleBox["Assumptions",
  FontSlant->"Italic"],
 " can be used to add additional conditions:"
}], "Text",
 CellChangeTimes->{{3.797193096093096*^9, 3.797193138373167*^9}, {
  3.797193178783224*^9, 3.7971932469893203`*^9}, {3.797936452175804*^9, 
  3.797936452603304*^9}},ExpressionUUID->"30d753eb-c45a-4ae6-98a2-\
d0a1a2b61b30"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"IsDivergent", "[", 
  RowBox[{"i", "[", 
   RowBox[{"n", ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"n", "+", "1"}], ",", 
      RowBox[{"n", "+", "1"}], ",", 
      RowBox[{"n", "+", "1"}]}], "}"}]}], "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"IsDivergent", "[", 
  RowBox[{"i", "[", 
   RowBox[{
    RowBox[{"n", "+", "1"}], ",", 
    RowBox[{"{", 
     RowBox[{"n", ",", "n", ",", "n"}], "}"}]}], "]"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"IsDivergent", "[", 
  RowBox[{
   RowBox[{"i", "[", 
    RowBox[{
     RowBox[{"n", "+", "1"}], ",", 
     RowBox[{"{", 
      RowBox[{"n", ",", "n", ",", "n"}], "}"}]}], "]"}], ",", " ", 
   RowBox[{"Assumptions", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"n", "\[Element]", "Integers"}], ",", 
      RowBox[{"n", "\[GreaterEqual]", "1"}]}], "}"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.7971931513051853`*^9, 3.7971931668972073`*^9}, {
  3.7971932118632708`*^9, 3.7971932214392843`*^9}, {3.7971932548363314`*^9, 
  3.797193285694375*^9}},ExpressionUUID->"638d66c2-1493-480b-9722-\
441850c76f6a"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{{3.797193157305194*^9, 3.7971931672072077`*^9}, 
   3.797193215543276*^9, 3.7971932862643757`*^9, 3.7971943452218685`*^9, 
   3.797442476658267*^9, 3.797936453762128*^9, 3.798248876156975*^9, 
   3.7986857546762896`*^9, 3.798685804454108*^9, 
   3.799037620964365*^9},ExpressionUUID->"5c72eaee-cf49-4e60-9fe7-\
d40c188fa53c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{"n", "\[Element]", 
     TemplateBox[{},
      "Integers"]}], "&&", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"n", "\[LessEqual]", 
       RowBox[{"-", "1"}]}], "||", 
      RowBox[{"n", "\[GreaterEqual]", "1"}]}], ")"}]}], ")"}], "||", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"2", " ", "n"}], "\[Element]", 
     TemplateBox[{},
      "Integers"]}], "&&", 
    RowBox[{
     RowBox[{"1", "+", 
      RowBox[{"2", " ", "n"}]}], "\[LessEqual]", "0"}]}], ")"}]}]], "Output",
 CellChangeTimes->{{3.797193157305194*^9, 3.7971931672072077`*^9}, 
   3.797193215543276*^9, 3.7971932862643757`*^9, 3.7971943452218685`*^9, 
   3.797442476658267*^9, 3.797936453762128*^9, 3.798248876156975*^9, 
   3.7986857546762896`*^9, 3.798685804454108*^9, 
   3.7990376211309023`*^9},ExpressionUUID->"6ee4200d-5961-41da-8852-\
e75c0f72fe7a"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{{3.797193157305194*^9, 3.7971931672072077`*^9}, 
   3.797193215543276*^9, 3.7971932862643757`*^9, 3.7971943452218685`*^9, 
   3.797442476658267*^9, 3.797936453762128*^9, 3.798248876156975*^9, 
   3.7986857546762896`*^9, 3.798685804454108*^9, 
   3.799037621132152*^9},ExpressionUUID->"b2b3c2a7-eab6-4b71-bf51-\
2fd305f3311e"]
}, Open  ]],

Cell[TextData[{
 "Divergences of double- and triple-",
 StyleBox["K",
  FontSlant->"Italic"],
 " integrals can be evaluated directly without the evaluation of the entire \
integral. See section 2.5.1 of [",
 ButtonBox["1511.02357",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://arxiv.org/pdf/1511.02357.pdf"], None},
  ButtonNote->"https://arxiv.org/pdf/1511.02357.pdf"],
 "] for details."
}], "Text",
 CellChangeTimes->{{3.79719343125058*^9, 3.7971935586127596`*^9}, {
   3.7971937752450647`*^9, 3.7971937804510717`*^9}, 3.797936458504402*^9, {
   3.798248888732459*^9, 
   3.798248889004491*^9}},ExpressionUUID->"5afdcbd9-626d-48dd-83b5-\
3632a7a4b713"],

Cell[TextData[{
 "To evaluate divergences of a given expression up to and including given \
order in \[Epsilon] use ",
 StyleBox["KDivergence",
  FontSlant->"Italic"],
 ":"
}], "Text",
 CellChangeTimes->{
  3.7982488919114647`*^9},ExpressionUUID->"b001977a-38d3-4492-8c29-\
99712bdb041b"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"KDivergence", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"i", "[", 
     RowBox[{
      RowBox[{"1", "+", "\[Epsilon]"}], ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", "1"}], "}"}]}], "]"}], "[", "p", "]"}], ",", 
   RowBox[{"ExpansionOrder", "\[Rule]", 
    RowBox[{"-", "1"}]}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"KDivergence", "[", 
  RowBox[{
   RowBox[{"i", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"1", "/", "2"}], "+", "\[Epsilon]"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"1", "/", "2"}], ",", 
       RowBox[{"1", "/", "2"}], ",", 
       RowBox[{"1", "/", "2"}]}], "}"}]}], "]"}], ",", 
   RowBox[{"ExpansionOrder", "\[Rule]", 
    RowBox[{"-", "1"}]}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"KDivergence", "[", 
   RowBox[{
    RowBox[{"i", "[", 
     RowBox[{"0", ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", "1", ",", "1"}], "}"}]}], "]"}], ",", 
    RowBox[{"ExpansionOrder", "\[Rule]", 
     RowBox[{"-", "1"}]}]}], "]"}], "//", "Simplify"}]}], "Input",
 CellChangeTimes->{{3.797193565328769*^9, 3.7971936166928415`*^9}, {
  3.798248901851735*^9, 
  3.798248910484271*^9}},ExpressionUUID->"6cd441ec-6249-4a0e-afba-\
d96370afb0c3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   FractionBox["1", "\[Epsilon]"], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "\[Epsilon]", "]"}], "0"],
    SeriesData[TripleK`\[Epsilon], 0, {}, -1, 0, 1],
    Editable->False]}],
  SeriesData[TripleK`\[Epsilon], 0, {1}, -1, 0, 1],
  Editable->False]], "Output",
 CellChangeTimes->{{3.797193580871791*^9, 3.7971936171878424`*^9}, 
   3.797194346887871*^9, 3.797442481304273*^9, 3.7979364621808243`*^9, {
   3.798248907656397*^9, 3.798248910738658*^9}, 3.7986857548823013`*^9, 
   3.798685804643119*^9, 
   3.799037621203949*^9},ExpressionUUID->"2c6cf54a-8eb7-4f74-931a-\
6f247af2bcca"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   FractionBox[
    SuperscriptBox["\[Pi]", 
     RowBox[{"3", "/", "2"}]], 
    RowBox[{"2", " ", 
     SqrtBox["2"], " ", "\[Epsilon]"}]], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "\[Epsilon]", "]"}], "0"],
    SeriesData[TripleK`\[Epsilon], 0, {}, -1, 0, 1],
    Editable->False]}],
  SeriesData[
  TripleK`\[Epsilon], 0, {
   Rational[1, 2] 2^Rational[-1, 2] Pi^Rational[3, 2]}, -1, 0, 1],
  Editable->False]], "Output",
 CellChangeTimes->{{3.797193580871791*^9, 3.7971936171878424`*^9}, 
   3.797194346887871*^9, 3.797442481304273*^9, 3.7979364621808243`*^9, {
   3.798248907656397*^9, 3.798248910738658*^9}, 3.7986857548823013`*^9, 
   3.798685804643119*^9, 
   3.799037621205304*^9},ExpressionUUID->"2d48966d-638d-4f0f-9b6e-\
64872f3c447e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SubsuperscriptBox["p", "1", "2"], "+", 
      SubsuperscriptBox["p", "2", "2"], "+", 
      SubsuperscriptBox["p", "3", "2"]}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SuperscriptBox["u", "2"]}], "-", 
        RowBox[{"8", " ", "u", " ", "v"}], "+", 
        RowBox[{"6", " ", 
         SuperscriptBox["v", "2"]}]}], ")"}], " ", 
      SuperscriptBox["\[Epsilon]", "2"]}]]}], "-", 
   RowBox[{
    FractionBox["1", 
     RowBox[{"4", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"u", "-", 
          RowBox[{"3", " ", "v"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"u", "-", "v"}], ")"}]}], ")"}], " ", "\[Epsilon]"}]], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"u", " ", 
       SubsuperscriptBox["p", "1", "2"]}], "-", 
      RowBox[{"2", " ", "EulerGamma", " ", "u", " ", 
       SubsuperscriptBox["p", "1", "2"]}], "-", 
      RowBox[{"3", " ", "v", " ", 
       SubsuperscriptBox["p", "1", "2"]}], "+", 
      RowBox[{"u", " ", 
       RowBox[{"Log", "[", "4", "]"}], " ", 
       SubsuperscriptBox["p", "1", "2"]}], "-", 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{"u", "-", 
         RowBox[{"3", " ", "v"}]}], ")"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "1"], "]"}], " ", 
       SubsuperscriptBox["p", "1", "2"]}], "+", 
      RowBox[{"u", " ", 
       SubsuperscriptBox["p", "2", "2"]}], "-", 
      RowBox[{"2", " ", "EulerGamma", " ", "u", " ", 
       SubsuperscriptBox["p", "2", "2"]}], "-", 
      RowBox[{"3", " ", "v", " ", 
       SubsuperscriptBox["p", "2", "2"]}], "+", 
      RowBox[{"u", " ", 
       RowBox[{"Log", "[", "4", "]"}], " ", 
       SubsuperscriptBox["p", "2", "2"]}], "-", 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{"u", "-", 
         RowBox[{"3", " ", "v"}]}], ")"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "2"], "]"}], " ", 
       SubsuperscriptBox["p", "2", "2"]}], "+", 
      RowBox[{"u", " ", 
       SubsuperscriptBox["p", "3", "2"]}], "-", 
      RowBox[{"2", " ", "EulerGamma", " ", "u", " ", 
       SubsuperscriptBox["p", "3", "2"]}], "-", 
      RowBox[{"3", " ", "v", " ", 
       SubsuperscriptBox["p", "3", "2"]}], "+", 
      RowBox[{"u", " ", 
       RowBox[{"Log", "[", "4", "]"}], " ", 
       SubsuperscriptBox["p", "3", "2"]}], "-", 
      RowBox[{"2", " ", "u", " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}], " ", 
       SubsuperscriptBox["p", "3", "2"]}], "+", 
      RowBox[{"6", " ", "v", " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}], " ", 
       SubsuperscriptBox["p", "3", "2"]}]}], ")"}]}], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "\[Epsilon]", "]"}], "0"],
    SeriesData[TripleK`\[Epsilon], 0, {}, -2, 0, 1],
    Editable->False]}],
  SeriesData[
  TripleK`\[Epsilon], 
   0, {-(2 TripleK`u^2 - 8 TripleK`u TripleK`v + 6 TripleK`v^2)^(-1) (
     TripleK`p[1]^2 + TripleK`p[2]^2 + TripleK`p[3]^2), 
    Rational[-1, 4] (TripleK`u - 3 TripleK`v)^(-1) (TripleK`u - 
      TripleK`v)^(-1) (TripleK`u TripleK`p[1]^2 - 2 EulerGamma TripleK`u 
     TripleK`p[1]^2 - 3 TripleK`v TripleK`p[1]^2 + 
     TripleK`u Log[4] TripleK`p[1]^2 - 2 (TripleK`u - 3 TripleK`v) Log[
       TripleK`p[1]] TripleK`p[1]^2 + TripleK`u TripleK`p[2]^2 - 2 EulerGamma 
     TripleK`u TripleK`p[2]^2 - 3 TripleK`v TripleK`p[2]^2 + 
     TripleK`u Log[4] TripleK`p[2]^2 - 2 (TripleK`u - 3 TripleK`v) Log[
       TripleK`p[2]] TripleK`p[2]^2 + TripleK`u TripleK`p[3]^2 - 2 EulerGamma 
     TripleK`u TripleK`p[3]^2 - 3 TripleK`v TripleK`p[3]^2 + 
     TripleK`u Log[4] TripleK`p[3]^2 - 2 TripleK`u Log[
       TripleK`p[3]] TripleK`p[3]^2 + 6 TripleK`v Log[
        TripleK`p[3]] TripleK`p[3]^2)}, -2, 0, 1],
  Editable->False]], "Output",
 CellChangeTimes->{{3.797193580871791*^9, 3.7971936171878424`*^9}, 
   3.797194346887871*^9, 3.797442481304273*^9, 3.7979364621808243`*^9, {
   3.798248907656397*^9, 3.798248910738658*^9}, 3.7986857548823013`*^9, 
   3.798685804643119*^9, 
   3.799037621646346*^9},ExpressionUUID->"d74e5f9b-0d66-470c-8b42-\
59e2a27e5459"]
}, Open  ]],

Cell[TextData[{
 "As in the case of ",
 StyleBox["KEvaluate",
  FontSlant->"Italic"],
 ", if no regulator is present the default parameterization is used. This can \
be changed by options ",
 StyleBox["uParameter",
  FontSlant->"Italic"],
 " and ",
 StyleBox["vParameters",
  FontSlant->"Italic"],
 "."
}], "Text",
 CellChangeTimes->{{3.7971936243538523`*^9, 
  3.797193668268914*^9}},ExpressionUUID->"c3bc55fc-c729-4983-9aaa-\
f6e666f1ed8d"],

Cell[TextData[{
 "In some cases ",
 StyleBox["KDivergence",
  FontSlant->"Italic"],
 " can also evaluate divergences with non-numerical parameters. Make sure the \
assumptions are taken into account."
}], "Text",
 CellChangeTimes->{{3.7971937920430884`*^9, 3.7971938654671917`*^9}, {
  3.797936473392755*^9, 
  3.7979364741199293`*^9}},ExpressionUUID->"723b8801-821c-48a5-8274-\
4facad3a5229"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"KDivergence", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"i", "[", 
     RowBox[{
      RowBox[{"1", "+", 
       RowBox[{"2", "n"}], "+", "\[Epsilon]"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"1", "+", 
         RowBox[{"3", "n"}]}], ",", 
        RowBox[{"1", "+", 
         RowBox[{"3", "n"}]}]}], "}"}]}], "]"}], "[", "p", "]"}], ",", " ", 
   RowBox[{"ExpansionOrder", "\[Rule]", 
    RowBox[{"-", "1"}]}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"KDivergence", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"i", "[", 
     RowBox[{
      RowBox[{"1", "+", 
       RowBox[{"2", "n"}], "+", "\[Epsilon]"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"1", "+", 
         RowBox[{"3", "n"}]}], ",", 
        RowBox[{"1", "+", 
         RowBox[{"3", "n"}]}]}], "}"}]}], "]"}], "[", "p", "]"}], ",", 
   RowBox[{"Assumptions", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"n", "\[GreaterEqual]", "0"}], ",", 
      RowBox[{"n", "\[Element]", "Integers"}]}], "}"}]}], ",", " ", 
   RowBox[{"ExpansionOrder", "\[Rule]", 
    RowBox[{"-", "1"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.798249212950382*^9, 3.7982492294121017`*^9}, {
  3.7982493191323643`*^9, 3.798249338996669*^9}, {3.7982506070229063`*^9, 
  3.798250705897128*^9}},ExpressionUUID->"16204cf1-4cb7-4e57-a33d-\
ad20d05c4f89"],

Cell[BoxData[
 InterpretationBox[
  SuperscriptBox[
   RowBox[{"O", "[", "\[Epsilon]", "]"}], "0"],
  SeriesData[TripleK`\[Epsilon], 0, {}, 0, 0, 1],
  Editable->False]], "Output",
 CellChangeTimes->{{3.798249326269698*^9, 3.798249339798521*^9}, 
   3.7982497057127542`*^9, 3.798249737622464*^9, {3.798250551302355*^9, 
   3.798250565071823*^9}, {3.798250607706571*^9, 3.798250645156434*^9}, {
   3.798250677298546*^9, 3.798250706589621*^9}, 3.798685755475335*^9, 
   3.7986858048741302`*^9, 
   3.799037621909053*^9},ExpressionUUID->"c1a6cff4-79e6-4a51-a346-\
53ebaa030f56"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   FractionBox[
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"-", 
        FractionBox["1", "2"]}], ")"}], 
      RowBox[{
       RowBox[{"-", "2"}], " ", "n"}]], " ", 
     SuperscriptBox["p", 
      RowBox[{"4", " ", "n"}]], " ", 
     SuperscriptBox[
      RowBox[{"Gamma", "[", 
       RowBox[{"1", "+", "n"}], "]"}], "2"], " ", 
     RowBox[{"Gamma", "[", 
      RowBox[{"2", "+", 
       RowBox[{"4", " ", "n"}]}], "]"}]}], 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2", " ", "n"}], ")"}], "!"}], " ", 
     RowBox[{"Gamma", "[", 
      RowBox[{"2", "+", 
       RowBox[{"2", " ", "n"}]}], "]"}], " ", "\[Epsilon]"}]], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "\[Epsilon]", "]"}], "0"],
    SeriesData[TripleK`\[Epsilon], 0, {}, -1, 0, 1],
    Editable->False]}],
  SeriesData[
  TripleK`\[Epsilon], 0, {
   Rational[-1, 2]^((-2) $CellContext`n) TripleK`p^(4 $CellContext`n) 
    Factorial[2 $CellContext`n]^(-1) Gamma[1 + $CellContext`n]^2 
    Gamma[2 + 2 $CellContext`n]^(-1) Gamma[2 + 4 $CellContext`n]}, -1, 0, 1],
  Editable->False]], "Output",
 CellChangeTimes->{{3.798249326269698*^9, 3.798249339798521*^9}, 
   3.7982497057127542`*^9, 3.798249737622464*^9, {3.798250551302355*^9, 
   3.798250565071823*^9}, {3.798250607706571*^9, 3.798250645156434*^9}, {
   3.798250677298546*^9, 3.798250706589621*^9}, 3.798685755475335*^9, 
   3.7986858048741302`*^9, 
   3.799037622036806*^9},ExpressionUUID->"f53338bc-2162-49c7-98f4-\
353f3791b85e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"KDivergence", "[", 
  RowBox[{
   RowBox[{"i", "[", 
    RowBox[{
     RowBox[{"n", "+", "1"}], ",", 
     RowBox[{"{", 
      RowBox[{"n", ",", "n", ",", "n"}], "}"}]}], "]"}], ",", 
   RowBox[{"ExpansionOrder", "\[Rule]", 
    RowBox[{"-", "1"}]}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"KDivergence", "[", 
  RowBox[{
   RowBox[{"i", "[", 
    RowBox[{
     RowBox[{"n", "+", "1"}], ",", 
     RowBox[{"{", 
      RowBox[{"n", ",", "n", ",", "n"}], "}"}]}], "]"}], ",", 
   RowBox[{"ExpansionOrder", "\[Rule]", 
    RowBox[{"-", "1"}]}], ",", " ", 
   RowBox[{"Assumptions", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"n", "\[Element]", "Integers"}], ",", 
      RowBox[{"n", "\[GreaterEqual]", "1"}]}], "}"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.797193836253151*^9, 
  3.7971938727232018`*^9}},ExpressionUUID->"7910339e-9638-453f-85ea-\
37d8e6bf457e"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.797193852980174*^9, 3.7971938732132025`*^9}, 
   3.797193992498371*^9, 3.797194351562877*^9, 3.797194406676955*^9, 
   3.7971944633700347`*^9, {3.7971944951100826`*^9, 3.797194506066098*^9}, 
   3.797442488155283*^9, 3.797936475472913*^9, 3.7982507142896833`*^9, 
   3.798685755678347*^9, 3.798685804983136*^9, 
   3.79903762212689*^9},ExpressionUUID->"090ba6bf-4251-4964-9e3c-\
0ee0a0427e01"],

Cell[BoxData[
 RowBox[{
  TagBox["Sum",
   HoldForm], "[", 
  RowBox[{
   InterpretationBox[
    RowBox[{
     FractionBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"-", "2"}], ")"}], 
        RowBox[{
         RowBox[{"-", "1"}], "+", "n"}]], " ", 
       RowBox[{"Gamma", "[", 
        RowBox[{"n", "-", 
         SubscriptBox["K", "1"]}], "]"}], " ", 
       RowBox[{"Gamma", "[", 
        RowBox[{"n", "-", 
         SubscriptBox["K", "2"]}], "]"}], " ", 
       RowBox[{"Gamma", "[", 
        RowBox[{"1", "+", 
         SubscriptBox["K", "1"], "+", 
         SubscriptBox["K", "2"]}], "]"}], " ", 
       SubsuperscriptBox["p", "1", 
        RowBox[{"2", " ", 
         SubscriptBox["K", "2"]}]], " ", 
       SubsuperscriptBox["p", "2", 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "n", "-", 
           SubscriptBox["K", "1"], "-", 
           SubscriptBox["K", "2"]}], ")"}]}]], " ", 
       SubsuperscriptBox["p", "3", 
        RowBox[{"2", " ", 
         SubscriptBox["K", "1"]}]]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"u", "-", 
         RowBox[{"3", " ", "v"}]}], ")"}], " ", 
       RowBox[{
        SubscriptBox["K", "1"], "!"}], " ", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "n", "-", 
          SubscriptBox["K", "1"], "-", 
          SubscriptBox["K", "2"]}], ")"}], "!"}], " ", 
       RowBox[{
        SubscriptBox["K", "2"], "!"}], " ", "\[Epsilon]"}]], "+", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", "\[Epsilon]", "]"}], "0"],
      SeriesData[TripleK`\[Epsilon], 0, {}, -1, 0, 1],
      Editable->False]}],
    SeriesData[
    TripleK`\[Epsilon], 
     0, {(-2)^(-1 + $CellContext`n) (TripleK`u - 3 TripleK`v)^(-1) Factorial[
         Subscript[K, 1]]^(-1) 
      Factorial[-1 + $CellContext`n - Subscript[K, 1] - Subscript[K, 2]]^(-1) 
      Factorial[
         Subscript[K, 2]]^(-1) Gamma[$CellContext`n - Subscript[K, 1]] 
      Gamma[$CellContext`n - Subscript[K, 2]] 
      Gamma[1 + Subscript[K, 1] + Subscript[K, 2]] 
      TripleK`p[1]^(2 Subscript[K, 2]) 
      TripleK`p[2]^(
        2 (-1 + $CellContext`n - Subscript[K, 1] - Subscript[K, 2])) 
      TripleK`p[3]^(2 Subscript[K, 1])}, -1, 0, 1],
    Editable->False], ",", 
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["K", "1"], ",", "0", ",", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "n"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["K", "2"], ",", "0", ",", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "n", "-", 
      SubscriptBox["K", "1"]}]}], "}"}]}], "]"}]], "Output",
 CellChangeTimes->{{3.797193852980174*^9, 3.7971938732132025`*^9}, 
   3.797193992498371*^9, 3.797194351562877*^9, 3.797194406676955*^9, 
   3.7971944633700347`*^9, {3.7971944951100826`*^9, 3.797194506066098*^9}, 
   3.797442488155283*^9, 3.797936475472913*^9, 3.7982507142896833`*^9, 
   3.798685755678347*^9, 3.798685804983136*^9, 
   3.799037622239253*^9},ExpressionUUID->"8dbc25fb-64c4-41ae-9a21-\
3ce8486546c5"]
}, Open  ]],

Cell[TextData[{
 "If no expansion order is specified, the resulting expression contains all \
finite ",
 StyleBox["u",
  FontSlant->"Italic"],
 "- and ",
 StyleBox["v",
  FontSlant->"Italic"],
 "-dependent terms. This is very useful for changing the regularization \
scheme. See section 2.5.2 of [",
 ButtonBox["1511.02357",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://arxiv.org/pdf/1511.02357.pdf"], None},
  ButtonNote->"https://arxiv.org/pdf/1511.02357.pdf"],
 "] for details."
}], "Text",
 CellChangeTimes->{{3.7971936779459276`*^9, 3.797193718441985*^9}, {
  3.7971937498020287`*^9, 
  3.7971937559220376`*^9}},ExpressionUUID->"b5d0bfb4-b7ba-4a24-9946-\
05b85752a5dc"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"KDivergence", "[", 
   RowBox[{"i", "[", 
    RowBox[{
     RowBox[{"1", "/", "2"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"1", "/", "2"}], ",", 
       RowBox[{"1", "/", "2"}], ",", 
       RowBox[{"1", "/", "2"}]}], "}"}]}], "]"}], "]"}], "//", 
  "Simplify"}]], "Input",
 CellChangeTimes->{{3.797194572621192*^9, 
  3.79719459236522*^9}},ExpressionUUID->"12c5d84c-a810-4f38-a937-\
3d29286f9644"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   FractionBox[
    SuperscriptBox["\[Pi]", 
     RowBox[{"3", "/", "2"}]], 
    RowBox[{
     SqrtBox["2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", "u"}], "-", 
       RowBox[{"6", " ", "v"}]}], ")"}], " ", "\[Epsilon]"}]], "-", 
   FractionBox[
    RowBox[{"3", " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["\[Pi]", 
        RowBox[{"3", "/", "2"}]], " ", "v", " ", 
       RowBox[{"(", 
        RowBox[{"EulerGamma", "+", 
         RowBox[{"Log", "[", "2", "]"}]}], ")"}]}], ")"}]}], 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{
       SqrtBox["2"], " ", 
       RowBox[{"(", 
        RowBox[{"u", "-", 
         RowBox[{"3", " ", "v"}]}], ")"}]}], ")"}]}]], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "\[Epsilon]", "]"}], "1"],
    SeriesData[TripleK`\[Epsilon], 0, {}, -1, 1, 1],
    Editable->False]}],
  SeriesData[
  TripleK`\[Epsilon], 0, {
   2^Rational[-1, 2] Pi^Rational[3, 2]/(2 TripleK`u - 6 TripleK`v), 
    Rational[-3, 2] 2^Rational[-1, 2] 
    Pi^Rational[3, 2] (TripleK`u - 3 TripleK`v)^(-1) 
    TripleK`v (EulerGamma + Log[2])}, -1, 1, 1],
  Editable->False]], "Output",
 CellChangeTimes->{{3.797194574667195*^9, 3.79719459274522*^9}, 
   3.79744249316829*^9, 3.797936482879777*^9, 3.798250767333899*^9, 
   3.7986857558073545`*^9, 3.7986858050211387`*^9, 
   3.799037622294578*^9},ExpressionUUID->"bbc6f42f-4732-4965-862b-\
0759c8f71133"]
}, Open  ]],

Cell[TextData[{
 "While ",
 StyleBox["IsDivergent",
  FontSlant->"Italic"],
 " takes for argument a single multiple-",
 StyleBox["K",
  FontSlant->"Italic"],
 " integral, ",
 StyleBox["KDivergence",
  FontSlant->"Italic"],
 " can be applied to any expression."
}], "Text",
 CellChangeTimes->{{3.797194645128295*^9, 
  3.7971946852373514`*^9}},ExpressionUUID->"9bb570e0-dd63-47c8-a160-\
fc02f430a81f"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Basic manipulations", "Subsection",
 CellChangeTimes->{{3.7817879964571447`*^9, 3.7817880076653833`*^9}, {
  3.7971948331925597`*^9, 
  3.7971948360185633`*^9}},ExpressionUUID->"9d826c2a-f428-45c3-9fef-\
af437394b46e"],

Cell[TextData[{
 "Triple-K integral with integral indices are evaluated in terms of two \
functions: ",
 StyleBox["NL",
  FontSlant->"Italic"],
 " and \[Lambda] and their derivatives. ",
 StyleBox["NL",
  FontSlant->"Italic"],
 " is a core of a non-local 3-point function and \[Lambda] denotes the K\
\[ADoubleDot]llen \[Lambda]-function. If no arguments are specified, the \
standard ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["p", "1"], ",", 
    SubscriptBox["p", "2"], ",", 
    SubscriptBox["p", "3"]}], TraditionalForm]],ExpressionUUID->
  "96ab1f21-ae0d-42b2-88d1-35e2b1fe5867"],
 " momentum magnitudes are assumed."
}], "Text",
 CellChangeTimes->{{3.7971948429645734`*^9, 
  3.797194878234623*^9}},ExpressionUUID->"d72e3ecf-616b-42b4-9b46-\
1468f234eb8c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"NL", ",", 
   RowBox[{"NL", "[", 
    RowBox[{
     RowBox[{"p", "[", "1", "]"}], ",", 
     RowBox[{"p", "[", "2", "]"}], ",", 
     RowBox[{"p", "[", "3", "]"}]}], "]"}], ",", "\[Lambda]"}], 
  "}"}]], "Input",
 CellChangeTimes->{{3.7971948804156265`*^9, 
  3.7971948949066467`*^9}},ExpressionUUID->"fe45192e-4ee7-417d-b215-\
eb604a028c9a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"NL", ",", "NL", ",", "\[Lambda]"}], "}"}]], "Output",
 CellChangeTimes->{{3.7971948819306283`*^9, 3.797194896601649*^9}, 
   3.797442499298299*^9, 3.797936503391436*^9, 3.7982507769662657`*^9, 
   3.7986857558203554`*^9, 3.7986858050311394`*^9, 
   3.799037622309409*^9},ExpressionUUID->"6db4a227-5f14-4030-ad11-\
562b723fe323"]
}, Open  ]],

Cell[TextData[{
 "Use ",
 StyleBox["KFullExpand",
  FontSlant->"Italic"],
 " to expand ",
 StyleBox["NL",
  FontSlant->"Italic"],
 " and \[Lambda] in terms of ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["p", "1"], ",", 
    SubscriptBox["p", "2"], ",", 
    SubscriptBox["p", "3"]}], TraditionalForm]],ExpressionUUID->
  "a6a44c39-d7d0-4f0c-8171-a9cbab3cf7e9"],
 ". Any derivatives of ",
 StyleBox["NL",
  FontSlant->"Italic"],
 " and \[Lambda] are also expanded."
}], "Text",
 CellChangeTimes->{{3.797194918274679*^9, 3.797194967842749*^9}, {
  3.7974425274683385`*^9, 
  3.797442528078339*^9}},ExpressionUUID->"ead0ff5f-8abc-469f-81ef-\
f5ba52e0af03"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"KFullExpand", "[", "\[Lambda]", "]"}], "\[IndentingNewLine]", 
 RowBox[{"KFullExpand", "[", "NL", "]"}]}], "Input",
 CellChangeTimes->{{3.797194971137754*^9, 3.7971950253548303`*^9}, {
  3.797442530188342*^9, 3.797442532908346*^9}, {3.797936525643499*^9, 
  3.7979365352478437`*^9}},ExpressionUUID->"4e4661ac-cace-4791-b6c0-\
4a3c3a0bf0bf"],

Cell[BoxData[
 RowBox[{
  SubsuperscriptBox["p", "1", "4"], "-", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["p", "1", "2"], " ", 
   SubsuperscriptBox["p", "2", "2"]}], "+", 
  SubsuperscriptBox["p", "2", "4"], "-", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["p", "1", "2"], " ", 
   SubsuperscriptBox["p", "3", "2"]}], "-", 
  RowBox[{"2", " ", 
   SubsuperscriptBox["p", "2", "2"], " ", 
   SubsuperscriptBox["p", "3", "2"]}], "+", 
  SubsuperscriptBox["p", "3", "4"]}]], "Output",
 CellChangeTimes->{{3.7971950036527996`*^9, 3.797195025754831*^9}, 
   3.7974425025433035`*^9, 3.7974425333283463`*^9, {3.797936512473795*^9, 
   3.7979365355074*^9}, 3.7982507789184628`*^9, 3.7986857558353558`*^9, 
   3.7986858050401397`*^9, 
   3.799037622328909*^9},ExpressionUUID->"80af7246-dccb-4c59-b5ec-\
55a718727927"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   SuperscriptBox["\[Pi]", "2"], "6"], "-", 
  RowBox[{"2", " ", 
   RowBox[{"Log", "[", 
    FractionBox[
     SubscriptBox["p", "1"], 
     SubscriptBox["p", "3"]], "]"}], " ", 
   RowBox[{"Log", "[", 
    FractionBox[
     SubscriptBox["p", "2"], 
     SubscriptBox["p", "3"]], "]"}]}], "+", 
  RowBox[{
   RowBox[{"Log", "[", 
    FractionBox[
     RowBox[{
      SubsuperscriptBox["p", "1", "2"], "-", 
      SubsuperscriptBox["p", "2", "2"], "+", 
      SubsuperscriptBox["p", "3", "2"], "-", 
      SqrtBox[
       RowBox[{
        SubsuperscriptBox["p", "1", "4"], "-", 
        RowBox[{"2", " ", 
         SubsuperscriptBox["p", "1", "2"], " ", 
         SubsuperscriptBox["p", "2", "2"]}], "+", 
        SubsuperscriptBox["p", "2", "4"], "-", 
        RowBox[{"2", " ", 
         SubsuperscriptBox["p", "1", "2"], " ", 
         SubsuperscriptBox["p", "3", "2"]}], "-", 
        RowBox[{"2", " ", 
         SubsuperscriptBox["p", "2", "2"], " ", 
         SubsuperscriptBox["p", "3", "2"]}], "+", 
        SubsuperscriptBox["p", "3", "4"]}]]}], 
     RowBox[{"2", " ", 
      SubsuperscriptBox["p", "3", "2"]}]], "]"}], " ", 
   RowBox[{"Log", "[", 
    FractionBox[
     RowBox[{
      RowBox[{"-", 
       SubsuperscriptBox["p", "1", "2"]}], "+", 
      SubsuperscriptBox["p", "2", "2"], "+", 
      SubsuperscriptBox["p", "3", "2"], "-", 
      SqrtBox[
       RowBox[{
        SubsuperscriptBox["p", "1", "4"], "-", 
        RowBox[{"2", " ", 
         SubsuperscriptBox["p", "1", "2"], " ", 
         SubsuperscriptBox["p", "2", "2"]}], "+", 
        SubsuperscriptBox["p", "2", "4"], "-", 
        RowBox[{"2", " ", 
         SubsuperscriptBox["p", "1", "2"], " ", 
         SubsuperscriptBox["p", "3", "2"]}], "-", 
        RowBox[{"2", " ", 
         SubsuperscriptBox["p", "2", "2"], " ", 
         SubsuperscriptBox["p", "3", "2"]}], "+", 
        SubsuperscriptBox["p", "3", "4"]}]]}], 
     RowBox[{"2", " ", 
      SubsuperscriptBox["p", "3", "2"]}]], "]"}]}], "-", 
  RowBox[{"PolyLog", "[", 
   RowBox[{"2", ",", 
    FractionBox[
     RowBox[{
      SubsuperscriptBox["p", "1", "2"], "-", 
      SubsuperscriptBox["p", "2", "2"], "+", 
      SubsuperscriptBox["p", "3", "2"], "-", 
      SqrtBox[
       RowBox[{
        SubsuperscriptBox["p", "1", "4"], "-", 
        RowBox[{"2", " ", 
         SubsuperscriptBox["p", "1", "2"], " ", 
         SubsuperscriptBox["p", "2", "2"]}], "+", 
        SubsuperscriptBox["p", "2", "4"], "-", 
        RowBox[{"2", " ", 
         SubsuperscriptBox["p", "1", "2"], " ", 
         SubsuperscriptBox["p", "3", "2"]}], "-", 
        RowBox[{"2", " ", 
         SubsuperscriptBox["p", "2", "2"], " ", 
         SubsuperscriptBox["p", "3", "2"]}], "+", 
        SubsuperscriptBox["p", "3", "4"]}]]}], 
     RowBox[{"2", " ", 
      SubsuperscriptBox["p", "3", "2"]}]]}], "]"}], "-", 
  RowBox[{"PolyLog", "[", 
   RowBox[{"2", ",", 
    FractionBox[
     RowBox[{
      RowBox[{"-", 
       SubsuperscriptBox["p", "1", "2"]}], "+", 
      SubsuperscriptBox["p", "2", "2"], "+", 
      SubsuperscriptBox["p", "3", "2"], "-", 
      SqrtBox[
       RowBox[{
        SubsuperscriptBox["p", "1", "4"], "-", 
        RowBox[{"2", " ", 
         SubsuperscriptBox["p", "1", "2"], " ", 
         SubsuperscriptBox["p", "2", "2"]}], "+", 
        SubsuperscriptBox["p", "2", "4"], "-", 
        RowBox[{"2", " ", 
         SubsuperscriptBox["p", "1", "2"], " ", 
         SubsuperscriptBox["p", "3", "2"]}], "-", 
        RowBox[{"2", " ", 
         SubsuperscriptBox["p", "2", "2"], " ", 
         SubsuperscriptBox["p", "3", "2"]}], "+", 
        SubsuperscriptBox["p", "3", "4"]}]]}], 
     RowBox[{"2", " ", 
      SubsuperscriptBox["p", "3", "2"]}]]}], "]"}]}]], "Output",
 CellChangeTimes->{{3.7971950036527996`*^9, 3.797195025754831*^9}, 
   3.7974425025433035`*^9, 3.7974425333283463`*^9, {3.797936512473795*^9, 
   3.7979365355074*^9}, 3.7982507789184628`*^9, 3.7986857558353558`*^9, 
   3.7986858050401397`*^9, 
   3.799037622330669*^9},ExpressionUUID->"70d9fbf9-9078-4be9-bf64-\
6337a06e556d"]
}, Open  ]],

Cell[TextData[{
 "In order to resolve derivatives of ",
 StyleBox["NL",
  FontSlant->"Italic"],
 " and \[Lambda], but ",
 StyleBox["not",
  FontSlant->"Italic"],
 " to substitute explicit expressions, use ",
 StyleBox["KExpand",
  FontSlant->"Italic"],
 "."
}], "Text",
 CellChangeTimes->{{3.797195051751868*^9, 3.7971950859369164`*^9}, {
  3.7974425431333604`*^9, 
  3.797442553234374*^9}},ExpressionUUID->"e54e4bfc-3fc7-4cf2-ac7b-\
aa83d7fb2aad"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"expr", "=", 
  RowBox[{"KExpand", "[", 
   RowBox[{"D", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"\[Lambda]", "[", 
        RowBox[{
         RowBox[{"p", "[", "1", "]"}], ",", 
         RowBox[{"p", "[", "2", "]"}], ",", 
         RowBox[{"p", "[", "3", "]"}]}], "]"}], "^", 
       RowBox[{"(", 
        RowBox[{"3", "/", "2"}], ")"}]}], "*", 
      RowBox[{"NL", "[", 
       RowBox[{
        RowBox[{"p", "[", "1", "]"}], ",", 
        RowBox[{"p", "[", "2", "]"}], ",", 
        RowBox[{"p", "[", "3", "]"}]}], "]"}]}], ",", 
     RowBox[{"p", "[", "1", "]"}]}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.7971950965479307`*^9, 3.797195118226961*^9}, {
  3.7974425576253805`*^9, 3.7974425735224032`*^9}, {3.7979365512801867`*^9, 
  3.797936551592286*^9}, {3.797936887930637*^9, 
  3.7979369169049397`*^9}},ExpressionUUID->"61eeec09-8477-4484-968f-\
70f09bf6f3bb"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["3", "2"], " ", "NL", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"4", " ", 
      SubsuperscriptBox["p", "1", "3"]}], "-", 
     RowBox[{"4", " ", 
      SubscriptBox["p", "1"], " ", 
      SubsuperscriptBox["p", "2", "2"]}], "-", 
     RowBox[{"4", " ", 
      SubscriptBox["p", "1"], " ", 
      SubsuperscriptBox["p", "3", "2"]}]}], ")"}], " ", 
   SqrtBox["\[Lambda]"]}], "+", 
  FractionBox[
   RowBox[{"2", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"Log", "[", 
        SubsuperscriptBox["p", "1", "2"], "]"}], " ", 
       SubsuperscriptBox["p", "1", "2"]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{"Log", "[", 
        SubsuperscriptBox["p", "3", "2"], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SubsuperscriptBox["p", "1", "2"]}], "+", 
         SubsuperscriptBox["p", "2", "2"], "-", 
         SubsuperscriptBox["p", "3", "2"]}], ")"}]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{"Log", "[", 
        SubsuperscriptBox["p", "2", "2"], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SubsuperscriptBox["p", "1", "2"]}], "-", 
         SubsuperscriptBox["p", "2", "2"], "+", 
         SubsuperscriptBox["p", "3", "2"]}], ")"}]}]}], ")"}], " ", 
    "\[Lambda]"}], 
   SubscriptBox["p", "1"]]}]], "Output",
 CellChangeTimes->{{3.7971951024689393`*^9, 3.7971951184569616`*^9}, 
   3.797442574997405*^9, 3.797936552180641*^9, {3.7979368899075813`*^9, 
   3.797936917289515*^9}, 3.798250785784479*^9, 3.7986857558613577`*^9, 
   3.798685805057141*^9, 
   3.79903762234579*^9},ExpressionUUID->"4dcf412f-292a-436b-b53b-\
80a254488578"]
}, Open  ]],

Cell[TextData[{
 StyleBox["KExpand",
  FontSlant->"Italic"],
 " applies 4 levels of expansions adjustable by option ",
 StyleBox["Level",
  FontSlant->"Italic"],
 ". "
}], "Text",
 CellChangeTimes->{
  3.798250807089087*^9},ExpressionUUID->"6798e88a-3819-4f3b-bcc2-\
3b99dfdc9d8a"],

Cell[CellGroupData[{

Cell[TextData[{
 "Level 1 (identifiers ",
 StyleBox["D",
  FontSlant->"Italic"],
 " or ",
 StyleBox["Diff",
  FontSlant->"Italic"],
 " can be used as well) expands derivatives of ",
 StyleBox["NL",
  FontSlant->"Italic"],
 " and \[Lambda] only and is equivalent to ",
 StyleBox["KExpand",
  FontSlant->"Italic"],
 " with no options."
}], "Item",
 CellChangeTimes->{{3.7974429452800303`*^9, 3.7974429479060345`*^9}, {
  3.797936554647592*^9, 3.797936879425899*^9}, {3.7982508035365667`*^9, 
  3.798250821558138*^9}},ExpressionUUID->"c1f03b33-97d6-49f2-813a-\
0ae171a92d80"],

Cell[TextData[{
 "In addition to level 1, level 2 (identifier ",
 StyleBox["Integer",
  FontSlant->"Italic"],
 " can be used as well) expands integral powers of \[Lambda]."
}], "Item",
 CellChangeTimes->{{3.7982508248966913`*^9, 
  3.79825083599806*^9}},ExpressionUUID->"969253ff-6711-454a-99f8-\
46e6c497caab"],

Cell["\<\
In addition to level 1, level 3 (identifier \[Lambda] can be used) expands \
all \[Lambda]\[CloseCurlyQuote]s.\
\>", "Item",
 CellChangeTimes->{{3.798250838144865*^9, 
  3.798250846541399*^9}},ExpressionUUID->"17303104-b700-452a-96d2-\
9eaa5b0c256d"],

Cell[TextData[{
 "In addition to previous levels, level 4 identified ",
 StyleBox["NL",
  FontSlant->"Italic"],
 " can be used) expands ",
 StyleBox["NL",
  FontSlant->"Italic"],
 " as well. ",
 StyleBox["KFullExpand",
  FontSlant->"Italic"],
 " is equivalent to ",
 StyleBox["KExpand",
  FontSlant->"Italic"],
 " with level 4 expansion."
}], "Item",
 CellChangeTimes->{{3.798250849824545*^9, 
  3.798250855670165*^9}},ExpressionUUID->"2f7542e4-1c7b-4117-93c4-\
06f02b94391d"],

Cell["Level 0 is also admissible.", "Item",
 CellChangeTimes->{
  3.798250859824139*^9},ExpressionUUID->"19ff4c1a-5631-48e8-824a-\
b4a47ad92505"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"KExpand", "[", 
   RowBox[{"expr", ",", " ", 
    RowBox[{"Level", "\[Rule]", "2"}]}], "]"}], "//", 
  "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"KExpand", "[", 
   RowBox[{"expr", ",", " ", 
    RowBox[{"Level", "\[Rule]", "\[Lambda]"}]}], "]"}], "//", 
  "Simplify"}]}], "Input",
 CellChangeTimes->{{3.7979368926203623`*^9, 3.7979368954995947`*^9}, {
  3.7979369308800783`*^9, 
  3.797936956239996*^9}},ExpressionUUID->"7117085d-0dbb-4bf1-90b5-\
be053d17be0e"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["1", 
    SubscriptBox["p", "1"]], 
   RowBox[{"2", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "1"], "]"}], " ", 
       SubsuperscriptBox["p", "1", "2"]}], "-", 
      RowBox[{
       RowBox[{"Log", "[", 
        SubscriptBox["p", "2"], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SubsuperscriptBox["p", "1", "2"], "+", 
         SubsuperscriptBox["p", "2", "2"], "-", 
         SubsuperscriptBox["p", "3", "2"]}], ")"}]}], "-", 
      RowBox[{
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SubsuperscriptBox["p", "1", "2"], "-", 
         SubsuperscriptBox["p", "2", "2"], "+", 
         SubsuperscriptBox["p", "3", "2"]}], ")"}]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SubsuperscriptBox["p", "1", "4"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SubsuperscriptBox["p", "2", "2"], "-", 
         SubsuperscriptBox["p", "3", "2"]}], ")"}], "2"], "-", 
      RowBox[{"2", " ", 
       SubsuperscriptBox["p", "1", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         SubsuperscriptBox["p", "2", "2"], "+", 
         SubsuperscriptBox["p", "3", "2"]}], ")"}]}]}], ")"}]}]}], "+", 
  RowBox[{"6", " ", "NL", " ", 
   SubscriptBox["p", "1"], " ", 
   RowBox[{"(", 
    RowBox[{
     SubsuperscriptBox["p", "1", "2"], "-", 
     SubsuperscriptBox["p", "2", "2"], "-", 
     SubsuperscriptBox["p", "3", "2"]}], ")"}], " ", 
   SqrtBox["\[Lambda]"]}]}]], "Output",
 CellChangeTimes->{{3.797936941319826*^9, 3.797936956519973*^9}, 
   3.798250866857401*^9, 3.798685755983364*^9, 3.7986858051721473`*^9, 
   3.799037622506981*^9},ExpressionUUID->"f1bfee96-637f-4004-b7d3-\
149f08b74026"],

Cell[BoxData[
 RowBox[{
  RowBox[{"6", " ", "NL", " ", 
   SubscriptBox["p", "1"], " ", 
   RowBox[{"(", 
    RowBox[{
     SubsuperscriptBox["p", "1", "2"], "-", 
     SubsuperscriptBox["p", "2", "2"], "-", 
     SubsuperscriptBox["p", "3", "2"]}], ")"}], " ", 
   SqrtBox[
    RowBox[{
     SubsuperscriptBox["p", "1", "4"], "+", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SubsuperscriptBox["p", "2", "2"], "-", 
        SubsuperscriptBox["p", "3", "2"]}], ")"}], "2"], "-", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["p", "1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SubsuperscriptBox["p", "2", "2"], "+", 
        SubsuperscriptBox["p", "3", "2"]}], ")"}]}]}]]}], "+", 
  RowBox[{
   FractionBox["1", 
    SubscriptBox["p", "1"]], 
   RowBox[{"2", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "1"], "]"}], " ", 
       SubsuperscriptBox["p", "1", "2"]}], "-", 
      RowBox[{
       RowBox[{"Log", "[", 
        SubscriptBox["p", "2"], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SubsuperscriptBox["p", "1", "2"], "+", 
         SubsuperscriptBox["p", "2", "2"], "-", 
         SubsuperscriptBox["p", "3", "2"]}], ")"}]}], "-", 
      RowBox[{
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SubsuperscriptBox["p", "1", "2"], "-", 
         SubsuperscriptBox["p", "2", "2"], "+", 
         SubsuperscriptBox["p", "3", "2"]}], ")"}]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SubsuperscriptBox["p", "1", "4"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SubsuperscriptBox["p", "2", "2"], "-", 
         SubsuperscriptBox["p", "3", "2"]}], ")"}], "2"], "-", 
      RowBox[{"2", " ", 
       SubsuperscriptBox["p", "1", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         SubsuperscriptBox["p", "2", "2"], "+", 
         SubsuperscriptBox["p", "3", "2"]}], ")"}]}]}], ")"}]}]}]}]], "Output",
 CellChangeTimes->{{3.797936941319826*^9, 3.797936956519973*^9}, 
   3.798250866857401*^9, 3.798685755983364*^9, 3.7986858051721473`*^9, 
   3.799037622918272*^9},ExpressionUUID->"513b8a56-7ad7-4962-8679-\
f09580085573"]
}, Open  ]],

Cell[TextData[{
 "Option ",
 StyleBox["ExpansionLevel",
  FontSlant->"Italic"],
 " can also be used in ",
 StyleBox["KEvaluate.",
  FontSlant->"Italic"]
}], "Text",
 CellChangeTimes->{{3.7979369666078577`*^9, 3.797936978368472*^9}, {
  3.797937032616392*^9, 
  3.797937032856307*^9}},ExpressionUUID->"ee939956-5879-4ecf-bc8b-\
a185a2d83067"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Triple-K integrals with integral indices", "Subsection",
 CellChangeTimes->{{3.7817879964571447`*^9, 
  3.7817880076653833`*^9}},ExpressionUUID->"451ec262-9a81-4378-b345-\
3edb27b3057e"],

Cell[TextData[{
 "The most basic triple-",
 StyleBox["K",
  FontSlant->"Italic"],
 " integral with integer indices is:"
}], "Text",
 CellChangeTimes->{{3.7971952261911135`*^9, 3.7971952521351504`*^9}, 
   3.7979370553129473`*^9},ExpressionUUID->"ef957067-8dbb-4b2f-9031-\
1c3d2938560f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"int", "=", 
  RowBox[{"KEvaluate", "[", 
   RowBox[{"i", "[", 
    RowBox[{"1", ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.781712599651158*^9, 3.7817126033392577`*^9}, {
  3.781788213372967*^9, 3.781788240385899*^9}, {3.7945521440048237`*^9, 
  3.794552156461781*^9}, {3.797442655918519*^9, 
  3.7974426649085317`*^9}},ExpressionUUID->"bec38e02-c1b1-4d57-9845-\
399dd0a23f6e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   FractionBox["NL", 
    RowBox[{"2", " ", 
     SqrtBox["\[Lambda]"]}]], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "\[Epsilon]", "]"}], "1"],
    SeriesData[TripleK`\[Epsilon], 0, {}, 0, 1, 1],
    Editable->False]}],
  SeriesData[TripleK`\[Epsilon], 0, {Rational[1, 2] TripleK`NL[
      TripleK`p[1], 
      TripleK`p[2], 
      TripleK`p[3]] TripleK`\[Lambda][
       TripleK`p[1], 
       TripleK`p[2], 
       TripleK`p[3]]^Rational[-1, 2]}, 0, 1, 1],
  Editable->False]], "Output",
 CellChangeTimes->{
  3.781712603940273*^9, 3.781713011625511*^9, 3.781788179001936*^9, {
   3.781788213977043*^9, 3.781788240781228*^9}, {3.794552138596632*^9, 
   3.794552156778504*^9}, 3.7945553620499783`*^9, 3.79455542949266*^9, 
   3.797195253250152*^9, {3.7974426374144926`*^9, 3.7974426659685335`*^9}, {
   3.7974429536510425`*^9, 3.7974429826660833`*^9}, 3.797937025177978*^9, 
   3.798250889312832*^9, 3.798685756186376*^9, 3.798685805363158*^9, 
   3.799037623013232*^9},ExpressionUUID->"83029b0e-4455-4a7c-9388-\
e7c2960978f9"]
}, Open  ]],

Cell[TextData[{
 "This integral, in particular, represents the 3-point function ",
 Cell[BoxData[
  FormBox[
   RowBox[{"<", 
    RowBox[{":", "\[Phi]\[Phi]", ":", 
     RowBox[{"(", 
      SubscriptBox["p", "1"], ")"}], " ", ":", "\[Phi]\[Phi]", ":", 
     RowBox[{"(", 
      SubscriptBox["p", "2"], ")"}], " ", ":", "\[Phi]\[Phi]", ":", 
     RowBox[{
      RowBox[{"(", 
       SubscriptBox["p", "3"], ")"}], ">"}]}]}], TraditionalForm]],
  ExpressionUUID->"75a14b2a-fc14-472b-9120-a072d7fad4ad"],
 ", where \[Phi] is a free scalar field in 4 spacetime dimensions. Fully \
expanded it reads:"
}], "Text",
 CellChangeTimes->{{3.797195256705157*^9, 3.797195350085288*^9}, 
   3.7979370537443438`*^9},ExpressionUUID->"55fdd9a2-0294-4bd5-b1c0-\
e3e09d0db5d4"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"int", " ", "//", " ", "KFullExpand"}]], "Input",
 CellChangeTimes->{{3.781712612148425*^9, 3.781712621264574*^9}, {
  3.781788214907814*^9, 3.78178824228969*^9}, {3.7971953557612963`*^9, 
  3.7971953643673086`*^9}, {3.797442989682093*^9, 
  3.797442990233094*^9}},ExpressionUUID->"1d5b2260-c33f-4d52-a3c7-\
3f4581e4433d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       SuperscriptBox["\[Pi]", "2"], "6"], "-", 
      RowBox[{"2", " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SubscriptBox["p", "1"], 
         SubscriptBox["p", "3"]], "]"}], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SubscriptBox["p", "2"], 
         SubscriptBox["p", "3"]], "]"}]}], "+", 
      RowBox[{
       RowBox[{"Log", "[", 
        FractionBox[
         RowBox[{
          SubsuperscriptBox["p", "1", "2"], "-", 
          SubsuperscriptBox["p", "2", "2"], "+", 
          SubsuperscriptBox["p", "3", "2"], "-", 
          SqrtBox[
           RowBox[{
            SubsuperscriptBox["p", "1", "4"], "-", 
            RowBox[{"2", " ", 
             SubsuperscriptBox["p", "1", "2"], " ", 
             SubsuperscriptBox["p", "2", "2"]}], "+", 
            SubsuperscriptBox["p", "2", "4"], "-", 
            RowBox[{"2", " ", 
             SubsuperscriptBox["p", "1", "2"], " ", 
             SubsuperscriptBox["p", "3", "2"]}], "-", 
            RowBox[{"2", " ", 
             SubsuperscriptBox["p", "2", "2"], " ", 
             SubsuperscriptBox["p", "3", "2"]}], "+", 
            SubsuperscriptBox["p", "3", "4"]}]]}], 
         RowBox[{"2", " ", 
          SubsuperscriptBox["p", "3", "2"]}]], "]"}], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         RowBox[{
          RowBox[{"-", 
           SubsuperscriptBox["p", "1", "2"]}], "+", 
          SubsuperscriptBox["p", "2", "2"], "+", 
          SubsuperscriptBox["p", "3", "2"], "-", 
          SqrtBox[
           RowBox[{
            SubsuperscriptBox["p", "1", "4"], "-", 
            RowBox[{"2", " ", 
             SubsuperscriptBox["p", "1", "2"], " ", 
             SubsuperscriptBox["p", "2", "2"]}], "+", 
            SubsuperscriptBox["p", "2", "4"], "-", 
            RowBox[{"2", " ", 
             SubsuperscriptBox["p", "1", "2"], " ", 
             SubsuperscriptBox["p", "3", "2"]}], "-", 
            RowBox[{"2", " ", 
             SubsuperscriptBox["p", "2", "2"], " ", 
             SubsuperscriptBox["p", "3", "2"]}], "+", 
            SubsuperscriptBox["p", "3", "4"]}]]}], 
         RowBox[{"2", " ", 
          SubsuperscriptBox["p", "3", "2"]}]], "]"}]}], "-", 
      RowBox[{"PolyLog", "[", 
       RowBox[{"2", ",", 
        FractionBox[
         RowBox[{
          SubsuperscriptBox["p", "1", "2"], "-", 
          SubsuperscriptBox["p", "2", "2"], "+", 
          SubsuperscriptBox["p", "3", "2"], "-", 
          SqrtBox[
           RowBox[{
            SubsuperscriptBox["p", "1", "4"], "-", 
            RowBox[{"2", " ", 
             SubsuperscriptBox["p", "1", "2"], " ", 
             SubsuperscriptBox["p", "2", "2"]}], "+", 
            SubsuperscriptBox["p", "2", "4"], "-", 
            RowBox[{"2", " ", 
             SubsuperscriptBox["p", "1", "2"], " ", 
             SubsuperscriptBox["p", "3", "2"]}], "-", 
            RowBox[{"2", " ", 
             SubsuperscriptBox["p", "2", "2"], " ", 
             SubsuperscriptBox["p", "3", "2"]}], "+", 
            SubsuperscriptBox["p", "3", "4"]}]]}], 
         RowBox[{"2", " ", 
          SubsuperscriptBox["p", "3", "2"]}]]}], "]"}], "-", 
      RowBox[{"PolyLog", "[", 
       RowBox[{"2", ",", 
        FractionBox[
         RowBox[{
          RowBox[{"-", 
           SubsuperscriptBox["p", "1", "2"]}], "+", 
          SubsuperscriptBox["p", "2", "2"], "+", 
          SubsuperscriptBox["p", "3", "2"], "-", 
          SqrtBox[
           RowBox[{
            SubsuperscriptBox["p", "1", "4"], "-", 
            RowBox[{"2", " ", 
             SubsuperscriptBox["p", "1", "2"], " ", 
             SubsuperscriptBox["p", "2", "2"]}], "+", 
            SubsuperscriptBox["p", "2", "4"], "-", 
            RowBox[{"2", " ", 
             SubsuperscriptBox["p", "1", "2"], " ", 
             SubsuperscriptBox["p", "3", "2"]}], "-", 
            RowBox[{"2", " ", 
             SubsuperscriptBox["p", "2", "2"], " ", 
             SubsuperscriptBox["p", "3", "2"]}], "+", 
            SubsuperscriptBox["p", "3", "4"]}]]}], 
         RowBox[{"2", " ", 
          SubsuperscriptBox["p", "3", "2"]}]]}], "]"}]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{"2", " ", 
      SqrtBox[
       RowBox[{
        SubsuperscriptBox["p", "1", "4"], "-", 
        RowBox[{"2", " ", 
         SubsuperscriptBox["p", "1", "2"], " ", 
         SubsuperscriptBox["p", "2", "2"]}], "+", 
        SubsuperscriptBox["p", "2", "4"], "-", 
        RowBox[{"2", " ", 
         SubsuperscriptBox["p", "1", "2"], " ", 
         SubsuperscriptBox["p", "3", "2"]}], "-", 
        RowBox[{"2", " ", 
         SubsuperscriptBox["p", "2", "2"], " ", 
         SubsuperscriptBox["p", "3", "2"]}], "+", 
        SubsuperscriptBox["p", "3", "4"]}]]}], ")"}]}], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "\[Epsilon]", "]"}], "1"],
    SeriesData[TripleK`\[Epsilon], 0, {}, 0, 1, 1],
    Editable->False]}],
  SeriesData[
  TripleK`\[Epsilon], 0, {
   Rational[1, 2] (TripleK`p[1]^4 - 2 TripleK`p[1]^2 TripleK`p[2]^2 + 
      TripleK`p[2]^4 - 2 TripleK`p[1]^2 TripleK`p[3]^2 - 2 TripleK`p[2]^2 
      TripleK`p[3]^2 + TripleK`p[3]^4)^Rational[-1, 2] (Rational[1, 6] Pi^2 - 
     2 Log[TripleK`p[1]/TripleK`p[3]] Log[TripleK`p[2]/TripleK`p[3]] + 
     Log[Rational[1, 2] 
        TripleK`p[3]^(-2) (TripleK`p[1]^2 - TripleK`p[2]^2 + 
         TripleK`p[3]^2 - (TripleK`p[1]^4 - 2 TripleK`p[1]^2 TripleK`p[2]^2 + 
          TripleK`p[2]^4 - 2 TripleK`p[1]^2 TripleK`p[3]^2 - 2 TripleK`p[2]^2 
          TripleK`p[3]^2 + TripleK`p[3]^4)^Rational[1, 2])] 
      Log[Rational[1, 2] 
        TripleK`p[3]^(-2) (-TripleK`p[1]^2 + TripleK`p[2]^2 + 
         TripleK`p[3]^2 - (TripleK`p[1]^4 - 2 TripleK`p[1]^2 TripleK`p[2]^2 + 
          TripleK`p[2]^4 - 2 TripleK`p[1]^2 TripleK`p[3]^2 - 2 TripleK`p[2]^2 
          TripleK`p[3]^2 + TripleK`p[3]^4)^Rational[1, 2])] - PolyLog[
     2, Rational[1, 2] 
      TripleK`p[3]^(-2) (TripleK`p[1]^2 - TripleK`p[2]^2 + 
       TripleK`p[3]^2 - (TripleK`p[1]^4 - 2 TripleK`p[1]^2 TripleK`p[2]^2 + 
        TripleK`p[2]^4 - 2 TripleK`p[1]^2 TripleK`p[3]^2 - 2 TripleK`p[2]^2 
        TripleK`p[3]^2 + TripleK`p[3]^4)^Rational[1, 2])] - PolyLog[
     2, Rational[1, 2] 
      TripleK`p[3]^(-2) (-TripleK`p[1]^2 + TripleK`p[2]^2 + 
       TripleK`p[3]^2 - (TripleK`p[1]^4 - 2 TripleK`p[1]^2 TripleK`p[2]^2 + 
        TripleK`p[2]^4 - 2 TripleK`p[1]^2 TripleK`p[3]^2 - 2 TripleK`p[2]^2 
        TripleK`p[3]^2 + TripleK`p[3]^4)^Rational[1, 2])])}, 0, 1, 1],
  Editable->False]], "Output",
 CellChangeTimes->{
  3.781712621792585*^9, 3.781713012095512*^9, {3.781788189597513*^9, 
   3.7817882427913237`*^9}, 3.794555368591178*^9, 3.794555430792547*^9, {
   3.797195360377303*^9, 3.797195364632309*^9}, {3.797442986232088*^9, 
   3.7974429912480955`*^9}, 3.7979370414504957`*^9, 3.798250893501561*^9, 
   3.7986857562023773`*^9, 3.798685805377159*^9, 
   3.799037623059963*^9},ExpressionUUID->"aa2ab14c-84b1-48b6-b524-\
736f3fd22c69"]
}, Open  ]],

Cell[TextData[{
 "To check conformality we can substitute this expression to ",
 StyleBox["ScalarKKOp",
  FontSlant->"Italic"],
 ". But taking derivatives of this expression can be painful. Instead we \
substitute the expression containing ",
 StyleBox["NL",
  FontSlant->"Italic"],
 " to ",
 StyleBox["ScalarKKOp",
  FontSlant->"Italic"],
 " and simplify afterwards:"
}], "Text",
 CellChangeTimes->{{3.781788250840424*^9, 3.781788300369917*^9}, {
  3.797195368937315*^9, 3.7971953943133507`*^9}, {3.797937051552498*^9, 
  3.797937069646018*^9}},ExpressionUUID->"cd001cfe-4a34-49fc-9b3c-\
6f867f3ed3f5"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ScalarKKOp", "[", 
    RowBox[{"int", ",", " ", 
     RowBox[{"p", "[", "1", "]"}], ",", 
     RowBox[{"p", "[", "2", "]"}], ",", "0", ",", "0"}], "]"}], "//", 
   "KFullExpand"}], "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.781712633451707*^9, 3.781712671522315*^9}, {
  3.781788221545508*^9, 3.781788222978047*^9}, {3.781788307044466*^9, 
  3.781788314568595*^9}, {3.794555372614237*^9, 3.794555376948853*^9}, {
  3.797195398053356*^9, 3.79719540781637*^9}, {3.7974430064951167`*^9, 
  3.797443007070118*^9}, {3.797937045176261*^9, 
  3.797937045800671*^9}},ExpressionUUID->"a12e3683-8896-4f55-a377-\
938e484db6b8"],

Cell[BoxData[
 InterpretationBox[
  SuperscriptBox[
   RowBox[{"O", "[", "\[Epsilon]", "]"}], "1"],
  SeriesData[TripleK`\[Epsilon], 0, {}, 1, 1, 1],
  Editable->False]], "Output",
 CellChangeTimes->{{3.781712657672079*^9, 3.7817126719693203`*^9}, 
   3.781713012647515*^9, 3.781788237150297*^9, {3.781788307959489*^9, 
   3.781788314967414*^9}, 3.794555377434651*^9, 3.7945554326964197`*^9, {
   3.7971954034903636`*^9, 3.7971954081913705`*^9}, 3.7974430077101183`*^9, {
   3.797937047577387*^9, 3.797937072735814*^9}, 3.7982508965566587`*^9, 
   3.7986857564023886`*^9, 3.798685805541168*^9, 
   3.799037623310273*^9},ExpressionUUID->"aef22c9a-b33a-49ef-a600-\
21e1080b7084"]
}, Open  ]],

Cell[TextData[{
 "Similarly, we can evaluate more complicated integrals. We can use option ",
 StyleBox["ExpansionLevel",
  FontSlant->"Italic"],
 " to ",
 StyleBox["KEvaluate",
  FontSlant->"Italic"],
 " for automated expansion:"
}], "Text",
 CellChangeTimes->{{3.781788350377157*^9, 3.781788358754922*^9}, {
  3.7971954399684153`*^9, 3.79719551458852*^9}, {3.797443017327132*^9, 
  3.7974430474551744`*^9}, {3.797937089446368*^9, 
  3.797937124737117*^9}},ExpressionUUID->"cb42a138-3c5c-400b-accd-\
d7b3124b429b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"int", "=", 
  RowBox[{
   RowBox[{"KEvaluate", "[", 
    RowBox[{
     RowBox[{"i", "[", 
      RowBox[{"3", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "1", ",", "1"}], "}"}]}], "]"}], ",", " ", 
     RowBox[{"ExpansionLevel", "\[Rule]", "Integer"}]}], "]"}], "//", 
   "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.7817127637938633`*^9, 3.7817127660329113`*^9}, {
  3.7817128178727207`*^9, 3.781712819017722*^9}, {3.794552169204451*^9, 
  3.79455217346596*^9}, {3.79719566409173*^9, 3.797195747740848*^9}, {
  3.7974430668822017`*^9, 3.7974430675272026`*^9}, {3.797937138576467*^9, 
  3.797937148384995*^9}},ExpressionUUID->"7e613e8c-61dc-4182-921c-\
2c7b7d7b7720"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   FractionBox["2", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"u", "-", 
       RowBox[{"3", " ", "v"}]}], ")"}], " ", "\[Epsilon]"}]], "+", 
   RowBox[{"(", 
    RowBox[{
     FractionBox[
      RowBox[{"2", " ", "v"}], 
      RowBox[{"u", "-", 
       RowBox[{"3", " ", "v"}]}]], "+", 
     FractionBox[
      RowBox[{"u", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", "EulerGamma"}], "+", 
         RowBox[{"Log", "[", "4", "]"}]}], ")"}]}], 
      RowBox[{"u", "-", 
       RowBox[{"3", " ", "v"}]}]], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4", " ", 
        SubsuperscriptBox["p", "1", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          SubsuperscriptBox["p", "1", "2"], "-", 
          SubsuperscriptBox["p", "2", "2"], "-", 
          SubsuperscriptBox["p", "3", "2"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"Log", "[", 
            SubscriptBox["p", "1"], "]"}], " ", 
           SubsuperscriptBox["p", "1", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             SubsuperscriptBox["p", "1", "2"], "-", 
             SubsuperscriptBox["p", "2", "2"], "-", 
             SubsuperscriptBox["p", "3", "2"]}], ")"}]}], "+", 
          RowBox[{
           RowBox[{"Log", "[", 
            SubscriptBox["p", "2"], "]"}], " ", 
           SubsuperscriptBox["p", "2", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              SubsuperscriptBox["p", "1", "2"]}], "+", 
             SubsuperscriptBox["p", "2", "2"], "-", 
             SubsuperscriptBox["p", "3", "2"]}], ")"}]}], "+", 
          RowBox[{
           RowBox[{"Log", "[", 
            SubscriptBox["p", "3"], "]"}], " ", 
           SubsuperscriptBox["p", "3", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              SubsuperscriptBox["p", "1", "2"]}], "-", 
             SubsuperscriptBox["p", "2", "2"], "+", 
             SubsuperscriptBox["p", "3", "2"]}], ")"}]}]}], ")"}]}], ")"}], 
      "/", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SubsuperscriptBox["p", "1", "4"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SubsuperscriptBox["p", "2", "2"], "-", 
            SubsuperscriptBox["p", "3", "2"]}], ")"}], "2"], "-", 
         RowBox[{"2", " ", 
          SubsuperscriptBox["p", "1", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SubsuperscriptBox["p", "2", "2"], "+", 
            SubsuperscriptBox["p", "3", "2"]}], ")"}]}]}], ")"}], "2"]}], "+", 
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"Log", "[", 
           SubscriptBox["p", "3"], "]"}], " ", 
          SubsuperscriptBox["p", "3", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SubsuperscriptBox["p", "1", "2"], "+", 
            SubsuperscriptBox["p", "2", "2"], "-", 
            SubsuperscriptBox["p", "3", "2"]}], ")"}]}], "+", 
         RowBox[{
          RowBox[{"Log", "[", 
           SubscriptBox["p", "2"], "]"}], " ", 
          SubsuperscriptBox["p", "2", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SubsuperscriptBox["p", "1", "2"], "-", 
            SubsuperscriptBox["p", "2", "2"], "+", 
            SubsuperscriptBox["p", "3", "2"]}], ")"}]}], "+", 
         RowBox[{
          RowBox[{"Log", "[", 
           SubscriptBox["p", "1"], "]"}], " ", 
          SubsuperscriptBox["p", "1", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SubsuperscriptBox["p", "1", "2"]}], "+", 
            SubsuperscriptBox["p", "2", "2"], "+", 
            SubsuperscriptBox["p", "3", "2"]}], ")"}]}]}], ")"}]}], 
      RowBox[{
       SubsuperscriptBox["p", "1", "4"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SubsuperscriptBox["p", "2", "2"], "-", 
          SubsuperscriptBox["p", "3", "2"]}], ")"}], "2"], "-", 
       RowBox[{"2", " ", 
        SubsuperscriptBox["p", "1", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          SubsuperscriptBox["p", "2", "2"], "+", 
          SubsuperscriptBox["p", "3", "2"]}], ")"}]}]}]], "-", 
     FractionBox[
      RowBox[{"2", " ", 
       SubsuperscriptBox["p", "1", "2"], " ", 
       SubsuperscriptBox["p", "2", "2"], " ", 
       SubsuperscriptBox["p", "3", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"4", " ", 
          RowBox[{"Log", "[", 
           SubscriptBox["p", "1"], "]"}], " ", 
          SubsuperscriptBox["p", "1", "2"]}], "-", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"Log", "[", 
              SubscriptBox["p", "2"], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               SubsuperscriptBox["p", "1", "2"], "+", 
               SubsuperscriptBox["p", "2", "2"], "-", 
               SubsuperscriptBox["p", "3", "2"]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{"Log", "[", 
              SubscriptBox["p", "3"], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               SubsuperscriptBox["p", "1", "2"], "-", 
               SubsuperscriptBox["p", "2", "2"], "+", 
               SubsuperscriptBox["p", "3", "2"]}], ")"}]}]}], ")"}]}]}], 
        ")"}]}], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SubsuperscriptBox["p", "1", "4"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SubsuperscriptBox["p", "2", "2"], "-", 
            SubsuperscriptBox["p", "3", "2"]}], ")"}], "2"], "-", 
         RowBox[{"2", " ", 
          SubsuperscriptBox["p", "1", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SubsuperscriptBox["p", "2", "2"], "+", 
            SubsuperscriptBox["p", "3", "2"]}], ")"}]}]}], ")"}], "2"]], "+", 
     FractionBox[
      RowBox[{
       SubsuperscriptBox["p", "1", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         SubsuperscriptBox["p", "1", "2"], "-", 
         SubsuperscriptBox["p", "2", "2"], "-", 
         RowBox[{"2", " ", 
          RowBox[{"Log", "[", 
           SubscriptBox["p", "2"], "]"}], " ", 
          SubsuperscriptBox["p", "2", "2"]}], "-", 
         SubsuperscriptBox["p", "3", "2"], "-", 
         RowBox[{"2", " ", 
          RowBox[{"Log", "[", 
           SubscriptBox["p", "3"], "]"}], " ", 
          SubsuperscriptBox["p", "3", "2"]}], "+", 
         RowBox[{
          RowBox[{"Log", "[", 
           SubscriptBox["p", "1"], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"4", " ", 
             SubsuperscriptBox["p", "1", "2"]}], "-", 
            RowBox[{"2", " ", 
             RowBox[{"(", 
              RowBox[{
               SubsuperscriptBox["p", "2", "2"], "+", 
               SubsuperscriptBox["p", "3", "2"]}], ")"}]}]}], ")"}]}]}], 
        ")"}]}], 
      RowBox[{
       SubsuperscriptBox["p", "1", "4"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SubsuperscriptBox["p", "2", "2"], "-", 
          SubsuperscriptBox["p", "3", "2"]}], ")"}], "2"], "-", 
       RowBox[{"2", " ", 
        SubsuperscriptBox["p", "1", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          SubsuperscriptBox["p", "2", "2"], "+", 
          SubsuperscriptBox["p", "3", "2"]}], ")"}]}]}]], "+", 
     FractionBox[
      RowBox[{"12", " ", "NL", " ", 
       SubsuperscriptBox["p", "1", "4"], " ", 
       SubsuperscriptBox["p", "2", "2"], " ", 
       SubsuperscriptBox["p", "3", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         SubsuperscriptBox["p", "1", "2"], "-", 
         SubsuperscriptBox["p", "2", "2"], "-", 
         SubsuperscriptBox["p", "3", "2"]}], ")"}]}], 
      SuperscriptBox["\[Lambda]", 
       RowBox[{"5", "/", "2"}]]]}], ")"}], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "\[Epsilon]", "]"}], "1"],
    SeriesData[TripleK`\[Epsilon], 0, {}, -1, 1, 1],
    Editable->False]}],
  SeriesData[
  TripleK`\[Epsilon], 0, {
   2/(TripleK`u - 3 TripleK`v), 2 (TripleK`u - 3 TripleK`v)^(-1) TripleK`v + 
    TripleK`u (TripleK`u - 3 TripleK`v)^(-1) ((-2) EulerGamma + Log[4]) - 4 
    TripleK`p[1]^2 (TripleK`p[1]^2 - TripleK`p[2]^2 - TripleK`p[3]^2) (Log[
        TripleK`p[1]] 
      TripleK`p[1]^2 (TripleK`p[1]^2 - TripleK`p[2]^2 - TripleK`p[3]^2) + Log[
        TripleK`p[2]] 
      TripleK`p[2]^2 (-TripleK`p[1]^2 + TripleK`p[2]^2 - TripleK`p[3]^2) + Log[
        TripleK`p[3]] 
      TripleK`p[3]^2 (-TripleK`p[1]^2 - TripleK`p[2]^2 + TripleK`p[3]^2)) (
      TripleK`p[1]^4 + (TripleK`p[2]^2 - TripleK`p[3]^2)^2 - 2 
      TripleK`p[1]^2 (TripleK`p[2]^2 + TripleK`p[3]^2))^(-2) + 
    2 (TripleK`p[1]^4 + (TripleK`p[2]^2 - TripleK`p[3]^2)^2 - 2 
       TripleK`p[1]^2 (TripleK`p[2]^2 + TripleK`p[3]^2))^(-1) (Log[
         TripleK`p[3]] 
       TripleK`p[3]^2 (TripleK`p[1]^2 + TripleK`p[2]^2 - TripleK`p[3]^2) + Log[
         TripleK`p[2]] 
       TripleK`p[2]^2 (TripleK`p[1]^2 - TripleK`p[2]^2 + TripleK`p[3]^2) + Log[
         TripleK`p[1]] 
       TripleK`p[1]^2 (-TripleK`p[1]^2 + TripleK`p[2]^2 + TripleK`p[3]^2)) - 
    2 TripleK`p[1]^2 TripleK`p[2]^2 
    TripleK`p[3]^2 (TripleK`p[1]^4 + (TripleK`p[2]^2 - TripleK`p[3]^2)^2 - 2 
      TripleK`p[1]^2 (TripleK`p[2]^2 + TripleK`p[3]^2))^(-2) (4 Log[
        TripleK`p[1]] TripleK`p[1]^2 - 2 (Log[
         TripleK`p[2]] (TripleK`p[1]^2 + TripleK`p[2]^2 - TripleK`p[3]^2) + 
      Log[
         TripleK`p[3]] (TripleK`p[1]^2 - TripleK`p[2]^2 + TripleK`p[3]^2))) + 
    TripleK`p[1]^2 (TripleK`p[1]^4 + (TripleK`p[2]^2 - TripleK`p[3]^2)^2 - 2 
       TripleK`p[1]^2 (TripleK`p[2]^2 + TripleK`p[3]^2))^(-1) (TripleK`p[1]^2 - 
      TripleK`p[2]^2 - 2 Log[
        TripleK`p[2]] TripleK`p[2]^2 - TripleK`p[3]^2 - 2 Log[
        TripleK`p[3]] TripleK`p[3]^2 + Log[
         TripleK`p[1]] (4 TripleK`p[1]^2 - 
        2 (TripleK`p[2]^2 + TripleK`p[3]^2))) + 12 TripleK`NL[
       TripleK`p[1], 
       TripleK`p[2], 
       TripleK`p[3]] TripleK`p[1]^4 TripleK`p[2]^2 
     TripleK`p[3]^2 (TripleK`p[1]^2 - TripleK`p[2]^2 - TripleK`p[3]^2) 
     TripleK`\[Lambda][
        TripleK`p[1], 
        TripleK`p[2], 
        TripleK`p[3]]^Rational[-5, 2]}, -1, 1, 1],
  Editable->False]], "Output",
 CellChangeTimes->{
  3.781712766482912*^9, 3.7817128192877226`*^9, 3.7817130143575735`*^9, 
   3.7817883605590153`*^9, {3.7945521624741488`*^9, 3.794552192254814*^9}, 
   3.7945554540580063`*^9, 3.794557783791621*^9, 3.797195527500538*^9, {
   3.797195665231732*^9, 3.7971957504108515`*^9}, 3.7974430703172064`*^9, 
   3.797937149160222*^9, 3.798250899851619*^9, 3.7986857568694153`*^9, 
   3.798685805937191*^9, 
   3.799037623798943*^9},ExpressionUUID->"30c16beb-d0f1-45e3-aa6c-\
e76f7dbd342f"]
}, Open  ]],

Cell[TextData[{
 "A number of tests can be carried out here. We can compare the divergence \
with the result of ",
 StyleBox["KDivergence:",
  FontSlant->"Italic"]
}], "Text",
 CellChangeTimes->{{3.797195550911571*^9, 3.797195595707634*^9}, {
  3.797937159168236*^9, 
  3.797937159735955*^9}},ExpressionUUID->"80aa21c7-fb18-4c3e-a47f-\
19049b6e9f6b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"SeriesCoefficient", "[", 
    RowBox[{"int", ",", 
     RowBox[{"-", "1"}]}], "]"}], "/", "\[Epsilon]"}], "-", 
  RowBox[{"KDivergence", "[", 
   RowBox[{
    RowBox[{"i", "[", 
     RowBox[{"3", ",", 
      RowBox[{"{", 
       RowBox[{"2", ",", "1", ",", "1"}], "}"}]}], "]"}], ",", " ", 
    RowBox[{"ExpansionOrder", "\[Rule]", 
     RowBox[{"-", "1"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.7971955981426373`*^9, 
  3.797195632087685*^9}},ExpressionUUID->"81311d0b-e7ea-4909-a7f2-\
90280d4e949d"],

Cell[BoxData[
 InterpretationBox[
  SuperscriptBox[
   RowBox[{"O", "[", "\[Epsilon]", "]"}], "0"],
  SeriesData[TripleK`\[Epsilon], 0, {}, 0, 0, 1],
  Editable->False]], "Output",
 CellChangeTimes->{{3.797195616095663*^9, 3.797195632612686*^9}, 
   3.7971957531658554`*^9, 3.7974430821692233`*^9, 3.7979371617258368`*^9, 
   3.798250904944395*^9, 3.798685756931419*^9, 3.798685805954192*^9, 
   3.7990376238420477`*^9},ExpressionUUID->"1ea0c2d0-eba8-4b5a-ba42-\
3d594ffb7a22"]
}, Open  ]],

Cell["\<\
Or, we can check if the result is conformal. In general, it is vital to keep \
track of the regulated dimensions:\
\>", "Text",
 CellChangeTimes->{{3.7971956374036927`*^9, 3.797195650629711*^9}, {
  3.79719575641086*^9, 3.7971957749878864`*^9}, {3.797937165888014*^9, 
  3.797937168080132*^9}},ExpressionUUID->"403444db-e9eb-4743-8f65-\
c8b1f03c2a28"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"ScalarKKOp", "[", 
    RowBox[{"int", ",", " ", 
     RowBox[{"p", "[", "1", "]"}], ",", " ", 
     RowBox[{"p", "[", "2", "]"}], ",", " ", 
     RowBox[{"2", "+", 
      RowBox[{"v", " ", "\[Epsilon]"}]}], ",", 
     RowBox[{"1", "+", 
      RowBox[{"v", " ", "\[Epsilon]"}]}]}], "]"}], "//", "KFullExpand"}], "//",
   "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ScalarKKOp", "[", 
    RowBox[{"int", ",", " ", 
     RowBox[{"p", "[", "2", "]"}], ",", " ", 
     RowBox[{"p", "[", "3", "]"}], ",", " ", 
     RowBox[{"1", "+", 
      RowBox[{"v", " ", "\[Epsilon]"}]}], ",", 
     RowBox[{"1", "+", 
      RowBox[{"v", " ", "\[Epsilon]"}]}]}], "]"}], "//", "KFullExpand"}], "//",
   "Simplify"}]}], "Input",
 CellChangeTimes->{{3.7817127851852474`*^9, 3.7817128579293427`*^9}, {
  3.78178837396472*^9, 3.781788415085559*^9}, {3.794555458118626*^9, 
  3.7945554730932417`*^9}, {3.794555507616417*^9, 3.7945555250135*^9}, {
  3.797195780709894*^9, 3.7971957931559114`*^9}, {3.7974430902252345`*^9, 
  3.7974430923452377`*^9}, {3.797937170328717*^9, 
  3.797937172524972*^9}},ExpressionUUID->"225fdc60-6239-4872-aba9-\
268383c0836c"],

Cell[BoxData[
 InterpretationBox[
  SuperscriptBox[
   RowBox[{"O", "[", "\[Epsilon]", "]"}], "1"],
  SeriesData[TripleK`\[Epsilon], 0, {}, 1, 1, 1],
  Editable->False]], "Output",
 CellChangeTimes->{{3.7817127932433424`*^9, 3.7817128600853667`*^9}, 
   3.7817130172706146`*^9, {3.781788368541439*^9, 3.781788415371773*^9}, {
   3.794555484929152*^9, 3.7945555096959743`*^9}, 3.79455554877697*^9, 
   3.7971958007419224`*^9, {3.7974430858242283`*^9, 3.79744309419024*^9}, 
   3.797937174559821*^9, 3.7982509077251997`*^9, 3.7986857581394877`*^9, 
   3.798685807027253*^9, 
   3.799037625040495*^9},ExpressionUUID->"dc037556-bb65-47d3-abef-\
93c382bb92d2"],

Cell[BoxData[
 InterpretationBox[
  SuperscriptBox[
   RowBox[{"O", "[", "\[Epsilon]", "]"}], "1"],
  SeriesData[TripleK`\[Epsilon], 0, {}, 1, 1, 1],
  Editable->False]], "Output",
 CellChangeTimes->{{3.7817127932433424`*^9, 3.7817128600853667`*^9}, 
   3.7817130172706146`*^9, {3.781788368541439*^9, 3.781788415371773*^9}, {
   3.794555484929152*^9, 3.7945555096959743`*^9}, 3.79455554877697*^9, 
   3.7971958007419224`*^9, {3.7974430858242283`*^9, 3.79744309419024*^9}, 
   3.797937174559821*^9, 3.7982509077251997`*^9, 3.7986857581394877`*^9, 
   3.798685807027253*^9, 
   3.7990376260150557`*^9},ExpressionUUID->"afa92f7d-ea92-4109-b5cb-\
cf3b42ae295e"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Momentum-space integrals", "Section",
 CellChangeTimes->{{3.781788433297215*^9, 
  3.781788438441738*^9}},ExpressionUUID->"8ea2412d-cc6f-4bb0-bf4d-\
940576ac4526"],

Cell[TextData[{
 "The package provides simple tools for reducing 2- and 3-point 1-loop \
momentum integrals to double- and triple-",
 StyleBox["K",
  FontSlant->"Italic"],
 " integrals. Any integral of the form\n",
 Cell[BoxData[
  RowBox[{"\[Integral]", 
   RowBox[{
    FractionBox[
     RowBox[{
      SuperscriptBox["d", "d"], "k"}], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"2", "\[Pi]"}], ")"}], "d"]], 
    FractionBox[
     RowBox[{
      RowBox[{
       RowBox[{
        SuperscriptBox["k", 
         SubscriptBox["\[Mu]", "1"]], 
        SuperscriptBox["k", 
         SubscriptBox["\[Mu]", "2"]]}], "..."}], 
      SuperscriptBox["k", 
       SubscriptBox["\[Mu]", "m"]]}], 
     RowBox[{
      SuperscriptBox["k", 
       RowBox[{"2", 
        SubscriptBox["\[Delta]", "3"]}]], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"k", "-", 
         SubscriptBox["p", "1"]}], ")"}], 
       RowBox[{"2", 
        SubscriptBox["\[Delta]", "2"]}]], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"k", "+", 
         SubscriptBox["p", "2"]}], ")"}], 
       RowBox[{"2", 
        SubscriptBox["\[Delta]", "1"]}]]}]]}]}]],ExpressionUUID->
  "4225b50b-bc3c-42f1-be92-1776ec1b546d"],
 "\ncan be expressed in terms of triple-",
 StyleBox["K",
  FontSlant->"Italic"],
 " integrals. Analogously any integral of the form\n",
 Cell[BoxData[
  RowBox[{"\[Integral]", 
   RowBox[{
    FractionBox[
     RowBox[{
      SuperscriptBox["d", "d"], "k"}], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"2", "\[Pi]"}], ")"}], "d"]], 
    FractionBox[
     RowBox[{
      RowBox[{
       RowBox[{
        SuperscriptBox["k", 
         SubscriptBox["\[Mu]", "1"]], 
        SuperscriptBox["k", 
         SubscriptBox["\[Mu]", "2"]]}], "..."}], 
      SuperscriptBox["k", 
       SubscriptBox["\[Mu]", "m"]]}], 
     RowBox[{
      SuperscriptBox["k", 
       RowBox[{"2", 
        SubscriptBox["\[Delta]", "1"]}]], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"k", "-", "p"}], ")"}], 
       RowBox[{"2", 
        SubscriptBox["\[Delta]", "2"]}]]}]]}]}]],ExpressionUUID->
  "589726bd-3b04-4dca-9a6b-c33ae0b2170a"],
 "\ncan be expressed in terms of double-",
 StyleBox["K",
  FontSlant->"Italic"],
 " integrals. For details, consult appendix A.3 of [",
 ButtonBox["1304.7760",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://arxiv.org/pdf/1304.7760.pdf"], None},
  ButtonNote->"https://arxiv.org/pdf/1304.7760.pdf"],
 "] and appendix C of [",
 ButtonBox["1902.01251",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://arxiv.org/pdf/1902.01251.pdf"], None},
  ButtonNote->"https://arxiv.org/pdf/1902.01251.pdf"],
 "]."
}], "Text",
 CellChangeTimes->{{3.797195852043998*^9, 3.7971961233043804`*^9}, {
  3.797196238331543*^9, 3.7971963113346457`*^9}, {3.797938170588299*^9, 
  3.797938205043384*^9}},ExpressionUUID->"0e569706-9359-4e43-b111-\
a0a977aca93d"],

Cell[TextData[{
 "The momentum space integrals above are represented by ",
 StyleBox["LoopIntegral",
  FontSlant->"Italic"],
 ". 2-point function-like integrals are represented as:"
}], "Text",
 CellChangeTimes->{{3.781788441696711*^9, 3.781788463337407*^9}, {
   3.797196323265662*^9, 3.797196333672677*^9}, 
   3.797938214225676*^9},ExpressionUUID->"cccffcc3-9cd2-450e-b901-\
0397d673f7a1"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"LoopIntegral", "[", 
   RowBox[{"d", ",", 
    RowBox[{"{", 
     RowBox[{"\[Delta]1", ",", "\[Delta]2"}], "}"}]}], "]"}], "[", 
  RowBox[{"Numerator", ",", "k", ",", "p"}], "]"}]], "Input",
 CellChangeTimes->{{3.7817884845219727`*^9, 3.78178851516964*^9}, {
  3.79719661905608*^9, 
  3.797196629192094*^9}},ExpressionUUID->"b919e6fb-849c-4190-860d-\
f73b53728e1c"],

Cell[BoxData[
 TagBox[
  RowBox[{"\<\"\\!\\(\\*StyleBox[\\\"\[Integral]\\\",FontSize->18]\\)\"\>", 
   " ", 
   TagBox[
    FractionBox[
     RowBox[{
      SuperscriptBox["\<\"\[DifferentialD]\"\>", "d"], " ", "k"}], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"2", " ", "\[Pi]"}], ")"}], "d"]],
    HoldForm], " ", 
   TagBox[
    FractionBox["Numerator", 
     RowBox[{
      SuperscriptBox["k", 
       RowBox[{"2", " ", "\[Delta]1"}]], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"k", "-", "p"}], ")"}], 
       RowBox[{"2", " ", "\[Delta]2"}]]}]],
    HoldForm]}],
  HoldForm]], "Output",
 CellChangeTimes->{
  3.781788516037409*^9, 3.794555563713339*^9, 3.797196338123684*^9, {
   3.797196622842085*^9, 3.797196630727096*^9}, 3.797444674697467*^9, {
   3.797444854407029*^9, 3.7974448997200933`*^9}, 3.797938215310196*^9, 
   3.7982509285336027`*^9, 3.7986857591275425`*^9, 3.7986858079043036`*^9, 
   3.799037626075899*^9},ExpressionUUID->"364be254-2195-453b-8aba-\
7a2c4007c8e4"]
}, Open  ]],

Cell[TextData[{
 "3-point function-like integrals assume standard momentum magnitudes ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["p", "1"], ",", " ", 
    SubscriptBox["p", "2"], ",", " ", 
    SubscriptBox["p", "3"]}], TraditionalForm]],ExpressionUUID->
  "8a4b802c-0778-4d7e-8479-e7341395c995"],
 ":"
}], "Text",
 CellChangeTimes->{{3.781788469849334*^9, 3.781788481681872*^9}, {
   3.781788526321504*^9, 3.781788541842341*^9}, {3.7971963439136915`*^9, 
   3.797196349054699*^9}, 
   3.797938221193215*^9},ExpressionUUID->"6964230c-52ed-4857-aee1-\
94872bc6df48"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"LoopIntegral", "[", 
   RowBox[{"d", ",", 
    RowBox[{"{", 
     RowBox[{"\[Delta]1", ",", "\[Delta]2", ",", "\[Delta]3"}], "}"}]}], 
   "]"}], "[", 
  RowBox[{"Numerator", ",", "k"}], "]"}]], "Input",
 CellChangeTimes->{{3.781788548961565*^9, 3.7817885531856833`*^9}, 
   3.7971966344731016`*^9},ExpressionUUID->"01aa5b81-766f-43ed-90ef-\
ccb10a0669d1"],

Cell[BoxData[
 TagBox[
  RowBox[{"\<\"\\!\\(\\*StyleBox[\\\"\[Integral]\\\",FontSize->18]\\)\"\>", 
   " ", 
   TagBox[
    FractionBox[
     RowBox[{
      SuperscriptBox["\<\"\[DifferentialD]\"\>", "d"], " ", "k"}], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"2", " ", "\[Pi]"}], ")"}], "d"]],
    HoldForm], " ", 
   TagBox[
    FractionBox["Numerator", 
     RowBox[{
      SuperscriptBox["k", 
       RowBox[{"2", " ", "\[Delta]3"}]], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"k", "-", 
         SubscriptBox["p", "1"]}], ")"}], 
       RowBox[{"2", " ", "\[Delta]2"}]], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"k", "+", 
         SubscriptBox["p", "2"]}], ")"}], 
       RowBox[{"2", " ", "\[Delta]1"}]]}]],
    HoldForm]}],
  HoldForm]], "Output",
 CellChangeTimes->{3.78178855392774*^9, 3.794555565031801*^9, 
  3.7971963499997005`*^9, 3.7971966351081023`*^9, 3.7974447908689404`*^9, 
  3.797444901086095*^9, 3.797938222248913*^9, 3.798250930928075*^9, 
  3.798685759150544*^9, 3.798685807914304*^9, 
  3.799037626088697*^9},ExpressionUUID->"af7f5926-b7f6-410a-ac1e-\
74540e19678d"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Momentum manipulations", "Subsection",
 CellChangeTimes->{{3.7974426213474703`*^9, 3.797442625932477*^9}, {
  3.797444000441516*^9, 
  3.797444054969592*^9}},ExpressionUUID->"e0926b4c-9868-42bb-9d36-\
4a1d8a6a35e1"],

Cell[TextData[{
 "When indices are put on momenta, they are treated as vectors. Such \
expressions can be manipulated by two functions: ",
 StyleBox["Contract",
  FontSlant->"Italic"],
 ", which contracts free or specified indices and ",
 StyleBox["Diff",
  FontSlant->"Italic"],
 ", which takes derivatives with respect to a given momentum."
}], "Text",
 CellChangeTimes->{{3.7974433454075937`*^9, 
  3.7974434427187304`*^9}},ExpressionUUID->"8e1ae90e-40f3-4b5b-9963-\
673bbe1aef23"],

Cell[TextData[{
 "When default momenta ",
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["p", "j", "\[Mu]"], TraditionalForm]],ExpressionUUID->
  "b744f970-0b5d-47f7-ad8c-ca95be0332a7"],
 " are used, it is always assumed that ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubsuperscriptBox["p", "3", "\[Mu]"], "=", 
    RowBox[{
     RowBox[{"-", 
      SubsuperscriptBox["p", "1", "\[Mu]"]}], "-", 
     SubsuperscriptBox["p", "2", "\[Mu]"]}]}], TraditionalForm]],
  ExpressionUUID->"d7fd89cb-11e7-4f0a-a4dc-8f0e20a1bfc1"],
 ". For this reason all scalar products ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["p", "i"], "\[CenterDot]", 
    SubscriptBox["p", "j"]}], TraditionalForm]],ExpressionUUID->
  "4addf5ed-710c-46eb-81ad-112c67c713b3"],
 " are expressed in terms of magnitudes:"
}], "Text",
 CellChangeTimes->{{3.7974442824749155`*^9, 3.797444381361055*^9}, 
   3.797444451317153*^9, {3.797937781969186*^9, 
   3.7979377821205673`*^9}},ExpressionUUID->"deae2631-dd54-4073-a2ea-\
52100380e07a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"p", "[", "1", "]"}], "\[CenterDot]", 
   RowBox[{"p", "[", "2", "]"}]}], "//", "KSimplify"}]], "Input",
 CellChangeTimes->{
  3.7982481066118193`*^9},ExpressionUUID->"d4519333-3e1e-438b-b90f-\
2f21f5c9ee26"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", 
     SubsuperscriptBox["p", "1", "2"]}], "-", 
    SubsuperscriptBox["p", "2", "2"], "+", 
    SubsuperscriptBox["p", "3", "2"]}], ")"}]}]], "Output",
 CellChangeTimes->{
  3.797937295441021*^9, {3.7982481068597813`*^9, 3.7982481097862062`*^9}, 
   3.7982509407007103`*^9, 3.7986857591755457`*^9, 3.798685807938306*^9, 
   3.799037626154673*^9},ExpressionUUID->"ebd36192-abe1-493a-a714-\
bb0bdc4870ef"]
}, Open  ]],

Cell[TextData[{
 "We used ",
 StyleBox["KSimplify",
  FontSlant->"Italic"],
 " for basic simplifications of expressions containing multiple-",
 StyleBox["K",
  FontSlant->"Italic"],
 " integrals (and also momentum loop integrals):"
}], "Text",
 CellChangeTimes->{{3.797937243367976*^9, 3.797937297745038*^9}, {
  3.797937748744872*^9, 
  3.7979377526889467`*^9}},ExpressionUUID->"3174dc97-845b-4790-846d-\
862c31086ff5"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"i", "[", 
   RowBox[{"2", ",", 
    RowBox[{"{", 
     RowBox[{"3", ",", "1", ",", "1"}], "}"}]}], "]"}], "+", 
  RowBox[{
   RowBox[{"p", "[", "1", "]"}], 
   RowBox[{"D", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"i", "[", 
       RowBox[{"1", ",", 
        RowBox[{"{", 
         RowBox[{"2", ",", "1", ",", "1"}], "}"}]}], "]"}], "[", 
      RowBox[{
       RowBox[{"p", "[", "1", "]"}], ",", 
       RowBox[{"p", "[", "2", "]"}], ",", 
       RowBox[{"p", "[", "3", "]"}]}], "]"}], ",", 
     RowBox[{"p", "[", "1", "]"}]}], "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"%", "//", "KSimplify"}]}], "Input",
 CellChangeTimes->{{3.797937524786771*^9, 3.797937561096759*^9}, {
  3.7979375958967657`*^9, 3.7979376411786737`*^9}, {3.797937681163629*^9, 
  3.797937695057639*^9}},ExpressionUUID->"1bb0f6be-f389-4b1c-8a34-\
6ab8b6314a41"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["i", 
   RowBox[{"2", ",", 
    RowBox[{"{", 
     RowBox[{"3", ",", "1", ",", "1"}], "}"}]}]], "+", 
  RowBox[{
   SubscriptBox["p", "1"], " ", 
   RowBox[{
    SuperscriptBox[
     SubscriptBox["i", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "1", ",", "1"}], "}"}]}]], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{
     SubscriptBox["p", "1"], ",", 
     SubscriptBox["p", "2"], ",", 
     SubscriptBox["p", "3"]}], "]"}]}]}]], "Output",
 CellChangeTimes->{{3.797937638430833*^9, 3.797937641454742*^9}, {
   3.797937690614043*^9, 3.797937695477777*^9}, 3.79825094353625*^9, 
   3.7986857592005467`*^9, 3.798685807950306*^9, 
   3.799037626222373*^9},ExpressionUUID->"9d8d5427-9ff2-4c30-b5e6-\
2b4c53a81467"],

Cell[BoxData[
 RowBox[{"4", " ", 
  SubscriptBox["i", 
   RowBox[{"1", ",", 
    RowBox[{"{", 
     RowBox[{"2", ",", "1", ",", "1"}], "}"}]}]]}]], "Output",
 CellChangeTimes->{{3.797937638430833*^9, 3.797937641454742*^9}, {
   3.797937690614043*^9, 3.797937695477777*^9}, 3.79825094353625*^9, 
   3.7986857592005467`*^9, 3.798685807950306*^9, 
   3.799037626223967*^9},ExpressionUUID->"bff125d8-2c7e-4b1b-9426-\
82720565902c"]
}, Open  ]],

Cell[TextData[{
 "To contract indices use ",
 StyleBox["Contract",
  FontSlant->"Italic"],
 ". Without any arguments ",
 StyleBox["Contract",
  FontSlant->"Italic"],
 " contracts all free indices appearing on known vectors. By default these \
are only ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["p", "j"], TraditionalForm]],ExpressionUUID->
  "10c1e9c3-5b05-4658-b501-71a6ad3f18ee"],
 StyleBox[" ",
  FontSlant->"Italic"],
 "and integration momenta ",
 StyleBox["LoopIntegral",
  FontSlant->"Italic"],
 "s:"
}], "Text",
 CellChangeTimes->{{3.797443486850793*^9, 3.797443589732937*^9}, {
  3.7974436771400604`*^9, 3.7974436782200623`*^9}, {3.7974444132230997`*^9, 
  3.7974444343201294`*^9}, {3.79793777770545*^9, 
  3.797937778113186*^9}},ExpressionUUID->"9e9a11f0-3e16-4d4d-a3be-\
f143f1c6dd3d"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Contract", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"p", "[", "1", "]"}], "[", "\[Mu]", "]"}], 
   RowBox[{
    RowBox[{"p", "[", "2", "]"}], "[", "\[Mu]", "]"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Contract", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"p", "[", "1", "]"}], "[", "\[Mu]", "]"}], 
   RowBox[{"k", "[", "\[Mu]", "]"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.797443466658764*^9, 3.7974434759187775`*^9}, {
  3.7974435952939453`*^9, 3.7974436375700045`*^9}, {3.797444622472394*^9, 
  3.7974446226923943`*^9}},ExpressionUUID->"eecc1fa3-d0d5-4dfc-b25e-\
b42616e3a1ed"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", 
     SubsuperscriptBox["p", "1", "2"]}], "-", 
    SubsuperscriptBox["p", "2", "2"], "+", 
    SubsuperscriptBox["p", "3", "2"]}], ")"}]}]], "Output",
 CellChangeTimes->{3.797443476638778*^9, 3.7974436379050055`*^9, 
  3.7974446239073963`*^9, 3.797937723281486*^9, 3.798250945831275*^9, 
  3.7986857592135477`*^9, 3.7986858079683075`*^9, 
  3.799037626238389*^9},ExpressionUUID->"dd7866a4-7211-46b6-9e40-\
ae780138f13f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"k", "[", "\[Mu]", "]"}], " ", 
  TemplateBox[{"p","1","\[Mu]"},
   "Subsuperscript"]}]], "Output",
 CellChangeTimes->{3.797443476638778*^9, 3.7974436379050055`*^9, 
  3.7974446239073963`*^9, 3.797937723281486*^9, 3.798250945831275*^9, 
  3.7986857592135477`*^9, 3.7986858079683075`*^9, 
  3.799037626240377*^9},ExpressionUUID->"acc122c1-2fe5-4f0f-81b2-\
ae54fc24ae32"]
}, Open  ]],

Cell[TextData[{
 "Additional vectors can be specified by option ",
 StyleBox["Vectors",
  FontSlant->"Italic"],
 ". Its argument can be a single vector or a list:"
}], "Text",
 CellChangeTimes->{{3.7974436472410183`*^9, 3.797443721021122*^9}, {
  3.797937786392928*^9, 
  3.797937786584846*^9}},ExpressionUUID->"be9d5955-2230-4998-9fc5-\
a28cdf532368"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Contract", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"p", "[", "1", "]"}], "[", "\[Mu]", "]"}], 
    RowBox[{"k", "[", "\[Mu]", "]"}]}], ",", " ", 
   RowBox[{"Vectors", "\[Rule]", "k"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.797443686600074*^9, 3.7974437064331017`*^9}, {
  3.7974438012142353`*^9, 
  3.7974438022942367`*^9}},ExpressionUUID->"6547ad10-5b9f-4424-a93b-\
db357fc90e05"],

Cell[BoxData[
 RowBox[{"k", "\[CenterDot]", 
  SubscriptBox["p", "1"]}]], "Output",
 CellChangeTimes->{{3.7974436998120923`*^9, 3.797443706688102*^9}, 
   3.7979377331707687`*^9, 3.797937770444351*^9, 3.798250947502111*^9, 
   3.798685759228548*^9, 3.798685807980308*^9, 
   3.799037626277972*^9},ExpressionUUID->"d0b0e33a-ff89-4b7c-8384-\
abbccd09bc56"]
}, Open  ]],

Cell[TextData[{
 "If option ",
 StyleBox["Vectors",
  FontSlant->"Italic"],
 " is set to ",
 StyleBox["All",
  FontSlant->"Italic"],
 ", all repeated indices are contracted. Note that this can lead to undesired \
results:"
}], "Text",
 CellChangeTimes->{{3.7974437554761705`*^9, 3.7974437993382325`*^9}, {
  3.797937788968882*^9, 
  3.797937789144876*^9}},ExpressionUUID->"3e73fdae-5149-4396-a18e-\
45ed3cad79a7"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Contract", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Sin", "[", "x", "]"}], 
     RowBox[{"Cos", "[", "x", "]"}]}], "+", 
    RowBox[{
     RowBox[{
      RowBox[{"p", "[", "1", "]"}], "[", "\[Mu]", "]"}], 
     RowBox[{"k", "[", "\[Mu]", "]"}]}]}], ",", " ", 
   RowBox[{"Vectors", "\[Rule]", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.797443806875243*^9, 3.797443817427258*^9}, {
  3.7974438745823383`*^9, 
  3.797443879508345*^9}},ExpressionUUID->"16d6244e-c4d1-4115-b4a7-\
f7c9524ce5e4"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Cos", "\[CenterDot]", "Sin"}], "+", 
  RowBox[{"k", "\[CenterDot]", 
   SubscriptBox["p", "1"]}]}]], "Output",
 CellChangeTimes->{{3.797443808931246*^9, 3.7974438177122583`*^9}, 
   3.7974438798383455`*^9, 3.797937771873611*^9, 3.7982509492799397`*^9, 
   3.798685759238549*^9, 3.7986858079893084`*^9, 
   3.799037626313621*^9},ExpressionUUID->"1aa3e654-1fd9-490e-a33b-\
d1608c24a255"]
}, Open  ]],

Cell["\<\
To contract over a specified index or a list of such indices, the extra \
argument can be supplied:\
\>", "Text",
 CellChangeTimes->{{3.7974438940003653`*^9, 3.797443938976429*^9}, {
  3.797937792440797*^9, 
  3.797937792625169*^9}},ExpressionUUID->"99b07dc7-84d9-43b8-8c93-\
1246d70a182e"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Contract", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Sin", "[", "x", "]"}], 
     RowBox[{"Cos", "[", "x", "]"}]}], "+", 
    RowBox[{
     RowBox[{
      RowBox[{"p", "[", "1", "]"}], "[", "\[Mu]", "]"}], 
     RowBox[{"k", "[", "\[Mu]", "]"}]}]}], ",", " ", "\[Mu]"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.797443924129408*^9, 
  3.79744392580941*^9}},ExpressionUUID->"6f8a9853-56d6-4e47-958e-\
4404d92ae176"],

Cell[BoxData[
 RowBox[{
  RowBox[{"k", "\[CenterDot]", 
   SubscriptBox["p", "1"]}], "+", 
  RowBox[{
   RowBox[{"Cos", "[", "x", "]"}], " ", 
   RowBox[{"Sin", "[", "x", "]"}]}]}]], "Output",
 CellChangeTimes->{3.797443926194411*^9, 3.798250950559822*^9, 
  3.7986857592475495`*^9, 3.798685808000309*^9, 
  3.799037626348784*^9},ExpressionUUID->"a225eca5-c18e-46bf-b617-\
211c9c8b7588"]
}, Open  ]],

Cell[TextData[{
 "To contract a pair of two distinct indices one can call the following \
version of ",
 StyleBox["Contract:",
  FontSlant->"Italic"]
}], "Text",
 CellChangeTimes->{{3.7974439492484436`*^9, 3.797443976763482*^9}, {
  3.797937795432889*^9, 
  3.797937795609158*^9}},ExpressionUUID->"053230b6-7339-4b10-8ecd-\
575c18a94cef"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Contract", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"p", "[", "1", "]"}], "[", "\[Mu]", "]"}], 
    RowBox[{"k", "[", "\[Nu]", "]"}]}], ",", " ", "\[Mu]", ",", "\[Nu]"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.797443984264493*^9, 
  3.797443989850501*^9}},ExpressionUUID->"2f013a70-a3c6-4c85-96e9-\
59ec7b8f87be"],

Cell[BoxData[
 RowBox[{"k", "\[CenterDot]", 
  SubscriptBox["p", "1"]}]], "Output",
 CellChangeTimes->{3.7974439902455015`*^9, 3.797937798341468*^9, 
  3.79825095194415*^9, 3.79868575925655*^9, 3.79868580800931*^9, 
  3.799037626384014*^9},ExpressionUUID->"e69da52f-7bb5-432f-a987-\
9914415f4b92"]
}, Open  ]],

Cell[TextData[{
 "Finally, option ",
 StyleBox["Dimension",
  FontSlant->"Italic"],
 " specifies spacetime dimension:"
}], "Text",
 CellChangeTimes->{{3.7982509743335123`*^9, 
  3.798250994478236*^9}},ExpressionUUID->"431e9a79-c7a0-4b66-be7d-\
2bb8f8ed3262"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Contract", "[", 
  RowBox[{
   RowBox[{"\[Delta]", "[", 
    RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}], ",", "\[Mu]", ",", "\[Nu]"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Contract", "[", 
  RowBox[{
   RowBox[{"\[Delta]", "[", 
    RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}], ",", "\[Mu]", ",", "\[Nu]", ",", 
   RowBox[{"Dimension", "\[Rule]", "4"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.7982510028313427`*^9, 3.7982510167259293`*^9}, {
   3.7985245803920794`*^9, 3.7985245882488947`*^9}, 
   3.7985306569271297`*^9},ExpressionUUID->"4c886d6f-0cb3-4a80-a4f6-\
1126972a3f9b"],

Cell[BoxData["d"], "Output",
 CellChangeTimes->{3.798251017071315*^9, 3.798524589269126*^9, 
  3.7985306574362*^9, 3.798685759268551*^9, 3.79868580801931*^9, 
  3.799037626421976*^9},ExpressionUUID->"63d78e31-95be-4182-b106-\
a27ed7229b60"],

Cell[BoxData["4"], "Output",
 CellChangeTimes->{3.798251017071315*^9, 3.798524589269126*^9, 
  3.7985306574362*^9, 3.798685759268551*^9, 3.79868580801931*^9, 
  3.7990376264239473`*^9},ExpressionUUID->"6ecc6fe6-7722-46bb-b872-\
5220a4296c79"]
}, Open  ]],

Cell[TextData[{
 "Any expression can be differentiated with respect to a given vector by \
using function ",
 StyleBox["Diff",
  FontSlant->"Italic"],
 ". To differentiate an expression with respect to ",
 StyleBox["k",
  FontSlant->"Italic"],
 "[\[Mu]] use the following:"
}], "Text",
 CellChangeTimes->{{3.7974440643516054`*^9, 3.797444152039729*^9}, {
  3.797937800361066*^9, 
  3.797937800615264*^9}},ExpressionUUID->"9cc0edd7-c632-46d8-b0f5-\
f47ead1bd19a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Diff", "[", 
  RowBox[{
   RowBox[{"k", "\[CenterDot]", 
    RowBox[{"p", "[", "1", "]"}]}], ",", "k", ",", "\[Mu]"}], "]"}]], "Input",
 CellChangeTimes->{{3.7974441389727106`*^9, 
  3.797444156215735*^9}},ExpressionUUID->"efa11422-383d-4ddc-bcc1-\
3b97b86b419b"],

Cell[BoxData[
 TemplateBox[{"p","1","\[Mu]"},
  "Subsuperscript"]], "Output",
 CellChangeTimes->{3.7974441565107355`*^9, 3.797937802812402*^9, 
  3.797937920485179*^9, 3.7982510248477783`*^9, 3.7985246313206577`*^9, 
  3.798530329637211*^9, 3.7985303979507732`*^9, 3.7985304863747253`*^9, 
  3.7986857592805514`*^9, 3.7986858080303106`*^9, 
  3.799037626460116*^9},ExpressionUUID->"cbae141c-e736-458f-8ff4-\
3a926a0e7511"]
}, Open  ]],

Cell[TextData[{
 "If a derivative with respect to ",
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["p", "1", "\[Mu]"], TraditionalForm]],ExpressionUUID->
  "cb0e871a-a209-482e-ae25-fccb534fa4ca"],
 StyleBox[" ",
  FontSlant->"Italic"],
 "or ",
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["p", "2", "\[Mu]"], TraditionalForm]],ExpressionUUID->
  "4e6d37b4-67d5-434d-a9fa-c33cb2040961"],
 " it is assumed that",
 StyleBox[" ",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubsuperscriptBox["p", "3", "\[Mu]"], "=", 
    RowBox[{
     RowBox[{"-", 
      SubsuperscriptBox["p", "1", "\[Mu]"]}], "-", 
     SubsuperscriptBox["p", "2", "\[Mu]"]}]}], TraditionalForm]],
  ExpressionUUID->"fe3d2068-b4c7-457b-88bf-ded2becec528"],
 ":"
}], "Text",
 CellChangeTimes->{{3.7974441655457506`*^9, 3.7974441992627983`*^9}, {
  3.797444232493845*^9, 3.79744424987687*^9}, {3.797444454822158*^9, 
  3.7974444877562046`*^9}, {3.797937804880941*^9, 
  3.797937805097074*^9}},ExpressionUUID->"62f695e2-32c0-4116-9fcd-\
64dd1bf8c459"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Diff", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"p", "[", "3", "]"}], "^", "2"}], 
    RowBox[{
     RowBox[{"p", "[", "3", "]"}], "[", "\[Mu]", "]"}]}], ",", " ", 
   RowBox[{"p", "[", "1", "]"}], ",", "\[Nu]"}], "]"}]], "Input",
 CellChangeTimes->{{3.7974444907062087`*^9, 3.7974445205962505`*^9}, {
  3.797938117564735*^9, 3.797938122346128*^9}, {3.7985246508849277`*^9, 
  3.798524658152813*^9}},ExpressionUUID->"df8f7d9d-b0e5-4166-bd19-\
c9e296dfc7f3"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", 
    SubsuperscriptBox["p", "3", "2"]}], " ", 
   SubscriptBox["\[Delta]", 
    RowBox[{"\[Mu]", ",", "\[Nu]"}]]}], "+", 
  RowBox[{"2", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      TemplateBox[{"p","1","\[Mu]"},
       "Subsuperscript"]}], "-", 
     TemplateBox[{"p","2","\[Mu]"},
      "Subsuperscript"]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     TemplateBox[{"p","1","\[Nu]"},
      "Subsuperscript"], "+", 
     TemplateBox[{"p","2","\[Nu]"},
      "Subsuperscript"]}], ")"}]}]}]], "Output",
 CellChangeTimes->{{3.797444515845244*^9, 3.7974445210962515`*^9}, 
   3.797937807367641*^9, 3.797937921983541*^9, 3.797938018681469*^9, 
   3.797938078258524*^9, {3.797938114695853*^9, 3.797938145313274*^9}, 
   3.7982510313636503`*^9, {3.798524632554282*^9, 3.798524658446271*^9}, 
   3.798525039976761*^9, 3.7985250958254213`*^9, 3.798530331792264*^9, 
   3.798530398986882*^9, 3.798530487208671*^9, 3.798685759291552*^9, 
   3.798685808040311*^9, 
   3.799037626493675*^9},ExpressionUUID->"cd7ca1cd-01ab-415e-978c-\
13a7f7c5f079"]
}, Open  ]],

Cell[TextData[{
 StyleBox["Diff",
  FontSlant->"Italic"],
 " and ",
 StyleBox["Contract",
  FontSlant->"Italic"],
 " tread over ",
 StyleBox["LoopIntegral",
  FontSlant->"Italic"],
 "s."
}], "Text",
 CellChangeTimes->{{3.7974446284684024`*^9, 
  3.7974446430994225`*^9}},ExpressionUUID->"f178ba43-15e5-45c5-bfb6-\
99a30c921eb2"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Reduction to multiple-K integrals", "Subsection",
 CellChangeTimes->{{3.7817885727924023`*^9, 
  3.781788584753702*^9}},ExpressionUUID->"0cf24d98-a44f-44d7-8079-\
bbdfc9ca3f6f"],

Cell[TextData[{
 "Loop integrals can be reduced to multiple-K integrals by ",
 StyleBox["LoopToK:",
  FontSlant->"Italic"]
}], "Text",
 CellChangeTimes->{{3.781788586361436*^9, 3.7817886036659737`*^9}, {
  3.797196392085759*^9, 3.797196427489809*^9}, {3.797938235161131*^9, 
  3.797938237681218*^9}},ExpressionUUID->"b293b4bf-df53-453e-874b-\
4ff2a9d80fc6"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"exp", "=", 
  RowBox[{
   RowBox[{"LoopIntegral", "[", 
    RowBox[{"d", ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "1", ",", "1"}], "}"}]}], "]"}], "[", 
   RowBox[{"1", ",", " ", "k"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.781712887654739*^9, 3.7817129113050814`*^9}, {
  3.797939064885973*^9, 3.797939092769745*^9}, {3.797939382452961*^9, 
  3.797939382978024*^9}},ExpressionUUID->"d73016d9-20ab-444c-8518-\
199c74a95ada"],

Cell[BoxData[
 TagBox[
  RowBox[{"\<\"\\!\\(\\*StyleBox[\\\"\[Integral]\\\",FontSize->18]\\)\"\>", 
   " ", 
   TagBox[
    FractionBox[
     RowBox[{
      SuperscriptBox["\<\"\[DifferentialD]\"\>", "d"], " ", "k"}], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"2", " ", "\[Pi]"}], ")"}], "d"]],
    HoldForm], " ", 
   TagBox[
    FractionBox["1", 
     RowBox[{
      SuperscriptBox["k", "2"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"k", "-", 
         SubscriptBox["p", "1"]}], ")"}], "2"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"k", "+", 
         SubscriptBox["p", "2"]}], ")"}], "2"]}]],
    HoldForm]}],
  HoldForm]], "Output",
 CellChangeTimes->{
  3.7817129130490875`*^9, 3.781713019420673*^9, 3.781713779304966*^9, {
   3.781715344327026*^9, 3.781715367217414*^9}, 3.781788608075409*^9, 
   3.79455556721495*^9, 3.794555608190811*^9, 3.797196415192792*^9, 
   3.797444909932108*^9, 3.79744495420817*^9, 3.7974455195929885`*^9, 
   3.797938238962219*^9, 3.797938313862163*^9, 3.797938346001845*^9, 
   3.7979384595577173`*^9, {3.797938498240282*^9, 3.7979385266282682`*^9}, 
   3.797938977339418*^9, {3.79793905012254*^9, 3.797939093112877*^9}, {
   3.797939357779067*^9, 3.797939383252781*^9}, 3.798251039093988*^9, 
   3.7986857593055525`*^9, 3.798685808050312*^9, 
   3.799037626530373*^9},ExpressionUUID->"5595b503-3176-41e0-83ea-\
924a4f98a9ac"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"int", "=", 
  RowBox[{"LoopToK", "[", "exp", "]"}]}]], "Input",
 CellChangeTimes->{{3.781712920530208*^9, 3.7817129285642266`*^9}, {
  3.797196430184813*^9, 3.7971964308708143`*^9}, {3.797938241609408*^9, 
  3.7979382424016123`*^9}},ExpressionUUID->"aa0a79f7-c8e0-4575-970b-\
dd210a15aad2"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["2", 
    RowBox[{"4", "-", 
     FractionBox[
      RowBox[{"3", " ", "d"}], "2"]}]], " ", 
   SuperscriptBox["\[Pi]", 
    RowBox[{
     RowBox[{"-", "d"}], "/", "2"}]], " ", 
   SubscriptBox["i", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      FractionBox["d", "2"]}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], "+", 
        FractionBox["d", "2"]}], ",", 
       RowBox[{
        RowBox[{"-", "2"}], "+", 
        FractionBox["d", "2"]}], ",", 
       RowBox[{
        RowBox[{"-", "2"}], "+", 
        FractionBox["d", "2"]}]}], "}"}]}]]}], 
  RowBox[{"Gamma", "[", 
   RowBox[{
    RowBox[{"-", "3"}], "+", "d"}], "]"}]]], "Output",
 CellChangeTimes->{
  3.781712928934227*^9, 3.781713019460673*^9, 3.7817137801599674`*^9, {
   3.781715344948028*^9, 3.7817153676984177`*^9}, 3.7817886095173492`*^9, 
   3.794555568276239*^9, 3.794555609028017*^9, {3.797196421669801*^9, 
   3.7971964317058153`*^9}, 3.7974449123021107`*^9, 3.797444955199171*^9, 
   3.79744552071799*^9, 3.797938242812314*^9, 3.797938314925375*^9, 
   3.797938346835451*^9, 3.797938460129053*^9, {3.7979384989147987`*^9, 
   3.797938527121779*^9}, 3.797938978003838*^9, {3.7979390507461233`*^9, 
   3.797939095674062*^9}, {3.79793935834509*^9, 3.797939384257575*^9}, 
   3.798251040011199*^9, 3.798685759324554*^9, 3.798685808075313*^9, 
   3.7990376265774097`*^9},ExpressionUUID->"149491a4-e844-4ff3-9414-\
d3009a4dae47"]
}, Open  ]],

Cell[TextData[{
 "Now these can we evaluated by means of ",
 StyleBox["KEvaluate",
  FontSlant->"Italic"],
 ". Equivalently ",
 StyleBox["LoopEvaluate",
  FontSlant->"Italic"],
 " evaluates a momentum integral in one go:"
}], "Text",
 CellChangeTimes->{{3.781788626225209*^9, 3.781788638793849*^9}, {
  3.7971964382718244`*^9, 3.7971964951419053`*^9}, {3.7979393602262993`*^9, 
  3.797939361578475*^9}},ExpressionUUID->"7bf55f78-37c4-4f70-a570-\
d1d86ce1dbfe"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"KEvaluate", "[", 
   RowBox[{"int", "/.", 
    RowBox[{"{", 
     RowBox[{"d", "\[Rule]", 
      RowBox[{"3", "-", 
       RowBox[{"2", "\[Epsilon]"}]}]}], "}"}]}], "]"}], "//", 
  "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"LoopEvaluate", "[", 
   RowBox[{"exp", "/.", 
    RowBox[{"{", 
     RowBox[{"d", "\[Rule]", 
      RowBox[{"3", "-", 
       RowBox[{"2", "\[Epsilon]"}]}]}], "}"}]}], "]"}], "//", 
  "Simplify"}]}], "Input",
 CellChangeTimes->{{3.7817129409124203`*^9, 3.781712990912261*^9}, {
  3.78171380620244*^9, 3.781713810522524*^9}, {3.7817153593722286`*^9, 
  3.78171536041923*^9}, {3.797196512382929*^9, 3.7971965345069604`*^9}, {
  3.797196590337039*^9, 
  3.7971965981350503`*^9}},ExpressionUUID->"4771dd85-bf54-400d-bcd1-\
6043455a673f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   FractionBox["1", 
    RowBox[{"8", " ", 
     SubscriptBox["p", "1"], " ", 
     SubscriptBox["p", "2"], " ", 
     SubscriptBox["p", "3"]}]], "+", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "EulerGamma"}], "+", 
       RowBox[{"Log", "[", "\[Pi]", "]"}], "+", 
       RowBox[{"4", " ", 
        RowBox[{"Log", "[", 
         RowBox[{
          SubscriptBox["p", "1"], "+", 
          SubscriptBox["p", "2"], "+", 
          SubscriptBox["p", "3"]}], "]"}]}]}], ")"}], " ", "\[Epsilon]"}], 
    RowBox[{"8", " ", 
     SubscriptBox["p", "1"], " ", 
     SubscriptBox["p", "2"], " ", 
     SubscriptBox["p", "3"]}]], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "\[Epsilon]", "]"}], "2"],
    SeriesData[TripleK`\[Epsilon], 0, {}, 0, 2, 1],
    Editable->False]}],
  SeriesData[
  TripleK`\[Epsilon], 0, {
   Rational[1, 8] TripleK`p[1]^(-1) TripleK`p[2]^(-1)/TripleK`p[3], 
    Rational[1, 8] (-EulerGamma + Log[Pi] + 
     4 Log[TripleK`p[1] + TripleK`p[2] + TripleK`p[3]]) TripleK`p[1]^(-1) 
    TripleK`p[2]^(-1)/TripleK`p[3]}, 0, 2, 1],
  Editable->False]], "Output",
 CellChangeTimes->{{3.781712944804537*^9, 3.781712991237262*^9}, 
   3.781713028821741*^9, {3.781713781658025*^9, 3.7817138112485247`*^9}, {
   3.7817153455180287`*^9, 3.7817153681424427`*^9}, 3.7817886497455273`*^9, 
   3.7945556284615088`*^9, {3.7971965173839364`*^9, 3.797196537557965*^9}, 
   3.797196598565051*^9, 3.7974456019991045`*^9, {3.797939363844327*^9, 
   3.797939386209597*^9}, 3.798251048902852*^9, 3.79868575960157*^9, 
   3.7986858081803193`*^9, 
   3.799037626909112*^9},ExpressionUUID->"057bc7ce-39c9-4b8f-a6d5-\
aa4a94f76323"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   FractionBox["1", 
    RowBox[{"8", " ", 
     SubscriptBox["p", "1"], " ", 
     SubscriptBox["p", "2"], " ", 
     SubscriptBox["p", "3"]}]], "+", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "EulerGamma"}], "+", 
       RowBox[{"Log", "[", "\[Pi]", "]"}], "+", 
       RowBox[{"4", " ", 
        RowBox[{"Log", "[", 
         RowBox[{
          SubscriptBox["p", "1"], "+", 
          SubscriptBox["p", "2"], "+", 
          SubscriptBox["p", "3"]}], "]"}]}]}], ")"}], " ", "\[Epsilon]"}], 
    RowBox[{"8", " ", 
     SubscriptBox["p", "1"], " ", 
     SubscriptBox["p", "2"], " ", 
     SubscriptBox["p", "3"]}]], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "\[Epsilon]", "]"}], "2"],
    SeriesData[TripleK`\[Epsilon], 0, {}, 0, 2, 1],
    Editable->False]}],
  SeriesData[
  TripleK`\[Epsilon], 0, {
   Rational[1, 8] TripleK`p[1]^(-1) TripleK`p[2]^(-1)/TripleK`p[3], 
    Rational[1, 8] (-EulerGamma + Log[Pi] + 
     4 Log[TripleK`p[1] + TripleK`p[2] + TripleK`p[3]]) TripleK`p[1]^(-1) 
    TripleK`p[2]^(-1)/TripleK`p[3]}, 0, 2, 1],
  Editable->False]], "Output",
 CellChangeTimes->{{3.781712944804537*^9, 3.781712991237262*^9}, 
   3.781713028821741*^9, {3.781713781658025*^9, 3.7817138112485247`*^9}, {
   3.7817153455180287`*^9, 3.7817153681424427`*^9}, 3.7817886497455273`*^9, 
   3.7945556284615088`*^9, {3.7971965173839364`*^9, 3.797196537557965*^9}, 
   3.797196598565051*^9, 3.7974456019991045`*^9, {3.797939363844327*^9, 
   3.797939386209597*^9}, 3.798251048902852*^9, 3.79868575960157*^9, 
   3.7986858081803193`*^9, 
   3.79903762692981*^9},ExpressionUUID->"c4baa201-e079-4739-85e0-\
8f1b9bb858b2"]
}, Open  ]],

Cell["\<\
Similarly, loop integrals with non-trivial numerators can be evaluated.\
\>", "Text",
 CellChangeTimes->{{3.797196645525117*^9, 
  3.797196672559155*^9}},ExpressionUUID->"795999c4-69b4-49b4-b53e-\
875782d69d68"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"LoopIntegral", "[", 
   RowBox[{
    RowBox[{"4", "-", 
     RowBox[{"2", "\[Epsilon]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"1", ",", "1", ",", "1"}], "}"}]}], "]"}], "[", 
  RowBox[{
   RowBox[{
    RowBox[{"k", "[", "\[Mu]", "]"}], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"k", "[", "\[Nu]", "]"}], "-", 
      RowBox[{
       RowBox[{"p", "[", "1", "]"}], "[", "\[Nu]", "]"}]}], ")"}]}], ",", 
   "k"}], "]"}]], "Input",
 CellChangeTimes->{{3.797196681191167*^9, 3.7971967096432076`*^9}, {
  3.797939411269285*^9, 
  3.797939411442069*^9}},ExpressionUUID->"84805282-6157-41b7-ad2d-\
252cbcb1f0a4"],

Cell[BoxData[
 TagBox[
  RowBox[{"\<\"\\!\\(\\*StyleBox[\\\"\[Integral]\\\",FontSize->18]\\)\"\>", 
   " ", 
   TagBox[
    FractionBox[
     RowBox[{
      SuperscriptBox["\<\"\[DifferentialD]\"\>", 
       RowBox[{"4", "-", 
        RowBox[{"2", " ", "\[Epsilon]"}]}]], " ", "k"}], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"2", " ", "\[Pi]"}], ")"}], 
      RowBox[{"4", "-", 
       RowBox[{"2", " ", "\[Epsilon]"}]}]]],
    HoldForm], " ", 
   TagBox[
    FractionBox[
     RowBox[{
      TemplateBox[{"k","\[Mu]"},
       "Superscript"], " ", 
      RowBox[{"(", 
       RowBox[{
        TemplateBox[{"k","\[Nu]"},
         "Superscript"], "-", 
        TemplateBox[{"p","1","\[Nu]"},
         "Subsuperscript"]}], ")"}]}], 
     RowBox[{
      SuperscriptBox["k", "2"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"k", "-", 
         SubscriptBox["p", "1"]}], ")"}], "2"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"k", "+", 
         SubscriptBox["p", "2"]}], ")"}], "2"]}]],
    HoldForm]}],
  HoldForm]], "Output",
 CellChangeTimes->{{3.797196702879198*^9, 3.797196721934225*^9}, 
   3.797445607795127*^9, {3.797939395816554*^9, 3.797939433221716*^9}, 
   3.7979396397956953`*^9, {3.7979396760894747`*^9, 3.797939693694087*^9}, 
   3.797939860772294*^9, {3.797939910216845*^9, 3.79793991436938*^9}, 
   3.7979399813769484`*^9, 3.797940043510231*^9, {3.798251052959659*^9, 
   3.7982510714564533`*^9}, 3.7986857596345716`*^9, 3.7986858082173214`*^9, 
   3.7990376269673347`*^9},ExpressionUUID->"64236c27-fa96-434d-b654-\
09559f84594d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"LoopEvaluate", "[", "%", "]"}]], "Input",
 CellChangeTimes->{{3.7971967160932164`*^9, 3.797196725140229*^9}, {
   3.797939984148567*^9, 3.797939992323243*^9}, {3.797940025463457*^9, 
   3.797940056714419*^9}, 
   3.798251070398942*^9},ExpressionUUID->"0f5df7ea-ff2b-46a2-be59-\
f7c3cfccf1d7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   FractionBox[
    SubscriptBox["\[Delta]", 
     RowBox[{"\[Mu]", ",", "\[Nu]"}]], 
    RowBox[{"64", " ", 
     SuperscriptBox["\[Pi]", "2"], " ", "\[Epsilon]"}]], "+", 
   RowBox[{"(", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         FractionBox["3", "2"], "-", "EulerGamma"}], ")"}], " ", 
       SubscriptBox["\[Delta]", 
        RowBox[{"\[Mu]", ",", "\[Nu]"}]]}], 
      RowBox[{"32", " ", 
       SuperscriptBox["\[Pi]", "2"]}]], "+", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{"2", "-", 
            RowBox[{"2", " ", "EulerGamma"}]}], ")"}], " ", 
          SubscriptBox["\[Delta]", 
           RowBox[{"\[Mu]", ",", "\[Nu]"}]]}], 
         RowBox[{"32", " ", 
          SuperscriptBox["\[Pi]", "2"]}]], "+", 
        FractionBox[
         RowBox[{
          RowBox[{"Log", "[", "\[Pi]", "]"}], " ", 
          SubscriptBox["\[Delta]", 
           RowBox[{"\[Mu]", ",", "\[Nu]"}]]}], 
         RowBox[{"32", " ", 
          SuperscriptBox["\[Pi]", "2"]}]], "+", 
        RowBox[{
         FractionBox["1", 
          SuperscriptBox["\[Pi]", "2"]], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            FractionBox["3", "32"], " ", 
            RowBox[{"Log", "[", "2", "]"}], " ", 
            SubscriptBox["\[Delta]", 
             RowBox[{"\[Mu]", ",", "\[Nu]"}]]}], "+", 
           RowBox[{
            FractionBox["1", "16"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SubscriptBox["\[Delta]", 
                RowBox[{"\[Mu]", ",", "\[Nu]"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "EulerGamma", "+", 
                 RowBox[{
                  FractionBox["1", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{"EulerGamma", "-", 
                    RowBox[{"Log", "[", "2", "]"}]}], ")"}]}], "+", 
                 FractionBox[
                  RowBox[{"2", " ", "NL", " ", 
                   SubsuperscriptBox["p", "1", "2"], " ", 
                   SubsuperscriptBox["p", "2", "2"], " ", 
                   SubsuperscriptBox["p", "3", "2"]}], 
                  SuperscriptBox["\[Lambda]", 
                   RowBox[{"3", "/", "2"}]]], "+", 
                 RowBox[{
                  FractionBox["1", 
                   RowBox[{"2", " ", "\[Lambda]"}]], 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"Log", "[", 
                    SubsuperscriptBox["p", "3", "2"], "]"}], " ", 
                    SubsuperscriptBox["p", "3", "2"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SubsuperscriptBox["p", "1", "2"], "+", 
                    SubsuperscriptBox["p", "2", "2"], "-", 
                    SubsuperscriptBox["p", "3", "2"]}], ")"}]}], "+", 
                    RowBox[{
                    RowBox[{"Log", "[", 
                    SubsuperscriptBox["p", "2", "2"], "]"}], " ", 
                    SubsuperscriptBox["p", "2", "2"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SubsuperscriptBox["p", "1", "2"], "-", 
                    SubsuperscriptBox["p", "2", "2"], "+", 
                    SubsuperscriptBox["p", "3", "2"]}], ")"}]}], "+", 
                    RowBox[{
                    RowBox[{"Log", "[", 
                    SubsuperscriptBox["p", "1", "2"], "]"}], " ", 
                    SubsuperscriptBox["p", "1", "2"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SubsuperscriptBox["p", "1", "2"]}], "+", 
                    SubsuperscriptBox["p", "2", "2"], "+", 
                    SubsuperscriptBox["p", "3", "2"]}], ")"}]}]}], ")"}]}]}], 
                ")"}]}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", 
                   SubscriptBox["p", "2"]}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"-", 
                    SubscriptBox["p", "2"]}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    FractionBox[
                    RowBox[{"3", " ", "NL", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "4"}], " ", 
                    SubsuperscriptBox["p", "1", "2"], " ", 
                    SubscriptBox["p", "2"]}], "+", 
                    RowBox[{"4", " ", 
                    SubsuperscriptBox["p", "2", "3"]}], "-", 
                    RowBox[{"4", " ", 
                    SubscriptBox["p", "2"], " ", 
                    SubsuperscriptBox["p", "3", "2"]}]}], ")"}], "2"]}], 
                    RowBox[{"8", " ", 
                    SuperscriptBox["\[Lambda]", 
                    RowBox[{"5", "/", "2"}]]}]], "-", 
                    RowBox[{
                    FractionBox["1", 
                    RowBox[{
                    SubscriptBox["p", "2"], " ", 
                    SuperscriptBox["\[Lambda]", "2"]}]], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "4"}], " ", 
                    SubsuperscriptBox["p", "1", "2"], " ", 
                    SubscriptBox["p", "2"]}], "+", 
                    RowBox[{"4", " ", 
                    SubsuperscriptBox["p", "2", "3"]}], "-", 
                    RowBox[{"4", " ", 
                    SubscriptBox["p", "2"], " ", 
                    SubsuperscriptBox["p", "3", "2"]}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Log", "[", 
                    SubsuperscriptBox["p", "2", "2"], "]"}], " ", 
                    SubsuperscriptBox["p", "2", "2"]}], "+", 
                    RowBox[{
                    FractionBox["1", "2"], " ", 
                    RowBox[{"Log", "[", 
                    SubsuperscriptBox["p", "3", "2"], "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SubsuperscriptBox["p", "1", "2"], "-", 
                    SubsuperscriptBox["p", "2", "2"], "-", 
                    SubsuperscriptBox["p", "3", "2"]}], ")"}]}], "+", 
                    RowBox[{
                    FractionBox["1", "2"], " ", 
                    RowBox[{"Log", "[", 
                    SubsuperscriptBox["p", "1", "2"], "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SubsuperscriptBox["p", "1", "2"]}], "-", 
                    SubsuperscriptBox["p", "2", "2"], "+", 
                    SubsuperscriptBox["p", "3", "2"]}], ")"}]}]}], ")"}]}]}], 
                    "-", 
                    FractionBox[
                    RowBox[{"NL", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "4"}], " ", 
                    SubsuperscriptBox["p", "1", "2"]}], "+", 
                    RowBox[{"12", " ", 
                    SubsuperscriptBox["p", "2", "2"]}], "-", 
                    RowBox[{"4", " ", 
                    SubsuperscriptBox["p", "3", "2"]}]}], ")"}]}], 
                    RowBox[{"4", " ", 
                    SuperscriptBox["\[Lambda]", 
                    RowBox[{"3", "/", "2"}]]}]], "+", 
                    RowBox[{
                    FractionBox["1", 
                    RowBox[{"2", " ", 
                    SqrtBox["\[Lambda]"]}]], 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{
                    FractionBox["1", 
                    RowBox[{
                    SubscriptBox["p", "2"], " ", 
                    SuperscriptBox["\[Lambda]", 
                    RowBox[{"3", "/", "2"}]]}]], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "4"}], " ", 
                    SubsuperscriptBox["p", "1", "2"], " ", 
                    SubscriptBox["p", "2"]}], "+", 
                    RowBox[{"4", " ", 
                    SubsuperscriptBox["p", "2", "3"]}], "-", 
                    RowBox[{"4", " ", 
                    SubscriptBox["p", "2"], " ", 
                    SubsuperscriptBox["p", "3", "2"]}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Log", "[", 
                    SubsuperscriptBox["p", "2", "2"], "]"}], " ", 
                    SubsuperscriptBox["p", "2", "2"]}], "+", 
                    RowBox[{
                    FractionBox["1", "2"], " ", 
                    RowBox[{"Log", "[", 
                    SubsuperscriptBox["p", "3", "2"], "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SubsuperscriptBox["p", "1", "2"], "-", 
                    SubsuperscriptBox["p", "2", "2"], "-", 
                    SubsuperscriptBox["p", "3", "2"]}], ")"}]}], "+", 
                    RowBox[{
                    FractionBox["1", "2"], " ", 
                    RowBox[{"Log", "[", 
                    SubsuperscriptBox["p", "1", "2"], "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SubsuperscriptBox["p", "1", "2"]}], "-", 
                    SubsuperscriptBox["p", "2", "2"], "+", 
                    SubsuperscriptBox["p", "3", "2"]}], ")"}]}]}], 
                    ")"}]}]}]}], "+", 
                    FractionBox[
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    SubscriptBox["p", "2"]}], "-", 
                    RowBox[{
                    RowBox[{"Log", "[", 
                    SubsuperscriptBox["p", "1", "2"], "]"}], " ", 
                    SubscriptBox["p", "2"]}], "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Log", "[", 
                    SubsuperscriptBox["p", "2", "2"], "]"}], " ", 
                    SubscriptBox["p", "2"]}], "-", 
                    RowBox[{
                    RowBox[{"Log", "[", 
                    SubsuperscriptBox["p", "3", "2"], "]"}], " ", 
                    SubscriptBox["p", "2"]}]}], ")"}]}], 
                    RowBox[{
                    SubscriptBox["p", "2"], " ", 
                    SqrtBox["\[Lambda]"]}]], "-", 
                    RowBox[{
                    FractionBox["1", 
                    RowBox[{
                    SubsuperscriptBox["p", "2", "2"], " ", 
                    SqrtBox["\[Lambda]"]}]], 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Log", "[", 
                    SubsuperscriptBox["p", "2", "2"], "]"}], " ", 
                    SubsuperscriptBox["p", "2", "2"]}], "+", 
                    RowBox[{
                    FractionBox["1", "2"], " ", 
                    RowBox[{"Log", "[", 
                    SubsuperscriptBox["p", "3", "2"], "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SubsuperscriptBox["p", "1", "2"], "-", 
                    SubsuperscriptBox["p", "2", "2"], "-", 
                    SubsuperscriptBox["p", "3", "2"]}], ")"}]}], "+", 
                    RowBox[{
                    FractionBox["1", "2"], " ", 
                    RowBox[{"Log", "[", 
                    SubsuperscriptBox["p", "1", "2"], "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SubsuperscriptBox["p", "1", "2"]}], "-", 
                    SubsuperscriptBox["p", "2", "2"], "+", 
                    SubsuperscriptBox["p", "3", "2"]}], ")"}]}]}], 
                    ")"}]}]}]}], ")"}]}]}], ")"}]}], "+", 
                    FractionBox[
                    RowBox[{"NL", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "4"}], " ", 
                    SubsuperscriptBox["p", "1", "2"], " ", 
                    SubscriptBox["p", "2"]}], "+", 
                    RowBox[{"4", " ", 
                    SubsuperscriptBox["p", "2", "3"]}], "-", 
                    RowBox[{"4", " ", 
                    SubscriptBox["p", "2"], " ", 
                    SubsuperscriptBox["p", "3", "2"]}]}], ")"}]}], 
                    RowBox[{"4", " ", 
                    SuperscriptBox["\[Lambda]", 
                    RowBox[{"3", "/", "2"}]]}]], "-", 
                    FractionBox[
                    RowBox[{
                    RowBox[{
                    RowBox[{"Log", "[", 
                    SubsuperscriptBox["p", "2", "2"], "]"}], " ", 
                    SubsuperscriptBox["p", "2", "2"]}], "+", 
                    RowBox[{
                    FractionBox["1", "2"], " ", 
                    RowBox[{"Log", "[", 
                    SubsuperscriptBox["p", "3", "2"], "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SubsuperscriptBox["p", "1", "2"], "-", 
                    SubsuperscriptBox["p", "2", "2"], "-", 
                    SubsuperscriptBox["p", "3", "2"]}], ")"}]}], "+", 
                    RowBox[{
                    FractionBox["1", "2"], " ", 
                    RowBox[{"Log", "[", 
                    SubsuperscriptBox["p", "1", "2"], "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SubsuperscriptBox["p", "1", "2"]}], "-", 
                    SubsuperscriptBox["p", "2", "2"], "+", 
                    SubsuperscriptBox["p", "3", "2"]}], ")"}]}]}], 
                    RowBox[{
                    SubscriptBox["p", "2"], " ", "\[Lambda]"}]]}], ")"}]}], 
                 "-", 
                 RowBox[{"2", " ", 
                  SubscriptBox["p", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox[
                    RowBox[{"NL", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "4"}], " ", 
                    SubsuperscriptBox["p", "1", "2"], " ", 
                    SubscriptBox["p", "2"]}], "+", 
                    RowBox[{"4", " ", 
                    SubsuperscriptBox["p", "2", "3"]}], "-", 
                    RowBox[{"4", " ", 
                    SubscriptBox["p", "2"], " ", 
                    SubsuperscriptBox["p", "3", "2"]}]}], ")"}]}], 
                    RowBox[{"4", " ", 
                    SuperscriptBox["\[Lambda]", 
                    RowBox[{"3", "/", "2"}]]}]]}], "+", 
                    FractionBox[
                    RowBox[{
                    RowBox[{
                    RowBox[{"Log", "[", 
                    SubsuperscriptBox["p", "2", "2"], "]"}], " ", 
                    SubsuperscriptBox["p", "2", "2"]}], "+", 
                    RowBox[{
                    FractionBox["1", "2"], " ", 
                    RowBox[{"Log", "[", 
                    SubsuperscriptBox["p", "3", "2"], "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SubsuperscriptBox["p", "1", "2"], "-", 
                    SubsuperscriptBox["p", "2", "2"], "-", 
                    SubsuperscriptBox["p", "3", "2"]}], ")"}]}], "+", 
                    RowBox[{
                    FractionBox["1", "2"], " ", 
                    RowBox[{"Log", "[", 
                    SubsuperscriptBox["p", "1", "2"], "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SubsuperscriptBox["p", "1", "2"]}], "-", 
                    SubsuperscriptBox["p", "2", "2"], "+", 
                    SubsuperscriptBox["p", "3", "2"]}], ")"}]}]}], 
                    RowBox[{
                    SubscriptBox["p", "2"], " ", "\[Lambda]"}]]}], ")"}]}]}], 
                ")"}], " ", 
               TemplateBox[{"p","1","\[Mu]"},
                "Subsuperscript"], " ", 
               TemplateBox[{"p","1","\[Nu]"},
                "Subsuperscript"]}], "+", 
              RowBox[{"4", " ", 
               SubscriptBox["p", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"NL", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "4"}], " ", 
                    SubsuperscriptBox["p", "1", "2"], " ", 
                    SubscriptBox["p", "2"]}], "+", 
                    RowBox[{"4", " ", 
                    SubsuperscriptBox["p", "2", "3"]}], "-", 
                    RowBox[{"4", " ", 
                    SubscriptBox["p", "2"], " ", 
                    SubsuperscriptBox["p", "3", "2"]}]}], ")"}]}], 
                   RowBox[{"4", " ", 
                    SuperscriptBox["\[Lambda]", 
                    RowBox[{"3", "/", "2"}]]}]]}], "+", 
                 FractionBox[
                  RowBox[{
                   RowBox[{
                    RowBox[{"Log", "[", 
                    SubsuperscriptBox["p", "2", "2"], "]"}], " ", 
                    SubsuperscriptBox["p", "2", "2"]}], "+", 
                   RowBox[{
                    FractionBox["1", "2"], " ", 
                    RowBox[{"Log", "[", 
                    SubsuperscriptBox["p", "3", "2"], "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SubsuperscriptBox["p", "1", "2"], "-", 
                    SubsuperscriptBox["p", "2", "2"], "-", 
                    SubsuperscriptBox["p", "3", "2"]}], ")"}]}], "+", 
                   RowBox[{
                    FractionBox["1", "2"], " ", 
                    RowBox[{"Log", "[", 
                    SubsuperscriptBox["p", "1", "2"], "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SubsuperscriptBox["p", "1", "2"]}], "-", 
                    SubsuperscriptBox["p", "2", "2"], "+", 
                    SubsuperscriptBox["p", "3", "2"]}], ")"}]}]}], 
                  RowBox[{
                   SubscriptBox["p", "2"], " ", "\[Lambda]"}]]}], ")"}], " ", 
               TemplateBox[{"p","1","\[Mu]"},
                "Subsuperscript"], " ", 
               TemplateBox[{"p","1","\[Nu]"},
                "Subsuperscript"]}], "-", 
              RowBox[{"4", " ", 
               SubscriptBox["p", "1"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"NL", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4", " ", 
                    SubsuperscriptBox["p", "1", "3"]}], "-", 
                    RowBox[{"4", " ", 
                    SubscriptBox["p", "1"], " ", 
                    SubsuperscriptBox["p", "2", "2"]}], "-", 
                    RowBox[{"4", " ", 
                    SubscriptBox["p", "1"], " ", 
                    SubsuperscriptBox["p", "3", "2"]}]}], ")"}]}], 
                   RowBox[{"4", " ", 
                    SuperscriptBox["\[Lambda]", 
                    RowBox[{"3", "/", "2"}]]}]]}], "+", 
                 FractionBox[
                  RowBox[{
                   RowBox[{
                    RowBox[{"Log", "[", 
                    SubsuperscriptBox["p", "1", "2"], "]"}], " ", 
                    SubsuperscriptBox["p", "1", "2"]}], "+", 
                   RowBox[{
                    FractionBox["1", "2"], " ", 
                    RowBox[{"Log", "[", 
                    SubsuperscriptBox["p", "3", "2"], "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SubsuperscriptBox["p", "1", "2"]}], "+", 
                    SubsuperscriptBox["p", "2", "2"], "-", 
                    SubsuperscriptBox["p", "3", "2"]}], ")"}]}], "+", 
                   RowBox[{
                    FractionBox["1", "2"], " ", 
                    RowBox[{"Log", "[", 
                    SubsuperscriptBox["p", "2", "2"], "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SubsuperscriptBox["p", "1", "2"]}], "-", 
                    SubsuperscriptBox["p", "2", "2"], "+", 
                    SubsuperscriptBox["p", "3", "2"]}], ")"}]}]}], 
                  RowBox[{
                   SubscriptBox["p", "1"], " ", "\[Lambda]"}]]}], ")"}], " ", 
               TemplateBox[{"p","1","\[Nu]"},
                "Subsuperscript"], " ", 
               TemplateBox[{"p","2","\[Mu]"},
                "Subsuperscript"]}], "-", 
              RowBox[{
               SubscriptBox["p", "1"], " ", 
               SubscriptBox["p", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 FractionBox[
                  RowBox[{"3", " ", "NL", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4", " ", 
                    SubsuperscriptBox["p", "1", "3"]}], "-", 
                    RowBox[{"4", " ", 
                    SubscriptBox["p", "1"], " ", 
                    SubsuperscriptBox["p", "2", "2"]}], "-", 
                    RowBox[{"4", " ", 
                    SubscriptBox["p", "1"], " ", 
                    SubsuperscriptBox["p", "3", "2"]}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "4"}], " ", 
                    SubsuperscriptBox["p", "1", "2"], " ", 
                    SubscriptBox["p", "2"]}], "+", 
                    RowBox[{"4", " ", 
                    SubsuperscriptBox["p", "2", "3"]}], "-", 
                    RowBox[{"4", " ", 
                    SubscriptBox["p", "2"], " ", 
                    SubsuperscriptBox["p", "3", "2"]}]}], ")"}]}], 
                  RowBox[{"8", " ", 
                   SuperscriptBox["\[Lambda]", 
                    RowBox[{"5", "/", "2"}]]}]], "-", 
                 RowBox[{
                  FractionBox["1", 
                   RowBox[{"2", " ", 
                    SubscriptBox["p", "2"], " ", 
                    SuperscriptBox["\[Lambda]", "2"]}]], 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4", " ", 
                    SubsuperscriptBox["p", "1", "3"]}], "-", 
                    RowBox[{"4", " ", 
                    SubscriptBox["p", "1"], " ", 
                    SubsuperscriptBox["p", "2", "2"]}], "-", 
                    RowBox[{"4", " ", 
                    SubscriptBox["p", "1"], " ", 
                    SubsuperscriptBox["p", "3", "2"]}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Log", "[", 
                    SubsuperscriptBox["p", "2", "2"], "]"}], " ", 
                    SubsuperscriptBox["p", "2", "2"]}], "+", 
                    RowBox[{
                    FractionBox["1", "2"], " ", 
                    RowBox[{"Log", "[", 
                    SubsuperscriptBox["p", "3", "2"], "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SubsuperscriptBox["p", "1", "2"], "-", 
                    SubsuperscriptBox["p", "2", "2"], "-", 
                    SubsuperscriptBox["p", "3", "2"]}], ")"}]}], "+", 
                    RowBox[{
                    FractionBox["1", "2"], " ", 
                    RowBox[{"Log", "[", 
                    SubsuperscriptBox["p", "1", "2"], "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SubsuperscriptBox["p", "1", "2"]}], "-", 
                    SubsuperscriptBox["p", "2", "2"], "+", 
                    SubsuperscriptBox["p", "3", "2"]}], ")"}]}]}], ")"}]}]}], 
                 "-", 
                 RowBox[{
                  FractionBox["1", 
                   RowBox[{"2", " ", 
                    SubscriptBox["p", "1"], " ", 
                    SuperscriptBox["\[Lambda]", "2"]}]], 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "4"}], " ", 
                    SubsuperscriptBox["p", "1", "2"], " ", 
                    SubscriptBox["p", "2"]}], "+", 
                    RowBox[{"4", " ", 
                    SubsuperscriptBox["p", "2", "3"]}], "-", 
                    RowBox[{"4", " ", 
                    SubscriptBox["p", "2"], " ", 
                    SubsuperscriptBox["p", "3", "2"]}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Log", "[", 
                    SubsuperscriptBox["p", "1", "2"], "]"}], " ", 
                    SubsuperscriptBox["p", "1", "2"]}], "+", 
                    RowBox[{
                    FractionBox["1", "2"], " ", 
                    RowBox[{"Log", "[", 
                    SubsuperscriptBox["p", "3", "2"], "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SubsuperscriptBox["p", "1", "2"]}], "+", 
                    SubsuperscriptBox["p", "2", "2"], "-", 
                    SubsuperscriptBox["p", "3", "2"]}], ")"}]}], "+", 
                    RowBox[{
                    FractionBox["1", "2"], " ", 
                    RowBox[{"Log", "[", 
                    SubsuperscriptBox["p", "2", "2"], "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SubsuperscriptBox["p", "1", "2"]}], "-", 
                    SubsuperscriptBox["p", "2", "2"], "+", 
                    SubsuperscriptBox["p", "3", "2"]}], ")"}]}]}], ")"}]}]}], 
                 "+", 
                 FractionBox[
                  RowBox[{"2", " ", "NL", " ", 
                   SubscriptBox["p", "1"], " ", 
                   SubscriptBox["p", "2"]}], 
                  SuperscriptBox["\[Lambda]", 
                   RowBox[{"3", "/", "2"}]]], "+", 
                 RowBox[{
                  FractionBox["1", 
                   RowBox[{"2", " ", 
                    SqrtBox["\[Lambda]"]}]], 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    RowBox[{
                    FractionBox["1", 
                    RowBox[{
                    SubscriptBox["p", "1"], " ", 
                    SuperscriptBox["\[Lambda]", 
                    RowBox[{"3", "/", "2"}]]}]], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "4"}], " ", 
                    SubsuperscriptBox["p", "1", "2"], " ", 
                    SubscriptBox["p", "2"]}], "+", 
                    RowBox[{"4", " ", 
                    SubsuperscriptBox["p", "2", "3"]}], "-", 
                    RowBox[{"4", " ", 
                    SubscriptBox["p", "2"], " ", 
                    SubsuperscriptBox["p", "3", "2"]}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Log", "[", 
                    SubsuperscriptBox["p", "1", "2"], "]"}], " ", 
                    SubsuperscriptBox["p", "1", "2"]}], "+", 
                    RowBox[{
                    FractionBox["1", "2"], " ", 
                    RowBox[{"Log", "[", 
                    SubsuperscriptBox["p", "3", "2"], "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SubsuperscriptBox["p", "1", "2"]}], "+", 
                    SubsuperscriptBox["p", "2", "2"], "-", 
                    SubsuperscriptBox["p", "3", "2"]}], ")"}]}], "+", 
                    RowBox[{
                    FractionBox["1", "2"], " ", 
                    RowBox[{"Log", "[", 
                    SubsuperscriptBox["p", "2", "2"], "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SubsuperscriptBox["p", "1", "2"]}], "-", 
                    SubsuperscriptBox["p", "2", "2"], "+", 
                    SubsuperscriptBox["p", "3", "2"]}], ")"}]}]}], 
                    ")"}]}]}]}], "+", 
                    FractionBox[
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"Log", "[", 
                    SubsuperscriptBox["p", "2", "2"], "]"}]}], " ", 
                    SubscriptBox["p", "2"]}], "+", 
                    RowBox[{
                    RowBox[{"Log", "[", 
                    SubsuperscriptBox["p", "3", "2"], "]"}], " ", 
                    SubscriptBox["p", "2"]}], "+", 
                    FractionBox[
                    RowBox[{
                    RowBox[{"-", 
                    SubsuperscriptBox["p", "1", "2"]}], "-", 
                    SubsuperscriptBox["p", "2", "2"], "+", 
                    SubsuperscriptBox["p", "3", "2"]}], 
                    SubscriptBox["p", "2"]]}], ")"}]}], 
                    RowBox[{
                    SubscriptBox["p", "1"], " ", 
                    SqrtBox["\[Lambda]"]}]]}], ")"}]}]}], ")"}], " ", 
               TemplateBox[{"p","1","\[Nu]"},
                "Subsuperscript"], " ", 
               TemplateBox[{"p","2","\[Mu]"},
                "Subsuperscript"]}], "-", 
              RowBox[{
               SubscriptBox["p", "1"], " ", 
               SubscriptBox["p", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 FractionBox[
                  RowBox[{"3", " ", "NL", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4", " ", 
                    SubsuperscriptBox["p", "1", "3"]}], "-", 
                    RowBox[{"4", " ", 
                    SubscriptBox["p", "1"], " ", 
                    SubsuperscriptBox["p", "2", "2"]}], "-", 
                    RowBox[{"4", " ", 
                    SubscriptBox["p", "1"], " ", 
                    SubsuperscriptBox["p", "3", "2"]}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "4"}], " ", 
                    SubsuperscriptBox["p", "1", "2"], " ", 
                    SubscriptBox["p", "2"]}], "+", 
                    RowBox[{"4", " ", 
                    SubsuperscriptBox["p", "2", "3"]}], "-", 
                    RowBox[{"4", " ", 
                    SubscriptBox["p", "2"], " ", 
                    SubsuperscriptBox["p", "3", "2"]}]}], ")"}]}], 
                  RowBox[{"8", " ", 
                   SuperscriptBox["\[Lambda]", 
                    RowBox[{"5", "/", "2"}]]}]], "-", 
                 RowBox[{
                  FractionBox["1", 
                   RowBox[{"2", " ", 
                    SubscriptBox["p", "2"], " ", 
                    SuperscriptBox["\[Lambda]", "2"]}]], 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4", " ", 
                    SubsuperscriptBox["p", "1", "3"]}], "-", 
                    RowBox[{"4", " ", 
                    SubscriptBox["p", "1"], " ", 
                    SubsuperscriptBox["p", "2", "2"]}], "-", 
                    RowBox[{"4", " ", 
                    SubscriptBox["p", "1"], " ", 
                    SubsuperscriptBox["p", "3", "2"]}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Log", "[", 
                    SubsuperscriptBox["p", "2", "2"], "]"}], " ", 
                    SubsuperscriptBox["p", "2", "2"]}], "+", 
                    RowBox[{
                    FractionBox["1", "2"], " ", 
                    RowBox[{"Log", "[", 
                    SubsuperscriptBox["p", "3", "2"], "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SubsuperscriptBox["p", "1", "2"], "-", 
                    SubsuperscriptBox["p", "2", "2"], "-", 
                    SubsuperscriptBox["p", "3", "2"]}], ")"}]}], "+", 
                    RowBox[{
                    FractionBox["1", "2"], " ", 
                    RowBox[{"Log", "[", 
                    SubsuperscriptBox["p", "1", "2"], "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SubsuperscriptBox["p", "1", "2"]}], "-", 
                    SubsuperscriptBox["p", "2", "2"], "+", 
                    SubsuperscriptBox["p", "3", "2"]}], ")"}]}]}], ")"}]}]}], 
                 "-", 
                 RowBox[{
                  FractionBox["1", 
                   RowBox[{"2", " ", 
                    SubscriptBox["p", "1"], " ", 
                    SuperscriptBox["\[Lambda]", "2"]}]], 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "4"}], " ", 
                    SubsuperscriptBox["p", "1", "2"], " ", 
                    SubscriptBox["p", "2"]}], "+", 
                    RowBox[{"4", " ", 
                    SubsuperscriptBox["p", "2", "3"]}], "-", 
                    RowBox[{"4", " ", 
                    SubscriptBox["p", "2"], " ", 
                    SubsuperscriptBox["p", "3", "2"]}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Log", "[", 
                    SubsuperscriptBox["p", "1", "2"], "]"}], " ", 
                    SubsuperscriptBox["p", "1", "2"]}], "+", 
                    RowBox[{
                    FractionBox["1", "2"], " ", 
                    RowBox[{"Log", "[", 
                    SubsuperscriptBox["p", "3", "2"], "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SubsuperscriptBox["p", "1", "2"]}], "+", 
                    SubsuperscriptBox["p", "2", "2"], "-", 
                    SubsuperscriptBox["p", "3", "2"]}], ")"}]}], "+", 
                    RowBox[{
                    FractionBox["1", "2"], " ", 
                    RowBox[{"Log", "[", 
                    SubsuperscriptBox["p", "2", "2"], "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SubsuperscriptBox["p", "1", "2"]}], "-", 
                    SubsuperscriptBox["p", "2", "2"], "+", 
                    SubsuperscriptBox["p", "3", "2"]}], ")"}]}]}], ")"}]}]}], 
                 "+", 
                 FractionBox[
                  RowBox[{"2", " ", "NL", " ", 
                   SubscriptBox["p", "1"], " ", 
                   SubscriptBox["p", "2"]}], 
                  SuperscriptBox["\[Lambda]", 
                   RowBox[{"3", "/", "2"}]]], "+", 
                 RowBox[{
                  FractionBox["1", 
                   RowBox[{"2", " ", 
                    SqrtBox["\[Lambda]"]}]], 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    RowBox[{
                    FractionBox["1", 
                    RowBox[{
                    SubscriptBox["p", "1"], " ", 
                    SuperscriptBox["\[Lambda]", 
                    RowBox[{"3", "/", "2"}]]}]], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "4"}], " ", 
                    SubsuperscriptBox["p", "1", "2"], " ", 
                    SubscriptBox["p", "2"]}], "+", 
                    RowBox[{"4", " ", 
                    SubsuperscriptBox["p", "2", "3"]}], "-", 
                    RowBox[{"4", " ", 
                    SubscriptBox["p", "2"], " ", 
                    SubsuperscriptBox["p", "3", "2"]}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Log", "[", 
                    SubsuperscriptBox["p", "1", "2"], "]"}], " ", 
                    SubsuperscriptBox["p", "1", "2"]}], "+", 
                    RowBox[{
                    FractionBox["1", "2"], " ", 
                    RowBox[{"Log", "[", 
                    SubsuperscriptBox["p", "3", "2"], "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SubsuperscriptBox["p", "1", "2"]}], "+", 
                    SubsuperscriptBox["p", "2", "2"], "-", 
                    SubsuperscriptBox["p", "3", "2"]}], ")"}]}], "+", 
                    RowBox[{
                    FractionBox["1", "2"], " ", 
                    RowBox[{"Log", "[", 
                    SubsuperscriptBox["p", "2", "2"], "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SubsuperscriptBox["p", "1", "2"]}], "-", 
                    SubsuperscriptBox["p", "2", "2"], "+", 
                    SubsuperscriptBox["p", "3", "2"]}], ")"}]}]}], 
                    ")"}]}]}]}], "+", 
                    FractionBox[
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"Log", "[", 
                    SubsuperscriptBox["p", "2", "2"], "]"}]}], " ", 
                    SubscriptBox["p", "2"]}], "+", 
                    RowBox[{
                    RowBox[{"Log", "[", 
                    SubsuperscriptBox["p", "3", "2"], "]"}], " ", 
                    SubscriptBox["p", "2"]}], "+", 
                    FractionBox[
                    RowBox[{
                    RowBox[{"-", 
                    SubsuperscriptBox["p", "1", "2"]}], "-", 
                    SubsuperscriptBox["p", "2", "2"], "+", 
                    SubsuperscriptBox["p", "3", "2"]}], 
                    SubscriptBox["p", "2"]]}], ")"}]}], 
                    RowBox[{
                    SubscriptBox["p", "1"], " ", 
                    SqrtBox["\[Lambda]"]}]]}], ")"}]}]}], ")"}], " ", 
               TemplateBox[{"p","1","\[Mu]"},
                "Subsuperscript"], " ", 
               TemplateBox[{"p","2","\[Nu]"},
                "Subsuperscript"]}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", 
                   SubscriptBox["p", "1"]}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"-", 
                    SubscriptBox["p", "1"]}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    FractionBox[
                    RowBox[{"3", " ", "NL", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4", " ", 
                    SubsuperscriptBox["p", "1", "3"]}], "-", 
                    RowBox[{"4", " ", 
                    SubscriptBox["p", "1"], " ", 
                    SubsuperscriptBox["p", "2", "2"]}], "-", 
                    RowBox[{"4", " ", 
                    SubscriptBox["p", "1"], " ", 
                    SubsuperscriptBox["p", "3", "2"]}]}], ")"}], "2"]}], 
                    RowBox[{"8", " ", 
                    SuperscriptBox["\[Lambda]", 
                    RowBox[{"5", "/", "2"}]]}]], "-", 
                    RowBox[{
                    FractionBox["1", 
                    RowBox[{
                    SubscriptBox["p", "1"], " ", 
                    SuperscriptBox["\[Lambda]", "2"]}]], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4", " ", 
                    SubsuperscriptBox["p", "1", "3"]}], "-", 
                    RowBox[{"4", " ", 
                    SubscriptBox["p", "1"], " ", 
                    SubsuperscriptBox["p", "2", "2"]}], "-", 
                    RowBox[{"4", " ", 
                    SubscriptBox["p", "1"], " ", 
                    SubsuperscriptBox["p", "3", "2"]}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Log", "[", 
                    SubsuperscriptBox["p", "1", "2"], "]"}], " ", 
                    SubsuperscriptBox["p", "1", "2"]}], "+", 
                    RowBox[{
                    FractionBox["1", "2"], " ", 
                    RowBox[{"Log", "[", 
                    SubsuperscriptBox["p", "3", "2"], "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SubsuperscriptBox["p", "1", "2"]}], "+", 
                    SubsuperscriptBox["p", "2", "2"], "-", 
                    SubsuperscriptBox["p", "3", "2"]}], ")"}]}], "+", 
                    RowBox[{
                    FractionBox["1", "2"], " ", 
                    RowBox[{"Log", "[", 
                    SubsuperscriptBox["p", "2", "2"], "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SubsuperscriptBox["p", "1", "2"]}], "-", 
                    SubsuperscriptBox["p", "2", "2"], "+", 
                    SubsuperscriptBox["p", "3", "2"]}], ")"}]}]}], ")"}]}]}], 
                    "-", 
                    FractionBox[
                    RowBox[{"NL", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"12", " ", 
                    SubsuperscriptBox["p", "1", "2"]}], "-", 
                    RowBox[{"4", " ", 
                    SubsuperscriptBox["p", "2", "2"]}], "-", 
                    RowBox[{"4", " ", 
                    SubsuperscriptBox["p", "3", "2"]}]}], ")"}]}], 
                    RowBox[{"4", " ", 
                    SuperscriptBox["\[Lambda]", 
                    RowBox[{"3", "/", "2"}]]}]], "+", 
                    RowBox[{
                    FractionBox["1", 
                    RowBox[{"2", " ", 
                    SqrtBox["\[Lambda]"]}]], 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{
                    FractionBox["1", 
                    RowBox[{
                    SubscriptBox["p", "1"], " ", 
                    SuperscriptBox["\[Lambda]", 
                    RowBox[{"3", "/", "2"}]]}]], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4", " ", 
                    SubsuperscriptBox["p", "1", "3"]}], "-", 
                    RowBox[{"4", " ", 
                    SubscriptBox["p", "1"], " ", 
                    SubsuperscriptBox["p", "2", "2"]}], "-", 
                    RowBox[{"4", " ", 
                    SubscriptBox["p", "1"], " ", 
                    SubsuperscriptBox["p", "3", "2"]}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Log", "[", 
                    SubsuperscriptBox["p", "1", "2"], "]"}], " ", 
                    SubsuperscriptBox["p", "1", "2"]}], "+", 
                    RowBox[{
                    FractionBox["1", "2"], " ", 
                    RowBox[{"Log", "[", 
                    SubsuperscriptBox["p", "3", "2"], "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SubsuperscriptBox["p", "1", "2"]}], "+", 
                    SubsuperscriptBox["p", "2", "2"], "-", 
                    SubsuperscriptBox["p", "3", "2"]}], ")"}]}], "+", 
                    RowBox[{
                    FractionBox["1", "2"], " ", 
                    RowBox[{"Log", "[", 
                    SubsuperscriptBox["p", "2", "2"], "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SubsuperscriptBox["p", "1", "2"]}], "-", 
                    SubsuperscriptBox["p", "2", "2"], "+", 
                    SubsuperscriptBox["p", "3", "2"]}], ")"}]}]}], 
                    ")"}]}]}]}], "+", 
                    FractionBox[
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    SubscriptBox["p", "1"]}], "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Log", "[", 
                    SubsuperscriptBox["p", "1", "2"], "]"}], " ", 
                    SubscriptBox["p", "1"]}], "-", 
                    RowBox[{
                    RowBox[{"Log", "[", 
                    SubsuperscriptBox["p", "2", "2"], "]"}], " ", 
                    SubscriptBox["p", "1"]}], "-", 
                    RowBox[{
                    RowBox[{"Log", "[", 
                    SubsuperscriptBox["p", "3", "2"], "]"}], " ", 
                    SubscriptBox["p", "1"]}]}], ")"}]}], 
                    RowBox[{
                    SubscriptBox["p", "1"], " ", 
                    SqrtBox["\[Lambda]"]}]], "-", 
                    RowBox[{
                    FractionBox["1", 
                    RowBox[{
                    SubsuperscriptBox["p", "1", "2"], " ", 
                    SqrtBox["\[Lambda]"]}]], 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Log", "[", 
                    SubsuperscriptBox["p", "1", "2"], "]"}], " ", 
                    SubsuperscriptBox["p", "1", "2"]}], "+", 
                    RowBox[{
                    FractionBox["1", "2"], " ", 
                    RowBox[{"Log", "[", 
                    SubsuperscriptBox["p", "3", "2"], "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SubsuperscriptBox["p", "1", "2"]}], "+", 
                    SubsuperscriptBox["p", "2", "2"], "-", 
                    SubsuperscriptBox["p", "3", "2"]}], ")"}]}], "+", 
                    RowBox[{
                    FractionBox["1", "2"], " ", 
                    RowBox[{"Log", "[", 
                    SubsuperscriptBox["p", "2", "2"], "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SubsuperscriptBox["p", "1", "2"]}], "-", 
                    SubsuperscriptBox["p", "2", "2"], "+", 
                    SubsuperscriptBox["p", "3", "2"]}], ")"}]}]}], 
                    ")"}]}]}]}], ")"}]}]}], ")"}]}], "+", 
                    FractionBox[
                    RowBox[{"NL", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4", " ", 
                    SubsuperscriptBox["p", "1", "3"]}], "-", 
                    RowBox[{"4", " ", 
                    SubscriptBox["p", "1"], " ", 
                    SubsuperscriptBox["p", "2", "2"]}], "-", 
                    RowBox[{"4", " ", 
                    SubscriptBox["p", "1"], " ", 
                    SubsuperscriptBox["p", "3", "2"]}]}], ")"}]}], 
                    RowBox[{"4", " ", 
                    SuperscriptBox["\[Lambda]", 
                    RowBox[{"3", "/", "2"}]]}]], "-", 
                    FractionBox[
                    RowBox[{
                    RowBox[{
                    RowBox[{"Log", "[", 
                    SubsuperscriptBox["p", "1", "2"], "]"}], " ", 
                    SubsuperscriptBox["p", "1", "2"]}], "+", 
                    RowBox[{
                    FractionBox["1", "2"], " ", 
                    RowBox[{"Log", "[", 
                    SubsuperscriptBox["p", "3", "2"], "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SubsuperscriptBox["p", "1", "2"]}], "+", 
                    SubsuperscriptBox["p", "2", "2"], "-", 
                    SubsuperscriptBox["p", "3", "2"]}], ")"}]}], "+", 
                    RowBox[{
                    FractionBox["1", "2"], " ", 
                    RowBox[{"Log", "[", 
                    SubsuperscriptBox["p", "2", "2"], "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SubsuperscriptBox["p", "1", "2"]}], "-", 
                    SubsuperscriptBox["p", "2", "2"], "+", 
                    SubsuperscriptBox["p", "3", "2"]}], ")"}]}]}], 
                    RowBox[{
                    SubscriptBox["p", "1"], " ", "\[Lambda]"}]]}], ")"}]}], 
                 "-", 
                 RowBox[{"2", " ", 
                  SubscriptBox["p", "1"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox[
                    RowBox[{"NL", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4", " ", 
                    SubsuperscriptBox["p", "1", "3"]}], "-", 
                    RowBox[{"4", " ", 
                    SubscriptBox["p", "1"], " ", 
                    SubsuperscriptBox["p", "2", "2"]}], "-", 
                    RowBox[{"4", " ", 
                    SubscriptBox["p", "1"], " ", 
                    SubsuperscriptBox["p", "3", "2"]}]}], ")"}]}], 
                    RowBox[{"4", " ", 
                    SuperscriptBox["\[Lambda]", 
                    RowBox[{"3", "/", "2"}]]}]]}], "+", 
                    FractionBox[
                    RowBox[{
                    RowBox[{
                    RowBox[{"Log", "[", 
                    SubsuperscriptBox["p", "1", "2"], "]"}], " ", 
                    SubsuperscriptBox["p", "1", "2"]}], "+", 
                    RowBox[{
                    FractionBox["1", "2"], " ", 
                    RowBox[{"Log", "[", 
                    SubsuperscriptBox["p", "3", "2"], "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SubsuperscriptBox["p", "1", "2"]}], "+", 
                    SubsuperscriptBox["p", "2", "2"], "-", 
                    SubsuperscriptBox["p", "3", "2"]}], ")"}]}], "+", 
                    RowBox[{
                    FractionBox["1", "2"], " ", 
                    RowBox[{"Log", "[", 
                    SubsuperscriptBox["p", "2", "2"], "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SubsuperscriptBox["p", "1", "2"]}], "-", 
                    SubsuperscriptBox["p", "2", "2"], "+", 
                    SubsuperscriptBox["p", "3", "2"]}], ")"}]}]}], 
                    RowBox[{
                    SubscriptBox["p", "1"], " ", "\[Lambda]"}]]}], ")"}]}]}], 
                ")"}], " ", 
               TemplateBox[{"p","2","\[Mu]"},
                "Subsuperscript"], " ", 
               TemplateBox[{"p","2","\[Nu]"},
                "Subsuperscript"]}]}], ")"}]}]}], ")"}]}]}], ")"}]}]}], ")"}],
    "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "\[Epsilon]", "]"}], "1"],
    SeriesData[TripleK`\[Epsilon], 0, {}, -1, 1, 1],
    Editable->False]}],
  SeriesData[
  TripleK`\[Epsilon], 0, {
   Rational[1, 64] Pi^(-2) 
    TripleK`\[Delta][$CellContext`\[Mu], $CellContext`\[Nu]], 
    Rational[1, 32] (Rational[3, 2] - EulerGamma) Pi^(-2) 
     TripleK`\[Delta][$CellContext`\[Mu], $CellContext`\[Nu]] + 
    Rational[1, 2] (
      Rational[1, 32] (2 - 2 EulerGamma) Pi^(-2) 
       TripleK`\[Delta][$CellContext`\[Mu], $CellContext`\[Nu]] + 
      Rational[1, 32] Pi^(-2) Log[Pi] 
       TripleK`\[Delta][$CellContext`\[Mu], $CellContext`\[Nu]] + 
      Pi^(-2) (Rational[3, 32] Log[2] 
         TripleK`\[Delta][$CellContext`\[Mu], $CellContext`\[Nu]] + 
        Rational[1, 16] (
          TripleK`\[Delta][$CellContext`\[Mu], $CellContext`\[Nu]] (-1 + 
            EulerGamma + Rational[1, 2] (EulerGamma - Log[2]) + 2 TripleK`NL[
               TripleK`p[1], 
               TripleK`p[2], 
               TripleK`p[3]] TripleK`p[1]^2 TripleK`p[2]^2 TripleK`p[3]^2 
             TripleK`\[Lambda][
                TripleK`p[1], 
                TripleK`p[2], 
                TripleK`p[3]]^Rational[-3, 2] + 
            Rational[1, 2] (
              Log[TripleK`p[3]^2] 
               TripleK`p[3]^2 (TripleK`p[1]^2 + TripleK`p[2]^2 - 
                TripleK`p[3]^2) + 
              Log[TripleK`p[2]^2] 
               TripleK`p[2]^2 (TripleK`p[1]^2 - TripleK`p[2]^2 + 
                TripleK`p[3]^2) + 
              Log[TripleK`p[1]^2] 
               TripleK`p[1]^2 (-TripleK`p[1]^2 + TripleK`p[2]^2 + 
                TripleK`p[3]^2))/TripleK`\[Lambda][
              TripleK`p[1], 
              TripleK`p[2], 
              TripleK`p[3]]) + (-
             TripleK`p[2] (-TripleK`p[2] (Rational[3, 8] TripleK`NL[
                   TripleK`p[1], 
                   TripleK`p[2], 
                   TripleK`p[3]] ((-4) TripleK`p[1]^2 TripleK`p[2] + 
                   4 TripleK`p[2]^3 - 4 TripleK`p[2] TripleK`p[3]^2)^2 
                 TripleK`\[Lambda][
                    TripleK`p[1], 
                    TripleK`p[2], 
                    TripleK`p[3]]^Rational[-5, 2] - 
                TripleK`p[2]^(-1) ((-4) TripleK`p[1]^2 TripleK`p[2] + 
                 4 TripleK`p[2]^3 - 4 TripleK`p[2] TripleK`p[3]^2) (
                 Log[TripleK`p[2]^2] TripleK`p[2]^2 + 
                 Rational[1, 2] 
                  Log[TripleK`p[3]^2] (TripleK`p[1]^2 - TripleK`p[2]^2 - 
                   TripleK`p[3]^2) + 
                 Rational[1, 2] 
                  Log[TripleK`p[1]^2] (-TripleK`p[1]^2 - TripleK`p[2]^2 + 
                   TripleK`p[3]^2)) TripleK`\[Lambda][
                   TripleK`p[1], 
                   TripleK`p[2], 
                   TripleK`p[3]]^(-2) + Rational[-1, 4] TripleK`NL[
                   TripleK`p[1], 
                   TripleK`p[2], 
                   TripleK`p[3]] ((-4) TripleK`p[1]^2 + 12 TripleK`p[2]^2 - 4 
                  TripleK`p[3]^2) TripleK`\[Lambda][
                    TripleK`p[1], 
                    TripleK`p[2], 
                    TripleK`p[3]]^Rational[-3, 2] + 
                Rational[
                  1, 2] (-
                   TripleK`p[2]^(-1) ((-4) TripleK`p[1]^2 TripleK`p[2] + 
                    4 TripleK`p[2]^3 - 4 TripleK`p[2] TripleK`p[3]^2) (
                    Log[TripleK`p[2]^2] TripleK`p[2]^2 + 
                    Rational[1, 2] 
                    Log[TripleK`p[3]^2] (TripleK`p[1]^2 - TripleK`p[2]^2 - 
                    TripleK`p[3]^2) + 
                    Rational[1, 2] 
                    Log[TripleK`p[1]^2] (-TripleK`p[1]^2 - TripleK`p[2]^2 + 
                    TripleK`p[3]^2)) TripleK`\[Lambda][
                    TripleK`p[1], 
                    TripleK`p[2], 
                    TripleK`p[3]]^Rational[-3, 2] + 
                  2 TripleK`p[2]^(-1) (2 TripleK`p[2] - Log[TripleK`p[1]^2] 
                    TripleK`p[2] + 2 Log[TripleK`p[2]^2] TripleK`p[2] - 
                    Log[TripleK`p[3]^2] TripleK`p[2]) TripleK`\[Lambda][
                    TripleK`p[1], 
                    TripleK`p[2], 
                    TripleK`p[3]]^Rational[-1, 2] - 2 
                  TripleK`p[2]^(-2) (Log[TripleK`p[2]^2] TripleK`p[2]^2 + 
                   Rational[1, 2] 
                    Log[TripleK`p[3]^2] (TripleK`p[1]^2 - TripleK`p[2]^2 - 
                    TripleK`p[3]^2) + 
                   Rational[1, 2] 
                    Log[TripleK`p[1]^2] (-TripleK`p[1]^2 - TripleK`p[2]^2 + 
                    TripleK`p[3]^2)) TripleK`\[Lambda][
                    TripleK`p[1], 
                    TripleK`p[2], 
                    TripleK`p[3]]^Rational[-1, 2]) TripleK`\[Lambda][
                    TripleK`p[1], 
                    TripleK`p[2], 
                    TripleK`p[3]]^Rational[-1, 2]) + Rational[1, 4] TripleK`NL[
                 TripleK`p[1], 
                 TripleK`p[2], 
                 TripleK`p[3]] ((-4) TripleK`p[1]^2 TripleK`p[2] + 
                4 TripleK`p[2]^3 - 4 TripleK`p[2] TripleK`p[3]^2) 
               TripleK`\[Lambda][
                  TripleK`p[1], 
                  TripleK`p[2], 
                  TripleK`p[3]]^Rational[-3, 2] - 
              TripleK`p[2]^(-1) (Log[TripleK`p[2]^2] TripleK`p[2]^2 + 
               Rational[1, 2] 
                Log[TripleK`p[3]^2] (TripleK`p[1]^2 - TripleK`p[2]^2 - 
                 TripleK`p[3]^2) + 
               Rational[1, 2] 
                Log[TripleK`p[1]^2] (-TripleK`p[1]^2 - TripleK`p[2]^2 + 
                 TripleK`p[3]^2))/TripleK`\[Lambda][
               TripleK`p[1], 
               TripleK`p[2], 
               TripleK`p[3]]) - 2 TripleK`p[2] (Rational[-1, 4] TripleK`NL[
                TripleK`p[1], 
                TripleK`p[2], 
                TripleK`p[3]] ((-4) TripleK`p[1]^2 TripleK`p[2] + 
               4 TripleK`p[2]^3 - 4 TripleK`p[2] TripleK`p[3]^2) 
              TripleK`\[Lambda][
                 TripleK`p[1], 
                 TripleK`p[2], 
                 TripleK`p[3]]^Rational[-3, 2] + 
             TripleK`p[2]^(-1) (Log[TripleK`p[2]^2] TripleK`p[2]^2 + 
               Rational[1, 2] 
                Log[TripleK`p[3]^2] (TripleK`p[1]^2 - TripleK`p[2]^2 - 
                 TripleK`p[3]^2) + 
               Rational[1, 2] 
                Log[TripleK`p[1]^2] (-TripleK`p[1]^2 - TripleK`p[2]^2 + 
                 TripleK`p[3]^2))/TripleK`\[Lambda][
               TripleK`p[1], 
               TripleK`p[2], 
               TripleK`p[3]])) TripleK`p[1][$CellContext`\[Mu]] 
           TripleK`p[1][$CellContext`\[Nu]] + 
          4 TripleK`p[2] (Rational[-1, 4] TripleK`NL[
               TripleK`p[1], 
               TripleK`p[2], 
               TripleK`p[3]] ((-4) TripleK`p[1]^2 TripleK`p[2] + 
              4 TripleK`p[2]^3 - 4 TripleK`p[2] TripleK`p[3]^2) 
             TripleK`\[Lambda][
                TripleK`p[1], 
                TripleK`p[2], 
                TripleK`p[3]]^Rational[-3, 2] + 
            TripleK`p[2]^(-1) (Log[TripleK`p[2]^2] TripleK`p[2]^2 + 
              Rational[1, 2] 
               Log[TripleK`p[3]^2] (TripleK`p[1]^2 - TripleK`p[2]^2 - 
                TripleK`p[3]^2) + 
              Rational[1, 2] 
               Log[TripleK`p[1]^2] (-TripleK`p[1]^2 - TripleK`p[2]^2 + 
                TripleK`p[3]^2))/TripleK`\[Lambda][
              TripleK`p[1], 
              TripleK`p[2], 
              TripleK`p[3]]) TripleK`p[1][$CellContext`\[Mu]] 
           TripleK`p[1][$CellContext`\[Nu]] - 4 
          TripleK`p[1] (Rational[-1, 4] TripleK`NL[
              TripleK`p[1], 
              TripleK`p[2], 
              TripleK`p[3]] (4 TripleK`p[1]^3 - 4 TripleK`p[1] TripleK`p[2]^2 - 
             4 TripleK`p[1] TripleK`p[3]^2) TripleK`\[Lambda][
               TripleK`p[1], 
               TripleK`p[2], 
               TripleK`p[3]]^Rational[-3, 2] + 
           TripleK`p[1]^(-1) (Log[TripleK`p[1]^2] TripleK`p[1]^2 + 
             Rational[1, 2] 
              Log[TripleK`p[3]^2] (-TripleK`p[1]^2 + TripleK`p[2]^2 - 
               TripleK`p[3]^2) + 
             Rational[1, 2] 
              Log[TripleK`p[2]^2] (-TripleK`p[1]^2 - TripleK`p[2]^2 + 
               TripleK`p[3]^2))/TripleK`\[Lambda][
             TripleK`p[1], 
             TripleK`p[2], 
             TripleK`p[3]]) TripleK`p[1][$CellContext`\[Nu]] 
          TripleK`p[2][$CellContext`\[Mu]] - TripleK`p[1] 
          TripleK`p[2] (Rational[3, 8] TripleK`NL[
              TripleK`p[1], 
              TripleK`p[2], 
              TripleK`p[3]] (4 TripleK`p[1]^3 - 4 TripleK`p[1] TripleK`p[2]^2 - 
             4 TripleK`p[1] TripleK`p[3]^2) ((-4) TripleK`p[1]^2 TripleK`p[2] + 
             4 TripleK`p[2]^3 - 4 TripleK`p[2] TripleK`p[3]^2) 
            TripleK`\[Lambda][
               TripleK`p[1], 
               TripleK`p[2], 
               TripleK`p[3]]^Rational[-5, 2] + 
           Rational[-1, 2] 
            TripleK`p[2]^(-1) (4 TripleK`p[1]^3 - 4 TripleK`p[1] 
             TripleK`p[2]^2 - 4 TripleK`p[1] TripleK`p[3]^2) (
             Log[TripleK`p[2]^2] TripleK`p[2]^2 + 
             Rational[1, 2] 
              Log[TripleK`p[3]^2] (TripleK`p[1]^2 - TripleK`p[2]^2 - 
               TripleK`p[3]^2) + 
             Rational[1, 2] 
              Log[TripleK`p[1]^2] (-TripleK`p[1]^2 - TripleK`p[2]^2 + 
               TripleK`p[3]^2)) TripleK`\[Lambda][
               TripleK`p[1], 
               TripleK`p[2], 
               TripleK`p[3]]^(-2) + 
           Rational[-1, 2] 
            TripleK`p[1]^(-1) ((-4) TripleK`p[1]^2 TripleK`p[2] + 
             4 TripleK`p[2]^3 - 4 TripleK`p[2] TripleK`p[3]^2) (
             Log[TripleK`p[1]^2] TripleK`p[1]^2 + 
             Rational[1, 2] 
              Log[TripleK`p[3]^2] (-TripleK`p[1]^2 + TripleK`p[2]^2 - 
               TripleK`p[3]^2) + 
             Rational[1, 2] 
              Log[TripleK`p[2]^2] (-TripleK`p[1]^2 - TripleK`p[2]^2 + 
               TripleK`p[3]^2)) TripleK`\[Lambda][
               TripleK`p[1], 
               TripleK`p[2], 
               TripleK`p[3]]^(-2) + 2 TripleK`NL[
              TripleK`p[1], 
              TripleK`p[2], 
              TripleK`p[3]] TripleK`p[1] TripleK`p[2] TripleK`\[Lambda][
               TripleK`p[1], 
               TripleK`p[2], 
               TripleK`p[3]]^Rational[-3, 2] + 
           Rational[
             1, 2] (-TripleK`p[1]^(-1) ((-4) TripleK`p[1]^2 TripleK`p[2] + 
               4 TripleK`p[2]^3 - 4 TripleK`p[2] TripleK`p[3]^2) (
               Log[TripleK`p[1]^2] TripleK`p[1]^2 + 
               Rational[1, 2] 
                Log[TripleK`p[3]^2] (-TripleK`p[1]^2 + TripleK`p[2]^2 - 
                 TripleK`p[3]^2) + 
               Rational[1, 2] 
                Log[TripleK`p[2]^2] (-TripleK`p[1]^2 - TripleK`p[2]^2 + 
                 TripleK`p[3]^2)) TripleK`\[Lambda][
                 TripleK`p[1], 
                 TripleK`p[2], 
                 TripleK`p[3]]^Rational[-3, 2] + 
             2 TripleK`p[1]^(-1) (-Log[TripleK`p[2]^2] TripleK`p[2] + 
               Log[TripleK`p[3]^2] TripleK`p[2] + 
               TripleK`p[2]^(-1) (-TripleK`p[1]^2 - TripleK`p[2]^2 + 
                 TripleK`p[3]^2)) TripleK`\[Lambda][
                 TripleK`p[1], 
                 TripleK`p[2], 
                 TripleK`p[3]]^Rational[-1, 2]) TripleK`\[Lambda][
               TripleK`p[1], 
               TripleK`p[2], 
               TripleK`p[3]]^Rational[-1, 2]) 
          TripleK`p[1][$CellContext`\[Nu]] TripleK`p[2][$CellContext`\[Mu]] - 
          TripleK`p[1] TripleK`p[2] (Rational[3, 8] TripleK`NL[
              TripleK`p[1], 
              TripleK`p[2], 
              TripleK`p[3]] (4 TripleK`p[1]^3 - 4 TripleK`p[1] TripleK`p[2]^2 - 
             4 TripleK`p[1] TripleK`p[3]^2) ((-4) TripleK`p[1]^2 TripleK`p[2] + 
             4 TripleK`p[2]^3 - 4 TripleK`p[2] TripleK`p[3]^2) 
            TripleK`\[Lambda][
               TripleK`p[1], 
               TripleK`p[2], 
               TripleK`p[3]]^Rational[-5, 2] + 
           Rational[-1, 2] 
            TripleK`p[2]^(-1) (4 TripleK`p[1]^3 - 4 TripleK`p[1] 
             TripleK`p[2]^2 - 4 TripleK`p[1] TripleK`p[3]^2) (
             Log[TripleK`p[2]^2] TripleK`p[2]^2 + 
             Rational[1, 2] 
              Log[TripleK`p[3]^2] (TripleK`p[1]^2 - TripleK`p[2]^2 - 
               TripleK`p[3]^2) + 
             Rational[1, 2] 
              Log[TripleK`p[1]^2] (-TripleK`p[1]^2 - TripleK`p[2]^2 + 
               TripleK`p[3]^2)) TripleK`\[Lambda][
               TripleK`p[1], 
               TripleK`p[2], 
               TripleK`p[3]]^(-2) + 
           Rational[-1, 2] 
            TripleK`p[1]^(-1) ((-4) TripleK`p[1]^2 TripleK`p[2] + 
             4 TripleK`p[2]^3 - 4 TripleK`p[2] TripleK`p[3]^2) (
             Log[TripleK`p[1]^2] TripleK`p[1]^2 + 
             Rational[1, 2] 
              Log[TripleK`p[3]^2] (-TripleK`p[1]^2 + TripleK`p[2]^2 - 
               TripleK`p[3]^2) + 
             Rational[1, 2] 
              Log[TripleK`p[2]^2] (-TripleK`p[1]^2 - TripleK`p[2]^2 + 
               TripleK`p[3]^2)) TripleK`\[Lambda][
               TripleK`p[1], 
               TripleK`p[2], 
               TripleK`p[3]]^(-2) + 2 TripleK`NL[
              TripleK`p[1], 
              TripleK`p[2], 
              TripleK`p[3]] TripleK`p[1] TripleK`p[2] TripleK`\[Lambda][
               TripleK`p[1], 
               TripleK`p[2], 
               TripleK`p[3]]^Rational[-3, 2] + 
           Rational[
             1, 2] (-TripleK`p[1]^(-1) ((-4) TripleK`p[1]^2 TripleK`p[2] + 
               4 TripleK`p[2]^3 - 4 TripleK`p[2] TripleK`p[3]^2) (
               Log[TripleK`p[1]^2] TripleK`p[1]^2 + 
               Rational[1, 2] 
                Log[TripleK`p[3]^2] (-TripleK`p[1]^2 + TripleK`p[2]^2 - 
                 TripleK`p[3]^2) + 
               Rational[1, 2] 
                Log[TripleK`p[2]^2] (-TripleK`p[1]^2 - TripleK`p[2]^2 + 
                 TripleK`p[3]^2)) TripleK`\[Lambda][
                 TripleK`p[1], 
                 TripleK`p[2], 
                 TripleK`p[3]]^Rational[-3, 2] + 
             2 TripleK`p[1]^(-1) (-Log[TripleK`p[2]^2] TripleK`p[2] + 
               Log[TripleK`p[3]^2] TripleK`p[2] + 
               TripleK`p[2]^(-1) (-TripleK`p[1]^2 - TripleK`p[2]^2 + 
                 TripleK`p[3]^2)) TripleK`\[Lambda][
                 TripleK`p[1], 
                 TripleK`p[2], 
                 TripleK`p[3]]^Rational[-1, 2]) TripleK`\[Lambda][
               TripleK`p[1], 
               TripleK`p[2], 
               TripleK`p[3]]^Rational[-1, 2]) 
          TripleK`p[1][$CellContext`\[Mu]] 
          TripleK`p[
           2][$CellContext`\[Nu]] + (-
             TripleK`p[1] (-TripleK`p[1] (Rational[3, 8] TripleK`NL[
                   TripleK`p[1], 
                   TripleK`p[2], 
                   TripleK`p[3]] (4 TripleK`p[1]^3 - 4 TripleK`p[1] 
                   TripleK`p[2]^2 - 4 TripleK`p[1] TripleK`p[3]^2)^2 
                 TripleK`\[Lambda][
                    TripleK`p[1], 
                    TripleK`p[2], 
                    TripleK`p[3]]^Rational[-5, 2] - 
                TripleK`p[1]^(-1) (4 TripleK`p[1]^3 - 4 TripleK`p[1] 
                 TripleK`p[2]^2 - 4 TripleK`p[1] TripleK`p[3]^2) (
                 Log[TripleK`p[1]^2] TripleK`p[1]^2 + 
                 Rational[1, 2] 
                  Log[TripleK`p[3]^2] (-TripleK`p[1]^2 + TripleK`p[2]^2 - 
                   TripleK`p[3]^2) + 
                 Rational[1, 2] 
                  Log[TripleK`p[2]^2] (-TripleK`p[1]^2 - TripleK`p[2]^2 + 
                   TripleK`p[3]^2)) TripleK`\[Lambda][
                   TripleK`p[1], 
                   TripleK`p[2], 
                   TripleK`p[3]]^(-2) + Rational[-1, 4] TripleK`NL[
                   TripleK`p[1], 
                   TripleK`p[2], 
                   TripleK`p[3]] (12 TripleK`p[1]^2 - 4 TripleK`p[2]^2 - 4 
                  TripleK`p[3]^2) TripleK`\[Lambda][
                    TripleK`p[1], 
                    TripleK`p[2], 
                    TripleK`p[3]]^Rational[-3, 2] + 
                Rational[
                  1, 2] (-
                   TripleK`p[1]^(-1) (4 TripleK`p[1]^3 - 4 TripleK`p[1] 
                    TripleK`p[2]^2 - 4 TripleK`p[1] TripleK`p[3]^2) (
                    Log[TripleK`p[1]^2] TripleK`p[1]^2 + 
                    Rational[1, 2] 
                    Log[TripleK`p[3]^2] (-TripleK`p[1]^2 + TripleK`p[2]^2 - 
                    TripleK`p[3]^2) + 
                    Rational[1, 2] 
                    Log[TripleK`p[2]^2] (-TripleK`p[1]^2 - TripleK`p[2]^2 + 
                    TripleK`p[3]^2)) TripleK`\[Lambda][
                    TripleK`p[1], 
                    TripleK`p[2], 
                    TripleK`p[3]]^Rational[-3, 2] + 
                  2 TripleK`p[1]^(-1) (2 TripleK`p[1] + 
                    2 Log[TripleK`p[1]^2] TripleK`p[1] - Log[TripleK`p[2]^2] 
                    TripleK`p[1] - Log[TripleK`p[3]^2] TripleK`p[1]) 
                   TripleK`\[Lambda][
                    TripleK`p[1], 
                    TripleK`p[2], 
                    TripleK`p[3]]^Rational[-1, 2] - 2 
                  TripleK`p[1]^(-2) (Log[TripleK`p[1]^2] TripleK`p[1]^2 + 
                   Rational[1, 2] 
                    Log[TripleK`p[3]^2] (-TripleK`p[1]^2 + TripleK`p[2]^2 - 
                    TripleK`p[3]^2) + 
                   Rational[1, 2] 
                    Log[TripleK`p[2]^2] (-TripleK`p[1]^2 - TripleK`p[2]^2 + 
                    TripleK`p[3]^2)) TripleK`\[Lambda][
                    TripleK`p[1], 
                    TripleK`p[2], 
                    TripleK`p[3]]^Rational[-1, 2]) TripleK`\[Lambda][
                    TripleK`p[1], 
                    TripleK`p[2], 
                    TripleK`p[3]]^Rational[-1, 2]) + Rational[1, 4] TripleK`NL[
                 TripleK`p[1], 
                 TripleK`p[2], 
                 TripleK`p[3]] (4 TripleK`p[1]^3 - 4 TripleK`p[1] 
                TripleK`p[2]^2 - 4 TripleK`p[1] TripleK`p[3]^2) 
               TripleK`\[Lambda][
                  TripleK`p[1], 
                  TripleK`p[2], 
                  TripleK`p[3]]^Rational[-3, 2] - 
              TripleK`p[1]^(-1) (Log[TripleK`p[1]^2] TripleK`p[1]^2 + 
               Rational[1, 2] 
                Log[TripleK`p[3]^2] (-TripleK`p[1]^2 + TripleK`p[2]^2 - 
                 TripleK`p[3]^2) + 
               Rational[1, 2] 
                Log[TripleK`p[2]^2] (-TripleK`p[1]^2 - TripleK`p[2]^2 + 
                 TripleK`p[3]^2))/TripleK`\[Lambda][
               TripleK`p[1], 
               TripleK`p[2], 
               TripleK`p[3]]) - 2 TripleK`p[1] (Rational[-1, 4] TripleK`NL[
                TripleK`p[1], 
                TripleK`p[2], 
                TripleK`p[3]] (4 TripleK`p[1]^3 - 4 TripleK`p[1] 
               TripleK`p[2]^2 - 4 TripleK`p[1] TripleK`p[3]^2) 
              TripleK`\[Lambda][
                 TripleK`p[1], 
                 TripleK`p[2], 
                 TripleK`p[3]]^Rational[-3, 2] + 
             TripleK`p[1]^(-1) (Log[TripleK`p[1]^2] TripleK`p[1]^2 + 
               Rational[1, 2] 
                Log[TripleK`p[3]^2] (-TripleK`p[1]^2 + TripleK`p[2]^2 - 
                 TripleK`p[3]^2) + 
               Rational[1, 2] 
                Log[TripleK`p[2]^2] (-TripleK`p[1]^2 - TripleK`p[2]^2 + 
                 TripleK`p[3]^2))/TripleK`\[Lambda][
               TripleK`p[1], 
               TripleK`p[2], 
               TripleK`p[3]])) TripleK`p[2][$CellContext`\[Mu]] 
           TripleK`p[2][$CellContext`\[Nu]])))}, -1, 1, 1],
  Editable->False]], "Output",
 CellChangeTimes->{
  3.7979399211119003`*^9, 3.79794000577896*^9, {3.7979400409364967`*^9, 
   3.797940058869975*^9}, {3.798251055868717*^9, 3.798251072328506*^9}, 
   3.7986857602386045`*^9, 3.7986858087023478`*^9, 
   3.79903762761036*^9},ExpressionUUID->"2246aa49-92c4-4406-87fb-\
0ec612d353ed"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Scalar integrals", "Section",
 CellChangeTimes->{{3.7948875259934883`*^9, 
  3.794887528825492*^9}},ExpressionUUID->"fd49f45b-d987-49cc-abd1-\
a0545e72588e"],

Cell[TextData[{
 "We consider two scalar examples here: the 3-point functions of the \
operators of dimensions\n1.  ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[CapitalDelta]", "1"], "=", 
    RowBox[{
     SubscriptBox["\[CapitalDelta]", "2"], "=", 
     RowBox[{
      SubscriptBox["\[CapitalDelta]", "3"], "=", "3"}]}]}], TraditionalForm]],
  ExpressionUUID->"f902248b-bf44-40f0-a0bf-2571dffd8670"],
 " in d=3 spacetime dimensions,\n2. ",
 Cell[BoxData[
  FormBox[
   RowBox[{" ", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[CapitalDelta]", "1"], "=", "4"}], ",", " ", 
     RowBox[{
      SubscriptBox["\[CapitalDelta]", "2"], "=", 
      RowBox[{
       SubscriptBox["\[CapitalDelta]", "3"], "=", "3"}]}]}]}], 
   TraditionalForm]],ExpressionUUID->"309f0ddf-a52c-4b2a-92d2-695a0ee3f88c"],
 " in d=4 spacetime dimensions.\nBoth examples are discussed in [",
 ButtonBox["1510.08442",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://arxiv.org/pdf/1510.08442.pdf"], None},
  ButtonNote->"https://arxiv.org/pdf/1510.08442.pdf"],
 "], examples 8 and 9 respectively as well as appendix C."
}], "Text",
 CellChangeTimes->{{3.7948875730815573`*^9, 3.7948876614977207`*^9}, 
   3.794887757199727*^9, {3.7948879784379253`*^9, 3.794887981218059*^9}, {
   3.797196787150316*^9, 3.797196827356373*^9}, {3.797196869967433*^9, 
   3.797196877724444*^9}, {3.7971985750798416`*^9, 3.797198579850848*^9}, {
   3.798252945519853*^9, 
   3.798252950591144*^9}},ExpressionUUID->"0c3d5b31-b0cf-4e50-9af4-\
dfa1a4c7d99c"],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[CapitalDelta]", "1"], "=", 
    RowBox[{
     SubscriptBox["\[CapitalDelta]", "2"], "=", 
     RowBox[{
      SubscriptBox["\[CapitalDelta]", "3"], "=", "3"}]}]}], TraditionalForm]],
  ExpressionUUID->"65539e9d-9302-4798-852a-ab921ea9304c"],
 " in d = 3"
}], "Subsection",
 CellChangeTimes->{{3.794887765950613*^9, 
  3.794887770946147*^9}},ExpressionUUID->"c292588b-0fdd-4a5c-bef2-\
a028d303aa5f"],

Cell[TextData[{
 "Case of ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[CapitalDelta]", "1"], "=", 
    RowBox[{
     SubscriptBox["\[CapitalDelta]", "2"], "=", 
     RowBox[{
      SubscriptBox["\[CapitalDelta]", "3"], "=", "3"}]}]}], TraditionalForm]],
  ExpressionUUID->"cdb58954-e9f4-41aa-8e8d-eeacacc25e2b"],
 " in d=3 can be realized as the 3-point function ",
 Cell[BoxData[
  FormBox[
   RowBox[{"<", " ", 
    RowBox[{":", 
     SuperscriptBox["\[Phi]", "6"], ":", 
     RowBox[{"(", 
      SubscriptBox["p", "1"], ")"}], " ", ":", 
     SuperscriptBox["\[Phi]", "6"], ":", 
     RowBox[{"(", 
      SubscriptBox["p", "2"], ")"}], " ", ":", 
     SuperscriptBox["\[Phi]", "6"], ":", 
     RowBox[{
      RowBox[{"(", 
       SubscriptBox["p", "3"], ")"}], " ", ">"}]}]}], TraditionalForm]],
  ExpressionUUID->"75df53d7-79ce-4306-9c45-96608a4147a6"],
 ", where \[Phi] is a free real scalar field."
}], "Text",
 CellChangeTimes->{{3.7974457050522633`*^9, 3.7974458313964415`*^9}, {
   3.797445863868487*^9, 3.7974459539146137`*^9}, 3.7974477631774616`*^9, {
   3.798251142534429*^9, 
   3.798251143133768*^9}},ExpressionUUID->"53bc34e9-5a29-4968-8652-\
ba552978ba3e"],

Cell[TextData[{
 "We will also need the 2-point function ",
 Cell[BoxData[
  FormBox[
   RowBox[{"<", " ", 
    RowBox[{":", 
     SuperscriptBox["\[Phi]", "6"], ":", 
     RowBox[{"(", "p", ")"}], " ", ":", 
     SuperscriptBox["\[Phi]", "6"], ":", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"-", "p"}], ")"}], " ", ">"}]}]}], TraditionalForm]],
  ExpressionUUID->"1df5b165-3369-41ed-a002-be4ed07d4de2"],
 ". The symmetry factor and the momentum integral of a single diagram are"
}], "Text",
 CellChangeTimes->{{3.798251369941934*^9, 
  3.798251418205805*^9}},ExpressionUUID->"5df6d6a9-49c7-4eee-a0f4-\
910346731b3f"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"SymmetryFactor", "=", 
  RowBox[{"6", "!"}]}], "\[IndentingNewLine]", 
 RowBox[{"TwoPtLoopIntegral", "=", 
  RowBox[{
   RowBox[{"Fold", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"LoopIntegral", "[", 
        RowBox[{
         RowBox[{"3", "-", 
          RowBox[{"2", "\[Epsilon]"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "1"}], "}"}]}], "]"}], "[", 
       RowBox[{"#1", ",", 
        RowBox[{"k", "[", "#2", "]"}], ",", 
        RowBox[{"k", "[", 
         RowBox[{"#2", "+", "1"}], "]"}]}], "]"}], "&"}], ",", 
     RowBox[{
      RowBox[{"LoopIntegral", "[", 
       RowBox[{
        RowBox[{"3", "-", 
         RowBox[{"2", "\[Epsilon]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1"}], "}"}]}], "]"}], "[", 
      RowBox[{"1", ",", 
       RowBox[{"k", "[", "1", "]"}], ",", 
       RowBox[{"k", "[", "2", "]"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "3", ",", "4", ",", "5"}], "}"}]}], "]"}], "/.", 
   RowBox[{
    RowBox[{"k", "[", "6", "]"}], "\[Rule]", "p"}]}]}]}], "Input",
 CellChangeTimes->{{3.798251435536137*^9, 
  3.798251460070874*^9}},ExpressionUUID->"27b39e08-614e-42c9-bb47-\
cd1d867ddb7a"],

Cell[BoxData["720"], "Output",
 CellChangeTimes->{{3.798251453540126*^9, 3.7982514603499317`*^9}, 
   3.7986857605406218`*^9, 3.7986858089303603`*^9, 
   3.79903762768111*^9},ExpressionUUID->"5e59b870-d3cf-473f-b1cd-\
f855e9bd3bc9"],

Cell[BoxData[
 TagBox[
  RowBox[{"\<\"\\!\\(\\*StyleBox[\\\"\[Integral]\\\",FontSize->18]\\)\"\>", 
   " ", 
   TagBox[
    FractionBox[
     RowBox[{
      SuperscriptBox["\<\"\[DifferentialD]\"\>", 
       RowBox[{"3", "-", 
        RowBox[{"2", " ", "\[Epsilon]"}]}]], " ", 
      RowBox[{"k", "[", "5", "]"}]}], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"2", " ", "\[Pi]"}], ")"}], 
      RowBox[{"3", "-", 
       RowBox[{"2", " ", "\[Epsilon]"}]}]]],
    HoldForm], " ", 
   TagBox[
    FractionBox[
     TagBox[
      RowBox[{"\<\"\\!\\(\\*StyleBox[\\\"\[Integral]\\\",FontSize->18]\\)\"\>\
", " ", 
       TagBox[
        FractionBox[
         RowBox[{
          SuperscriptBox["\<\"\[DifferentialD]\"\>", 
           RowBox[{"3", "-", 
            RowBox[{"2", " ", "\[Epsilon]"}]}]], " ", 
          RowBox[{"k", "[", "4", "]"}]}], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"2", " ", "\[Pi]"}], ")"}], 
          RowBox[{"3", "-", 
           RowBox[{"2", " ", "\[Epsilon]"}]}]]],
        HoldForm], " ", 
       TagBox[
        FractionBox[
         TagBox[
          
          RowBox[{"\<\"\\!\\(\\*StyleBox[\\\"\[Integral]\\\",FontSize->18]\\)\
\"\>", " ", 
           TagBox[
            FractionBox[
             RowBox[{
              SuperscriptBox["\<\"\[DifferentialD]\"\>", 
               RowBox[{"3", "-", 
                RowBox[{"2", " ", "\[Epsilon]"}]}]], " ", 
              RowBox[{"k", "[", "3", "]"}]}], 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"2", " ", "\[Pi]"}], ")"}], 
              RowBox[{"3", "-", 
               RowBox[{"2", " ", "\[Epsilon]"}]}]]],
            HoldForm], " ", 
           TagBox[
            FractionBox[
             TagBox[
              
              RowBox[{"\<\"\\!\\(\\*StyleBox[\\\"\[Integral]\\\",FontSize->18]\
\\)\"\>", " ", 
               TagBox[
                FractionBox[
                 RowBox[{
                  SuperscriptBox["\<\"\[DifferentialD]\"\>", 
                   RowBox[{"3", "-", 
                    RowBox[{"2", " ", "\[Epsilon]"}]}]], " ", 
                  RowBox[{"k", "[", "2", "]"}]}], 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{"2", " ", "\[Pi]"}], ")"}], 
                  RowBox[{"3", "-", 
                   RowBox[{"2", " ", "\[Epsilon]"}]}]]],
                HoldForm], " ", 
               TagBox[
                FractionBox[
                 TagBox[
                  
                  RowBox[{"\<\"\\!\\(\\*StyleBox[\\\"\[Integral]\\\",FontSize-\
>18]\\)\"\>", " ", 
                   TagBox[
                    FractionBox[
                    RowBox[{
                    SuperscriptBox["\<\"\[DifferentialD]\"\>", 
                    RowBox[{"3", "-", 
                    RowBox[{"2", " ", "\[Epsilon]"}]}]], " ", 
                    RowBox[{"k", "[", "1", "]"}]}], 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"2", " ", "\[Pi]"}], ")"}], 
                    RowBox[{"3", "-", 
                    RowBox[{"2", " ", "\[Epsilon]"}]}]]],
                    HoldForm], " ", 
                   TagBox[
                    FractionBox["1", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"k", "[", "1", "]"}], "2"], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"k", "[", "1", "]"}], "-", 
                    RowBox[{"k", "[", "2", "]"}]}], ")"}], "2"]}]],
                    HoldForm]}],
                  HoldForm], 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"k", "[", "2", "]"}], "0"], " ", 
                  SuperscriptBox[
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"k", "[", "2", "]"}], "-", 
                    RowBox[{"k", "[", "3", "]"}]}], ")"}], "2"]}]],
                HoldForm]}],
              HoldForm], 
             RowBox[{
              SuperscriptBox[
               RowBox[{"k", "[", "3", "]"}], "0"], " ", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"k", "[", "3", "]"}], "-", 
                 RowBox[{"k", "[", "4", "]"}]}], ")"}], "2"]}]],
            HoldForm]}],
          HoldForm], 
         RowBox[{
          SuperscriptBox[
           RowBox[{"k", "[", "4", "]"}], "0"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"k", "[", "4", "]"}], "-", 
             RowBox[{"k", "[", "5", "]"}]}], ")"}], "2"]}]],
        HoldForm]}],
      HoldForm], 
     RowBox[{
      SuperscriptBox[
       RowBox[{"k", "[", "5", "]"}], "0"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"k", "[", "5", "]"}], "-", "p"}], ")"}], "2"]}]],
    HoldForm]}],
  HoldForm]], "Output",
 CellChangeTimes->{{3.798251453540126*^9, 3.7982514603499317`*^9}, 
   3.7986857605406218`*^9, 3.7986858089303603`*^9, 
   3.799037627684038*^9},ExpressionUUID->"88178ec1-fc6e-4ac4-af65-\
1095b55ce746"]
}, Open  ]],

Cell[TextData[{
 "The result is finite. Compare with (C.34) of [",
 ButtonBox["1510.08442",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://arxiv.org/pdf/1510.08442.pdf"], None},
  ButtonNote->"https://arxiv.org/pdf/1510.08442.pdf"],
 "]."
}], "Text",
 CellChangeTimes->{{3.798251476710108*^9, 3.7982515252310257`*^9}, {
  3.79825159530963*^9, 
  3.798251616582614*^9}},ExpressionUUID->"2a3730d0-bfd6-40d7-a0b9-\
54ca3575b095"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"TwoPtReg", "=", 
  RowBox[{
   RowBox[{"SymmetryFactor", "*", "TwoPtLoopIntegral"}], "//", 
   "LoopEvaluate"}]}], "\[IndentingNewLine]", 
 RowBox[{"TwoPt", "=", 
  RowBox[{"TwoPtReg", "/.", 
   RowBox[{"\[Epsilon]", "\[Rule]", "0"}]}]}]}], "Input",
 CellChangeTimes->{{3.798251510777603*^9, 
  3.7982515412618303`*^9}},ExpressionUUID->"d0f2d88e-8972-482e-87eb-\
0d14c726ff49"],

Cell[BoxData[
 FractionBox[
  RowBox[{"45", " ", 
   SuperscriptBox["2", 
    RowBox[{
     RowBox[{"-", "11"}], "+", 
     RowBox[{"10", " ", "\[Epsilon]"}]}]], " ", 
   SuperscriptBox["p", 
    RowBox[{"3", "-", 
     RowBox[{"10", " ", "\[Epsilon]"}]}]], " ", 
   SuperscriptBox["\[Pi]", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["15", "2"]}], "+", 
     RowBox[{"5", " ", "\[Epsilon]"}]}]], " ", 
   SuperscriptBox[
    RowBox[{"Gamma", "[", 
     RowBox[{
      FractionBox["1", "2"], "-", "\[Epsilon]"}], "]"}], "6"], " ", 
   RowBox[{"Gamma", "[", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["3", "2"]}], "+", 
     RowBox[{"5", " ", "\[Epsilon]"}]}], "]"}]}], 
  RowBox[{"Gamma", "[", 
   RowBox[{"3", "-", 
    RowBox[{"6", " ", "\[Epsilon]"}]}], "]"}]]], "Output",
 CellChangeTimes->{
  3.797940115901535*^9, {3.798251514472712*^9, 3.798251541578825*^9}, 
   3.798251688382779*^9, 3.79868576068563*^9, 3.7986858090713687`*^9, 
   3.799037627853311*^9},ExpressionUUID->"7fa26429-6a76-4bf9-afe8-\
051b88fe668d"],

Cell[BoxData[
 FractionBox[
  RowBox[{"15", " ", 
   SuperscriptBox["p", "3"]}], 
  RowBox[{"1024", " ", 
   SuperscriptBox["\[Pi]", "4"]}]]], "Output",
 CellChangeTimes->{
  3.797940115901535*^9, {3.798251514472712*^9, 3.798251541578825*^9}, 
   3.798251688382779*^9, 3.79868576068563*^9, 3.7986858090713687`*^9, 
   3.79903762785528*^9},ExpressionUUID->"6c70c1d0-524a-45ef-b1f3-\
c8c1eda86109"]
}, Open  ]],

Cell[TextData[{
 "For the 3-point function first we define the effective propagators by \
integrating loops on each arm of the diagram in Figure 3 in [",
 ButtonBox["1510.08442",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://arxiv.org/pdf/1510.08442.pdf"], None},
  ButtonNote->"https://arxiv.org/pdf/1510.08442.pdf"],
 "]."
}], "Text",
 CellChangeTimes->{{3.7982516214298487`*^9, 3.798251677760189*^9}, {
  3.798251780014539*^9, 
  3.79825181475981*^9}},ExpressionUUID->"226404a7-37a5-4ad2-8d6e-\
d8dee37be64c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"EffectivePropagator", "=", 
  RowBox[{
   RowBox[{"Fold", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"LoopIntegral", "[", 
        RowBox[{
         RowBox[{"3", "-", 
          RowBox[{"2", "\[Epsilon]"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "1"}], "}"}]}], "]"}], "[", 
       RowBox[{"#1", ",", 
        RowBox[{"k", "[", "#2", "]"}], ",", 
        RowBox[{"k", "[", 
         RowBox[{"#2", "+", "1"}], "]"}]}], "]"}], "&"}], ",", 
     RowBox[{
      RowBox[{"LoopIntegral", "[", 
       RowBox[{
        RowBox[{"3", "-", 
         RowBox[{"2", "\[Epsilon]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1"}], "}"}]}], "]"}], "[", 
      RowBox[{"1", ",", 
       RowBox[{"k", "[", "1", "]"}], ",", 
       RowBox[{"k", "[", "2", "]"}]}], "]"}], ",", 
     RowBox[{"{", "2", "}"}]}], "]"}], "/.", 
   RowBox[{
    RowBox[{"k", "[", "3", "]"}], "\[Rule]", "q"}]}]}]], "Input",ExpressionUUI\
D->"bc8f433c-0959-48c1-9631-2b42e940ae1e"],

Cell[BoxData[
 TagBox[
  RowBox[{"\<\"\\!\\(\\*StyleBox[\\\"\[Integral]\\\",FontSize->18]\\)\"\>", 
   " ", 
   TagBox[
    FractionBox[
     RowBox[{
      SuperscriptBox["\<\"\[DifferentialD]\"\>", 
       RowBox[{"3", "-", 
        RowBox[{"2", " ", "\[Epsilon]"}]}]], " ", 
      RowBox[{"k", "[", "2", "]"}]}], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"2", " ", "\[Pi]"}], ")"}], 
      RowBox[{"3", "-", 
       RowBox[{"2", " ", "\[Epsilon]"}]}]]],
    HoldForm], " ", 
   TagBox[
    FractionBox[
     TagBox[
      RowBox[{"\<\"\\!\\(\\*StyleBox[\\\"\[Integral]\\\",FontSize->18]\\)\"\>\
", " ", 
       TagBox[
        FractionBox[
         RowBox[{
          SuperscriptBox["\<\"\[DifferentialD]\"\>", 
           RowBox[{"3", "-", 
            RowBox[{"2", " ", "\[Epsilon]"}]}]], " ", 
          RowBox[{"k", "[", "1", "]"}]}], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"2", " ", "\[Pi]"}], ")"}], 
          RowBox[{"3", "-", 
           RowBox[{"2", " ", "\[Epsilon]"}]}]]],
        HoldForm], " ", 
       TagBox[
        FractionBox["1", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"k", "[", "1", "]"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"k", "[", "1", "]"}], "-", 
             RowBox[{"k", "[", "2", "]"}]}], ")"}], "2"]}]],
        HoldForm]}],
      HoldForm], 
     RowBox[{
      SuperscriptBox[
       RowBox[{"k", "[", "2", "]"}], "0"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"k", "[", "2", "]"}], "-", "q"}], ")"}], "2"]}]],
    HoldForm]}],
  HoldForm]], "Output",
 CellChangeTimes->{3.7982518206275473`*^9, 3.798685760700631*^9, 
  3.7986858090833693`*^9, 
  3.799037627894144*^9},ExpressionUUID->"011984b9-0863-4e26-ab55-\
aabcf010cc03"]
}, Open  ]],

Cell["\<\
Then, the symmetry factor and the loop integral take the following forms:\
\>", "Text",
 CellChangeTimes->{{3.798251818664566*^9, 
  3.7982518312222757`*^9}},ExpressionUUID->"40000531-41bb-4bcc-9139-\
032d59bbf4ed"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"SymmetryFactor", " ", "=", " ", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"Binomial", "[", 
      RowBox[{"6", ",", "3"}], "]"}], "*", 
     RowBox[{"3", "!"}]}], ")"}], "^", "3"}]}], "\[IndentingNewLine]", 
 RowBox[{"ThreePtLoopIntegral", "=", 
  RowBox[{
   RowBox[{"LoopIntegral", "[", 
    RowBox[{
     RowBox[{"3", "-", 
      RowBox[{"2", "\[Epsilon]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "]"}], "[", 
   RowBox[{
    RowBox[{"EffectivePropagator", "*", 
     RowBox[{"(", 
      RowBox[{"EffectivePropagator", "/.", 
       RowBox[{"{", 
        RowBox[{"q", "\[Rule]", 
         RowBox[{"q", "-", 
          RowBox[{"p", "[", "1", "]"}]}]}], "}"}]}], ")"}], "*", 
     RowBox[{"(", 
      RowBox[{"EffectivePropagator", "/.", 
       RowBox[{"{", 
        RowBox[{"q", "\[Rule]", 
         RowBox[{"q", "+", 
          RowBox[{"p", "[", "2", "]"}]}]}], "}"}]}], ")"}]}], ",", "q"}], 
   "]"}]}]}], "Input",
 CellChangeTimes->{{3.798251174063397*^9, 3.7982511768219023`*^9}, {
  3.798251270966159*^9, 3.798251280309724*^9}, {3.798251767279789*^9, 
  3.798251776503118*^9}, {3.798251841264112*^9, 
  3.798251861062923*^9}},ExpressionUUID->"ff642a5f-7a24-4536-8054-\
1c9c5f931db3"],

Cell[BoxData["1728000"], "Output",
 CellChangeTimes->{3.798251280845684*^9, 3.7982517334171333`*^9, 
  3.7982518632374496`*^9, 3.798685760711632*^9, 3.79868580909337*^9, 
  3.7990376279080143`*^9},ExpressionUUID->"e0374a19-9a25-451c-9d08-\
e52ed64ff0b0"],

Cell[BoxData[
 TagBox[
  RowBox[{"\<\"\\!\\(\\*StyleBox[\\\"\[Integral]\\\",FontSize->18]\\)\"\>", 
   " ", 
   TagBox[
    FractionBox[
     RowBox[{
      SuperscriptBox["\<\"\[DifferentialD]\"\>", 
       RowBox[{"3", "-", 
        RowBox[{"2", " ", "\[Epsilon]"}]}]], " ", "q"}], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"2", " ", "\[Pi]"}], ")"}], 
      RowBox[{"3", "-", 
       RowBox[{"2", " ", "\[Epsilon]"}]}]]],
    HoldForm], " ", 
   TagBox[
    RowBox[{
     FractionBox["1", 
      RowBox[{
       SuperscriptBox["q", "0"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"q", "-", 
          SubscriptBox["p", "1"]}], ")"}], "0"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"q", "+", 
          SubscriptBox["p", "2"]}], ")"}], "0"]}]], 
     RowBox[{
      RowBox[{"(", 
       TagBox[
        RowBox[{"\<\"\\!\\(\\*StyleBox[\\\"\[Integral]\\\",FontSize->18]\\)\"\
\>", " ", 
         TagBox[
          FractionBox[
           RowBox[{
            SuperscriptBox["\<\"\[DifferentialD]\"\>", 
             RowBox[{"3", "-", 
              RowBox[{"2", " ", "\[Epsilon]"}]}]], " ", 
            RowBox[{"k", "[", "2", "]"}]}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"2", " ", "\[Pi]"}], ")"}], 
            RowBox[{"3", "-", 
             RowBox[{"2", " ", "\[Epsilon]"}]}]]],
          HoldForm], " ", 
         TagBox[
          FractionBox[
           TagBox[
            
            RowBox[{"\<\"\\!\\(\\*StyleBox[\\\"\[Integral]\\\",FontSize->18]\\\
)\"\>", " ", 
             TagBox[
              FractionBox[
               RowBox[{
                SuperscriptBox["\<\"\[DifferentialD]\"\>", 
                 RowBox[{"3", "-", 
                  RowBox[{"2", " ", "\[Epsilon]"}]}]], " ", 
                RowBox[{"k", "[", "1", "]"}]}], 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"2", " ", "\[Pi]"}], ")"}], 
                RowBox[{"3", "-", 
                 RowBox[{"2", " ", "\[Epsilon]"}]}]]],
              HoldForm], " ", 
             TagBox[
              FractionBox["1", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"k", "[", "1", "]"}], "2"], " ", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"k", "[", "1", "]"}], "-", 
                   RowBox[{"k", "[", "2", "]"}]}], ")"}], "2"]}]],
              HoldForm]}],
            HoldForm], 
           RowBox[{
            SuperscriptBox[
             RowBox[{"k", "[", "2", "]"}], "0"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"k", "[", "2", "]"}], "-", "q"}], ")"}], "2"]}]],
          HoldForm]}],
        HoldForm], ")"}], " ", 
      RowBox[{"(", 
       TagBox[
        RowBox[{"\<\"\\!\\(\\*StyleBox[\\\"\[Integral]\\\",FontSize->18]\\)\"\
\>", " ", 
         TagBox[
          FractionBox[
           RowBox[{
            SuperscriptBox["\<\"\[DifferentialD]\"\>", 
             RowBox[{"3", "-", 
              RowBox[{"2", " ", "\[Epsilon]"}]}]], " ", 
            RowBox[{"k", "[", "2", "]"}]}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"2", " ", "\[Pi]"}], ")"}], 
            RowBox[{"3", "-", 
             RowBox[{"2", " ", "\[Epsilon]"}]}]]],
          HoldForm], " ", 
         TagBox[
          FractionBox[
           TagBox[
            
            RowBox[{"\<\"\\!\\(\\*StyleBox[\\\"\[Integral]\\\",FontSize->18]\\\
)\"\>", " ", 
             TagBox[
              FractionBox[
               RowBox[{
                SuperscriptBox["\<\"\[DifferentialD]\"\>", 
                 RowBox[{"3", "-", 
                  RowBox[{"2", " ", "\[Epsilon]"}]}]], " ", 
                RowBox[{"k", "[", "1", "]"}]}], 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"2", " ", "\[Pi]"}], ")"}], 
                RowBox[{"3", "-", 
                 RowBox[{"2", " ", "\[Epsilon]"}]}]]],
              HoldForm], " ", 
             TagBox[
              FractionBox["1", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"k", "[", "1", "]"}], "2"], " ", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"k", "[", "1", "]"}], "-", 
                   RowBox[{"k", "[", "2", "]"}]}], ")"}], "2"]}]],
              HoldForm]}],
            HoldForm], 
           RowBox[{
            SuperscriptBox[
             RowBox[{"k", "[", "2", "]"}], "0"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"k", "[", "2", "]"}], "-", 
               RowBox[{"(", 
                RowBox[{"q", "-", 
                 SubscriptBox["p", "1"]}], ")"}]}], ")"}], "2"]}]],
          HoldForm]}],
        HoldForm], ")"}], " ", 
      RowBox[{"(", 
       TagBox[
        RowBox[{"\<\"\\!\\(\\*StyleBox[\\\"\[Integral]\\\",FontSize->18]\\)\"\
\>", " ", 
         TagBox[
          FractionBox[
           RowBox[{
            SuperscriptBox["\<\"\[DifferentialD]\"\>", 
             RowBox[{"3", "-", 
              RowBox[{"2", " ", "\[Epsilon]"}]}]], " ", 
            RowBox[{"k", "[", "2", "]"}]}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"2", " ", "\[Pi]"}], ")"}], 
            RowBox[{"3", "-", 
             RowBox[{"2", " ", "\[Epsilon]"}]}]]],
          HoldForm], " ", 
         TagBox[
          FractionBox[
           TagBox[
            
            RowBox[{"\<\"\\!\\(\\*StyleBox[\\\"\[Integral]\\\",FontSize->18]\\\
)\"\>", " ", 
             TagBox[
              FractionBox[
               RowBox[{
                SuperscriptBox["\<\"\[DifferentialD]\"\>", 
                 RowBox[{"3", "-", 
                  RowBox[{"2", " ", "\[Epsilon]"}]}]], " ", 
                RowBox[{"k", "[", "1", "]"}]}], 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"2", " ", "\[Pi]"}], ")"}], 
                RowBox[{"3", "-", 
                 RowBox[{"2", " ", "\[Epsilon]"}]}]]],
              HoldForm], " ", 
             TagBox[
              FractionBox["1", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"k", "[", "1", "]"}], "2"], " ", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"k", "[", "1", "]"}], "-", 
                   RowBox[{"k", "[", "2", "]"}]}], ")"}], "2"]}]],
              HoldForm]}],
            HoldForm], 
           RowBox[{
            SuperscriptBox[
             RowBox[{"k", "[", "2", "]"}], "0"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"k", "[", "2", "]"}], "-", 
               RowBox[{"(", 
                RowBox[{"q", "+", 
                 SubscriptBox["p", "2"]}], ")"}]}], ")"}], "2"]}]],
          HoldForm]}],
        HoldForm], ")"}]}]}],
    HoldForm]}],
  HoldForm]], "Output",
 CellChangeTimes->{3.798251280845684*^9, 3.7982517334171333`*^9, 
  3.7982518632374496`*^9, 3.798685760711632*^9, 3.79868580909337*^9, 
  3.799037627910635*^9},ExpressionUUID->"60b3ef16-37f5-46bb-b4ea-\
25163724d137"]
}, Open  ]],

Cell[TextData[{
 "In terms of triple-",
 StyleBox["K",
  FontSlant->"Italic"],
 " integrals this reads:"
}], "Text",
 CellChangeTimes->{{3.798252101389792*^9, 3.798252107838129*^9}, {
  3.798252153310279*^9, 
  3.798252165398307*^9}},ExpressionUUID->"963df61e-7d16-4fee-9c6a-\
6b9af9108305"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ThreePtTripleK", "=", 
  RowBox[{"LoopToK", "[", "ThreePtLoopIntegral", "]"}]}]], "Input",
 CellChangeTimes->{{3.798252177094473*^9, 
  3.798252189854335*^9}},ExpressionUUID->"1265e92b-d917-4049-a50a-\
0fbd10c3b8e7"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["2", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["37", "2"]}], "+", 
     RowBox[{"15", " ", "\[Epsilon]"}]}]], " ", 
   SuperscriptBox["\[Pi]", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["21", "2"]}], "+", 
     RowBox[{"7", " ", "\[Epsilon]"}]}]], " ", 
   SuperscriptBox[
    RowBox[{"Gamma", "[", 
     RowBox[{
      FractionBox["1", "2"], "-", "\[Epsilon]"}], "]"}], "9"], " ", 
   SubscriptBox["i", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], "-", "\[Epsilon]"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        FractionBox["3", "2"], "-", 
        RowBox[{"5", " ", "\[Epsilon]"}]}], ",", 
       RowBox[{
        FractionBox["3", "2"], "-", 
        RowBox[{"5", " ", "\[Epsilon]"}]}], ",", 
       RowBox[{
        FractionBox["3", "2"], "-", 
        RowBox[{"5", " ", "\[Epsilon]"}]}]}], "}"}]}]]}], 
  RowBox[{
   RowBox[{"Gamma", "[", 
    RowBox[{"3", "-", 
     RowBox[{"8", " ", "\[Epsilon]"}]}], "]"}], " ", 
   SuperscriptBox[
    RowBox[{"Gamma", "[", 
     RowBox[{
      FractionBox["3", "2"], "-", 
      RowBox[{"3", " ", "\[Epsilon]"}]}], "]"}], "3"]}]]], "Output",
 CellChangeTimes->{3.798252190215623*^9, 3.79868576086464*^9, 
  3.798685809233378*^9, 
  3.799037628100257*^9},ExpressionUUID->"d48adfbd-1ee2-43c6-9216-\
acd24fbf4706"]
}, Open  ]],

Cell["\<\
We see that the dimensional regularization in the usual sense leads to very \
specific regularization of the triple-K integral:\
\>", "Text",
 CellChangeTimes->{{3.798252101389792*^9, 3.798252107838129*^9}, {
  3.798252197575117*^9, 3.798252221838594*^9}, {3.798252319254704*^9, 
  3.798252320415037*^9}, {3.798252635166711*^9, 
  3.798252637295157*^9}},ExpressionUUID->"c9e11e6f-2ca8-4c51-9542-\
6d697da79784"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"uReg", "=", 
  RowBox[{"-", "1"}]}], "\[IndentingNewLine]", 
 RowBox[{"vReg", "=", 
  RowBox[{"-", "5"}]}]}], "Input",
 CellChangeTimes->{{3.7982526421695747`*^9, 
  3.798252652062948*^9}},ExpressionUUID->"784af205-3860-48d4-be21-\
dc0e98ec7515"],

Cell[BoxData[
 RowBox[{"-", "1"}]], "Output",
 CellChangeTimes->{3.7982526545338087`*^9, 3.798685760873641*^9, 
  3.798685809242378*^9, 
  3.7990376281127357`*^9},ExpressionUUID->"b1c657ca-3aeb-4c7c-ace1-\
c8d6dc286625"],

Cell[BoxData[
 RowBox[{"-", "5"}]], "Output",
 CellChangeTimes->{3.7982526545338087`*^9, 3.798685760873641*^9, 
  3.798685809242378*^9, 
  3.79903762811504*^9},ExpressionUUID->"85fb6e0b-6262-4d74-8a35-a5a0f6052072"]
}, Open  ]],

Cell["The regulated 3-point function reads:", "Text",
 CellChangeTimes->{
  3.798252639848802*^9},ExpressionUUID->"87ba0228-c4c5-4c75-af5e-\
e41817076d0f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ThreePtReg", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"SymmetryFactor", "*", "ThreePtLoopIntegral"}], "//", 
    "LoopEvaluate"}], "//", "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.798251908214418*^9, 3.79825191254198*^9}, {
  3.798252091384083*^9, 
  3.798252092918811*^9}},ExpressionUUID->"93db7e9c-55a1-41ef-9f28-\
602c9205305f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   FractionBox[
    RowBox[{"1125", " ", 
     RowBox[{"(", 
      RowBox[{
       SubsuperscriptBox["p", "1", "3"], "+", 
       SubsuperscriptBox["p", "2", "3"], "+", 
       SubsuperscriptBox["p", "3", "3"]}], ")"}]}], 
    RowBox[{"2048", " ", 
     SuperscriptBox["\[Pi]", "6"], " ", "\[Epsilon]"}]], "-", 
   RowBox[{
    FractionBox["1", 
     RowBox[{"2048", " ", 
      SuperscriptBox["\[Pi]", "6"]}]], 
    RowBox[{"375", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "86"}], " ", 
        SubsuperscriptBox["p", "1", "3"]}], "+", 
       RowBox[{"21", " ", "EulerGamma", " ", 
        SubsuperscriptBox["p", "1", "3"]}], "-", 
       RowBox[{"60", " ", 
        RowBox[{"Log", "[", "2", "]"}], " ", 
        SubsuperscriptBox["p", "1", "3"]}], "-", 
       RowBox[{"21", " ", 
        RowBox[{"Log", "[", "\[Pi]", "]"}], " ", 
        SubsuperscriptBox["p", "1", "3"]}], "+", 
       RowBox[{"30", " ", 
        RowBox[{"Log", "[", 
         SubscriptBox["p", "1"], "]"}], " ", 
        SubsuperscriptBox["p", "1", "3"]}], "-", 
       RowBox[{"12", " ", 
        SubsuperscriptBox["p", "1", "2"], " ", 
        SubscriptBox["p", "2"]}], "-", 
       RowBox[{"12", " ", 
        SubscriptBox["p", "1"], " ", 
        SubsuperscriptBox["p", "2", "2"]}], "-", 
       RowBox[{"86", " ", 
        SubsuperscriptBox["p", "2", "3"]}], "+", 
       RowBox[{"21", " ", "EulerGamma", " ", 
        SubsuperscriptBox["p", "2", "3"]}], "-", 
       RowBox[{"60", " ", 
        RowBox[{"Log", "[", "2", "]"}], " ", 
        SubsuperscriptBox["p", "2", "3"]}], "-", 
       RowBox[{"21", " ", 
        RowBox[{"Log", "[", "\[Pi]", "]"}], " ", 
        SubsuperscriptBox["p", "2", "3"]}], "+", 
       RowBox[{"30", " ", 
        RowBox[{"Log", "[", 
         SubscriptBox["p", "2"], "]"}], " ", 
        SubsuperscriptBox["p", "2", "3"]}], "-", 
       RowBox[{"12", " ", 
        SubsuperscriptBox["p", "1", "2"], " ", 
        SubscriptBox["p", "3"]}], "+", 
       RowBox[{"12", " ", 
        SubscriptBox["p", "1"], " ", 
        SubscriptBox["p", "2"], " ", 
        SubscriptBox["p", "3"]}], "-", 
       RowBox[{"12", " ", 
        SubsuperscriptBox["p", "2", "2"], " ", 
        SubscriptBox["p", "3"]}], "-", 
       RowBox[{"12", " ", 
        SubscriptBox["p", "1"], " ", 
        SubsuperscriptBox["p", "3", "2"]}], "-", 
       RowBox[{"12", " ", 
        SubscriptBox["p", "2"], " ", 
        SubsuperscriptBox["p", "3", "2"]}], "-", 
       RowBox[{"86", " ", 
        SubsuperscriptBox["p", "3", "3"]}], "+", 
       RowBox[{"21", " ", "EulerGamma", " ", 
        SubsuperscriptBox["p", "3", "3"]}], "-", 
       RowBox[{"60", " ", 
        RowBox[{"Log", "[", "2", "]"}], " ", 
        SubsuperscriptBox["p", "3", "3"]}], "-", 
       RowBox[{"21", " ", 
        RowBox[{"Log", "[", "\[Pi]", "]"}], " ", 
        SubsuperscriptBox["p", "3", "3"]}], "+", 
       RowBox[{"30", " ", 
        RowBox[{"Log", "[", 
         SubscriptBox["p", "3"], "]"}], " ", 
        SubsuperscriptBox["p", "3", "3"]}], "+", 
       RowBox[{"12", " ", 
        RowBox[{"Log", "[", 
         RowBox[{
          SubscriptBox["p", "1"], "+", 
          SubscriptBox["p", "2"], "+", 
          SubscriptBox["p", "3"]}], "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          SubsuperscriptBox["p", "1", "3"], "+", 
          SubsuperscriptBox["p", "2", "3"], "+", 
          SubsuperscriptBox["p", "3", "3"]}], ")"}]}]}], ")"}]}]}], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "\[Epsilon]", "]"}], "1"],
    SeriesData[TripleK`\[Epsilon], 0, {}, -1, 1, 1],
    Editable->False]}],
  SeriesData[
  TripleK`\[Epsilon], 0, {
   Rational[1125, 2048] 
    Pi^(-6) (TripleK`p[1]^3 + TripleK`p[2]^3 + TripleK`p[3]^3), 
    Rational[-375, 2048] 
    Pi^(-6) ((-86) TripleK`p[1]^3 + 21 EulerGamma TripleK`p[1]^3 - 60 Log[2] 
     TripleK`p[1]^3 - 21 Log[Pi] TripleK`p[1]^3 + 30 Log[
        TripleK`p[1]] TripleK`p[1]^3 - 12 TripleK`p[1]^2 TripleK`p[2] - 12 
     TripleK`p[1] TripleK`p[2]^2 - 86 TripleK`p[2]^3 + 
     21 EulerGamma TripleK`p[2]^3 - 60 Log[2] TripleK`p[2]^3 - 21 Log[Pi] 
     TripleK`p[2]^3 + 30 Log[
        TripleK`p[2]] TripleK`p[2]^3 - 12 TripleK`p[1]^2 TripleK`p[3] + 
     12 TripleK`p[1] TripleK`p[2] TripleK`p[3] - 12 TripleK`p[2]^2 
     TripleK`p[3] - 12 TripleK`p[1] TripleK`p[3]^2 - 12 TripleK`p[2] 
     TripleK`p[3]^2 - 86 TripleK`p[3]^3 + 21 EulerGamma TripleK`p[3]^3 - 60 
     Log[2] TripleK`p[3]^3 - 21 Log[Pi] TripleK`p[3]^3 + 30 Log[
        TripleK`p[3]] TripleK`p[3]^3 + 
     12 Log[TripleK`p[1] + TripleK`p[2] + TripleK`p[3]] (TripleK`p[1]^3 + 
       TripleK`p[2]^3 + TripleK`p[3]^3))}, -1, 1, 1],
  Editable->False]], "Output",
 CellChangeTimes->{
  3.798251915230257*^9, {3.7982520824873667`*^9, 3.7982520933005667`*^9}, 
   3.7986857620407076`*^9, 3.79868581069646*^9, 
   3.7990376299115553`*^9},ExpressionUUID->"2faa872e-71bf-40e0-9da3-\
82ee94398792"]
}, Open  ]],

Cell[TextData[{
 "The result is divergent and in a physical situation a suitable counterterm \
is required. The counterterm is given by equations (4.111) and (C.39) in [",
 ButtonBox["1510.08442",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://arxiv.org/pdf/1510.08442.pdf"], None},
  ButtonNote->"https://arxiv.org/pdf/1510.08442.pdf"],
 "]. Its contribution to the 3-point function is:"
}], "Text",
 CellChangeTimes->{{3.7971970351066656`*^9, 3.7971971007607584`*^9}, {
  3.798252324911376*^9, 
  3.798252358887068*^9}},ExpressionUUID->"6da59a45-df9e-4ffd-abd3-\
4385da9228d2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ctContrib", "=", 
  RowBox[{"Series", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"a", "[", 
          RowBox[{"-", "1"}], "]"}], "/", "\[Epsilon]"}], "+", 
        RowBox[{"a", "[", "0", "]"}]}], ")"}], " ", 
      RowBox[{"\[Mu]", "^", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{"uReg", "-", "vReg"}], ")"}]}], " ", "\[Epsilon]"}], 
        ")"}]}], 
      RowBox[{"(", " ", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"TwoPtReg", "/.", 
          RowBox[{"p", "\[Rule]", 
           RowBox[{"p", "[", "1", "]"}]}]}], ")"}], "+", 
        RowBox[{"(", 
         RowBox[{"TwoPtReg", "/.", 
          RowBox[{"p", "\[Rule]", 
           RowBox[{"p", "[", "2", "]"}]}]}], ")"}], "+", 
        RowBox[{"(", 
         RowBox[{"TwoPtReg", "/.", 
          RowBox[{"p", "\[Rule]", 
           RowBox[{"p", "[", "3", "]"}]}]}], ")"}]}], " ", ")"}]}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"a", "[", 
        RowBox[{"-", "1"}], "]"}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", "75"}], "/", 
        RowBox[{"(", 
         RowBox[{"2", 
          RowBox[{"Pi", "^", "2"}]}], ")"}]}]}], "}"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"\[Epsilon]", ",", "0", ",", "0"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.7948880510092154`*^9, 3.794888069722806*^9}, {
   3.794888103985053*^9, 3.7948881423626013`*^9}, 3.798252363063491*^9, {
   3.798252393232201*^9, 3.798252410383481*^9}, {3.798252442840928*^9, 
   3.7982524444074163`*^9}, {3.798252501688773*^9, 3.798252575479985*^9}, {
   3.798252668632863*^9, 3.798252677847735*^9}, {3.798252708250111*^9, 
   3.7982527086802998`*^9}, {3.7982527450335283`*^9, 
   3.7982527491449633`*^9}, {3.798252807200355*^9, 
   3.7982528077124166`*^9}},ExpressionUUID->"56b643c4-68b4-48d6-bdf3-\
27bead31b80c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{"1125", " ", 
      RowBox[{"(", 
       RowBox[{
        SubsuperscriptBox["p", "1", "3"], "+", 
        SubsuperscriptBox["p", "2", "3"], "+", 
        SubsuperscriptBox["p", "3", "3"]}], ")"}]}], 
     RowBox[{"2048", " ", 
      SuperscriptBox["\[Pi]", "6"], " ", "\[Epsilon]"}]]}], "+", 
   RowBox[{"(", 
    RowBox[{
     FractionBox[
      RowBox[{"15", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"a", "[", "0", "]"}], "+", 
         FractionBox[
          RowBox[{"150", " ", 
           RowBox[{"Log", "[", "\[Mu]", "]"}]}], 
          SuperscriptBox["\[Pi]", "2"]]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SubsuperscriptBox["p", "1", "3"], "+", 
         SubsuperscriptBox["p", "2", "3"], "+", 
         SubsuperscriptBox["p", "3", "3"]}], ")"}]}], 
      RowBox[{"1024", " ", 
       SuperscriptBox["\[Pi]", "4"]}]], "+", 
     RowBox[{
      FractionBox["1", 
       RowBox[{"2048", " ", 
        SuperscriptBox["\[Pi]", "6"]}]], 
      RowBox[{"1125", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "9"}], " ", 
          SubsuperscriptBox["p", "1", "3"]}], "+", 
         RowBox[{"6", " ", "EulerGamma", " ", 
          SubsuperscriptBox["p", "1", "3"]}], "-", 
         RowBox[{"10", " ", 
          RowBox[{"Log", "[", "2", "]"}], " ", 
          SubsuperscriptBox["p", "1", "3"]}], "-", 
         RowBox[{"5", " ", 
          RowBox[{"Log", "[", "\[Pi]", "]"}], " ", 
          SubsuperscriptBox["p", "1", "3"]}], "+", 
         RowBox[{"10", " ", 
          RowBox[{"Log", "[", 
           SubscriptBox["p", "1"], "]"}], " ", 
          SubsuperscriptBox["p", "1", "3"]}], "-", 
         RowBox[{"9", " ", 
          SubsuperscriptBox["p", "2", "3"]}], "+", 
         RowBox[{"6", " ", "EulerGamma", " ", 
          SubsuperscriptBox["p", "2", "3"]}], "-", 
         RowBox[{"10", " ", 
          RowBox[{"Log", "[", "2", "]"}], " ", 
          SubsuperscriptBox["p", "2", "3"]}], "-", 
         RowBox[{"5", " ", 
          RowBox[{"Log", "[", "\[Pi]", "]"}], " ", 
          SubsuperscriptBox["p", "2", "3"]}], "+", 
         RowBox[{"10", " ", 
          RowBox[{"Log", "[", 
           SubscriptBox["p", "2"], "]"}], " ", 
          SubsuperscriptBox["p", "2", "3"]}], "-", 
         RowBox[{"9", " ", 
          SubsuperscriptBox["p", "3", "3"]}], "+", 
         RowBox[{"6", " ", "EulerGamma", " ", 
          SubsuperscriptBox["p", "3", "3"]}], "-", 
         RowBox[{"10", " ", 
          RowBox[{"Log", "[", "2", "]"}], " ", 
          SubsuperscriptBox["p", "3", "3"]}], "-", 
         RowBox[{"5", " ", 
          RowBox[{"Log", "[", "\[Pi]", "]"}], " ", 
          SubsuperscriptBox["p", "3", "3"]}], "+", 
         RowBox[{"10", " ", 
          RowBox[{"Log", "[", 
           SubscriptBox["p", "3"], "]"}], " ", 
          SubsuperscriptBox["p", "3", "3"]}], "-", 
         RowBox[{"5", " ", 
          SubsuperscriptBox["p", "1", "3"], " ", 
          RowBox[{"PolyGamma", "[", 
           RowBox[{"0", ",", 
            RowBox[{"-", 
             FractionBox["3", "2"]}]}], "]"}]}], "-", 
         RowBox[{"5", " ", 
          SubsuperscriptBox["p", "2", "3"], " ", 
          RowBox[{"PolyGamma", "[", 
           RowBox[{"0", ",", 
            RowBox[{"-", 
             FractionBox["3", "2"]}]}], "]"}]}], "-", 
         RowBox[{"5", " ", 
          SubsuperscriptBox["p", "3", "3"], " ", 
          RowBox[{"PolyGamma", "[", 
           RowBox[{"0", ",", 
            RowBox[{"-", 
             FractionBox["3", "2"]}]}], "]"}]}], "+", 
         RowBox[{"6", " ", 
          SubsuperscriptBox["p", "1", "3"], " ", 
          RowBox[{"PolyGamma", "[", 
           RowBox[{"0", ",", 
            FractionBox["1", "2"]}], "]"}]}], "+", 
         RowBox[{"6", " ", 
          SubsuperscriptBox["p", "2", "3"], " ", 
          RowBox[{"PolyGamma", "[", 
           RowBox[{"0", ",", 
            FractionBox["1", "2"]}], "]"}]}], "+", 
         RowBox[{"6", " ", 
          SubsuperscriptBox["p", "3", "3"], " ", 
          RowBox[{"PolyGamma", "[", 
           RowBox[{"0", ",", 
            FractionBox["1", "2"]}], "]"}]}]}], ")"}]}]}]}], ")"}], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "\[Epsilon]", "]"}], "1"],
    SeriesData[TripleK`\[Epsilon], 0, {}, -1, 1, 1],
    Editable->False]}],
  SeriesData[
  TripleK`\[Epsilon], 0, {
   Rational[-1125, 2048] 
    Pi^(-6) (TripleK`p[1]^3 + TripleK`p[2]^3 + TripleK`p[3]^3), 
    Rational[15, 1024] 
     Pi^(-4) ($CellContext`a[0] + 150 Pi^(-2) Log[$CellContext`\[Mu]]) (
      TripleK`p[1]^3 + TripleK`p[2]^3 + TripleK`p[3]^3) + 
    Rational[1125, 2048] 
     Pi^(-6) ((-9) TripleK`p[1]^3 + 6 EulerGamma TripleK`p[1]^3 - 10 Log[2] 
      TripleK`p[1]^3 - 5 Log[Pi] TripleK`p[1]^3 + 10 Log[
         TripleK`p[1]] TripleK`p[1]^3 - 9 TripleK`p[2]^3 + 
      6 EulerGamma TripleK`p[2]^3 - 10 Log[2] TripleK`p[2]^3 - 5 Log[Pi] 
      TripleK`p[2]^3 + 10 Log[
         TripleK`p[2]] TripleK`p[2]^3 - 9 TripleK`p[3]^3 + 
      6 EulerGamma TripleK`p[3]^3 - 10 Log[2] TripleK`p[3]^3 - 5 Log[Pi] 
      TripleK`p[3]^3 + 10 Log[
         TripleK`p[3]] TripleK`p[3]^3 - 5 TripleK`p[1]^3 PolyGamma[0, 
        Rational[-3, 2]] - 5 TripleK`p[2]^3 PolyGamma[0, 
        Rational[-3, 2]] - 5 TripleK`p[3]^3 PolyGamma[0, 
        Rational[-3, 2]] + 6 TripleK`p[1]^3 PolyGamma[0, 
         Rational[1, 2]] + 6 TripleK`p[2]^3 PolyGamma[0, 
         Rational[1, 2]] + 6 TripleK`p[3]^3 PolyGamma[0, 
         Rational[1, 2]])}, -1, 1, 1],
  Editable->False]], "Output",
 CellChangeTimes->{{3.794888135160885*^9, 3.794888142569831*^9}, 
   3.794888275424686*^9, 3.794888349630229*^9, 3.7971971043657637`*^9, 
   3.798252412950946*^9, 3.798252444780992*^9, 3.798252535717423*^9, 
   3.7982525759768343`*^9, {3.7982526863897247`*^9, 3.798252709243812*^9}, 
   3.798252749600101*^9, 3.798252811450309*^9, 3.7986858107914653`*^9, 
   3.7990376300510883`*^9},ExpressionUUID->"c274c697-e7ed-4539-a52f-\
6fc175c34aed"]
}, Open  ]],

Cell["The renormalized 3-point function is now finite and reads.", "Text",
 CellChangeTimes->{{3.7971971085707693`*^9, 3.7971971186127834`*^9}, {
  3.797197187063885*^9, 
  3.7971971908338904`*^9}},ExpressionUUID->"d5450e56-84cd-4768-89f3-\
0fb49c8b1175"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ThreePtRen", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"ThreePtReg", "+", "ctContrib"}], "//", 
    RowBox[{
     RowBox[{"FullSimplify", "[", 
      RowBox[{"#", ",", 
       RowBox[{"{", 
        RowBox[{"\[Mu]", ">", "0"}], "}"}]}], "]"}], "&"}]}], "//", 
   "Normal"}]}]], "Input",
 CellChangeTimes->{{3.7948881498154793`*^9, 3.794888183113894*^9}, {
   3.797197178381873*^9, 3.797197179296874*^9}, {3.7982524248908157`*^9, 
   3.7982524321988173`*^9}, 3.798252549105101*^9, {3.798252819160187*^9, 
   3.798252822407633*^9}},ExpressionUUID->"7f0bcb58-20bb-425e-966e-\
44d8576066c4"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{"2048", " ", 
    SuperscriptBox["\[Pi]", "6"]}]], 
  RowBox[{"15", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"475", "-", 
        RowBox[{"150", " ", "EulerGamma"}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["\[Pi]", "2"], " ", 
         RowBox[{"a", "[", "0", "]"}]}], "+", 
        RowBox[{"600", " ", 
         RowBox[{"Log", "[", "2", "]"}]}], "+", 
        RowBox[{"150", " ", 
         RowBox[{"Log", "[", "\[Pi]", "]"}]}]}], ")"}], " ", 
      SubsuperscriptBox["p", "1", "3"]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"475", "-", 
        RowBox[{"150", " ", "EulerGamma"}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["\[Pi]", "2"], " ", 
         RowBox[{"a", "[", "0", "]"}]}], "+", 
        RowBox[{"600", " ", 
         RowBox[{"Log", "[", "2", "]"}]}], "+", 
        RowBox[{"150", " ", 
         RowBox[{"Log", "[", "\[Pi]", "]"}]}]}], ")"}], " ", 
      SubsuperscriptBox["p", "2", "3"]}], "+", 
     RowBox[{"300", " ", 
      SubsuperscriptBox["p", "2", "2"], " ", 
      SubscriptBox["p", "3"]}], "+", 
     RowBox[{"300", " ", 
      SubscriptBox["p", "2"], " ", 
      SubsuperscriptBox["p", "3", "2"]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"475", "-", 
        RowBox[{"150", " ", "EulerGamma"}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["\[Pi]", "2"], " ", 
         RowBox[{"a", "[", "0", "]"}]}], "+", 
        RowBox[{"600", " ", 
         RowBox[{"Log", "[", "2", "]"}]}], "+", 
        RowBox[{"150", " ", 
         RowBox[{"Log", "[", "\[Pi]", "]"}]}]}], ")"}], " ", 
      SubsuperscriptBox["p", "3", "3"]}], "+", 
     RowBox[{"300", " ", 
      SubsuperscriptBox["p", "1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["p", "2"], "+", 
        SubscriptBox["p", "3"]}], ")"}]}], "+", 
     RowBox[{"300", " ", 
      SubscriptBox["p", "1"], " ", 
      RowBox[{"(", 
       RowBox[{
        SubsuperscriptBox["p", "2", "2"], "-", 
        RowBox[{
         SubscriptBox["p", "2"], " ", 
         SubscriptBox["p", "3"]}], "+", 
        SubsuperscriptBox["p", "3", "2"]}], ")"}]}], "+", 
     RowBox[{"300", " ", 
      RowBox[{"Log", "[", 
       FractionBox["\[Mu]", 
        RowBox[{
         SubscriptBox["p", "1"], "+", 
         SubscriptBox["p", "2"], "+", 
         SubscriptBox["p", "3"]}]], "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SubsuperscriptBox["p", "1", "3"], "+", 
        SubsuperscriptBox["p", "2", "3"], "+", 
        SubsuperscriptBox["p", "3", "3"]}], ")"}]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{{3.7948881569907923`*^9, 3.79488819068723*^9}, 
   3.794888278574285*^9, 3.794888351621222*^9, 3.7971971233377905`*^9, {
   3.797197179791875*^9, 3.7971971970998993`*^9}, {3.798252437046061*^9, 
   3.7982524476206217`*^9}, {3.798252553809774*^9, 3.798252578809273*^9}, {
   3.7982526927267303`*^9, 3.798252711561369*^9}, 3.7982527648924723`*^9, 
   3.798252828208251*^9, 3.7986858159087543`*^9, 
   3.799037634970106*^9},ExpressionUUID->"23670956-3ce7-4b4d-91c1-\
841dc3264cd6"]
}, Open  ]],

Cell[TextData[{
 "The renormalized 3-point function depends explicitly on the renormalization \
scale \[Mu]. In this particular case the \[Mu]-dependence originates from the \
presence of the \[Beta]-function. See example 8 of [",
 ButtonBox["1510.08442",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://arxiv.org/pdf/1510.08442.pdf"], None},
  ButtonNote->"https://arxiv.org/pdf/1510.08442.pdf"],
 "] for more details."
}], "Text",
 CellChangeTimes->{{3.7971971085707693`*^9, 3.7971971186127834`*^9}, {
  3.797197187063885*^9, 3.7971972292799444`*^9}, {3.7971973532391195`*^9, 
  3.797197446585251*^9}},ExpressionUUID->"f2794c09-2596-4033-abb3-\
c0409dc8ccaf"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[Mu]", " ", 
   RowBox[{"D", "[", 
    RowBox[{"ThreePtRen", ",", "\[Mu]"}], "]"}]}], "//", 
  "FullSimplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ScalarKKOp", "[", 
   RowBox[{"ThreePtRen", ",", 
    RowBox[{"p", "[", "1", "]"}], ",", 
    RowBox[{"p", "[", "2", "]"}], ",", 
    RowBox[{"3", "/", "2"}], ",", 
    RowBox[{"3", "/", "2"}]}], "]"}], "//", "FullSimplify"}]}], "Input",
 CellChangeTimes->{{3.794888285966888*^9, 3.7948882960446453`*^9}, {
  3.7971971384998116`*^9, 3.797197164409853*^9}, {3.7971974477712526`*^9, 
  3.7971974497612553`*^9}, {3.798252845946392*^9, 
  3.79825284947163*^9}},ExpressionUUID->"cb3b6757-655e-4431-a10b-\
577e62bf4c95"],

Cell[BoxData[
 FractionBox[
  RowBox[{"1125", " ", 
   RowBox[{"(", 
    RowBox[{
     SubsuperscriptBox["p", "1", "3"], "+", 
     SubsuperscriptBox["p", "2", "3"], "+", 
     SubsuperscriptBox["p", "3", "3"]}], ")"}]}], 
  RowBox[{"512", " ", 
   SuperscriptBox["\[Pi]", "6"]}]]], "Output",
 CellChangeTimes->{
  3.7948882966871033`*^9, 3.794888351763431*^9, {3.797197152207831*^9, 
   3.7971971646148534`*^9}, 3.7971971978799005`*^9, 3.797197450591256*^9, 
   3.79825285702179*^9, 3.798685815961757*^9, 
   3.79903763503852*^9},ExpressionUUID->"3558d483-55e2-4a5a-a2ff-\
515440cce007"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.7948882966871033`*^9, 3.794888351763431*^9, {3.797197152207831*^9, 
   3.7971971646148534`*^9}, 3.7971971978799005`*^9, 3.797197450591256*^9, 
   3.79825285702179*^9, 3.798685815961757*^9, 
   3.799037635047262*^9},ExpressionUUID->"7eac238f-f26b-44c5-9ba7-\
52641e92390d"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["\[CapitalDelta]", "1"], "=", "4"}], ",", " ", 
    RowBox[{
     SubscriptBox["\[CapitalDelta]", "2"], "=", 
     RowBox[{
      SubscriptBox["\[CapitalDelta]", "3"], "=", "3"}]}]}], TraditionalForm]],
  ExpressionUUID->"03dfde39-903b-4ef4-aa0d-7cc52b29c462"],
 " in d = 4"
}], "Subsection",
 CellChangeTimes->{{3.794887765950613*^9, 3.794887770946147*^9}, {
  3.7948883127783823`*^9, 
  3.7948883146185493`*^9}},ExpressionUUID->"319a28d5-226e-4ddc-8b1e-\
4586a662c196"],

Cell[TextData[{
 "This case can be realized as the 3-point function ",
 Cell[BoxData[
  FormBox[
   RowBox[{"<", " ", 
    RowBox[{":", 
     SuperscriptBox["\[Phi]", "4"], ":", 
     RowBox[{"(", 
      SubscriptBox["p", "1"], ")"}], " ", ":", 
     SuperscriptBox["\[Phi]", "3"], ":", 
     RowBox[{"(", 
      SubscriptBox["p", "2"], ")"}], " ", ":", 
     SuperscriptBox["\[Phi]", "3"], ":", 
     RowBox[{
      RowBox[{"(", 
       SubscriptBox["p", "3"], ")"}], " ", ">"}]}]}], TraditionalForm]],
  ExpressionUUID->"c187113b-66b1-4ede-a0d0-9f7ac9986b94"],
 ", where \[Phi] is a free real scalar field."
}], "Text",
 CellChangeTimes->{{3.7982530097680397`*^9, 
  3.79825305471124*^9}},ExpressionUUID->"7c5a7b04-5e3d-40d2-9b14-\
0e1c47c14e3e"],

Cell[TextData[{
 "We will also need the 2-point function ",
 Cell[BoxData[
  FormBox[
   RowBox[{"<", " ", 
    RowBox[{":", 
     SuperscriptBox["\[Phi]", "3"], ":", 
     RowBox[{"(", "p", ")"}], " ", ":", 
     SuperscriptBox["\[Phi]", "3"], ":", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"-", "p"}], ")"}], " ", ">"}]}]}], TraditionalForm]],
  ExpressionUUID->"29b3f061-ea27-479d-a987-00edbdaa66f3"],
 ". The momentum integral reads:"
}], "Text",
 CellChangeTimes->{{3.798253057972784*^9, 
  3.798253085183751*^9}},ExpressionUUID->"41f6b6e8-0adf-49f6-b7b0-\
c2a556cf5c14"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TwoPtLoopIntegral", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"3", "!"}], "*", 
    RowBox[{"Fold", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"LoopIntegral", "[", 
         RowBox[{
          RowBox[{"4", "-", 
           RowBox[{"2", "\[Epsilon]"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1"}], "}"}]}], "]"}], "[", 
        RowBox[{"#1", ",", 
         RowBox[{"k", "[", "#2", "]"}], ",", 
         RowBox[{"k", "[", 
          RowBox[{"#2", "+", "1"}], "]"}]}], "]"}], "&"}], ",", 
      RowBox[{
       RowBox[{"LoopIntegral", "[", 
        RowBox[{
         RowBox[{"4", "-", 
          RowBox[{"2", "\[Epsilon]"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", "1"}], "}"}]}], "]"}], "[", 
       RowBox[{"1", ",", 
        RowBox[{"k", "[", "1", "]"}], ",", 
        RowBox[{"k", "[", "2", "]"}]}], "]"}], ",", 
      RowBox[{"{", "2", "}"}]}], "]"}]}], "/.", 
   RowBox[{
    RowBox[{"k", "[", "3", "]"}], "\[Rule]", "p"}]}]}]], "Input",
 CellChangeTimes->{{3.79744804637786*^9, 3.7974480734708986`*^9}, {
   3.7974488860810437`*^9, 3.797448928745104*^9}, {3.797449113669364*^9, 
   3.7974491216453753`*^9}, {3.797449427796568*^9, 3.7974494309025726`*^9}, 
   3.7975158995642567`*^9, {3.797516285037854*^9, 3.797516285817855*^9}, {
   3.7979403587500563`*^9, 3.7979403971238422`*^9}, {3.798253088320304*^9, 
   3.798253101224218*^9}},ExpressionUUID->"ae87c3a2-dd96-4fbd-994f-\
e9be3533381f"],

Cell[BoxData[
 RowBox[{"6", " ", 
  RowBox[{"(", 
   TagBox[
    RowBox[{"\<\"\\!\\(\\*StyleBox[\\\"\[Integral]\\\",FontSize->18]\\)\"\>", 
     " ", 
     TagBox[
      FractionBox[
       RowBox[{
        SuperscriptBox["\<\"\[DifferentialD]\"\>", 
         RowBox[{"4", "-", 
          RowBox[{"2", " ", "\[Epsilon]"}]}]], " ", 
        RowBox[{"k", "[", "2", "]"}]}], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"2", " ", "\[Pi]"}], ")"}], 
        RowBox[{"4", "-", 
         RowBox[{"2", " ", "\[Epsilon]"}]}]]],
      HoldForm], " ", 
     TagBox[
      FractionBox[
       TagBox[
        RowBox[{"\<\"\\!\\(\\*StyleBox[\\\"\[Integral]\\\",FontSize->18]\\)\"\
\>", " ", 
         TagBox[
          FractionBox[
           RowBox[{
            SuperscriptBox["\<\"\[DifferentialD]\"\>", 
             RowBox[{"4", "-", 
              RowBox[{"2", " ", "\[Epsilon]"}]}]], " ", 
            RowBox[{"k", "[", "1", "]"}]}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"2", " ", "\[Pi]"}], ")"}], 
            RowBox[{"4", "-", 
             RowBox[{"2", " ", "\[Epsilon]"}]}]]],
          HoldForm], " ", 
         TagBox[
          FractionBox["1", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"k", "[", "1", "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"k", "[", "1", "]"}], "-", 
               RowBox[{"k", "[", "2", "]"}]}], ")"}], "2"]}]],
          HoldForm]}],
        HoldForm], 
       RowBox[{
        SuperscriptBox[
         RowBox[{"k", "[", "2", "]"}], "0"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"k", "[", "2", "]"}], "-", "p"}], ")"}], "2"]}]],
      HoldForm]}],
    HoldForm], ")"}]}]], "Output",
 CellChangeTimes->{{3.7974480645048857`*^9, 3.7974480863429165`*^9}, 
   3.797448886606045*^9, 3.797448929520105*^9, {3.7974491166993685`*^9, 
   3.7974491218513756`*^9}, 3.7974492959760942`*^9, 3.797449431428573*^9, 
   3.797449473309644*^9, 3.797515832205162*^9, 3.797515899914257*^9, {
   3.7975162616958213`*^9, 3.7975162863978558`*^9}, 3.797940092581032*^9, {
   3.797940360344275*^9, 3.797940397461668*^9}, 3.7982531016140337`*^9, 
   3.7986858159847584`*^9, 
   3.799037635086607*^9},ExpressionUUID->"1a4fbdb8-625f-4d87-9a24-\
5cea86b3e5b8"]
}, Open  ]],

Cell["The 2-point function is divergent here:", "Text",
 CellChangeTimes->{{3.798253145062873*^9, 
  3.798253152454715*^9}},ExpressionUUID->"d0f88a61-2df2-4e41-9a3e-\
a7aff4ffccb6"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"TwoPtReg", "=", 
  RowBox[{
  "TwoPtLoopIntegral", "//", "LoopEvaluate"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Series", "[", 
   RowBox[{"TwoPtReg", ",", 
    RowBox[{"{", 
     RowBox[{"\[Epsilon]", ",", "0", ",", "0"}], "}"}]}], "]"}], "//", 
  "Simplify"}]}], "Input",
 CellChangeTimes->{{3.798253105855752*^9, 3.7982531101357203`*^9}, {
  3.798253158761628*^9, 
  3.798253159018875*^9}},ExpressionUUID->"8d9820d9-850a-4c4e-af3a-\
82e7abc70db4"],

Cell[BoxData[
 FractionBox[
  RowBox[{"3", " ", 
   SuperscriptBox["2", 
    RowBox[{
     RowBox[{"-", "7"}], "+", 
     RowBox[{"4", " ", "\[Epsilon]"}]}]], " ", 
   SuperscriptBox["p", 
    RowBox[{"2", "-", 
     RowBox[{"4", " ", "\[Epsilon]"}]}]], " ", 
   SuperscriptBox["\[Pi]", 
    RowBox[{
     RowBox[{"-", "4"}], "+", 
     RowBox[{"2", " ", "\[Epsilon]"}]}]], " ", 
   SuperscriptBox[
    RowBox[{"Gamma", "[", 
     RowBox[{"1", "-", "\[Epsilon]"}], "]"}], "3"], " ", 
   RowBox[{"Gamma", "[", 
    RowBox[{
     RowBox[{"-", "1"}], "+", 
     RowBox[{"2", " ", "\[Epsilon]"}]}], "]"}]}], 
  RowBox[{"Gamma", "[", 
   RowBox[{"3", "-", 
    RowBox[{"3", " ", "\[Epsilon]"}]}], "]"}]]], "Output",
 CellChangeTimes->{3.797940115901535*^9, 3.797940398282187*^9, 
  3.798253111329782*^9, 3.798253159765047*^9, 3.7986858160387616`*^9, 
  3.7990376351561117`*^9},ExpressionUUID->"13e7bc45-55eb-445b-899f-\
2c1a741d8870"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{"3", " ", 
      SuperscriptBox["p", "2"]}], 
     RowBox[{"512", " ", 
      SuperscriptBox["\[Pi]", "4"], " ", "\[Epsilon]"}]]}], "+", 
   FractionBox[
    RowBox[{"3", " ", 
     SuperscriptBox["p", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "13"}], "+", 
       RowBox[{"4", " ", "EulerGamma"}], "-", 
       RowBox[{"8", " ", 
        RowBox[{"Log", "[", "2", "]"}]}], "+", 
       RowBox[{"8", " ", 
        RowBox[{"Log", "[", "p", "]"}]}], "-", 
       RowBox[{"4", " ", 
        RowBox[{"Log", "[", "\[Pi]", "]"}]}]}], ")"}]}], 
    RowBox[{"1024", " ", 
     SuperscriptBox["\[Pi]", "4"]}]], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "\[Epsilon]", "]"}], "1"],
    SeriesData[TripleK`\[Epsilon], 0, {}, -1, 1, 1],
    Editable->False]}],
  SeriesData[
  TripleK`\[Epsilon], 0, {
   Rational[-3, 512] TripleK`p^2 Pi^(-4), Rational[3, 1024] TripleK`p^2 
    Pi^(-4) (-13 + 4 EulerGamma - 8 Log[2] + 8 Log[TripleK`p] - 4 
     Log[Pi])}, -1, 1, 1],
  Editable->False]], "Output",
 CellChangeTimes->{3.797940115901535*^9, 3.797940398282187*^9, 
  3.798253111329782*^9, 3.798253159765047*^9, 3.7986858160387616`*^9, 
  3.7990376352532797`*^9},ExpressionUUID->"f1af7048-7b42-473e-8994-\
61f9935cf4d6"]
}, Open  ]],

Cell["For the 3-point function we can write:", "Text",
 CellChangeTimes->{{3.7982531693509283`*^9, 
  3.798253187655593*^9}},ExpressionUUID->"6b5dfc5a-3137-4aa1-9742-\
5c6a475bd430"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"EffectivePropagator", "=", 
  RowBox[{
   RowBox[{"LoopIntegral", "[", 
    RowBox[{
     RowBox[{"4", "-", 
      RowBox[{"2", "\[Epsilon]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "1"}], "}"}]}], "]"}], "[", 
   RowBox[{"1", ",", 
    RowBox[{"k", "[", "1", "]"}], ",", "q"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"ThreePtLoopIntegral", "=", 
  RowBox[{
   RowBox[{"LoopIntegral", "[", 
    RowBox[{
     RowBox[{"4", "-", 
      RowBox[{"2", "\[Epsilon]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "]"}], "[", 
   RowBox[{
    RowBox[{"1", "*", 
     RowBox[{"(", 
      RowBox[{"EffectivePropagator", "/.", 
       RowBox[{"{", 
        RowBox[{"q", "\[Rule]", 
         RowBox[{"q", "-", 
          RowBox[{"p", "[", "1", "]"}]}]}], "}"}]}], ")"}], "*", 
     RowBox[{"(", 
      RowBox[{"EffectivePropagator", "/.", 
       RowBox[{"{", 
        RowBox[{"q", "\[Rule]", 
         RowBox[{"q", "+", 
          RowBox[{"p", "[", "2", "]"}]}]}], "}"}]}], ")"}]}], ",", "q"}], 
   "]"}]}]}], "Input",
 CellChangeTimes->{{3.7974462494190297`*^9, 3.797446260376045*^9}, {
  3.7974462981590977`*^9, 3.7974463999042416`*^9}, {3.79744655430546*^9, 
  3.7974465677424793`*^9}, {3.7974466313125687`*^9, 3.7974466404335814`*^9}, {
  3.79744718045864*^9, 3.797447182193642*^9}, {3.797447767242467*^9, 
  3.79744776945347*^9}, {3.7974495337977295`*^9, 3.7974495686507783`*^9}, {
  3.7975290956575875`*^9, 3.7975290970085897`*^9}, {3.7979404247337637`*^9, 
  3.797940432930921*^9}, {3.798253190352024*^9, 
  3.798253211047983*^9}},ExpressionUUID->"9177c9d3-75b0-490a-9d71-\
d91eb3310819"],

Cell[BoxData[
 TagBox[
  RowBox[{"\<\"\\!\\(\\*StyleBox[\\\"\[Integral]\\\",FontSize->18]\\)\"\>", 
   " ", 
   TagBox[
    FractionBox[
     RowBox[{
      SuperscriptBox["\<\"\[DifferentialD]\"\>", 
       RowBox[{"4", "-", 
        RowBox[{"2", " ", "\[Epsilon]"}]}]], " ", 
      RowBox[{"k", "[", "1", "]"}]}], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"2", " ", "\[Pi]"}], ")"}], 
      RowBox[{"4", "-", 
       RowBox[{"2", " ", "\[Epsilon]"}]}]]],
    HoldForm], " ", 
   TagBox[
    FractionBox["1", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"k", "[", "1", "]"}], "2"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"k", "[", "1", "]"}], "-", "q"}], ")"}], "2"]}]],
    HoldForm]}],
  HoldForm]], "Output",
 CellChangeTimes->{{3.797446352954176*^9, 3.7974464013142433`*^9}, {
   3.7974465563354626`*^9, 3.7974465680474796`*^9}, {3.7974466279865637`*^9, 
   3.797446640703582*^9}, 3.797447182773643*^9, 3.7974477736244764`*^9, 
   3.797449568950779*^9, 3.7975163187039013`*^9, 3.7975288625382986`*^9, 
   3.797529009205466*^9, 3.797529097908591*^9, 3.797940131777479*^9, 
   3.797940434224622*^9, 3.7982532135056953`*^9, 3.798685816135767*^9, 
   3.7990376352638397`*^9},ExpressionUUID->"172ee5cd-828e-43ab-9e9c-\
da6c6be60276"],

Cell[BoxData[
 TagBox[
  RowBox[{"\<\"\\!\\(\\*StyleBox[\\\"\[Integral]\\\",FontSize->18]\\)\"\>", 
   " ", 
   TagBox[
    FractionBox[
     RowBox[{
      SuperscriptBox["\<\"\[DifferentialD]\"\>", 
       RowBox[{"4", "-", 
        RowBox[{"2", " ", "\[Epsilon]"}]}]], " ", "q"}], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"2", " ", "\[Pi]"}], ")"}], 
      RowBox[{"4", "-", 
       RowBox[{"2", " ", "\[Epsilon]"}]}]]],
    HoldForm], " ", 
   TagBox[
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       TagBox[
        RowBox[{"\<\"\\!\\(\\*StyleBox[\\\"\[Integral]\\\",FontSize->18]\\)\"\
\>", " ", 
         TagBox[
          FractionBox[
           RowBox[{
            SuperscriptBox["\<\"\[DifferentialD]\"\>", 
             RowBox[{"4", "-", 
              RowBox[{"2", " ", "\[Epsilon]"}]}]], " ", 
            RowBox[{"k", "[", "1", "]"}]}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"2", " ", "\[Pi]"}], ")"}], 
            RowBox[{"4", "-", 
             RowBox[{"2", " ", "\[Epsilon]"}]}]]],
          HoldForm], " ", 
         TagBox[
          FractionBox["1", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"k", "[", "1", "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"k", "[", "1", "]"}], "-", 
               RowBox[{"(", 
                RowBox[{"q", "-", 
                 SubscriptBox["p", "1"]}], ")"}]}], ")"}], "2"]}]],
          HoldForm]}],
        HoldForm], ")"}], " ", 
      RowBox[{"(", 
       TagBox[
        RowBox[{"\<\"\\!\\(\\*StyleBox[\\\"\[Integral]\\\",FontSize->18]\\)\"\
\>", " ", 
         TagBox[
          FractionBox[
           RowBox[{
            SuperscriptBox["\<\"\[DifferentialD]\"\>", 
             RowBox[{"4", "-", 
              RowBox[{"2", " ", "\[Epsilon]"}]}]], " ", 
            RowBox[{"k", "[", "1", "]"}]}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"2", " ", "\[Pi]"}], ")"}], 
            RowBox[{"4", "-", 
             RowBox[{"2", " ", "\[Epsilon]"}]}]]],
          HoldForm], " ", 
         TagBox[
          FractionBox["1", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"k", "[", "1", "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"k", "[", "1", "]"}], "-", 
               RowBox[{"(", 
                RowBox[{"q", "+", 
                 SubscriptBox["p", "2"]}], ")"}]}], ")"}], "2"]}]],
          HoldForm]}],
        HoldForm], ")"}]}], 
     RowBox[{
      SuperscriptBox["q", "2"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"q", "-", 
         SubscriptBox["p", "1"]}], ")"}], "0"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"q", "+", 
         SubscriptBox["p", "2"]}], ")"}], "0"]}]],
    HoldForm]}],
  HoldForm]], "Output",
 CellChangeTimes->{{3.797446352954176*^9, 3.7974464013142433`*^9}, {
   3.7974465563354626`*^9, 3.7974465680474796`*^9}, {3.7974466279865637`*^9, 
   3.797446640703582*^9}, 3.797447182773643*^9, 3.7974477736244764`*^9, 
   3.797449568950779*^9, 3.7975163187039013`*^9, 3.7975288625382986`*^9, 
   3.797529009205466*^9, 3.797529097908591*^9, 3.797940131777479*^9, 
   3.797940434224622*^9, 3.7982532135056953`*^9, 3.798685816135767*^9, 
   3.799037635265996*^9},ExpressionUUID->"b0b97aca-6a5f-4e49-ad83-\
39d0baa9c7d8"]
}, Open  ]],

Cell[TextData[{
 "In terms of the triple-",
 StyleBox["K",
  FontSlant->"Italic"],
 " integral this becomes:"
}], "Text",
 CellChangeTimes->{{3.7982532398553333`*^9, 
  3.7982532479589577`*^9}},ExpressionUUID->"c465d17f-f044-4273-91bf-\
a6ede013140e"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ThreePtTripleK", "=", 
  RowBox[{"LoopToK", "[", "ThreePtLoopIntegral", "]"}]}]], "Input",
 CellChangeTimes->{{3.797528873684936*^9, 3.797528876466095*^9}, {
  3.797940181915784*^9, 3.797940182666843*^9}, {3.798253224000301*^9, 
  3.798253231290629*^9}},ExpressionUUID->"0f100c5c-b836-4a32-be45-\
08111150848e"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["2", 
    RowBox[{
     RowBox[{"-", "10"}], "+", 
     RowBox[{"7", " ", "\[Epsilon]"}]}]], " ", 
   SuperscriptBox["\[Pi]", 
    RowBox[{
     RowBox[{"-", "6"}], "+", 
     RowBox[{"3", " ", "\[Epsilon]"}]}]], " ", 
   SuperscriptBox[
    RowBox[{"Gamma", "[", 
     RowBox[{"1", "-", "\[Epsilon]"}], "]"}], "4"], " ", 
   SubscriptBox["i", 
    RowBox[{
     RowBox[{"1", "-", "\[Epsilon]"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"1", "-", 
        RowBox[{"2", " ", "\[Epsilon]"}]}], ",", 
       RowBox[{"1", "-", 
        RowBox[{"2", " ", "\[Epsilon]"}]}], ",", 
       RowBox[{"2", "-", 
        RowBox[{"3", " ", "\[Epsilon]"}]}]}], "}"}]}]]}], 
  RowBox[{
   RowBox[{"Gamma", "[", 
    RowBox[{"3", "-", 
     RowBox[{"4", " ", "\[Epsilon]"}]}], "]"}], " ", 
   SuperscriptBox[
    RowBox[{"Gamma", "[", 
     RowBox[{"2", "-", 
      RowBox[{"2", " ", "\[Epsilon]"}]}], "]"}], "2"]}]]], "Output",
 CellChangeTimes->{
  3.797528876765112*^9, {3.7975290395295086`*^9, 3.797529065112544*^9}, 
   3.797529108850606*^9, 3.797940143376185*^9, 3.797940183219904*^9, 
   3.797940475234001*^9, 3.798253252916964*^9, 3.798685816251774*^9, 
   3.799037635400366*^9},ExpressionUUID->"f1642879-b963-46f6-94aa-\
f9a9c90aa1ef"]
}, Open  ]],

Cell["and exhibits the double pole:", "Text",
 CellChangeTimes->{{3.798253267751069*^9, 
  3.7982532812792673`*^9}},ExpressionUUID->"959c6477-6869-4f26-a1de-\
edcd83fa37c7"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"KDivergence", "[", 
   RowBox[{"ThreePtTripleK", ",", 
    RowBox[{"ExpansionOrder", "\[Rule]", 
     RowBox[{"-", "1"}]}]}], "]"}], "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.798253283169726*^9, 
  3.7982533027592688`*^9}},ExpressionUUID->"23f319ec-23e6-4abe-ac7f-\
9afd2c1a99d7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SubsuperscriptBox["p", "1", "2"], "+", 
      SubsuperscriptBox["p", "2", "2"]}], 
     RowBox[{"24576", " ", 
      SuperscriptBox["\[Pi]", "6"], " ", 
      SuperscriptBox["\[Epsilon]", "2"]}]]}], "-", 
   RowBox[{
    FractionBox["1", 
     RowBox[{"24576", " ", 
      SuperscriptBox["\[Pi]", "6"], " ", "\[Epsilon]"}]], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"10", " ", 
       SubsuperscriptBox["p", "1", "2"]}], "-", 
      RowBox[{"3", " ", "EulerGamma", " ", 
       SubsuperscriptBox["p", "1", "2"]}], "+", 
      RowBox[{
       RowBox[{"Log", "[", "64", "]"}], " ", 
       SubsuperscriptBox["p", "1", "2"]}], "+", 
      RowBox[{"3", " ", 
       RowBox[{"Log", "[", "\[Pi]", "]"}], " ", 
       SubsuperscriptBox["p", "1", "2"]}], "-", 
      RowBox[{"6", " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "1"], "]"}], " ", 
       SubsuperscriptBox["p", "1", "2"]}], "+", 
      RowBox[{"10", " ", 
       SubsuperscriptBox["p", "2", "2"]}], "-", 
      RowBox[{"3", " ", "EulerGamma", " ", 
       SubsuperscriptBox["p", "2", "2"]}], "+", 
      RowBox[{
       RowBox[{"Log", "[", "64", "]"}], " ", 
       SubsuperscriptBox["p", "2", "2"]}], "+", 
      RowBox[{"3", " ", 
       RowBox[{"Log", "[", "\[Pi]", "]"}], " ", 
       SubsuperscriptBox["p", "2", "2"]}], "-", 
      RowBox[{"6", " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "2"], "]"}], " ", 
       SubsuperscriptBox["p", "2", "2"]}], "+", 
      SubsuperscriptBox["p", "3", "2"]}], ")"}]}], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "\[Epsilon]", "]"}], "0"],
    SeriesData[TripleK`\[Epsilon], 0, {}, -2, 0, 1],
    Editable->False]}],
  SeriesData[
  TripleK`\[Epsilon], 0, {
   Rational[-1, 24576] Pi^(-6) (TripleK`p[1]^2 + TripleK`p[2]^2), 
    Rational[-1, 24576] 
    Pi^(-6) (10 TripleK`p[1]^2 - 3 EulerGamma TripleK`p[1]^2 + 
     Log[64] TripleK`p[1]^2 + 3 Log[Pi] TripleK`p[1]^2 - 6 Log[
       TripleK`p[1]] TripleK`p[1]^2 + 10 TripleK`p[2]^2 - 3 EulerGamma 
     TripleK`p[2]^2 + Log[64] TripleK`p[2]^2 + 3 Log[Pi] TripleK`p[2]^2 - 6 
     Log[
       TripleK`p[2]] TripleK`p[2]^2 + TripleK`p[3]^2)}, -2, 0, 1],
  Editable->False]], "Output",
 CellChangeTimes->{{3.798253298589353*^9, 3.798253303089509*^9}, 
   3.798685816697799*^9, 
   3.799037635913533*^9},ExpressionUUID->"e5441522-7187-4f19-9449-\
4e269b4a299b"]
}, Open  ]],

Cell[TextData[{
 "To keep things general here we will work with general ",
 StyleBox["u",
  FontSlant->"Italic"],
 " and ",
 StyleBox["v",
  FontSlant->"Italic"],
 ". Recall that our results are valid in any CFT and the free field example \
above is only a single realization. Indeed, for dimensions ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["\[CapitalDelta]", "1"], "=", "4"}], ",", " ", 
    RowBox[{
     SubscriptBox["\[CapitalDelta]", "2"], "=", 
     RowBox[{
      SubscriptBox["\[CapitalDelta]", "3"], "=", "3"}]}]}], TraditionalForm]],
  ExpressionUUID->"d29c45c3-6825-41a6-85cf-f97de58e32fc"],
 " in d = 4 the 3-point function is represented by the triple-",
 StyleBox["K",
  FontSlant->"Italic"],
 " integral:"
}], "Text",
 CellChangeTimes->{{3.797197250178974*^9, 3.7971973267700815`*^9}, {
  3.7971974962173204`*^9, 3.797197498127323*^9}, {3.7971986943860126`*^9, 
  3.7971987326730666`*^9}, {3.7982533116555653`*^9, 3.798253414696026*^9}, {
  3.7982534474250298`*^9, 
  3.7982534667434807`*^9}},ExpressionUUID->"ec60d745-6dd3-4910-bfba-\
130759644c08"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"int", "=", 
  RowBox[{
   RowBox[{"i", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"d", "/", "2"}], "-", "1"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"\[CapitalDelta]", "[", "1", "]"}], "-", 
        RowBox[{"d", "/", "2"}]}], ",", 
       RowBox[{
        RowBox[{"\[CapitalDelta]", "[", "2", "]"}], "-", 
        RowBox[{"d", "/", "2"}]}], ",", 
       RowBox[{
        RowBox[{"\[CapitalDelta]", "[", "3", "]"}], "-", 
        RowBox[{"d", "/", "2"}]}]}], "}"}]}], "]"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"d", "\[Rule]", "4"}], ",", 
     RowBox[{
      RowBox[{"\[CapitalDelta]", "[", "1", "]"}], "\[Rule]", "4"}], ",", 
     RowBox[{
      RowBox[{"\[CapitalDelta]", "[", "2", "]"}], "\[Rule]", "3"}], ",", 
     RowBox[{
      RowBox[{"\[CapitalDelta]", "[", "3", "]"}], "\[Rule]", "3"}]}], 
    "}"}]}]}]], "Input",
 CellChangeTimes->{{3.798253419504801*^9, 
  3.798253442416556*^9}},ExpressionUUID->"88f8d7a9-93b9-4f47-9582-\
4ba536b036c4"],

Cell[BoxData[
 SubscriptBox["i", 
  RowBox[{"1", ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "1", ",", "1"}], "}"}]}]]], "Output",
 CellChangeTimes->{3.798253437632291*^9, 3.798253476730616*^9, 
  3.7986858167067995`*^9, 
  3.799037635923704*^9},ExpressionUUID->"7219f887-96ed-429c-80f2-\
c77c8d3b5a1e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"exp", "=", 
  RowBox[{
   RowBox[{"KEvaluate", "[", 
    RowBox[{"int", "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"d", "\[Rule]", "4"}], ",", 
       RowBox[{
        RowBox[{"\[CapitalDelta]", "[", "1", "]"}], "\[Rule]", "4"}], ",", 
       RowBox[{
        RowBox[{"\[CapitalDelta]", "[", "2", "]"}], "\[Rule]", "3"}], ",", 
       RowBox[{
        RowBox[{"\[CapitalDelta]", "[", "3", "]"}], "\[Rule]", "3"}]}], 
      "}"}]}], "]"}], "//", "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.7948877746151247`*^9, 3.794887908354054*^9}, {
   3.7948880957102137`*^9, 3.7948880985630693`*^9}, {3.794888268983263*^9, 
   3.794888269226495*^9}, {3.7948883576229563`*^9, 3.794888378770617*^9}, 
   3.7971973201540723`*^9, 3.797197480544298*^9, {3.797198675552986*^9, 
   3.7971986793839917`*^9}},ExpressionUUID->"2f8284c9-72aa-412f-ae33-\
1514e5ee12c5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SubsuperscriptBox["p", "2", "2"], "+", 
      SubsuperscriptBox["p", "3", "2"]}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["u", "2"], "-", 
        RowBox[{"4", " ", "u", " ", "v"}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["v", "2"]}]}], ")"}], " ", 
      SuperscriptBox["\[Epsilon]", "2"]}]]}], "+", 
   RowBox[{
    FractionBox["1", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{"u", "-", 
        RowBox[{"3", " ", "v"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"u", "-", "v"}], ")"}], " ", "\[Epsilon]"}]], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "u"}], " ", 
       SubsuperscriptBox["p", "1", "2"]}], "+", 
      RowBox[{"v", " ", 
       SubsuperscriptBox["p", "1", "2"]}], "-", 
      RowBox[{"u", " ", 
       SubsuperscriptBox["p", "2", "2"]}], "+", 
      RowBox[{"2", " ", "EulerGamma", " ", "u", " ", 
       SubsuperscriptBox["p", "2", "2"]}], "+", 
      RowBox[{"v", " ", 
       SubsuperscriptBox["p", "2", "2"]}], "-", 
      RowBox[{"u", " ", 
       RowBox[{"Log", "[", "4", "]"}], " ", 
       SubsuperscriptBox["p", "2", "2"]}], "+", 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{"u", "-", 
         RowBox[{"3", " ", "v"}]}], ")"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "2"], "]"}], " ", 
       SubsuperscriptBox["p", "2", "2"]}], "-", 
      RowBox[{"u", " ", 
       SubsuperscriptBox["p", "3", "2"]}], "+", 
      RowBox[{"2", " ", "EulerGamma", " ", "u", " ", 
       SubsuperscriptBox["p", "3", "2"]}], "+", 
      RowBox[{"v", " ", 
       SubsuperscriptBox["p", "3", "2"]}], "-", 
      RowBox[{"u", " ", 
       RowBox[{"Log", "[", "4", "]"}], " ", 
       SubsuperscriptBox["p", "3", "2"]}], "+", 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{"u", "-", 
         RowBox[{"3", " ", "v"}]}], ")"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}], " ", 
       SubsuperscriptBox["p", "3", "2"]}]}], ")"}]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", 
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SuperscriptBox["\[Pi]", "2"], " ", 
           SuperscriptBox["v", "2"]}], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", "v"}], "+", 
             RowBox[{"u", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", "EulerGamma", "-", 
                RowBox[{"Log", "[", "2", "]"}]}], ")"}]}]}], ")"}], "2"], "+", 
          RowBox[{
           SuperscriptBox["u", "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"EulerGamma", "-", 
              RowBox[{"Log", "[", "2", "]"}]}], ")"}], "2"]}]}], ")"}], " ", 
        SubsuperscriptBox["p", "1", "2"]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"u", "-", 
          RowBox[{"3", " ", "v"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"u", "-", "v"}], ")"}]}]], "+", 
      RowBox[{"2", " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "1"], "]"}], " ", 
       SubsuperscriptBox["p", "1", "2"]}], "-", 
      FractionBox[
       RowBox[{"4", " ", "v", " ", 
        RowBox[{"Log", "[", 
         SubscriptBox["p", "1"], "]"}], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"Log", "[", 
           SubscriptBox["p", "1"], "]"}]}], ")"}], " ", 
        SubsuperscriptBox["p", "1", "2"]}], 
       RowBox[{"u", "-", "v"}]], "+", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", "v"}], "+", 
          RowBox[{"u", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             RowBox[{"2", " ", "EulerGamma"}], "-", 
             RowBox[{"Log", "[", "4", "]"}]}], ")"}]}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"2", " ", 
           RowBox[{"Log", "[", 
            SubscriptBox["p", "1"], "]"}]}]}], ")"}], " ", 
        SubsuperscriptBox["p", "1", "2"]}], 
       RowBox[{"u", "-", "v"}]], "+", 
      RowBox[{"2", " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "2"], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SubsuperscriptBox["p", "1", "2"], "-", 
         SubsuperscriptBox["p", "2", "2"], "-", 
         SubsuperscriptBox["p", "3", "2"]}], ")"}]}], "-", 
      RowBox[{
       RowBox[{"Log", "[", 
        SubscriptBox["p", "2"], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SubsuperscriptBox["p", "1", "2"], "+", 
         SubsuperscriptBox["p", "2", "2"], "-", 
         SubsuperscriptBox["p", "3", "2"]}], ")"}]}], "-", 
      RowBox[{"2", " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "1"], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "2"], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SubsuperscriptBox["p", "1", "2"], "+", 
         SubsuperscriptBox["p", "2", "2"], "-", 
         SubsuperscriptBox["p", "3", "2"]}], ")"}]}], "+", 
      RowBox[{
       RowBox[{"Log", "[", 
        SubscriptBox["p", "2"], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SubsuperscriptBox["p", "1", "2"], "+", 
         RowBox[{"2", " ", 
          RowBox[{"Log", "[", 
           SubscriptBox["p", "1"], "]"}], " ", 
          SubsuperscriptBox["p", "1", "2"]}], "-", 
         RowBox[{"2", " ", 
          RowBox[{"Log", "[", 
           SubscriptBox["p", "3"], "]"}], " ", 
          SubsuperscriptBox["p", "1", "2"]}], "+", 
         SubsuperscriptBox["p", "2", "2"], "-", 
         SubsuperscriptBox["p", "3", "2"]}], ")"}]}], "-", 
      RowBox[{
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SubsuperscriptBox["p", "1", "2"], "-", 
         SubsuperscriptBox["p", "2", "2"], "+", 
         SubsuperscriptBox["p", "3", "2"]}], ")"}]}], "-", 
      RowBox[{"2", " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "1"], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SubsuperscriptBox["p", "1", "2"], "-", 
         SubsuperscriptBox["p", "2", "2"], "+", 
         SubsuperscriptBox["p", "3", "2"]}], ")"}]}], "+", 
      RowBox[{
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SubsuperscriptBox["p", "1", "2"], "+", 
         RowBox[{"2", " ", 
          RowBox[{"Log", "[", 
           SubscriptBox["p", "1"], "]"}], " ", 
          SubsuperscriptBox["p", "1", "2"]}], "-", 
         SubsuperscriptBox["p", "2", "2"], "+", 
         SubsuperscriptBox["p", "3", "2"]}], ")"}]}], "-", 
      RowBox[{
       FractionBox["1", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"u", "-", 
           RowBox[{"3", " ", "v"}]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"u", "-", "v"}], ")"}]}]], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SuperscriptBox["\[Pi]", "2"], " ", 
           SuperscriptBox["v", "2"]}], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", "v"}], "+", 
             RowBox[{"u", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", "EulerGamma", "-", 
                RowBox[{"Log", "[", "2", "]"}]}], ")"}]}]}], ")"}], "2"], "+", 
          RowBox[{
           SuperscriptBox["u", "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"EulerGamma", "-", 
              RowBox[{"Log", "[", "2", "]"}]}], ")"}], "2"]}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          SubsuperscriptBox["p", "1", "2"], "+", 
          SubsuperscriptBox["p", "2", "2"], "+", 
          SubsuperscriptBox["p", "3", "2"]}], ")"}]}]}], "-", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", "v"}], "+", 
          RowBox[{"u", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             RowBox[{"2", " ", "EulerGamma"}], "-", 
             RowBox[{"Log", "[", "4", "]"}]}], ")"}]}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"Log", "[", 
            SubscriptBox["p", "1"], "]"}], " ", 
           SubsuperscriptBox["p", "1", "2"]}], "+", 
          RowBox[{
           RowBox[{"Log", "[", 
            SubscriptBox["p", "2"], "]"}], " ", 
           SubsuperscriptBox["p", "2", "2"]}], "+", 
          RowBox[{
           RowBox[{"Log", "[", 
            SubscriptBox["p", "3"], "]"}], " ", 
           SubsuperscriptBox["p", "3", "2"]}]}], ")"}]}], 
       RowBox[{"u", "-", "v"}]], "+", 
      FractionBox[
       RowBox[{"4", " ", "v", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"Log", "[", 
             SubscriptBox["p", "1"], "]"}], "2"], " ", 
           SubsuperscriptBox["p", "1", "2"]}], "+", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"Log", "[", 
             SubscriptBox["p", "2"], "]"}], "2"], " ", 
           SubsuperscriptBox["p", "2", "2"]}], "+", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"Log", "[", 
             SubscriptBox["p", "3"], "]"}], "2"], " ", 
           SubsuperscriptBox["p", "3", "2"]}]}], ")"}]}], 
       RowBox[{"u", "-", "v"}]], "+", 
      RowBox[{
       FractionBox["1", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"u", "-", 
           RowBox[{"3", " ", "v"}]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"u", "-", "v"}], ")"}]}]], 
       RowBox[{"2", " ", "v", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", "v"}], "+", 
             RowBox[{"u", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"2", " ", "EulerGamma"}], "-", 
                RowBox[{"Log", "[", "4", "]"}]}], ")"}]}]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             SubsuperscriptBox["p", "1", "2"], "+", 
             SubsuperscriptBox["p", "2", "2"], "+", 
             SubsuperscriptBox["p", "3", "2"]}], ")"}]}], "+", 
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{"u", "-", 
             RowBox[{"3", " ", "v"}]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"Log", "[", 
               SubscriptBox["p", "1"], "]"}], " ", 
              SubsuperscriptBox["p", "1", "2"]}], "+", 
             RowBox[{
              RowBox[{"Log", "[", 
               SubscriptBox["p", "2"], "]"}], " ", 
              SubsuperscriptBox["p", "2", "2"]}], "+", 
             RowBox[{
              RowBox[{"Log", "[", 
               SubscriptBox["p", "3"], "]"}], " ", 
              SubsuperscriptBox["p", "3", "2"]}]}], ")"}]}]}], ")"}]}]}], "+", 
      FractionBox[
       RowBox[{"NL", " ", 
        SubsuperscriptBox["p", "1", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          SubsuperscriptBox["p", "1", "2"], "-", 
          SubsuperscriptBox["p", "2", "2"], "-", 
          SubsuperscriptBox["p", "3", "2"]}], ")"}]}], 
       SqrtBox["\[Lambda]"]], "-", 
      RowBox[{"NL", " ", 
       SqrtBox["\[Lambda]"]}]}], ")"}]}], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "\[Epsilon]", "]"}], "1"],
    SeriesData[TripleK`\[Epsilon], 0, {}, -2, 1, 1],
    Editable->False]}],
  SeriesData[
  TripleK`\[Epsilon], 
   0, {-(TripleK`u^2 - 4 TripleK`u TripleK`v + 3 TripleK`v^2)^(-1) (
     TripleK`p[2]^2 + TripleK`p[3]^2), 
    Rational[1, 2] (TripleK`u - 3 TripleK`v)^(-1) (TripleK`u - 
      TripleK`v)^(-1) (-TripleK`u TripleK`p[1]^2 + TripleK`v TripleK`p[1]^2 - 
     TripleK`u TripleK`p[2]^2 + 2 EulerGamma TripleK`u TripleK`p[2]^2 + 
     TripleK`v TripleK`p[2]^2 - TripleK`u Log[4] TripleK`p[2]^2 + 
     2 (TripleK`u - 3 TripleK`v) Log[
        TripleK`p[2]] TripleK`p[2]^2 - TripleK`u TripleK`p[3]^2 + 
     2 EulerGamma TripleK`u TripleK`p[3]^2 + TripleK`v TripleK`p[3]^2 - 
     TripleK`u Log[4] TripleK`p[3]^2 + 2 (TripleK`u - 3 TripleK`v) Log[
        TripleK`p[3]] TripleK`p[3]^2), 
    Rational[1, 
      4] ((TripleK`u - 3 TripleK`v)^(-1) (TripleK`u - TripleK`v)^(-1) (
       Pi^2 TripleK`v^2 + (3 TripleK`v + 
         TripleK`u (-1 + EulerGamma - Log[2]))^2 + 
       TripleK`u^2 (EulerGamma - Log[2])^2) TripleK`p[1]^2 + 2 Log[
        TripleK`p[1]] TripleK`p[1]^2 - 4 (TripleK`u - TripleK`v)^(-1) 
     TripleK`v Log[
       TripleK`p[1]] (1 + Log[
        TripleK`p[1]]) 
     TripleK`p[1]^2 + (TripleK`u - TripleK`v)^(-1) (3 TripleK`v + 
       TripleK`u (-1 + 2 EulerGamma - Log[4])) (1 + 2 Log[
          TripleK`p[1]]) TripleK`p[1]^2 + 2 Log[
        TripleK`p[2]] Log[
        TripleK`p[3]] (TripleK`p[1]^2 - TripleK`p[2]^2 - TripleK`p[3]^2) - Log[
       TripleK`p[2]] (TripleK`p[1]^2 + TripleK`p[2]^2 - TripleK`p[3]^2) - 2 
     Log[
       TripleK`p[1]] Log[
       TripleK`p[2]] (TripleK`p[1]^2 + TripleK`p[2]^2 - TripleK`p[3]^2) + Log[
        TripleK`p[2]] (TripleK`p[1]^2 + 2 Log[
          TripleK`p[1]] TripleK`p[1]^2 - 2 Log[
         TripleK`p[3]] TripleK`p[1]^2 + TripleK`p[2]^2 - TripleK`p[3]^2) - Log[
       TripleK`p[3]] (TripleK`p[1]^2 - TripleK`p[2]^2 + TripleK`p[3]^2) - 2 
     Log[
       TripleK`p[1]] Log[
       TripleK`p[3]] (TripleK`p[1]^2 - TripleK`p[2]^2 + TripleK`p[3]^2) + Log[
        TripleK`p[3]] (TripleK`p[1]^2 + 2 Log[
          TripleK`p[1]] TripleK`p[1]^2 - TripleK`p[2]^2 + TripleK`p[3]^2) - (
       TripleK`u - 3 TripleK`v)^(-1) (TripleK`u - TripleK`v)^(-1) (
      Pi^2 TripleK`v^2 + (3 TripleK`v + 
        TripleK`u (-1 + EulerGamma - Log[2]))^2 + 
      TripleK`u^2 (EulerGamma - Log[2])^2) (TripleK`p[1]^2 + TripleK`p[2]^2 + 
      TripleK`p[3]^2) - 
     2 (TripleK`u - TripleK`v)^(-1) (3 TripleK`v + 
      TripleK`u (-1 + 2 EulerGamma - Log[4])) (Log[
         TripleK`p[1]] TripleK`p[1]^2 + Log[
         TripleK`p[2]] TripleK`p[2]^2 + Log[
         TripleK`p[3]] TripleK`p[3]^2) + 
     4 (TripleK`u - TripleK`v)^(-1) TripleK`v (Log[
           TripleK`p[1]]^2 TripleK`p[1]^2 + Log[
           TripleK`p[2]]^2 TripleK`p[2]^2 + Log[
           TripleK`p[3]]^2 TripleK`p[3]^2) + 
     2 (TripleK`u - 3 TripleK`v)^(-1) (TripleK`u - TripleK`v)^(-1) 
      TripleK`v ((3 TripleK`v + TripleK`u (-1 + 2 EulerGamma - Log[4])) (
         TripleK`p[1]^2 + TripleK`p[2]^2 + TripleK`p[3]^2) + 
       2 (TripleK`u - 3 TripleK`v) (Log[
            TripleK`p[1]] TripleK`p[1]^2 + Log[
            TripleK`p[2]] TripleK`p[2]^2 + Log[
            TripleK`p[3]] TripleK`p[3]^2)) + TripleK`NL[
        TripleK`p[1], 
        TripleK`p[2], 
        TripleK`p[3]] 
      TripleK`p[1]^2 (TripleK`p[1]^2 - TripleK`p[2]^2 - TripleK`p[3]^2) 
      TripleK`\[Lambda][
         TripleK`p[1], 
         TripleK`p[2], 
         TripleK`p[3]]^Rational[-1, 2] - TripleK`NL[
       TripleK`p[1], 
       TripleK`p[2], 
       TripleK`p[3]] TripleK`\[Lambda][
        TripleK`p[1], 
        TripleK`p[2], 
        TripleK`p[3]]^Rational[1, 2])}, -2, 1, 1],
  Editable->False]], "Output",
 CellChangeTimes->{
  3.797197480820299*^9, {3.797198676132987*^9, 3.7971986806039934`*^9}, 
   3.7982534788973227`*^9, 3.7986858176398535`*^9, 
   3.79903763689469*^9},ExpressionUUID->"ff2f603e-d2d1-48e9-904c-\
a6425ac05a22"]
}, Open  ]],

Cell[TextData[{
 "The integral has a double pole. We can confirm this result by using ",
 StyleBox["KDivergence",
  FontSlant->"Italic"],
 "."
}], "Text",
 CellChangeTimes->{{3.7971973370410967`*^9, 3.7971973395860996`*^9}, {
  3.7971974542862616`*^9, 3.797197464952276*^9}, {3.7971975047343326`*^9, 
  3.7971975220403566`*^9}},ExpressionUUID->"4f6ee97f-15fd-4bce-a9ec-\
8e71ea08f0b1"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"divergence", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"KDivergence", "[", 
    RowBox[{
     RowBox[{"int", "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"d", "\[Rule]", "4"}], ",", 
        RowBox[{
         RowBox[{"\[CapitalDelta]", "[", "1", "]"}], "\[Rule]", "4"}], ",", 
        RowBox[{
         RowBox[{"\[CapitalDelta]", "[", "2", "]"}], "\[Rule]", "3"}], ",", 
        RowBox[{
         RowBox[{"\[CapitalDelta]", "[", "3", "]"}], "\[Rule]", "3"}]}], 
       "}"}]}], ",", 
     RowBox[{"ExpansionOrder", "\[Rule]", 
      RowBox[{"-", "1"}]}]}], "]"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"exp", "-", "divergence"}]}], "Input",
 CellChangeTimes->{{3.794888383028459*^9, 3.794888384666686*^9}, {
   3.794888551209244*^9, 3.794888646948359*^9}, {3.794888706146985*^9, 
   3.7948887202022877`*^9}, {3.7971975580554075`*^9, 3.797197563106415*^9}, 
   3.7971987483060884`*^9},ExpressionUUID->"be7217a6-6276-401b-b479-\
3c3d31c68c30"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SubsuperscriptBox["p", "2", "2"], "+", 
      SubsuperscriptBox["p", "3", "2"]}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["u", "2"], "-", 
        RowBox[{"4", " ", "u", " ", "v"}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["v", "2"]}]}], ")"}], " ", 
      SuperscriptBox["\[Epsilon]", "2"]}]]}], "+", 
   RowBox[{
    FractionBox["1", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{"u", "-", 
        RowBox[{"3", " ", "v"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"u", "-", "v"}], ")"}], " ", "\[Epsilon]"}]], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "u"}], " ", 
       SubsuperscriptBox["p", "1", "2"]}], "+", 
      RowBox[{"v", " ", 
       SubsuperscriptBox["p", "1", "2"]}], "-", 
      RowBox[{"u", " ", 
       SubsuperscriptBox["p", "2", "2"]}], "+", 
      RowBox[{"2", " ", "EulerGamma", " ", "u", " ", 
       SubsuperscriptBox["p", "2", "2"]}], "+", 
      RowBox[{"v", " ", 
       SubsuperscriptBox["p", "2", "2"]}], "-", 
      RowBox[{"u", " ", 
       RowBox[{"Log", "[", "4", "]"}], " ", 
       SubsuperscriptBox["p", "2", "2"]}], "+", 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{"u", "-", 
         RowBox[{"3", " ", "v"}]}], ")"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "2"], "]"}], " ", 
       SubsuperscriptBox["p", "2", "2"]}], "-", 
      RowBox[{"u", " ", 
       SubsuperscriptBox["p", "3", "2"]}], "+", 
      RowBox[{"2", " ", "EulerGamma", " ", "u", " ", 
       SubsuperscriptBox["p", "3", "2"]}], "+", 
      RowBox[{"v", " ", 
       SubsuperscriptBox["p", "3", "2"]}], "-", 
      RowBox[{"u", " ", 
       RowBox[{"Log", "[", "4", "]"}], " ", 
       SubsuperscriptBox["p", "3", "2"]}], "+", 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{"u", "-", 
         RowBox[{"3", " ", "v"}]}], ")"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}], " ", 
       SubsuperscriptBox["p", "3", "2"]}]}], ")"}]}], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "\[Epsilon]", "]"}], "0"],
    SeriesData[TripleK`\[Epsilon], 0, {}, -2, 0, 1],
    Editable->False]}],
  SeriesData[
  TripleK`\[Epsilon], 
   0, {-(TripleK`u^2 - 4 TripleK`u TripleK`v + 3 TripleK`v^2)^(-1) (
     TripleK`p[2]^2 + TripleK`p[3]^2), 
    Rational[1, 2] (TripleK`u - 3 TripleK`v)^(-1) (TripleK`u - 
      TripleK`v)^(-1) (-TripleK`u TripleK`p[1]^2 + TripleK`v TripleK`p[1]^2 - 
     TripleK`u TripleK`p[2]^2 + 2 EulerGamma TripleK`u TripleK`p[2]^2 + 
     TripleK`v TripleK`p[2]^2 - TripleK`u Log[4] TripleK`p[2]^2 + 
     2 (TripleK`u - 3 TripleK`v) Log[
        TripleK`p[2]] TripleK`p[2]^2 - TripleK`u TripleK`p[3]^2 + 
     2 EulerGamma TripleK`u TripleK`p[3]^2 + TripleK`v TripleK`p[3]^2 - 
     TripleK`u Log[4] TripleK`p[3]^2 + 2 (TripleK`u - 3 TripleK`v) Log[
        TripleK`p[3]] TripleK`p[3]^2)}, -2, 0, 1],
  Editable->False]], "Output",
 CellChangeTimes->{{3.7948885578590317`*^9, 3.794888601769557*^9}, {
   3.7948886320844727`*^9, 3.794888647731489*^9}, {3.7948887080259438`*^9, 
   3.794888720557199*^9}, 3.7971975296963673`*^9, 3.7971975636764154`*^9, 
   3.797198748786089*^9, 3.7982534843265038`*^9, 3.7986858180338755`*^9, 
   3.799037637364208*^9},ExpressionUUID->"ae138ef9-6648-4dfc-b6fa-\
0bb316181074"],

Cell[BoxData[
 InterpretationBox[
  SuperscriptBox[
   RowBox[{"O", "[", "\[Epsilon]", "]"}], "0"],
  SeriesData[TripleK`\[Epsilon], 0, {}, 0, 0, 1],
  Editable->False]], "Output",
 CellChangeTimes->{{3.7948885578590317`*^9, 3.794888601769557*^9}, {
   3.7948886320844727`*^9, 3.794888647731489*^9}, {3.7948887080259438`*^9, 
   3.794888720557199*^9}, 3.7971975296963673`*^9, 3.7971975636764154`*^9, 
   3.797198748786089*^9, 3.7982534843265038`*^9, 3.7986858180338755`*^9, 
   3.7990376373657923`*^9},ExpressionUUID->"0407cd50-9f4c-4024-97bf-\
13165054bdff"]
}, Open  ]],

Cell[TextData[{
 "The source of the double pole can be traced back to the appearance of both \
non-trivial \[Beta]-function and scaling anomaly. The appropriate counterterm \
is given in equation (4.122) of [",
 ButtonBox["1510.08442",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://arxiv.org/pdf/1510.08442.pdf"], None},
  ButtonNote->"https://arxiv.org/pdf/1510.08442.pdf"],
 "] and its contribution to the 3-point function in (4.123)."
}], "Text",
 CellChangeTimes->{{3.797197590573453*^9, 
  3.797197659413551*^9}},ExpressionUUID->"f14535b6-a05a-4b55-8e41-\
daaaaa905efe"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Clear", "[", "TwoPtReg", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"TwoPtReg", "[", "p_", "]"}], ":=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"cO", "/", 
       RowBox[{"(", 
        RowBox[{"v", " ", "\[Epsilon]"}], ")"}]}], "+", 
      RowBox[{"cO", "[", "0", "]"}]}], ")"}], 
    RowBox[{"p", "^", 
     RowBox[{"(", 
      RowBox[{"2", "+", 
       RowBox[{"2", "v", " ", "\[Epsilon]"}]}], ")"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"ctContrib", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     RowBox[{"a1", "[", "\[Epsilon]", "]"}]}], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"p", "[", "2", "]"}], "^", "2"}], "+", 
      RowBox[{
       RowBox[{"p", "[", "3", "]"}], "^", "2"}]}], ")"}], 
    RowBox[{"\[Mu]", "^", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", "v"}], "-", "u"}], ")"}], "\[Epsilon]"}], ")"}]}]}], 
   "-", 
   RowBox[{"2", 
    RowBox[{"a2", "[", "\[Epsilon]", "]"}], 
    RowBox[{
     RowBox[{"p", "[", "1", "]"}], "^", "2"}], 
    RowBox[{"\[Mu]", "^", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", "v"}], "-", "u"}], ")"}], "\[Epsilon]"}], ")"}]}]}], 
   "-", 
   RowBox[{
    RowBox[{"a0", "[", "\[Epsilon]", "]"}], 
    RowBox[{"\[Mu]", "^", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"v", "-", "u"}], ")"}], "\[Epsilon]"}], ")"}]}], "*", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"TwoPtReg", "[", 
       RowBox[{"p", "[", "2", "]"}], "]"}], "+", 
      RowBox[{"TwoPtReg", "[", 
       RowBox[{"p", "[", "3", "]"}], "]"}]}], ")"}]}]}]}]}], "Input",
 CellChangeTimes->{{3.7971977377926607`*^9, 3.7971978703448477`*^9}, {
  3.7971979331969366`*^9, 3.7971979342469378`*^9}, {3.7971982059463205`*^9, 
  3.7971982266753497`*^9}, {3.797198758347103*^9, 3.7971987627431087`*^9}, {
  3.79825349700769*^9, 
  3.7982535002567043`*^9}},ExpressionUUID->"8b489d85-6940-40df-8c9c-\
55edb1bc6975"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "2"}], " ", 
   SuperscriptBox["\[Mu]", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "u"}], "+", 
       RowBox[{"3", " ", "v"}]}], ")"}], " ", "\[Epsilon]"}]], " ", 
   RowBox[{"a2", "[", "\[Epsilon]", "]"}], " ", 
   SubsuperscriptBox["p", "1", "2"]}], "-", 
  RowBox[{
   SuperscriptBox["\[Mu]", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "u"}], "+", 
       RowBox[{"3", " ", "v"}]}], ")"}], " ", "\[Epsilon]"}]], " ", 
   RowBox[{"a1", "[", "\[Epsilon]", "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     SubsuperscriptBox["p", "2", "2"], "+", 
     SubsuperscriptBox["p", "3", "2"]}], ")"}]}], "-", 
  RowBox[{
   SuperscriptBox["\[Mu]", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "u"}], "+", "v"}], ")"}], " ", "\[Epsilon]"}]], " ", 
   RowBox[{"a0", "[", "\[Epsilon]", "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        FractionBox["cO", 
         RowBox[{"v", " ", "\[Epsilon]"}]], "+", 
        RowBox[{"cO", "[", "0", "]"}]}], ")"}], " ", 
      SubsuperscriptBox["p", "2", 
       RowBox[{"2", "+", 
        RowBox[{"2", " ", "v", " ", "\[Epsilon]"}]}]]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        FractionBox["cO", 
         RowBox[{"v", " ", "\[Epsilon]"}]], "+", 
        RowBox[{"cO", "[", "0", "]"}]}], ")"}], " ", 
      SubsuperscriptBox["p", "3", 
       RowBox[{"2", "+", 
        RowBox[{"2", " ", "v", " ", "\[Epsilon]"}]}]]}]}], 
    ")"}]}]}]], "Output",
 CellChangeTimes->{{3.797197864077839*^9, 3.7971978707948484`*^9}, {
   3.7971982075223227`*^9, 3.79719822700035*^9}, 3.79719876372311*^9, {
   3.798253493914674*^9, 3.798253500555739*^9}, 3.7986858180468764`*^9, 
   3.799037637381341*^9},ExpressionUUID->"b9ea5f5e-d882-425b-8c50-\
241f1d1c3f6a"]
}, Open  ]],

Cell[TextData[{
 "We add ",
 StyleBox["ctContrib",
  FontSlant->"Italic"],
 " to ",
 StyleBox["divergence",
  FontSlant->"Italic"],
 " and choose the parameters in such a way that the divergence is cancelled. \
With ",
 StyleBox["a",
  FontSlant->"Italic"],
 "0 and ",
 StyleBox["a",
  FontSlant->"Italic"],
 "2 starting at ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[Epsilon]", 
    RowBox[{"-", "1"}]], TraditionalForm]],ExpressionUUID->
  "0ae65ed0-3f43-4003-b37f-34c33b1161cc"],
 " and ",
 StyleBox["a",
  FontSlant->"Italic"],
 "1 at ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[Epsilon]", 
    RowBox[{"-", "2"}]], TraditionalForm]],ExpressionUUID->
  "97dd3107-aa8c-4597-b58d-0622b97fbb5c"],
 " we find"
}], "Text",
 CellChangeTimes->{{3.7971978863328705`*^9, 3.7971979157979116`*^9}, {
  3.7971982404823694`*^9, 3.797198293827445*^9}, {3.797198405610603*^9, 
  3.797198411706611*^9}},ExpressionUUID->"bc709146-c9b3-4460-bb71-\
bb4ad40dd382"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"aExpand", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"a2", "[", "\[Epsilon]", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"a2", "[", "1", "]"}], "/", "\[Epsilon]"}], "+", 
       RowBox[{"a2", "[", "0", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"a0", "[", "\[Epsilon]", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"a0", "[", "1", "]"}], "/", "\[Epsilon]"}], "+", 
       RowBox[{"a0", "[", "0", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"a1", "[", "\[Epsilon]", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"a1", "[", "2", "]"}], "/", 
        RowBox[{"\[Epsilon]", "^", "2"}]}], "+", 
       RowBox[{
        RowBox[{"a1", "[", "1", "]"}], "/", "\[Epsilon]"}], "+", 
       RowBox[{"a1", "[", "0", "]"}]}]}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"ShouldBe0", "=", 
  RowBox[{"divergence", "+", 
   RowBox[{"Series", "[", 
    RowBox[{
     RowBox[{"ctContrib", "/.", "aExpand"}], ",", 
     RowBox[{"{", 
      RowBox[{"\[Epsilon]", ",", "0", ",", 
       RowBox[{"-", "1"}]}], "}"}]}], "]"}]}]}]}], "Input",
 CellChangeTimes->{{3.797198303433459*^9, 3.7971983907775817`*^9}, {
  3.7971988750412683`*^9, 
  3.797198887278285*^9}},ExpressionUUID->"204aa2f3-ce9d-40f3-a8f8-\
abd7f1ea4f4e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   FractionBox[
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        SubsuperscriptBox["p", "2", "2"], "+", 
        SubsuperscriptBox["p", "3", "2"]}], 
       RowBox[{
        SuperscriptBox["u", "2"], "-", 
        RowBox[{"4", " ", "u", " ", "v"}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["v", "2"]}]}]]}], "-", 
     RowBox[{
      RowBox[{"a1", "[", "2", "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SubsuperscriptBox["p", "2", "2"], "+", 
        SubsuperscriptBox["p", "3", "2"]}], ")"}]}], "-", 
     FractionBox[
      RowBox[{
       RowBox[{"a0", "[", "1", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"cO", " ", 
          SubsuperscriptBox["p", "2", "2"]}], "+", 
         RowBox[{"cO", " ", 
          SubsuperscriptBox["p", "3", "2"]}]}], ")"}]}], "v"]}], 
    SuperscriptBox["\[Epsilon]", "2"]], "+", 
   RowBox[{
    FractionBox["1", "\[Epsilon]"], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       RowBox[{"a2", "[", "1", "]"}], " ", 
       SubsuperscriptBox["p", "1", "2"]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a1", "[", "1", "]"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"u", "-", 
            RowBox[{"3", " ", "v"}]}], ")"}], " ", 
          RowBox[{"a1", "[", "2", "]"}], " ", 
          RowBox[{"Log", "[", "\[Mu]", "]"}]}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SubsuperscriptBox["p", "2", "2"], "+", 
         SubsuperscriptBox["p", "3", "2"]}], ")"}]}], "-", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"a0", "[", "0", "]"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "u"}], "+", "v"}], ")"}], " ", 
           RowBox[{"a0", "[", "1", "]"}], " ", 
           RowBox[{"Log", "[", "\[Mu]", "]"}]}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"cO", " ", 
           SubsuperscriptBox["p", "2", "2"]}], "+", 
          RowBox[{"cO", " ", 
           SubsuperscriptBox["p", "3", "2"]}]}], ")"}]}], "v"], "-", 
      RowBox[{
       RowBox[{"a0", "[", "1", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"cO", "[", "0", "]"}], " ", 
          SubsuperscriptBox["p", "2", "2"]}], "+", 
         RowBox[{"2", " ", "cO", " ", 
          RowBox[{"Log", "[", 
           SubscriptBox["p", "2"], "]"}], " ", 
          SubsuperscriptBox["p", "2", "2"]}], "+", 
         RowBox[{
          RowBox[{"cO", "[", "0", "]"}], " ", 
          SubsuperscriptBox["p", "3", "2"]}], "+", 
         RowBox[{"2", " ", "cO", " ", 
          RowBox[{"Log", "[", 
           SubscriptBox["p", "3"], "]"}], " ", 
          SubsuperscriptBox["p", "3", "2"]}]}], ")"}]}], "+", 
      RowBox[{
       FractionBox["1", 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{"u", "-", 
           RowBox[{"3", " ", "v"}]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"u", "-", "v"}], ")"}]}]], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "u"}], " ", 
          SubsuperscriptBox["p", "1", "2"]}], "+", 
         RowBox[{"v", " ", 
          SubsuperscriptBox["p", "1", "2"]}], "-", 
         RowBox[{"u", " ", 
          SubsuperscriptBox["p", "2", "2"]}], "+", 
         RowBox[{"2", " ", "EulerGamma", " ", "u", " ", 
          SubsuperscriptBox["p", "2", "2"]}], "+", 
         RowBox[{"v", " ", 
          SubsuperscriptBox["p", "2", "2"]}], "-", 
         RowBox[{"u", " ", 
          RowBox[{"Log", "[", "4", "]"}], " ", 
          SubsuperscriptBox["p", "2", "2"]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{"u", "-", 
            RowBox[{"3", " ", "v"}]}], ")"}], " ", 
          RowBox[{"Log", "[", 
           SubscriptBox["p", "2"], "]"}], " ", 
          SubsuperscriptBox["p", "2", "2"]}], "-", 
         RowBox[{"u", " ", 
          SubsuperscriptBox["p", "3", "2"]}], "+", 
         RowBox[{"2", " ", "EulerGamma", " ", "u", " ", 
          SubsuperscriptBox["p", "3", "2"]}], "+", 
         RowBox[{"v", " ", 
          SubsuperscriptBox["p", "3", "2"]}], "-", 
         RowBox[{"u", " ", 
          RowBox[{"Log", "[", "4", "]"}], " ", 
          SubsuperscriptBox["p", "3", "2"]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{"u", "-", 
            RowBox[{"3", " ", "v"}]}], ")"}], " ", 
          RowBox[{"Log", "[", 
           SubscriptBox["p", "3"], "]"}], " ", 
          SubsuperscriptBox["p", "3", "2"]}]}], ")"}]}]}], ")"}]}], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "\[Epsilon]", "]"}], "0"],
    SeriesData[TripleK`\[Epsilon], 0, {}, -2, 0, 1],
    Editable->False]}],
  SeriesData[
  TripleK`\[Epsilon], 
   0, {-(TripleK`u^2 - 4 TripleK`u TripleK`v + 3 TripleK`v^2)^(-1) (
      TripleK`p[2]^2 + TripleK`p[3]^2) - $CellContext`a1[2] (TripleK`p[2]^2 + 
     TripleK`p[3]^2) - 
    TripleK`v^(-1) $CellContext`a0[
     1] ($CellContext`cO TripleK`p[2]^2 + $CellContext`cO 
      TripleK`p[3]^2), (-2) $CellContext`a2[1] 
     TripleK`p[
       1]^2 + (-$CellContext`a1[1] + (TripleK`u - 3 
        TripleK`v) $CellContext`a1[2] Log[$CellContext`\[Mu]]) (
      TripleK`p[2]^2 + TripleK`p[3]^2) - 
    TripleK`v^(-1) ($CellContext`a0[
      0] + (-TripleK`u + TripleK`v) $CellContext`a0[1] 
      Log[$CellContext`\[Mu]]) ($CellContext`cO 
      TripleK`p[2]^2 + $CellContext`cO TripleK`p[3]^2) - $CellContext`a0[
     1] ($CellContext`cO[0] TripleK`p[2]^2 + 2 $CellContext`cO Log[
        TripleK`p[2]] TripleK`p[2]^2 + $CellContext`cO[0] TripleK`p[3]^2 + 
     2 $CellContext`cO Log[
        TripleK`p[3]] TripleK`p[3]^2) + 
    Rational[1, 2] (TripleK`u - 3 TripleK`v)^(-1) (TripleK`u - 
       TripleK`v)^(-1) (-TripleK`u TripleK`p[1]^2 + TripleK`v TripleK`p[1]^2 - 
      TripleK`u TripleK`p[2]^2 + 2 EulerGamma TripleK`u TripleK`p[2]^2 + 
      TripleK`v TripleK`p[2]^2 - TripleK`u Log[4] TripleK`p[2]^2 + 
      2 (TripleK`u - 3 TripleK`v) Log[
         TripleK`p[2]] TripleK`p[2]^2 - TripleK`u TripleK`p[3]^2 + 
      2 EulerGamma TripleK`u TripleK`p[3]^2 + TripleK`v TripleK`p[3]^2 - 
      TripleK`u Log[4] TripleK`p[3]^2 + 2 (TripleK`u - 3 TripleK`v) Log[
         TripleK`p[3]] TripleK`p[3]^2)}, -2, 0, 1],
  Editable->False]], "Output",
 CellChangeTimes->{{3.797198341319512*^9, 3.7971983911675825`*^9}, 
   3.797198767664116*^9, 3.797198887924286*^9, 3.79825350389607*^9, 
   3.79868581810988*^9, 
   3.799037637482951*^9},ExpressionUUID->"1791e11e-d15d-4888-a161-\
5cc1a4073a16"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"Equations", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Coefficient", "[", 
        RowBox[{
         RowBox[{"SeriesCoefficient", "[", 
          RowBox[{"ShouldBe0", ",", 
           RowBox[{"-", "2"}]}], "]"}], ",", 
         RowBox[{
          RowBox[{"p", "[", "2", "]"}], "^", "2"}]}], "]"}], ",", 
       RowBox[{"Coefficient", "[", 
        RowBox[{
         RowBox[{"SeriesCoefficient", "[", 
          RowBox[{"ShouldBe0", ",", 
           RowBox[{"-", "1"}]}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"p", "[", "1", "]"}], "^", "2"}], ",", 
           RowBox[{
            RowBox[{"p", "[", "2", "]"}], "^", "2"}], ",", 
           RowBox[{
            RowBox[{
             RowBox[{"p", "[", "3", "]"}], "^", "2"}], 
            RowBox[{"Log", "[", 
             RowBox[{"p", "[", "3", "]"}], "]"}]}], ",", " ", 
           RowBox[{
            RowBox[{
             RowBox[{"p", "[", "1", "]"}], "^", "2"}], 
            RowBox[{"Log", "[", "\[Mu]", "]"}]}], ",", 
           RowBox[{
            RowBox[{
             RowBox[{"p", "[", "2", "]"}], "^", "2"}], 
            RowBox[{"Log", "[", "\[Mu]", "]"}]}], ",", " ", 
           RowBox[{
            RowBox[{
             RowBox[{"p", "[", "3", "]"}], "^", "2"}], 
            RowBox[{"Log", "[", "\[Mu]", "]"}]}]}], "}"}]}], "]"}]}], "}"}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"Log", "[", "\[Mu]", "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"Log", "[", 
         RowBox[{"p", "[", "j_", "]"}], "]"}], "\[RuleDelayed]", "0"}]}], 
      "}"}]}], "//", "Flatten"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7971984224086266`*^9, 3.7971985124997535`*^9}, {
  3.7971987846631403`*^9, 3.7971988119521785`*^9}, {3.7971988930492935`*^9, 
  3.797198905526311*^9}, {3.7971990165044675`*^9, 
  3.7971990251004796`*^9}},ExpressionUUID->"699a0f47-3c3e-4f8c-863f-\
15fad1a8c17c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"aSolution", "=", 
  RowBox[{
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"0", "\[Equal]", "#"}], "&"}], "/@", "Equations"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"a2", "[", "1", "]"}], ",", 
       RowBox[{"a2", "[", "0", "]"}], ",", 
       RowBox[{"a0", "[", "1", "]"}], ",", 
       RowBox[{"a0", "[", "0", "]"}], ",", 
       RowBox[{"a1", "[", "2", "]"}], ",", 
       RowBox[{"a1", "[", "1", "]"}], ",", 
       RowBox[{"a1", "[", "0", "]"}]}], "}"}]}], "]"}], 
   "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}]], "Input",
 CellChangeTimes->{{3.7971988191491885`*^9, 
  3.7971988597142467`*^9}},ExpressionUUID->"605ddd1d-a5bb-4af3-97f2-\
a57e80956642"],

Cell[BoxData[
 TemplateBox[{
  "Solve","svars",
   "\"Equations may not give solutions for all \\\"solve\\\" variables.\"",2,
   100,1,29347142503502531606,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{{3.797198850378233*^9, 3.7971988620202494`*^9}, 
   3.7971989066063128`*^9, 3.797199026291481*^9, 3.79825350655195*^9, 
   3.7986858181508827`*^9, 
   3.799037637559449*^9},ExpressionUUID->"1cc0590c-9b75-4389-b71d-\
31fbcf14dabb"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"a2", "[", "1", "]"}], "\[Rule]", 
    RowBox[{"-", 
     FractionBox["1", 
      RowBox[{"4", " ", 
       RowBox[{"(", 
        RowBox[{"u", "-", 
         RowBox[{"3", " ", "v"}]}], ")"}]}]]}]}], ",", 
   RowBox[{
    RowBox[{"a0", "[", "1", "]"}], "\[Rule]", 
    FractionBox["1", 
     RowBox[{"2", " ", "cO", " ", 
      RowBox[{"(", 
       RowBox[{"u", "-", "v"}], ")"}]}]]}], ",", 
   RowBox[{
    RowBox[{"a1", "[", "2", "]"}], "\[Rule]", 
    RowBox[{"-", 
     FractionBox["1", 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{"u", "-", 
         RowBox[{"3", " ", "v"}]}], ")"}], " ", "v"}]]}]}], ",", 
   RowBox[{
    RowBox[{"a1", "[", "1", "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"cO", " ", 
        RowBox[{"a0", "[", "0", "]"}]}], "v"]}], "-", 
     FractionBox[
      RowBox[{
       RowBox[{"cO", " ", "u"}], "-", 
       RowBox[{"2", " ", "cO", " ", "EulerGamma", " ", "u"}], "-", 
       RowBox[{"cO", " ", "v"}], "+", 
       RowBox[{"u", " ", 
        RowBox[{"cO", "[", "0", "]"}]}], "-", 
       RowBox[{"3", " ", "v", " ", 
        RowBox[{"cO", "[", "0", "]"}]}], "+", 
       RowBox[{"cO", " ", "u", " ", 
        RowBox[{"Log", "[", "4", "]"}]}]}], 
      RowBox[{"2", " ", "cO", " ", 
       RowBox[{"(", 
        RowBox[{"u", "-", 
         RowBox[{"3", " ", "v"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"u", "-", "v"}], ")"}]}]]}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.797198850383233*^9, 3.79719886205025*^9}, 
   3.7971989066363125`*^9, 3.797199026321481*^9, 3.798253506563003*^9, 
   3.7986858181538825`*^9, 
   3.799037637561575*^9},ExpressionUUID->"8e97fed1-5279-4148-9135-\
225a01b14e76"]
}, Open  ]],

Cell["With this solution the reormalized 3-point function becomes", "Text",
 CellChangeTimes->{{3.79719891185632*^9, 3.797198924693338*^9}, {
  3.797199027171482*^9, 
  3.7971990278114834`*^9}},ExpressionUUID->"f609131b-45e4-4a4c-b83f-\
8e3441da9de4"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"OOOren", "=", 
  RowBox[{
   RowBox[{"exp", "+", 
    RowBox[{"Series", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"ctContrib", "/.", "aExpand"}], "/.", "aSolution"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[Epsilon]", ",", "0", ",", "0"}], "}"}]}], "]"}]}], "//", 
   "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.7971989449023666`*^9, 
  3.7971990003964443`*^9}},ExpressionUUID->"ada3f711-6803-4636-9cda-\
e3f409ce6c30"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{
    FractionBox["1", "4"], " ", 
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SuperscriptBox["\[Pi]", "2"], " ", 
           SuperscriptBox["v", "2"]}], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", "v"}], "+", 
             RowBox[{"u", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", "EulerGamma", "-", 
                RowBox[{"Log", "[", "2", "]"}]}], ")"}]}]}], ")"}], "2"], "+", 
          RowBox[{
           SuperscriptBox["u", "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"EulerGamma", "-", 
              RowBox[{"Log", "[", "2", "]"}]}], ")"}], "2"]}]}], ")"}], " ", 
        SubsuperscriptBox["p", "1", "2"]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"u", "-", 
          RowBox[{"3", " ", "v"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"u", "-", "v"}], ")"}]}]], "-", 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"4", " ", 
          RowBox[{"a2", "[", "0", "]"}]}], "+", 
         RowBox[{"Log", "[", "\[Mu]", "]"}]}], ")"}], " ", 
       SubsuperscriptBox["p", "1", "2"]}], "+", 
      RowBox[{"2", " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "1"], "]"}], " ", 
       SubsuperscriptBox["p", "1", "2"]}], "-", 
      FractionBox[
       RowBox[{"4", " ", "v", " ", 
        RowBox[{"Log", "[", 
         SubscriptBox["p", "1"], "]"}], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"Log", "[", 
           SubscriptBox["p", "1"], "]"}]}], ")"}], " ", 
        SubsuperscriptBox["p", "1", "2"]}], 
       RowBox[{"u", "-", "v"}]], "+", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", "v"}], "+", 
          RowBox[{"u", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             RowBox[{"2", " ", "EulerGamma"}], "-", 
             RowBox[{"Log", "[", "4", "]"}]}], ")"}]}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"2", " ", 
           RowBox[{"Log", "[", 
            SubscriptBox["p", "1"], "]"}]}]}], ")"}], " ", 
        SubsuperscriptBox["p", "1", "2"]}], 
       RowBox[{"u", "-", "v"}]], "+", 
      RowBox[{"2", " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "2"], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SubsuperscriptBox["p", "1", "2"], "-", 
         SubsuperscriptBox["p", "2", "2"], "-", 
         SubsuperscriptBox["p", "3", "2"]}], ")"}]}], "-", 
      RowBox[{
       RowBox[{"Log", "[", 
        SubscriptBox["p", "2"], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SubsuperscriptBox["p", "1", "2"], "+", 
         SubsuperscriptBox["p", "2", "2"], "-", 
         SubsuperscriptBox["p", "3", "2"]}], ")"}]}], "-", 
      RowBox[{"2", " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "1"], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "2"], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SubsuperscriptBox["p", "1", "2"], "+", 
         SubsuperscriptBox["p", "2", "2"], "-", 
         SubsuperscriptBox["p", "3", "2"]}], ")"}]}], "+", 
      RowBox[{
       RowBox[{"Log", "[", 
        SubscriptBox["p", "2"], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SubsuperscriptBox["p", "1", "2"], "+", 
         RowBox[{"2", " ", 
          RowBox[{"Log", "[", 
           SubscriptBox["p", "1"], "]"}], " ", 
          SubsuperscriptBox["p", "1", "2"]}], "-", 
         RowBox[{"2", " ", 
          RowBox[{"Log", "[", 
           SubscriptBox["p", "3"], "]"}], " ", 
          SubsuperscriptBox["p", "1", "2"]}], "+", 
         SubsuperscriptBox["p", "2", "2"], "-", 
         SubsuperscriptBox["p", "3", "2"]}], ")"}]}], "-", 
      RowBox[{
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SubsuperscriptBox["p", "1", "2"], "-", 
         SubsuperscriptBox["p", "2", "2"], "+", 
         SubsuperscriptBox["p", "3", "2"]}], ")"}]}], "-", 
      RowBox[{"2", " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "1"], "]"}], " ", 
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SubsuperscriptBox["p", "1", "2"], "-", 
         SubsuperscriptBox["p", "2", "2"], "+", 
         SubsuperscriptBox["p", "3", "2"]}], ")"}]}], "+", 
      RowBox[{
       RowBox[{"Log", "[", 
        SubscriptBox["p", "3"], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SubsuperscriptBox["p", "1", "2"], "+", 
         RowBox[{"2", " ", 
          RowBox[{"Log", "[", 
           SubscriptBox["p", "1"], "]"}], " ", 
          SubsuperscriptBox["p", "1", "2"]}], "-", 
         SubsuperscriptBox["p", "2", "2"], "+", 
         SubsuperscriptBox["p", "3", "2"]}], ")"}]}], "+", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{"u", "-", "v"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"4", " ", "cO", " ", 
           RowBox[{"a0", "[", "0", "]"}]}], "-", 
          RowBox[{"Log", "[", "\[Mu]", "]"}]}], ")"}], " ", 
        RowBox[{"Log", "[", "\[Mu]", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          SubsuperscriptBox["p", "2", "2"], "+", 
          SubsuperscriptBox["p", "3", "2"]}], ")"}]}], "v"], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "4"}], " ", 
          RowBox[{"a1", "[", "0", "]"}]}], "-", 
         RowBox[{
          FractionBox["1", 
           RowBox[{"cO", " ", 
            RowBox[{"(", 
             RowBox[{"u", "-", "v"}], ")"}], " ", "v"}]], 
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", 
              SuperscriptBox["cO", "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["u", "2"], "-", 
                RowBox[{"4", " ", "u", " ", "v"}], "+", 
                RowBox[{"3", " ", 
                 SuperscriptBox["v", "2"]}]}], ")"}], " ", 
              RowBox[{"a0", "[", "0", "]"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"u", "-", 
                RowBox[{"3", " ", "v"}]}], ")"}], " ", "v", " ", 
              RowBox[{"cO", "[", "0", "]"}]}], "+", 
             RowBox[{"cO", " ", "v", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "v"}], "+", 
                RowBox[{"u", " ", 
                 RowBox[{"(", 
                  RowBox[{"1", "-", 
                   RowBox[{"2", " ", "EulerGamma"}], "+", 
                   RowBox[{"Log", "[", "4", "]"}]}], ")"}]}]}], ")"}]}]}], 
            ")"}], " ", 
           RowBox[{"Log", "[", "\[Mu]", "]"}]}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "3"}], "+", 
            FractionBox["u", "v"]}], ")"}], " ", 
          SuperscriptBox[
           RowBox[{"Log", "[", "\[Mu]", "]"}], "2"]}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SubsuperscriptBox["p", "2", "2"], "+", 
         SubsuperscriptBox["p", "3", "2"]}], ")"}]}], "-", 
      RowBox[{
       FractionBox["1", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"u", "-", 
           RowBox[{"3", " ", "v"}]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"u", "-", "v"}], ")"}]}]], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SuperscriptBox["\[Pi]", "2"], " ", 
           SuperscriptBox["v", "2"]}], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", "v"}], "+", 
             RowBox[{"u", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", "EulerGamma", "-", 
                RowBox[{"Log", "[", "2", "]"}]}], ")"}]}]}], ")"}], "2"], "+", 
          RowBox[{
           SuperscriptBox["u", "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"EulerGamma", "-", 
              RowBox[{"Log", "[", "2", "]"}]}], ")"}], "2"]}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          SubsuperscriptBox["p", "1", "2"], "+", 
          SubsuperscriptBox["p", "2", "2"], "+", 
          SubsuperscriptBox["p", "3", "2"]}], ")"}]}]}], "-", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", "v"}], "+", 
          RowBox[{"u", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             RowBox[{"2", " ", "EulerGamma"}], "-", 
             RowBox[{"Log", "[", "4", "]"}]}], ")"}]}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"Log", "[", 
            SubscriptBox["p", "1"], "]"}], " ", 
           SubsuperscriptBox["p", "1", "2"]}], "+", 
          RowBox[{
           RowBox[{"Log", "[", 
            SubscriptBox["p", "2"], "]"}], " ", 
           SubsuperscriptBox["p", "2", "2"]}], "+", 
          RowBox[{
           RowBox[{"Log", "[", 
            SubscriptBox["p", "3"], "]"}], " ", 
           SubsuperscriptBox["p", "3", "2"]}]}], ")"}]}], 
       RowBox[{"u", "-", "v"}]], "+", 
      FractionBox[
       RowBox[{"4", " ", "v", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"Log", "[", 
             SubscriptBox["p", "1"], "]"}], "2"], " ", 
           SubsuperscriptBox["p", "1", "2"]}], "+", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"Log", "[", 
             SubscriptBox["p", "2"], "]"}], "2"], " ", 
           SubsuperscriptBox["p", "2", "2"]}], "+", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"Log", "[", 
             SubscriptBox["p", "3"], "]"}], "2"], " ", 
           SubsuperscriptBox["p", "3", "2"]}]}], ")"}]}], 
       RowBox[{"u", "-", "v"}]], "-", 
      FractionBox[
       RowBox[{"4", " ", "v", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"cO", "[", "0", "]"}], " ", 
           RowBox[{"Log", "[", 
            SubscriptBox["p", "2"], "]"}], " ", 
           SubsuperscriptBox["p", "2", "2"]}], "+", 
          RowBox[{"cO", " ", 
           SuperscriptBox[
            RowBox[{"Log", "[", 
             SubscriptBox["p", "2"], "]"}], "2"], " ", 
           SubsuperscriptBox["p", "2", "2"]}], "+", 
          RowBox[{
           RowBox[{"Log", "[", 
            SubscriptBox["p", "3"], "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"cO", "[", "0", "]"}], "+", 
             RowBox[{"cO", " ", 
              RowBox[{"Log", "[", 
               SubscriptBox["p", "3"], "]"}]}]}], ")"}], " ", 
           SubsuperscriptBox["p", "3", "2"]}]}], ")"}]}], 
       RowBox[{"cO", " ", 
        RowBox[{"(", 
         RowBox[{"u", "-", "v"}], ")"}]}]], "-", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", "cO", " ", 
           RowBox[{"a0", "[", "0", "]"}]}], "-", 
          RowBox[{"Log", "[", "\[Mu]", "]"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", "cO", " ", 
           RowBox[{"Log", "[", 
            SubscriptBox["p", "2"], "]"}], " ", 
           SubsuperscriptBox["p", "2", "2"]}], "+", 
          RowBox[{"2", " ", "cO", " ", 
           RowBox[{"Log", "[", 
            SubscriptBox["p", "3"], "]"}], " ", 
           SubsuperscriptBox["p", "3", "2"]}], "+", 
          RowBox[{
           RowBox[{"cO", "[", "0", "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             SubsuperscriptBox["p", "2", "2"], "+", 
             SubsuperscriptBox["p", "3", "2"]}], ")"}]}]}], ")"}]}], "cO"], 
      "+", 
      RowBox[{
       FractionBox["1", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"u", "-", 
           RowBox[{"3", " ", "v"}]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"u", "-", "v"}], ")"}]}]], 
       RowBox[{"2", " ", "v", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", "v"}], "+", 
             RowBox[{"u", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"2", " ", "EulerGamma"}], "-", 
                RowBox[{"Log", "[", "4", "]"}]}], ")"}]}]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             SubsuperscriptBox["p", "1", "2"], "+", 
             SubsuperscriptBox["p", "2", "2"], "+", 
             SubsuperscriptBox["p", "3", "2"]}], ")"}]}], "+", 
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{"u", "-", 
             RowBox[{"3", " ", "v"}]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"Log", "[", 
               SubscriptBox["p", "1"], "]"}], " ", 
              SubsuperscriptBox["p", "1", "2"]}], "+", 
             RowBox[{
              RowBox[{"Log", "[", 
               SubscriptBox["p", "2"], "]"}], " ", 
              SubsuperscriptBox["p", "2", "2"]}], "+", 
             RowBox[{
              RowBox[{"Log", "[", 
               SubscriptBox["p", "3"], "]"}], " ", 
              SubsuperscriptBox["p", "3", "2"]}]}], ")"}]}]}], ")"}]}]}], "+", 
      FractionBox[
       RowBox[{"NL", " ", 
        SubsuperscriptBox["p", "1", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          SubsuperscriptBox["p", "1", "2"], "-", 
          SubsuperscriptBox["p", "2", "2"], "-", 
          SubsuperscriptBox["p", "3", "2"]}], ")"}]}], 
       SqrtBox["\[Lambda]"]], "-", 
      RowBox[{"NL", " ", 
       SqrtBox["\[Lambda]"]}]}], ")"}]}], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "\[Epsilon]", "]"}], "1"],
    SeriesData[TripleK`\[Epsilon], 0, {}, 0, 1, 1],
    Editable->False]}],
  SeriesData[
  TripleK`\[Epsilon], 0, {
   Rational[1, 
      4] ((TripleK`u - 3 TripleK`v)^(-1) (TripleK`u - TripleK`v)^(-1) (
       Pi^2 TripleK`v^2 + (3 TripleK`v + 
         TripleK`u (-1 + EulerGamma - Log[2]))^2 + 
       TripleK`u^2 (EulerGamma - Log[2])^2) TripleK`p[1]^2 - 
     2 (4 $CellContext`a2[0] + Log[$CellContext`\[Mu]]) TripleK`p[1]^2 + 2 Log[
        TripleK`p[1]] TripleK`p[1]^2 - 4 (TripleK`u - TripleK`v)^(-1) 
     TripleK`v Log[
       TripleK`p[1]] (1 + Log[
        TripleK`p[1]]) 
     TripleK`p[1]^2 + (TripleK`u - TripleK`v)^(-1) (3 TripleK`v + 
       TripleK`u (-1 + 2 EulerGamma - Log[4])) (1 + 2 Log[
          TripleK`p[1]]) TripleK`p[1]^2 + 2 Log[
        TripleK`p[2]] Log[
        TripleK`p[3]] (TripleK`p[1]^2 - TripleK`p[2]^2 - TripleK`p[3]^2) - Log[
       TripleK`p[2]] (TripleK`p[1]^2 + TripleK`p[2]^2 - TripleK`p[3]^2) - 2 
     Log[
       TripleK`p[1]] Log[
       TripleK`p[2]] (TripleK`p[1]^2 + TripleK`p[2]^2 - TripleK`p[3]^2) + Log[
        TripleK`p[2]] (TripleK`p[1]^2 + 2 Log[
          TripleK`p[1]] TripleK`p[1]^2 - 2 Log[
         TripleK`p[3]] TripleK`p[1]^2 + TripleK`p[2]^2 - TripleK`p[3]^2) - Log[
       TripleK`p[3]] (TripleK`p[1]^2 - TripleK`p[2]^2 + TripleK`p[3]^2) - 2 
     Log[
       TripleK`p[1]] Log[
       TripleK`p[3]] (TripleK`p[1]^2 - TripleK`p[2]^2 + TripleK`p[3]^2) + Log[
        TripleK`p[3]] (TripleK`p[1]^2 + 2 Log[
          TripleK`p[1]] TripleK`p[1]^2 - TripleK`p[2]^2 + TripleK`p[3]^2) + (
       TripleK`u - TripleK`v) 
      TripleK`v^(-1) (4 $CellContext`cO $CellContext`a0[0] - 
       Log[$CellContext`\[Mu]]) 
      Log[$CellContext`\[Mu]] (TripleK`p[2]^2 + 
       TripleK`p[3]^2) + ((-4) $CellContext`a1[0] - 
       2 $CellContext`cO^(-1) (TripleK`u - TripleK`v)^(-1) 
       TripleK`v^(-1) (
        2 $CellContext`cO^2 (TripleK`u^2 - 4 TripleK`u TripleK`v + 
          3 TripleK`v^2) $CellContext`a0[0] + (TripleK`u - 3 TripleK`v) 
         TripleK`v $CellContext`cO[0] + $CellContext`cO 
         TripleK`v (-TripleK`v + TripleK`u (1 - 2 EulerGamma + Log[4]))) 
       Log[$CellContext`\[Mu]] + (-3 + TripleK`u/TripleK`v) 
        Log[$CellContext`\[Mu]]^2) (TripleK`p[2]^2 + TripleK`p[3]^2) - (
       TripleK`u - 3 TripleK`v)^(-1) (TripleK`u - TripleK`v)^(-1) (
      Pi^2 TripleK`v^2 + (3 TripleK`v + 
        TripleK`u (-1 + EulerGamma - Log[2]))^2 + 
      TripleK`u^2 (EulerGamma - Log[2])^2) (TripleK`p[1]^2 + TripleK`p[2]^2 + 
      TripleK`p[3]^2) - 
     2 (TripleK`u - TripleK`v)^(-1) (3 TripleK`v + 
      TripleK`u (-1 + 2 EulerGamma - Log[4])) (Log[
         TripleK`p[1]] TripleK`p[1]^2 + Log[
         TripleK`p[2]] TripleK`p[2]^2 + Log[
         TripleK`p[3]] TripleK`p[3]^2) + 
     4 (TripleK`u - TripleK`v)^(-1) TripleK`v (Log[
           TripleK`p[1]]^2 TripleK`p[1]^2 + Log[
           TripleK`p[2]]^2 TripleK`p[2]^2 + Log[
           TripleK`p[3]]^2 TripleK`p[3]^2) - 
     4 $CellContext`cO^(-1) (TripleK`u - TripleK`v)^(-1) 
     TripleK`v ($CellContext`cO[0] Log[
         TripleK`p[2]] TripleK`p[2]^2 + $CellContext`cO Log[
          TripleK`p[2]]^2 TripleK`p[2]^2 + Log[
         TripleK`p[3]] ($CellContext`cO[0] + $CellContext`cO Log[
           TripleK`p[3]]) TripleK`p[3]^2) - 
     2 $CellContext`cO^(-1) (2 $CellContext`cO $CellContext`a0[0] - 
      Log[$CellContext`\[Mu]]) (2 $CellContext`cO Log[
         TripleK`p[2]] TripleK`p[2]^2 + 2 $CellContext`cO Log[
         TripleK`p[3]] 
       TripleK`p[3]^2 + $CellContext`cO[0] (TripleK`p[2]^2 + TripleK`p[3]^2)) + 
     2 (TripleK`u - 3 TripleK`v)^(-1) (TripleK`u - TripleK`v)^(-1) 
      TripleK`v ((3 TripleK`v + TripleK`u (-1 + 2 EulerGamma - Log[4])) (
         TripleK`p[1]^2 + TripleK`p[2]^2 + TripleK`p[3]^2) + 
       2 (TripleK`u - 3 TripleK`v) (Log[
            TripleK`p[1]] TripleK`p[1]^2 + Log[
            TripleK`p[2]] TripleK`p[2]^2 + Log[
            TripleK`p[3]] TripleK`p[3]^2)) + TripleK`NL[
        TripleK`p[1], 
        TripleK`p[2], 
        TripleK`p[3]] 
      TripleK`p[1]^2 (TripleK`p[1]^2 - TripleK`p[2]^2 - TripleK`p[3]^2) 
      TripleK`\[Lambda][
         TripleK`p[1], 
         TripleK`p[2], 
         TripleK`p[3]]^Rational[-1, 2] - TripleK`NL[
       TripleK`p[1], 
       TripleK`p[2], 
       TripleK`p[3]] TripleK`\[Lambda][
        TripleK`p[1], 
        TripleK`p[2], 
        TripleK`p[3]]^Rational[1, 2])}, 0, 1, 1],
  Editable->False]], "Output",
 CellChangeTimes->{{3.7971989490873723`*^9, 3.797199029376486*^9}, 
   3.7982535103855667`*^9, 3.798685819333948*^9, 
   3.7990376386471453`*^9},ExpressionUUID->"b80d6769-9ce2-40d9-8324-\
4e08d279a08c"]
}, Open  ]],

Cell["\<\
We find a beautiful, finite, renormalized solution. It is anomalous though,\
\>", "Text",
 CellChangeTimes->{{3.7971990382124977`*^9, 
  3.7971990605115294`*^9}},ExpressionUUID->"c32e5082-c4ab-49ac-bca6-\
6448f9187f52"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ScaleViolation", "=", 
  RowBox[{
   RowBox[{"\[Mu]", " ", 
    RowBox[{"D", "[", 
     RowBox[{"OOOren", ",", "\[Mu]"}], "]"}]}], "//", 
   "FullSimplify"}]}]], "Input",
 CellChangeTimes->{{3.7971991755336914`*^9, 
  3.7971991779486947`*^9}},ExpressionUUID->"e921198d-adf8-41c3-8673-\
e26e7b4aeea5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{
    FractionBox["1", 
     RowBox[{"2", " ", "cO", " ", 
      RowBox[{"(", 
       RowBox[{"u", "-", "v"}], ")"}]}]], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", "cO", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "u"}], "+", "v"}], ")"}], " ", 
       RowBox[{"Log", "[", 
        FractionBox["\[Mu]", 
         SubscriptBox["p", "2"]], "]"}], " ", 
       SubsuperscriptBox["p", "2", "2"]}], "+", 
      RowBox[{"2", " ", "cO", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "u"}], "+", "v"}], ")"}], " ", 
       RowBox[{"Log", "[", 
        FractionBox["\[Mu]", 
         SubscriptBox["p", "3"]], "]"}], " ", 
       SubsuperscriptBox["p", "3", "2"]}], "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["cO", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"u", "-", "v"}], ")"}], " ", 
       RowBox[{"a0", "[", "0", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SubsuperscriptBox["p", "2", "2"], "+", 
         SubsuperscriptBox["p", "3", "2"]}], ")"}]}], "+", 
      RowBox[{"2", " ", "v", " ", 
       RowBox[{"cO", "[", "0", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SubsuperscriptBox["p", "2", "2"], "+", 
         SubsuperscriptBox["p", "3", "2"]}], ")"}]}], "+", 
      RowBox[{"cO", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "u"}], " ", 
          SubsuperscriptBox["p", "1", "2"]}], "+", 
         RowBox[{"u", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{"2", " ", "EulerGamma"}], "-", 
            RowBox[{"Log", "[", "4", "]"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SubsuperscriptBox["p", "2", "2"], "+", 
            SubsuperscriptBox["p", "3", "2"]}], ")"}]}], "+", 
         RowBox[{"v", " ", 
          RowBox[{"(", 
           RowBox[{
            SubsuperscriptBox["p", "1", "2"], "+", 
            SubsuperscriptBox["p", "2", "2"], "+", 
            SubsuperscriptBox["p", "3", "2"]}], ")"}]}]}], ")"}]}]}], ")"}]}],
    "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "\[Epsilon]", "]"}], "1"],
    SeriesData[TripleK`\[Epsilon], 0, {}, 0, 1, 1],
    Editable->False]}],
  SeriesData[
  TripleK`\[Epsilon], 0, {
   Rational[1, 2] $CellContext`cO^(-1) (TripleK`u - TripleK`v)^(-1) (
     2 $CellContext`cO (-TripleK`u + TripleK`v) 
      Log[$CellContext`\[Mu]/TripleK`p[2]] TripleK`p[2]^2 + 
     2 $CellContext`cO (-TripleK`u + TripleK`v) 
      Log[$CellContext`\[Mu]/TripleK`p[3]] TripleK`p[3]^2 + 
     4 $CellContext`cO^2 (TripleK`u - TripleK`v) $CellContext`a0[0] (
       TripleK`p[2]^2 + TripleK`p[3]^2) + 
     2 TripleK`v $CellContext`cO[0] (TripleK`p[2]^2 + 
       TripleK`p[3]^2) + $CellContext`cO (-TripleK`u TripleK`p[1]^2 + 
       TripleK`u (-1 + 2 EulerGamma - Log[4]) (TripleK`p[2]^2 + 
         TripleK`p[3]^2) + 
       TripleK`v (TripleK`p[1]^2 + TripleK`p[2]^2 + TripleK`p[3]^2)))}, 0, 1, 
   1],
  Editable->False]], "Output",
 CellChangeTimes->{3.7971990754285507`*^9, 3.7971991786586957`*^9, 
  3.7982535175280046`*^9, 3.798685823026158*^9, 
  3.7990376419420977`*^9},ExpressionUUID->"6b8a0306-c963-4f0d-a211-\
caee82aa29c0"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   RowBox[{"<", 
    RowBox[{
     SuperscriptBox["T", "\[Mu]\[Nu]"], " ", "O", " ", "O"}], " ", ">"}], 
   TraditionalForm]],ExpressionUUID->"402334c8-454a-4819-ae65-c7d8a4becd5c"],
 " "
}], "Section",
 CellChangeTimes->{
  3.7948822340242157`*^9, {3.794887530584834*^9, 
   3.794887564115209*^9}},ExpressionUUID->"2f6d1ec5-a0ce-48b9-aec2-\
d5222270966d"],

Cell[TextData[{
 "Here we show in detail the analysis of the 3-point function",
 Cell[BoxData[
  FormBox[
   RowBox[{" ", 
    RowBox[{"<", 
     RowBox[{
      SuperscriptBox["T", "\[Mu]\[Nu]"], " ", ":", 
      SuperscriptBox["\[Phi]", "2"], ":", " ", ":", 
      SuperscriptBox["\[Phi]", "2"], ":", " ", ">"}]}]}], TraditionalForm]],
  ExpressionUUID->"07b782d7-e965-4204-8939-ebe82154cbdb"],
 " for a real, free, conformally coupled scalar field \[Phi]. Stress tensor \
for conformal scalars is a sum of two terms: the stress tensor for minimal \
scalars and an improvement term. We can write the two terms are follows:"
}], "Text",
 CellChangeTimes->{{3.7971993522209406`*^9, 
  3.797199413572027*^9}},ExpressionUUID->"c7c446fa-ac13-4089-83f1-\
3b9049214936"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"MinimalScalarIntegral", " ", "=", " ", 
  RowBox[{
   RowBox[{"k", "[", "\[Rho]", "]"}], 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"k", "[", "\[Sigma]", "]"}], "-", 
     RowBox[{
      RowBox[{"p", "[", "1", "]"}], "[", "\[Sigma]", "]"}]}], 
    ")"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"MimimalScalarStructure", " ", "=", " ", 
  RowBox[{
   RowBox[{"1", "/", "2"}], 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"\[Delta]", "[", 
       RowBox[{"\[Mu]", ",", "\[Rho]"}], "]"}], 
      RowBox[{"\[Delta]", "[", 
       RowBox[{"\[Nu]", ",", "\[Sigma]"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"\[Delta]", "[", 
       RowBox[{"\[Mu]", ",", "\[Sigma]"}], "]"}], 
      RowBox[{"\[Delta]", "[", 
       RowBox[{"\[Nu]", ",", "\[Rho]"}], "]"}]}], "-", 
     RowBox[{
      RowBox[{"\[Delta]", "[", 
       RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}], 
      RowBox[{"\[Delta]", "[", 
       RowBox[{"\[Rho]", ",", "\[Sigma]"}], "]"}]}]}], 
    ")"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"ConformalCorrection", " ", "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"d", "-", "2"}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{"4", 
      RowBox[{"(", 
       RowBox[{"d", "-", "1"}], ")"}]}], ")"}]}], "*", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       RowBox[{"\[Delta]", "[", 
        RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}]}], 
      RowBox[{
       RowBox[{"p", "[", "1", "]"}], "^", "2"}]}], "+", 
     RowBox[{
      RowBox[{
       RowBox[{"p", "[", "1", "]"}], "[", "\[Mu]", "]"}], 
      RowBox[{
       RowBox[{"p", "[", "1", "]"}], "[", "\[Nu]", "]"}]}]}], 
    ")"}]}]}]}], "Input",
 CellChangeTimes->{{3.781788777229788*^9, 
  3.7817888305260563`*^9}},ExpressionUUID->"425c0f68-d53e-46b7-8b27-\
c88b73fcf1d9"],

Cell[BoxData[
 RowBox[{
  RowBox[{"k", "[", "\[Rho]", "]"}], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"k", "[", "\[Sigma]", "]"}], "-", 
    TemplateBox[{"p","1","\[Sigma]"},
     "Subsuperscript"]}], ")"}]}]], "Output",
 CellChangeTimes->{3.781788835701792*^9, 3.781789818850987*^9, 
  3.794555670945004*^9, 3.7971994211090374`*^9, 3.7982535341948442`*^9, 
  3.79868582306116*^9, 
  3.799037642002709*^9},ExpressionUUID->"38956383-22c2-4be9-b50b-\
c797f2fe333e"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[Delta]", 
      RowBox[{"\[Mu]", ",", "\[Sigma]"}]], " ", 
     SubscriptBox["\[Delta]", 
      RowBox[{"\[Nu]", ",", "\[Rho]"}]]}], "+", 
    RowBox[{
     SubscriptBox["\[Delta]", 
      RowBox[{"\[Mu]", ",", "\[Rho]"}]], " ", 
     SubscriptBox["\[Delta]", 
      RowBox[{"\[Nu]", ",", "\[Sigma]"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Delta]", 
      RowBox[{"\[Mu]", ",", "\[Nu]"}]], " ", 
     SubscriptBox["\[Delta]", 
      RowBox[{"\[Rho]", ",", "\[Sigma]"}]]}]}], ")"}]}]], "Output",
 CellChangeTimes->{3.781788835701792*^9, 3.781789818850987*^9, 
  3.794555670945004*^9, 3.7971994211090374`*^9, 3.7982535341948442`*^9, 
  3.79868582306116*^9, 
  3.799037642005028*^9},ExpressionUUID->"aa9787b8-11b0-469e-8396-\
939528532131"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "2"}], "+", "d"}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       SubsuperscriptBox["p", "1", "2"]}], " ", 
      SubscriptBox["\[Delta]", 
       RowBox[{"\[Mu]", ",", "\[Nu]"}]]}], "+", 
     RowBox[{
      TemplateBox[{"p","1","\[Mu]"},
       "Subsuperscript"], " ", 
      TemplateBox[{"p","1","\[Nu]"},
       "Subsuperscript"]}]}], ")"}]}], 
  RowBox[{"4", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "d"}], ")"}]}]]], "Output",
 CellChangeTimes->{3.781788835701792*^9, 3.781789818850987*^9, 
  3.794555670945004*^9, 3.7971994211090374`*^9, 3.7982535341948442`*^9, 
  3.79868582306116*^9, 
  3.7990376420070744`*^9},ExpressionUUID->"9ab2c739-539c-41d9-b4a1-\
84bb415f7500"]
}, Open  ]],

Cell["This given the numerator of the loop integral equal", "Text",
 CellChangeTimes->{{3.7971994459630737`*^9, 
  3.79719945757909*^9}},ExpressionUUID->"b2927a49-ff0a-415e-b94f-\
fd279215c1f4"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ConformalT", " ", "=", " ", 
  RowBox[{"8", 
   RowBox[{"Contract", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"MimimalScalarStructure", "*", "MinimalScalarIntegral"}], "+", 
      "ConformalCorrection"}], ",", " ", 
     RowBox[{"Vectors", "\[Rule]", "k"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.781788837900639*^9, 3.781788866249881*^9}, 
   3.781789798533478*^9, {3.7971997268504686`*^9, 
   3.797199733286478*^9}},ExpressionUUID->"c96d877e-e8ac-42bb-ba99-\
8ec893da4548"],

Cell[BoxData[
 RowBox[{"8", " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"k", "[", "\[Mu]", "]"}], " ", 
     RowBox[{"k", "[", "\[Nu]", "]"}]}], "-", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     RowBox[{"k", "\[CenterDot]", "k"}], " ", 
     SubscriptBox["\[Delta]", 
      RowBox[{"\[Mu]", ",", "\[Nu]"}]]}], "+", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     RowBox[{"k", "\[CenterDot]", 
      SubscriptBox["p", "1"]}], " ", 
     SubscriptBox["\[Delta]", 
      RowBox[{"\[Mu]", ",", "\[Nu]"}]]}], "+", 
    FractionBox[
     RowBox[{
      SubsuperscriptBox["p", "1", "2"], " ", 
      SubscriptBox["\[Delta]", 
       RowBox[{"\[Mu]", ",", "\[Nu]"}]]}], 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "d"}], ")"}]}]], "-", 
    FractionBox[
     RowBox[{"d", " ", 
      SubsuperscriptBox["p", "1", "2"], " ", 
      SubscriptBox["\[Delta]", 
       RowBox[{"\[Mu]", ",", "\[Nu]"}]]}], 
     RowBox[{"4", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "d"}], ")"}]}]], "-", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     RowBox[{"k", "[", "\[Nu]", "]"}], " ", 
     TemplateBox[{"p","1","\[Mu]"},
      "Subsuperscript"]}], "-", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     RowBox[{"k", "[", "\[Mu]", "]"}], " ", 
     TemplateBox[{"p","1","\[Nu]"},
      "Subsuperscript"]}], "-", 
    FractionBox[
     RowBox[{
      TemplateBox[{"p","1","\[Mu]"},
       "Subsuperscript"], " ", 
      TemplateBox[{"p","1","\[Nu]"},
       "Subsuperscript"]}], 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "d"}], ")"}]}]], "+", 
    FractionBox[
     RowBox[{"d", " ", 
      TemplateBox[{"p","1","\[Mu]"},
       "Subsuperscript"], " ", 
      TemplateBox[{"p","1","\[Nu]"},
       "Subsuperscript"]}], 
     RowBox[{"4", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "d"}], ")"}]}]]}], ")"}]}]], "Output",
 CellChangeTimes->{
  3.781788866549595*^9, {3.781789799468275*^9, 3.781789819437937*^9}, 
   3.7945556736706963`*^9, 3.797199459060092*^9, 3.797199733661478*^9, {
   3.797199888810697*^9, 3.7971999332067595`*^9}, 3.798253542984428*^9, 
   3.798685823082161*^9, 
   3.799037642055359*^9},ExpressionUUID->"1d9d49dc-0de1-49f8-aade-\
6dc8f1870705"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Ward identities", "Subsubsection",
 CellChangeTimes->{{3.7817895471537733`*^9, 
  3.781789549362796*^9}},ExpressionUUID->"a87354aa-c6db-4bdd-b601-\
2c96c630fe15"],

Cell["\<\
Before we compute this correlator, we can check Ward identities. To do it, we \
first need the scalar 2-point function\
\>", "Text",
 CellChangeTimes->{{3.7817893979140263`*^9, 3.781789419345872*^9}, {
  3.797199467906104*^9, 
  3.7971994779531183`*^9}},ExpressionUUID->"b19528b8-295c-494c-abbb-\
d367ee28aba0"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"toOO", " ", "=", " ", 
  RowBox[{"2", "*", 
   RowBox[{
    RowBox[{"LoopIntegral", "[", 
     RowBox[{"d", ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", "1"}], "}"}]}], "]"}], "[", 
    RowBox[{"1", ",", "k", ",", "p"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.781789567212894*^9, 3.781789588586605*^9}, {
   3.794555737511733*^9, 3.794555738813958*^9}, 
   3.794556239722151*^9},ExpressionUUID->"76377155-a343-4cc6-9c8f-\
1b82d9c489ae"],

Cell[BoxData[
 RowBox[{"2", " ", 
  RowBox[{"(", 
   TagBox[
    RowBox[{"\<\"\\!\\(\\*StyleBox[\\\"\[Integral]\\\",FontSize->18]\\)\"\>", 
     " ", 
     TagBox[
      FractionBox[
       RowBox[{
        SuperscriptBox["\<\"\[DifferentialD]\"\>", "d"], " ", "k"}], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"2", " ", "\[Pi]"}], ")"}], "d"]],
      HoldForm], " ", 
     TagBox[
      FractionBox["1", 
       RowBox[{
        SuperscriptBox["k", "2"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"k", "-", "p"}], ")"}], "2"]}]],
      HoldForm]}],
    HoldForm], ")"}]}]], "Output",
 CellChangeTimes->{{3.781789585649431*^9, 3.781789588881411*^9}, 
   3.781789821479484*^9, 3.79455567843929*^9, 3.794555739205954*^9, 
   3.794556240132682*^9, 3.797199481193123*^9, 3.798253547080283*^9, 
   3.7986858230941615`*^9, 
   3.799037642066753*^9},ExpressionUUID->"3027ccca-b81a-46c3-bd0b-\
ba52da20585f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"OO", "=", 
  RowBox[{
   RowBox[{"toOO", "//", "LoopEvaluate"}], "//", "FullSimplify"}]}]], "Input",
 CellChangeTimes->{{3.781789592276375*^9, 3.781789619884099*^9}, 
   3.794556314609548*^9},ExpressionUUID->"935e18c3-ba1d-494e-b82c-\
abb5eb61a956"],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["4", 
     RowBox[{"2", "-", "d"}]], " ", 
    SuperscriptBox["p", 
     RowBox[{
      RowBox[{"-", "4"}], "+", "d"}]], " ", 
    SuperscriptBox["\[Pi]", 
     RowBox[{
      FractionBox["3", "2"], "-", 
      FractionBox["d", "2"]}]], " ", 
    RowBox[{"Csc", "[", 
     FractionBox[
      RowBox[{"d", " ", "\[Pi]"}], "2"], "]"}]}], 
   RowBox[{"Gamma", "[", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "d"}], ")"}]}], "]"}]]}]], "Output",
 CellChangeTimes->{{3.7817895986094933`*^9, 3.781789620792754*^9}, 
   3.781789824201701*^9, 3.794555680946417*^9, 3.794555740373169*^9, 
   3.794556242524948*^9, {3.794556287924712*^9, 3.794556315517481*^9}, 
   3.7971994834281263`*^9, 3.7982535500355053`*^9, 3.7986858236931953`*^9, 
   3.799037642681139*^9},ExpressionUUID->"762b4738-6019-4bc3-b1f8-\
8b61a8745ee3"]
}, Open  ]],

Cell[TextData[{
 "Ward identities are given in equations (R.6.1) and (R.6.2) of [",
 ButtonBox["1304.7760",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://arxiv.org/pdf/1304.7760.pdf"], None},
  ButtonNote->"https://arxiv.org/pdf/1304.7760.pdf"],
 "]."
}], "Text",
 CellChangeTimes->{{3.781789660057892*^9, 3.781789663314397*^9}, {
  3.797200239101241*^9, 
  3.797200271733287*^9}},ExpressionUUID->"6f9f0efc-d343-4e2a-ba9a-\
0ef82a5df08a"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"TransverseWI", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"p", "[", "2", "]"}], "[", "\[Nu]", "]"}], 
       RowBox[{"(", 
        RowBox[{"OO", "/.", 
         RowBox[{"p", "\[Rule]", 
          RowBox[{"p", "[", "2", "]"}]}]}], ")"}]}], "+", 
      RowBox[{
       RowBox[{
        RowBox[{"p", "[", "3", "]"}], "[", "\[Nu]", "]"}], 
       RowBox[{"(", 
        RowBox[{"OO", "/.", 
         RowBox[{"p", "\[Rule]", 
          RowBox[{"p", "[", "3", "]"}]}]}], ")"}]}]}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x_", "\[CenterDot]", "x_"}], "\[RuleDelayed]", 
       RowBox[{"x", "^", "2"}]}], "}"}]}], "//", "Simplify"}], "//", 
   "Expand"}]}], "\[IndentingNewLine]", 
 RowBox[{"TraceWI", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"-", "\[CapitalDelta]"}], 
       RowBox[{"(", 
        RowBox[{"OO", "/.", 
         RowBox[{"p", "\[Rule]", 
          RowBox[{"p", "[", "2", "]"}]}]}], ")"}]}], "-", 
      RowBox[{"\[CapitalDelta]", 
       RowBox[{"(", 
        RowBox[{"OO", "/.", 
         RowBox[{"p", "\[Rule]", 
          RowBox[{"p", "[", "3", "]"}]}]}], ")"}]}]}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"x_", "\[CenterDot]", "x_"}], "\[RuleDelayed]", 
        RowBox[{"x", "^", "2"}]}], ",", 
       RowBox[{"\[CapitalDelta]", "\[Rule]", 
        RowBox[{"d", "-", "2"}]}]}], "}"}]}], "//", "Simplify"}], "//", 
   "Expand"}]}]}], "Input",
 CellChangeTimes->{{3.781789664538272*^9, 3.781789748146719*^9}, {
  3.781789855620162*^9, 
  3.781789864377858*^9}},ExpressionUUID->"5b277083-867e-49f5-8455-\
1d4456a09a32"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox[
    RowBox[{
     SuperscriptBox["4", 
      RowBox[{"2", "-", "d"}]], " ", 
     SuperscriptBox["\[Pi]", 
      RowBox[{
       FractionBox["3", "2"], "-", 
       FractionBox["d", "2"]}]], " ", 
     RowBox[{"Csc", "[", 
      FractionBox[
       RowBox[{"d", " ", "\[Pi]"}], "2"], "]"}], " ", 
     SubsuperscriptBox["p", "2", 
      RowBox[{
       RowBox[{"-", "4"}], "+", "d"}]], " ", 
     TemplateBox[{"p","2","\[Nu]"},
      "Subsuperscript"]}], 
    RowBox[{"Gamma", "[", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "d"}], ")"}]}], "]"}]]}], "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["4", 
     RowBox[{"2", "-", "d"}]], " ", 
    SuperscriptBox["\[Pi]", 
     RowBox[{
      FractionBox["3", "2"], "-", 
      FractionBox["d", "2"]}]], " ", 
    RowBox[{"Csc", "[", 
     FractionBox[
      RowBox[{"d", " ", "\[Pi]"}], "2"], "]"}], " ", 
    SubsuperscriptBox["p", "3", 
     RowBox[{
      RowBox[{"-", "4"}], "+", "d"}]], " ", 
    TemplateBox[{"p","3","\[Nu]"},
     "Subsuperscript"]}], 
   RowBox[{"Gamma", "[", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "d"}], ")"}]}], "]"}]]}]], "Output",
 CellChangeTimes->{{3.781789702181869*^9, 3.781789748529003*^9}, 
   3.781789825698485*^9, 3.781789865310979*^9, 3.794555683362217*^9, 
   3.794555743419599*^9, 3.794556291402272*^9, 3.7971994878791323`*^9, 
   3.7972000047418604`*^9, 3.798253553302246*^9, 3.7986858237941985`*^9, 
   3.799037642787258*^9},ExpressionUUID->"83e74197-0d26-4937-b560-\
eeea9a2952ba"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox[
    RowBox[{
     SuperscriptBox["2", 
      RowBox[{"5", "-", 
       RowBox[{"2", " ", "d"}]}]], " ", 
     SuperscriptBox["\[Pi]", 
      RowBox[{
       FractionBox["3", "2"], "-", 
       FractionBox["d", "2"]}]], " ", 
     RowBox[{"Csc", "[", 
      FractionBox[
       RowBox[{"d", " ", "\[Pi]"}], "2"], "]"}], " ", 
     SubsuperscriptBox["p", "2", 
      RowBox[{
       RowBox[{"-", "4"}], "+", "d"}]]}], 
    RowBox[{"Gamma", "[", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "d"}], ")"}]}], "]"}]]}], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["4", 
     RowBox[{"2", "-", "d"}]], " ", "d", " ", 
    SuperscriptBox["\[Pi]", 
     RowBox[{
      FractionBox["3", "2"], "-", 
      FractionBox["d", "2"]}]], " ", 
    RowBox[{"Csc", "[", 
     FractionBox[
      RowBox[{"d", " ", "\[Pi]"}], "2"], "]"}], " ", 
    SubsuperscriptBox["p", "2", 
     RowBox[{
      RowBox[{"-", "4"}], "+", "d"}]]}], 
   RowBox[{"Gamma", "[", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "d"}], ")"}]}], "]"}]], "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["2", 
     RowBox[{"5", "-", 
      RowBox[{"2", " ", "d"}]}]], " ", 
    SuperscriptBox["\[Pi]", 
     RowBox[{
      FractionBox["3", "2"], "-", 
      FractionBox["d", "2"]}]], " ", 
    RowBox[{"Csc", "[", 
     FractionBox[
      RowBox[{"d", " ", "\[Pi]"}], "2"], "]"}], " ", 
    SubsuperscriptBox["p", "3", 
     RowBox[{
      RowBox[{"-", "4"}], "+", "d"}]]}], 
   RowBox[{"Gamma", "[", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "d"}], ")"}]}], "]"}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["4", 
     RowBox[{"2", "-", "d"}]], " ", "d", " ", 
    SuperscriptBox["\[Pi]", 
     RowBox[{
      FractionBox["3", "2"], "-", 
      FractionBox["d", "2"]}]], " ", 
    RowBox[{"Csc", "[", 
     FractionBox[
      RowBox[{"d", " ", "\[Pi]"}], "2"], "]"}], " ", 
    SubsuperscriptBox["p", "3", 
     RowBox[{
      RowBox[{"-", "4"}], "+", "d"}]]}], 
   RowBox[{"Gamma", "[", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "d"}], ")"}]}], "]"}]]}]], "Output",
 CellChangeTimes->{{3.781789702181869*^9, 3.781789748529003*^9}, 
   3.781789825698485*^9, 3.781789865310979*^9, 3.794555683362217*^9, 
   3.794555743419599*^9, 3.794556291402272*^9, 3.7971994878791323`*^9, 
   3.7972000047418604`*^9, 3.798253553302246*^9, 3.7986858237941985`*^9, 
   3.7990376428661613`*^9},ExpressionUUID->"5106d475-a12b-42bc-bba7-\
0c93ce736836"]
}, Open  ]],

Cell["Now we check these identities", "Text",
 CellChangeTimes->{{3.781789758940968*^9, 
  3.781789764034541*^9}},ExpressionUUID->"d5e46db6-d771-44da-bb2c-\
39a565c48b6a"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"toCheckTransverseWI", "=", 
  RowBox[{
   RowBox[{"KSimplify", "[", 
    RowBox[{
     RowBox[{"LoopIntegral", "[", 
      RowBox[{"d", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1", ",", "1"}], "}"}]}], "]"}], "[", 
     RowBox[{
      RowBox[{"Contract", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"p", "[", "1", "]"}], "[", "\[Mu]", "]"}], "ConformalT"}], 
       "]"}], ",", " ", "k"}], "]"}], "]"}], "//", 
   "Simplify"}]}], "\[IndentingNewLine]", 
 RowBox[{"toCheckTraceWI", "=", 
  RowBox[{
   RowBox[{"KSimplify", "[", 
    RowBox[{
     RowBox[{"LoopIntegral", "[", 
      RowBox[{"d", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1", ",", "1"}], "}"}]}], "]"}], "[", 
     RowBox[{
      RowBox[{"Contract", "[", 
       RowBox[{"ConformalT", ",", "\[Mu]", ",", "\[Nu]"}], "]"}], ",", " ", 
      "k"}], "]"}], "]"}], "//", "Simplify"}]}]}], "Input",
 CellChangeTimes->{{3.7817192143001275`*^9, 3.781719217291133*^9}, {
   3.7817192511137266`*^9, 3.7817192727718315`*^9}, 3.7817201038387737`*^9, {
   3.781788987630102*^9, 3.781788990122148*^9}, {3.781789091637293*^9, 
   3.78178909829792*^9}, {3.781789194157604*^9, 3.781789206122551*^9}, {
   3.7817893160296993`*^9, 3.781789319154963*^9}, {3.7817893718531523`*^9, 
   3.781789372042863*^9}, {3.781789441923974*^9, 3.781789474298379*^9}, {
   3.781789752933465*^9, 3.7817897568222322`*^9}, {3.794556298883122*^9, 
   3.794556303945414*^9}, {3.79719950734616*^9, 3.7971995097061634`*^9}, {
   3.797199568682246*^9, 
   3.7971995772832584`*^9}},ExpressionUUID->"ef92b8f7-0e76-4302-b03f-\
fd40d1dd20fc"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "4"}], " ", 
   RowBox[{"(", 
    TagBox[
     RowBox[{"\<\"\\!\\(\\*StyleBox[\\\"\[Integral]\\\",FontSize->18]\\)\"\>",
       " ", 
      TagBox[
       FractionBox[
        RowBox[{
         SuperscriptBox["\<\"\[DifferentialD]\"\>", "d"], " ", "k"}], 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"2", " ", "\[Pi]"}], ")"}], "d"]],
       HoldForm], " ", 
      TagBox[
       FractionBox[
        TemplateBox[{"k","\[Nu]"},
         "Superscript"], 
        RowBox[{
         SuperscriptBox["k", "2"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"k", "+", 
            SubscriptBox["p", "2"]}], ")"}], "2"]}]],
       HoldForm]}],
     HoldForm], ")"}]}], "+", 
  RowBox[{"4", " ", 
   RowBox[{"(", 
    TagBox[
     RowBox[{"\<\"\\!\\(\\*StyleBox[\\\"\[Integral]\\\",FontSize->18]\\)\"\>",
       " ", 
      TagBox[
       FractionBox[
        RowBox[{
         SuperscriptBox["\<\"\[DifferentialD]\"\>", "d"], " ", "k"}], 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"2", " ", "\[Pi]"}], ")"}], "d"]],
       HoldForm], " ", 
      TagBox[
       FractionBox[
        TemplateBox[{"k","\[Nu]"},
         "Superscript"], 
        RowBox[{
         SuperscriptBox["k", "2"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"k", "-", 
            SubscriptBox["p", "3"]}], ")"}], "2"]}]],
       HoldForm]}],
     HoldForm], ")"}]}]}]], "Output",
 CellChangeTimes->{
  3.7817192175661335`*^9, {3.78171925299973*^9, 3.7817192731158514`*^9}, 
   3.7817197224699326`*^9, 3.78171993138105*^9, 3.7817199721856694`*^9, {
   3.7817200750023746`*^9, 3.7817201040997887`*^9}, 3.781720263491074*^9, 
   3.781720294562661*^9, {3.7817207581583724`*^9, 3.781720770074463*^9}, 
   3.78172093284814*^9, 3.7817212904924006`*^9, 3.7817215721624937`*^9, 
   3.7817218178443265`*^9, 3.7817220108061056`*^9, 3.781788701356482*^9, 
   3.781788990640402*^9, 3.781789034952849*^9, 3.781789098772332*^9, 
   3.781789207202098*^9, 3.7817893194509773`*^9, 3.78178937258399*^9, {
   3.78178945879033*^9, 3.781789474718463*^9}, 3.7817897657366533`*^9, {
   3.78178980941794*^9, 3.781789827070155*^9}, 3.781789866725607*^9, {
   3.7945562938346767`*^9, 3.794556304361225*^9}, 3.7971995783992596`*^9, {
   3.7971999915148416`*^9, 3.797200006881863*^9}, 3.798253555045953*^9, 
   3.798685823935206*^9, 
   3.799037642910033*^9},ExpressionUUID->"9d1ab604-0723-4e3f-8340-\
40ef091088a1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "2"}], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", "2"}], "+", "d"}], ")"}], " ", 
  RowBox[{"(", 
   RowBox[{
    TagBox[
     RowBox[{"\<\"\\!\\(\\*StyleBox[\\\"\[Integral]\\\",FontSize->18]\\)\"\>",
       " ", 
      TagBox[
       FractionBox[
        RowBox[{
         SuperscriptBox["\<\"\[DifferentialD]\"\>", "d"], " ", "k"}], 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"2", " ", "\[Pi]"}], ")"}], "d"]],
       HoldForm], " ", 
      TagBox[
       FractionBox["1", 
        RowBox[{
         SuperscriptBox["k", "2"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"k", "+", 
            SubscriptBox["p", "2"]}], ")"}], "2"]}]],
       HoldForm]}],
     HoldForm], "+", 
    TagBox[
     RowBox[{"\<\"\\!\\(\\*StyleBox[\\\"\[Integral]\\\",FontSize->18]\\)\"\>",
       " ", 
      TagBox[
       FractionBox[
        RowBox[{
         SuperscriptBox["\<\"\[DifferentialD]\"\>", "d"], " ", "k"}], 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"2", " ", "\[Pi]"}], ")"}], "d"]],
       HoldForm], " ", 
      TagBox[
       FractionBox["1", 
        RowBox[{
         SuperscriptBox["k", "2"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"k", "-", 
            SubscriptBox["p", "3"]}], ")"}], "2"]}]],
       HoldForm]}],
     HoldForm]}], ")"}]}]], "Output",
 CellChangeTimes->{
  3.7817192175661335`*^9, {3.78171925299973*^9, 3.7817192731158514`*^9}, 
   3.7817197224699326`*^9, 3.78171993138105*^9, 3.7817199721856694`*^9, {
   3.7817200750023746`*^9, 3.7817201040997887`*^9}, 3.781720263491074*^9, 
   3.781720294562661*^9, {3.7817207581583724`*^9, 3.781720770074463*^9}, 
   3.78172093284814*^9, 3.7817212904924006`*^9, 3.7817215721624937`*^9, 
   3.7817218178443265`*^9, 3.7817220108061056`*^9, 3.781788701356482*^9, 
   3.781788990640402*^9, 3.781789034952849*^9, 3.781789098772332*^9, 
   3.781789207202098*^9, 3.7817893194509773`*^9, 3.78178937258399*^9, {
   3.78178945879033*^9, 3.781789474718463*^9}, 3.7817897657366533`*^9, {
   3.78178980941794*^9, 3.781789827070155*^9}, 3.781789866725607*^9, {
   3.7945562938346767`*^9, 3.794556304361225*^9}, 3.7971995783992596`*^9, {
   3.7971999915148416`*^9, 3.797200006881863*^9}, 3.798253555045953*^9, 
   3.798685823935206*^9, 
   3.799037642921126*^9},ExpressionUUID->"a036177f-cdd8-4972-a9f0-\
1d768583fc15"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"CheckTransverseWI", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"toCheckTransverseWI", "//", "LoopEvaluate"}], "//", 
    "FullSimplify"}], "//", "Expand"}]}], "\[IndentingNewLine]", 
 RowBox[{"CheckTraceWI", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"toCheckTraceWI", "//", "LoopEvaluate"}], "//", "FullSimplify"}], 
   "//", "Expand"}]}]}], "Input",
 CellChangeTimes->{{3.781789326497999*^9, 3.781789378026739*^9}, {
  3.781789462291429*^9, 3.781789497614431*^9}, {3.781789644506452*^9, 
  3.781789644682458*^9}, {3.781789767973946*^9, 3.781789774653767*^9}, {
  3.794556328103726*^9, 
  3.794556332133088*^9}},ExpressionUUID->"dc05385d-60fe-4ebb-85c0-\
82e2552886d6"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox[
    RowBox[{
     SuperscriptBox["2", 
      RowBox[{"2", "-", "d"}]], " ", 
     SuperscriptBox["\[Pi]", 
      RowBox[{"1", "-", 
       FractionBox["d", "2"]}]], " ", 
     RowBox[{"Csc", "[", 
      FractionBox[
       RowBox[{"d", " ", "\[Pi]"}], "2"], "]"}], " ", 
     RowBox[{"Gamma", "[", 
      FractionBox["d", "2"], "]"}], " ", 
     SubsuperscriptBox["p", "2", 
      RowBox[{
       RowBox[{"-", "4"}], "+", "d"}]], " ", 
     TemplateBox[{"p","2","\[Nu]"},
      "Subsuperscript"]}], 
    RowBox[{"Gamma", "[", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "d"}], "]"}]]}], "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["2", 
     RowBox[{"2", "-", "d"}]], " ", 
    SuperscriptBox["\[Pi]", 
     RowBox[{"1", "-", 
      FractionBox["d", "2"]}]], " ", 
    RowBox[{"Csc", "[", 
     FractionBox[
      RowBox[{"d", " ", "\[Pi]"}], "2"], "]"}], " ", 
    RowBox[{"Gamma", "[", 
     FractionBox["d", "2"], "]"}], " ", 
    SubsuperscriptBox["p", "3", 
     RowBox[{
      RowBox[{"-", "4"}], "+", "d"}]], " ", 
    TemplateBox[{"p","3","\[Nu]"},
     "Subsuperscript"]}], 
   RowBox[{"Gamma", "[", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "d"}], "]"}]]}]], "Output",
 CellChangeTimes->{{3.781789329841569*^9, 3.781789378813224*^9}, 
   3.781789489132619*^9, 3.781789645586049*^9, 3.7817897750645237`*^9, {
   3.781789810938574*^9, 3.7817898284574203`*^9}, 3.7817898675097637`*^9, 
   3.794556333539268*^9, 3.7971995872562723`*^9, 3.797200052432928*^9, 
   3.798253563431738*^9, 3.7986858246872487`*^9, 
   3.799037643642139*^9},ExpressionUUID->"8ff5e4f9-dd28-4abb-9e50-\
568a6c36bb9c"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{
    SuperscriptBox["2", 
     RowBox[{"2", "-", "d"}]], " ", 
    SuperscriptBox["\[Pi]", 
     RowBox[{"1", "-", 
      FractionBox["d", "2"]}]], " ", 
    RowBox[{"Csc", "[", 
     FractionBox[
      RowBox[{"d", " ", "\[Pi]"}], "2"], "]"}], " ", 
    RowBox[{"Gamma", "[", 
     FractionBox["d", "2"], "]"}], " ", 
    SubsuperscriptBox["p", "2", 
     RowBox[{
      RowBox[{"-", "4"}], "+", "d"}]]}], 
   RowBox[{"Gamma", "[", 
    RowBox[{
     RowBox[{"-", "2"}], "+", "d"}], "]"}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["2", 
     RowBox[{"2", "-", "d"}]], " ", 
    SuperscriptBox["\[Pi]", 
     RowBox[{"1", "-", 
      FractionBox["d", "2"]}]], " ", 
    RowBox[{"Csc", "[", 
     FractionBox[
      RowBox[{"d", " ", "\[Pi]"}], "2"], "]"}], " ", 
    RowBox[{"Gamma", "[", 
     FractionBox["d", "2"], "]"}], " ", 
    SubsuperscriptBox["p", "3", 
     RowBox[{
      RowBox[{"-", "4"}], "+", "d"}]]}], 
   RowBox[{"Gamma", "[", 
    RowBox[{
     RowBox[{"-", "2"}], "+", "d"}], "]"}]]}]], "Output",
 CellChangeTimes->{{3.781789329841569*^9, 3.781789378813224*^9}, 
   3.781789489132619*^9, 3.781789645586049*^9, 3.7817897750645237`*^9, {
   3.781789810938574*^9, 3.7817898284574203`*^9}, 3.7817898675097637`*^9, 
   3.794556333539268*^9, 3.7971995872562723`*^9, 3.797200052432928*^9, 
   3.798253563431738*^9, 3.7986858246872487`*^9, 
   3.7990376441855097`*^9},ExpressionUUID->"9ce60e3b-cb86-42b8-925b-\
afea96bc7237"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"CheckTransverseWI", "/", "TransverseWI"}], "//", 
  "FullSimplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CheckTraceWI", "/", "TraceWI"}], "//", "FullSimplify"}]}], "Input",
 CellChangeTimes->{{3.781789782849987*^9, 3.7817897892908154`*^9}, {
  3.7817898331167507`*^9, 
  3.781789842626822*^9}},ExpressionUUID->"831962e5-6bf7-4abc-9e8e-\
e5ac45d7d171"],

Cell[BoxData["1"], "Output",
 CellChangeTimes->{{3.7817897896094418`*^9, 3.781789868259102*^9}, 
   3.7945563359147243`*^9, 3.798253569065233*^9, 3.7986858253242855`*^9, 
   3.799037644279985*^9},ExpressionUUID->"01258b66-6b13-4861-ad3c-\
73b39f1c06f9"],

Cell[BoxData["1"], "Output",
 CellChangeTimes->{{3.7817897896094418`*^9, 3.781789868259102*^9}, 
   3.7945563359147243`*^9, 3.798253569065233*^9, 3.7986858253242855`*^9, 
   3.79903764431527*^9},ExpressionUUID->"42073e3a-75bf-43e6-b094-\
3173bd9dca63"]
}, Open  ]],

Cell["Good.", "Text",
 CellChangeTimes->{{3.7817898733464117`*^9, 
  3.781789873978593*^9}},ExpressionUUID->"a13129be-7277-488c-a178-\
6b6350a9b698"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Actual 3-point functions", "Subsubsection",
 CellChangeTimes->{{3.7817898914901333`*^9, 3.7817898980588703`*^9}, {
  3.7945592367192087`*^9, 
  3.794559240630815*^9}},ExpressionUUID->"863f88d1-0c2c-46cc-a7c9-\
ac34ca9458a8"],

Cell["Now we can calculate the full correlation function.", "Text",
 CellChangeTimes->{{3.781788869345563*^9, 3.781788961730935*^9}, {
  3.781789388602454*^9, 3.78178939244307*^9}, {3.781790654363316*^9, 
  3.781790657251906*^9}, {3.7972001508801165`*^9, 
  3.797200163596135*^9}},ExpressionUUID->"74e912b5-2dbe-421d-8ad0-\
a4459e118c52"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"exp", "=", 
  RowBox[{
   RowBox[{"LoopIntegral", "[", 
    RowBox[{"d", ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "1", ",", "1"}], "}"}]}], "]"}], "[", 
   RowBox[{"ConformalT", ",", " ", "k"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.7817138908694277`*^9, 3.7817138978304453`*^9}, {
   3.781714034664646*^9, 3.7817140400847626`*^9}, {3.781714104917627*^9, 
   3.7817141391278563`*^9}, {3.7817161174514527`*^9, 
   3.7817161304025784`*^9}, {3.781716421832241*^9, 3.7817164241923*^9}, {
   3.78171902536621*^9, 3.781719026822237*^9}, {3.781719078439083*^9, 
   3.781719081724102*^9}, {3.781788973353142*^9, 3.781788999500132*^9}, 
   3.781789960693499*^9},ExpressionUUID->"9726064b-053c-4efb-abc9-\
ff4ec56944ec"],

Cell[BoxData[
 TagBox[
  RowBox[{"\<\"\\!\\(\\*StyleBox[\\\"\[Integral]\\\",FontSize->18]\\)\"\>", 
   " ", 
   TagBox[
    FractionBox[
     RowBox[{
      SuperscriptBox["\<\"\[DifferentialD]\"\>", "d"], " ", "k"}], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"2", " ", "\[Pi]"}], ")"}], "d"]],
    HoldForm], " ", 
   TagBox[
    RowBox[{
     FractionBox["1", 
      RowBox[{
       SuperscriptBox["k", "2"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"k", "-", 
          SubscriptBox["p", "1"]}], ")"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"k", "+", 
          SubscriptBox["p", "2"]}], ")"}], "2"]}]], "8", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        TemplateBox[{"k","\[Mu]"},
         "Superscript"], " ", 
        TemplateBox[{"k","\[Nu]"},
         "Superscript"]}], "-", 
       RowBox[{
        FractionBox["1", "2"], " ", 
        RowBox[{"k", "\[CenterDot]", "k"}], " ", 
        SubscriptBox["\[Delta]", 
         RowBox[{"\[Mu]", ",", "\[Nu]"}]]}], "+", 
       RowBox[{
        FractionBox["1", "2"], " ", 
        RowBox[{"k", "\[CenterDot]", 
         SubscriptBox["p", "1"]}], " ", 
        SubscriptBox["\[Delta]", 
         RowBox[{"\[Mu]", ",", "\[Nu]"}]]}], "+", 
       FractionBox[
        RowBox[{
         SubsuperscriptBox["p", "1", "2"], " ", 
         SubscriptBox["\[Delta]", 
          RowBox[{"\[Mu]", ",", "\[Nu]"}]]}], 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "d"}], ")"}]}]], "-", 
       FractionBox[
        RowBox[{"d", " ", 
         SubsuperscriptBox["p", "1", "2"], " ", 
         SubscriptBox["\[Delta]", 
          RowBox[{"\[Mu]", ",", "\[Nu]"}]]}], 
        RowBox[{"4", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "d"}], ")"}]}]], "-", 
       RowBox[{
        FractionBox["1", "2"], " ", 
        TemplateBox[{"k","\[Nu]"},
         "Superscript"], " ", 
        TemplateBox[{"p","1","\[Mu]"},
         "Subsuperscript"]}], "-", 
       RowBox[{
        FractionBox["1", "2"], " ", 
        TemplateBox[{"k","\[Mu]"},
         "Superscript"], " ", 
        TemplateBox[{"p","1","\[Nu]"},
         "Subsuperscript"]}], "-", 
       FractionBox[
        RowBox[{
         TemplateBox[{"p","1","\[Mu]"},
          "Subsuperscript"], " ", 
         TemplateBox[{"p","1","\[Nu]"},
          "Subsuperscript"]}], 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "d"}], ")"}]}]], "+", 
       FractionBox[
        RowBox[{"d", " ", 
         TemplateBox[{"p","1","\[Mu]"},
          "Subsuperscript"], " ", 
         TemplateBox[{"p","1","\[Nu]"},
          "Subsuperscript"]}], 
        RowBox[{"4", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "d"}], ")"}]}]]}], ")"}]}],
    HoldForm]}],
  HoldForm]], "Output",
 CellChangeTimes->{3.781789960899387*^9, 3.79455634677556*^9, 
  3.7972000937089863`*^9, 3.7972001648811364`*^9, 3.798253577759738*^9, 
  3.798685825373288*^9, 
  3.7990376443301764`*^9},ExpressionUUID->"1ba42c82-5109-4990-a7e9-\
c80b6b09f66a"]
}, Open  ]],

Cell["The 3-point function in 3 and 4 dimensions read", "Text",
 CellChangeTimes->{{3.7817899269301643`*^9, 
  3.7817899413708353`*^9}},ExpressionUUID->"03f7db83-7586-41f0-bf3d-\
67c6947a9ba4"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"TOO3", "=", 
  RowBox[{
   RowBox[{"Series", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"LoopEvaluate", "[", 
       RowBox[{"exp", "/.", 
        RowBox[{"{", 
         RowBox[{"d", "\[Rule]", 
          RowBox[{"3", "-", 
           RowBox[{"2", "\[Epsilon]"}]}]}], "}"}]}], "]"}], "//", 
      "Simplify"}], ",", 
     RowBox[{"{", 
      RowBox[{"\[Epsilon]", ",", "0", ",", "0"}], "}"}]}], "]"}], "//", 
   "Normal"}]}], "\[IndentingNewLine]", 
 RowBox[{"TOO4", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"LoopEvaluate", "[", 
     RowBox[{"exp", "/.", 
      RowBox[{"{", 
       RowBox[{"d", "\[Rule]", 
        RowBox[{"4", "-", 
         RowBox[{"2", "\[Epsilon]"}]}]}], "}"}]}], "]"}], "//", "Simplify"}], 
   "//", "Normal"}]}]}], "Input",
 CellChangeTimes->{{3.7817140653902316`*^9, 3.7817140672522893`*^9}, 
   3.7817158653159833`*^9, {3.781718471299429*^9, 3.78171848606367*^9}, {
   3.7817185290240808`*^9, 3.7817185294810824`*^9}, {3.78171909786841*^9, 
   3.7817191202277184`*^9}, {3.7817218229943886`*^9, 3.781721866750224*^9}, {
   3.781789914291154*^9, 3.7817900053631287`*^9}, {3.781790040558188*^9, 
   3.7817900895873337`*^9}, {3.7945565411140537`*^9, 3.794556578157539*^9}, {
   3.794557816251148*^9, 
   3.794557830790922*^9}},ExpressionUUID->"4abb0d77-e286-409b-ba12-\
4f51d8874069"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     SubscriptBox["p", "1"], " ", 
     RowBox[{"(", 
      RowBox[{
       SubsuperscriptBox["p", "1", "3"], "-", 
       RowBox[{
        SubscriptBox["p", "1"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", 
           SubsuperscriptBox["p", "2", "2"]}], "+", 
          RowBox[{"2", " ", 
           SubscriptBox["p", "2"], " ", 
           SubscriptBox["p", "3"]}], "+", 
          RowBox[{"3", " ", 
           SubsuperscriptBox["p", "3", "2"]}]}], ")"}]}], "-", 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          SubsuperscriptBox["p", "2", "3"], "+", 
          RowBox[{
           SubsuperscriptBox["p", "2", "2"], " ", 
           SubscriptBox["p", "3"]}], "+", 
          RowBox[{
           SubscriptBox["p", "2"], " ", 
           SubsuperscriptBox["p", "3", "2"]}], "+", 
          SubsuperscriptBox["p", "3", "3"]}], ")"}]}]}], ")"}], " ", 
     SubscriptBox["\[Delta]", 
      RowBox[{"\[Mu]", ",", "\[Nu]"}]]}], "+", 
    RowBox[{
     TemplateBox[{"p","1","\[Mu]"},
      "Subsuperscript"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["p", "1"], "-", 
           SubscriptBox["p", "2"], "+", 
           SubscriptBox["p", "3"]}], ")"}], "2"], " ", 
        TemplateBox[{"p","1","\[Nu]"},
         "Subsuperscript"]}], "+", 
       RowBox[{"4", " ", 
        SubscriptBox["p", "1"], " ", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["p", "1"], "+", 
          SubscriptBox["p", "3"]}], ")"}], " ", 
        TemplateBox[{"p","2","\[Nu]"},
         "Subsuperscript"]}]}], ")"}]}], "+", 
    RowBox[{"4", " ", 
     SubscriptBox["p", "1"], " ", 
     TemplateBox[{"p","2","\[Mu]"},
      "Subsuperscript"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["p", "1"], "+", 
          SubscriptBox["p", "3"]}], ")"}], " ", 
        TemplateBox[{"p","1","\[Nu]"},
         "Subsuperscript"]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", 
           SubscriptBox["p", "1"]}], "+", 
          SubscriptBox["p", "2"], "+", 
          SubscriptBox["p", "3"]}], ")"}], " ", 
        TemplateBox[{"p","2","\[Nu]"},
         "Subsuperscript"]}]}], ")"}]}]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"8", " ", 
    SubscriptBox["p", "1"], " ", 
    SubscriptBox["p", "2"], " ", 
    SubscriptBox["p", "3"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["p", "1"], "+", 
       SubscriptBox["p", "2"], "+", 
       SubscriptBox["p", "3"]}], ")"}], "2"]}], ")"}]}]], "Output",
 CellChangeTimes->{
  3.781714068225324*^9, 3.781714157285055*^9, 3.7817156216330156`*^9, 
   3.781715869029044*^9, 3.7817164292433467`*^9, 3.7817176116128855`*^9, 
   3.7817182717917676`*^9, 3.781718487421713*^9, 3.781718530111083*^9, {
   3.7817191092165103`*^9, 3.781719120697719*^9}, 3.781719166997359*^9, 
   3.7817212587209206`*^9, 3.7817213057067103`*^9, 3.781721573627496*^9, {
   3.781721835608621*^9, 3.7817218676002254`*^9}, 3.7817220257802925`*^9, {
   3.781789954394083*^9, 3.781790005872068*^9}, {3.781790044177047*^9, 
   3.7817900900055428`*^9}, 3.794556353806403*^9, {3.794556557126513*^9, 
   3.794556579054214*^9}, {3.794557820833263*^9, 3.794557831366025*^9}, 
   3.7945579601486607`*^9, 3.797200111063048*^9, 3.7972001664911385`*^9, 
   3.798253587254828*^9, 3.7986858276774178`*^9, 
   3.799037646918523*^9},ExpressionUUID->"b6fafe2a-78d3-48cc-962c-\
5c26f31f5374"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox[
    SubscriptBox["\[Delta]", 
     RowBox[{"\[Mu]", ",", "\[Nu]"}]], 
    RowBox[{"8", " ", 
     SuperscriptBox["\[Pi]", "2"], " ", "\[Epsilon]"}]]}], "+", 
  RowBox[{
   FractionBox["1", 
    RowBox[{"24", " ", 
     SuperscriptBox["\[Pi]", "2"], " ", 
     SuperscriptBox["\[Lambda]", 
      RowBox[{"5", "/", "2"}]]}]], 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2", " ", "NL", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SubsuperscriptBox["p", "1", "2"], " ", 
         SubscriptBox["\[Delta]", 
          RowBox[{"\[Mu]", ",", "\[Nu]"}]], " ", "\[Lambda]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"6", " ", 
            SubsuperscriptBox["p", "2", "2"], " ", 
            SubsuperscriptBox["p", "3", "2"]}], "+", "\[Lambda]"}], ")"}]}], 
        "+", 
        RowBox[{"6", " ", 
         SubsuperscriptBox["p", "1", "2"], " ", 
         TemplateBox[{"p","2","\[Mu]"},
          "Subsuperscript"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"3", " ", 
               SubsuperscriptBox["p", "2", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 SubsuperscriptBox["p", "1", "4"], "-", 
                 RowBox[{"2", " ", 
                  SubsuperscriptBox["p", "1", "2"], " ", 
                  SubsuperscriptBox["p", "2", "2"]}], "+", 
                 SubsuperscriptBox["p", "2", "4"], "-", 
                 SubsuperscriptBox["p", "3", "4"]}], ")"}]}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 SubsuperscriptBox["p", "1", "2"], "-", 
                 RowBox[{"2", " ", 
                  SubsuperscriptBox["p", "2", "2"]}], "-", 
                 SubsuperscriptBox["p", "3", "2"]}], ")"}], " ", 
               "\[Lambda]"}]}], ")"}], " ", 
            TemplateBox[{"p","1","\[Nu]"},
             "Subsuperscript"]}], "+", 
           RowBox[{
            SubsuperscriptBox["p", "1", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"3", " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", 
                   SubsuperscriptBox["p", "1", "2"]}], "+", 
                  SubsuperscriptBox["p", "2", "2"], "+", 
                  SubsuperscriptBox["p", "3", "2"]}], ")"}], "2"]}], "-", 
              "\[Lambda]"}], ")"}], " ", 
            TemplateBox[{"p","2","\[Nu]"},
             "Subsuperscript"]}]}], ")"}]}], "+", 
        RowBox[{"2", " ", 
         TemplateBox[{"p","1","\[Mu]"},
          "Subsuperscript"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"9", " ", 
               SubsuperscriptBox["p", "2", "4"], " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  SubsuperscriptBox["p", "1", "2"], "-", 
                  SubsuperscriptBox["p", "2", "2"], "+", 
                  SubsuperscriptBox["p", "3", "2"]}], ")"}], "2"]}], "+", 
              RowBox[{"3", " ", 
               SubsuperscriptBox["p", "2", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"2", " ", 
                  SubsuperscriptBox["p", "1", "2"]}], "-", 
                 RowBox[{"3", " ", 
                  SubsuperscriptBox["p", "2", "2"]}], "+", 
                 RowBox[{"2", " ", 
                  SubsuperscriptBox["p", "3", "2"]}]}], ")"}], " ", 
               "\[Lambda]"}], "+", 
              SuperscriptBox["\[Lambda]", "2"]}], ")"}], " ", 
            TemplateBox[{"p","1","\[Nu]"},
             "Subsuperscript"]}], "+", 
           RowBox[{"3", " ", 
            SubsuperscriptBox["p", "1", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"3", " ", 
               SubsuperscriptBox["p", "2", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 SubsuperscriptBox["p", "1", "4"], "-", 
                 RowBox[{"2", " ", 
                  SubsuperscriptBox["p", "1", "2"], " ", 
                  SubsuperscriptBox["p", "2", "2"]}], "+", 
                 SubsuperscriptBox["p", "2", "4"], "-", 
                 SubsuperscriptBox["p", "3", "4"]}], ")"}]}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 SubsuperscriptBox["p", "1", "2"], "-", 
                 RowBox[{"2", " ", 
                  SubsuperscriptBox["p", "2", "2"]}], "-", 
                 SubsuperscriptBox["p", "3", "2"]}], ")"}], " ", 
               "\[Lambda]"}]}], ")"}], " ", 
            TemplateBox[{"p","2","\[Nu]"},
             "Subsuperscript"]}]}], ")"}]}]}], ")"}]}], "+", 
     RowBox[{
      SqrtBox["\[Lambda]"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SubscriptBox["\[Delta]", 
          RowBox[{"\[Mu]", ",", "\[Nu]"}]], " ", "\[Lambda]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"6", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"Log", "[", 
                SubscriptBox["p", "3"], "]"}], " ", 
               SubsuperscriptBox["p", "3", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 SubsuperscriptBox["p", "1", "2"], "+", 
                 SubsuperscriptBox["p", "2", "2"], "-", 
                 SubsuperscriptBox["p", "3", "2"]}], ")"}]}], "+", 
              RowBox[{
               RowBox[{"Log", "[", 
                SubscriptBox["p", "2"], "]"}], " ", 
               SubsuperscriptBox["p", "2", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 SubsuperscriptBox["p", "1", "2"], "-", 
                 SubsuperscriptBox["p", "2", "2"], "+", 
                 SubsuperscriptBox["p", "3", "2"]}], ")"}]}], "+", 
              RowBox[{
               RowBox[{"Log", "[", 
                SubscriptBox["p", "1"], "]"}], " ", 
               SubsuperscriptBox["p", "1", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  SubsuperscriptBox["p", "1", "2"]}], "+", 
                 SubsuperscriptBox["p", "2", "2"], "+", 
                 SubsuperscriptBox["p", "3", "2"]}], ")"}]}]}], ")"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "3"}], "+", 
              RowBox[{"3", " ", "EulerGamma"}], "-", 
              RowBox[{"Log", "[", "64", "]"}], "-", 
              RowBox[{"3", " ", 
               RowBox[{"Log", "[", "\[Pi]", "]"}]}], "+", 
              RowBox[{"6", " ", 
               RowBox[{"Log", "[", 
                SubscriptBox["p", "2"], "]"}]}], "+", 
              RowBox[{"6", " ", 
               RowBox[{"Log", "[", 
                SubscriptBox["p", "3"], "]"}]}]}], ")"}], " ", 
            "\[Lambda]"}]}], ")"}]}], "-", 
        RowBox[{"6", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            TemplateBox[{"p","1","\[Mu]"},
             "Subsuperscript"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"3", " ", 
                  SubsuperscriptBox["p", "2", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    SubsuperscriptBox["p", "1", "2"], "-", 
                    SubsuperscriptBox["p", "2", "2"], "+", 
                    SubsuperscriptBox["p", "3", "2"]}], ")"}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"-", "2"}], " ", 
                    RowBox[{"Log", "[", 
                    SubscriptBox["p", "2"], "]"}], " ", 
                    SubsuperscriptBox["p", "2", "2"]}], "+", 
                    RowBox[{
                    RowBox[{"Log", "[", 
                    SubscriptBox["p", "1"], "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SubsuperscriptBox["p", "1", "2"], "+", 
                    SubsuperscriptBox["p", "2", "2"], "-", 
                    SubsuperscriptBox["p", "3", "2"]}], ")"}]}], "+", 
                    RowBox[{
                    RowBox[{"Log", "[", 
                    SubscriptBox["p", "3"], "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SubsuperscriptBox["p", "1", "2"]}], "+", 
                    SubsuperscriptBox["p", "2", "2"], "+", 
                    SubsuperscriptBox["p", "3", "2"]}], ")"}]}]}], ")"}]}], 
                 "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{"4", " ", 
                    RowBox[{"Log", "[", 
                    SubscriptBox["p", "2"], "]"}]}]}], ")"}]}], " ", 
                    SubsuperscriptBox["p", "2", "2"]}], "+", 
                    RowBox[{
                    RowBox[{"Log", "[", 
                    SubscriptBox["p", "1"], "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SubsuperscriptBox["p", "1", "2"], "+", 
                    RowBox[{"2", " ", 
                    SubsuperscriptBox["p", "2", "2"]}], "-", 
                    SubsuperscriptBox["p", "3", "2"]}], ")"}]}], "+", 
                    RowBox[{
                    RowBox[{"Log", "[", 
                    SubscriptBox["p", "3"], "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SubsuperscriptBox["p", "1", "2"]}], "+", 
                    RowBox[{"2", " ", 
                    SubsuperscriptBox["p", "2", "2"]}], "+", 
                    SubsuperscriptBox["p", "3", "2"]}], ")"}]}]}], ")"}], " ",
                   "\[Lambda]"}]}], ")"}], " ", 
               TemplateBox[{"p","1","\[Nu]"},
                "Subsuperscript"]}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "2"}], " ", 
                  RowBox[{"Log", "[", 
                   SubscriptBox["p", "3"], "]"}], " ", 
                  SubsuperscriptBox["p", "1", "6"]}], "-", 
                 RowBox[{"8", " ", 
                  RowBox[{"Log", "[", 
                   SubscriptBox["p", "2"], "]"}], " ", 
                  SubsuperscriptBox["p", "1", "4"], " ", 
                  SubsuperscriptBox["p", "2", "2"]}], "+", 
                 RowBox[{"4", " ", 
                  RowBox[{"Log", "[", 
                   SubscriptBox["p", "2"], "]"}], " ", 
                  SubsuperscriptBox["p", "1", "2"], " ", 
                  SubsuperscriptBox["p", "2", "4"]}], "+", 
                 RowBox[{"6", " ", 
                  RowBox[{"Log", "[", 
                   SubscriptBox["p", "3"], "]"}], " ", 
                  SubsuperscriptBox["p", "1", "2"], " ", 
                  SubsuperscriptBox["p", "2", "4"]}], "+", 
                 RowBox[{"4", " ", 
                  RowBox[{"Log", "[", 
                   SubscriptBox["p", "2"], "]"}], " ", 
                  SubsuperscriptBox["p", "2", "6"]}], "-", 
                 RowBox[{"4", " ", 
                  RowBox[{"Log", "[", 
                   SubscriptBox["p", "3"], "]"}], " ", 
                  SubsuperscriptBox["p", "2", "6"]}], "+", 
                 RowBox[{"4", " ", 
                  RowBox[{"Log", "[", 
                   SubscriptBox["p", "3"], "]"}], " ", 
                  SubsuperscriptBox["p", "1", "4"], " ", 
                  SubsuperscriptBox["p", "3", "2"]}], "+", 
                 RowBox[{"4", " ", 
                  RowBox[{"Log", "[", 
                   SubscriptBox["p", "2"], "]"}], " ", 
                  SubsuperscriptBox["p", "1", "2"], " ", 
                  SubsuperscriptBox["p", "2", "2"], " ", 
                  SubsuperscriptBox["p", "3", "2"]}], "-", 
                 RowBox[{"12", " ", 
                  RowBox[{"Log", "[", 
                   SubscriptBox["p", "3"], "]"}], " ", 
                  SubsuperscriptBox["p", "1", "2"], " ", 
                  SubsuperscriptBox["p", "2", "2"], " ", 
                  SubsuperscriptBox["p", "3", "2"]}], "-", 
                 RowBox[{"8", " ", 
                  RowBox[{"Log", "[", 
                   SubscriptBox["p", "2"], "]"}], " ", 
                  SubsuperscriptBox["p", "2", "4"], " ", 
                  SubsuperscriptBox["p", "3", "2"]}], "+", 
                 RowBox[{"8", " ", 
                  RowBox[{"Log", "[", 
                   SubscriptBox["p", "3"], "]"}], " ", 
                  SubsuperscriptBox["p", "2", "4"], " ", 
                  SubsuperscriptBox["p", "3", "2"]}], "-", 
                 RowBox[{"2", " ", 
                  RowBox[{"Log", "[", 
                   SubscriptBox["p", "3"], "]"}], " ", 
                  SubsuperscriptBox["p", "1", "2"], " ", 
                  SubsuperscriptBox["p", "3", "4"]}], "+", 
                 RowBox[{"4", " ", 
                  RowBox[{"Log", "[", 
                   SubscriptBox["p", "2"], "]"}], " ", 
                  SubsuperscriptBox["p", "2", "2"], " ", 
                  SubsuperscriptBox["p", "3", "4"]}], "-", 
                 RowBox[{"4", " ", 
                  RowBox[{"Log", "[", 
                   SubscriptBox["p", "3"], "]"}], " ", 
                  SubsuperscriptBox["p", "2", "2"], " ", 
                  SubsuperscriptBox["p", "3", "4"]}], "+", 
                 RowBox[{"2", " ", 
                  RowBox[{"Log", "[", 
                   SubscriptBox["p", "1"], "]"}], " ", 
                  SubsuperscriptBox["p", "1", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    SubsuperscriptBox["p", "1", "4"], "-", 
                    RowBox[{"5", " ", 
                    SubsuperscriptBox["p", "2", "4"]}], "+", 
                    RowBox[{"4", " ", 
                    SubsuperscriptBox["p", "2", "2"], " ", 
                    SubsuperscriptBox["p", "3", "2"]}], "+", 
                    SubsuperscriptBox["p", "3", "4"], "+", 
                    RowBox[{
                    SubsuperscriptBox["p", "1", "2"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4", " ", 
                    SubsuperscriptBox["p", "2", "2"]}], "-", 
                    RowBox[{"2", " ", 
                    SubsuperscriptBox["p", "3", "2"]}]}], ")"}]}]}], ")"}]}], 
                 "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    SubsuperscriptBox["p", "1", "2"]}], "+", 
                    RowBox[{"4", " ", 
                    RowBox[{"Log", "[", 
                    SubscriptBox["p", "1"], "]"}], " ", 
                    SubsuperscriptBox["p", "1", "2"]}], "-", 
                    RowBox[{"2", " ", 
                    RowBox[{"Log", "[", 
                    SubscriptBox["p", "3"], "]"}], " ", 
                    SubsuperscriptBox["p", "1", "2"]}], "-", 
                    SubsuperscriptBox["p", "2", "2"], "+", 
                    RowBox[{"4", " ", 
                    RowBox[{"Log", "[", 
                    SubscriptBox["p", "3"], "]"}], " ", 
                    SubsuperscriptBox["p", "2", "2"]}], "+", 
                    SubsuperscriptBox["p", "3", "2"], "-", 
                    RowBox[{"2", " ", 
                    RowBox[{"Log", "[", 
                    SubscriptBox["p", "3"], "]"}], " ", 
                    SubsuperscriptBox["p", "3", "2"]}], "-", 
                    RowBox[{"2", " ", 
                    RowBox[{"Log", "[", 
                    SubscriptBox["p", "2"], "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SubsuperscriptBox["p", "1", "2"], "+", 
                    RowBox[{"2", " ", 
                    SubsuperscriptBox["p", "2", "2"]}], "-", 
                    SubsuperscriptBox["p", "3", "2"]}], ")"}]}]}], ")"}], " ",
                   "\[Lambda]"}]}], ")"}], " ", 
               TemplateBox[{"p","2","\[Nu]"},
                "Subsuperscript"]}]}], ")"}]}], "+", 
           RowBox[{
            TemplateBox[{"p","2","\[Mu]"},
             "Subsuperscript"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "2"}], " ", 
                  RowBox[{"Log", "[", 
                   SubscriptBox["p", "3"], "]"}], " ", 
                  SubsuperscriptBox["p", "1", "6"]}], "-", 
                 RowBox[{"8", " ", 
                  RowBox[{"Log", "[", 
                   SubscriptBox["p", "2"], "]"}], " ", 
                  SubsuperscriptBox["p", "1", "4"], " ", 
                  SubsuperscriptBox["p", "2", "2"]}], "+", 
                 RowBox[{"4", " ", 
                  RowBox[{"Log", "[", 
                   SubscriptBox["p", "2"], "]"}], " ", 
                  SubsuperscriptBox["p", "1", "2"], " ", 
                  SubsuperscriptBox["p", "2", "4"]}], "+", 
                 RowBox[{"6", " ", 
                  RowBox[{"Log", "[", 
                   SubscriptBox["p", "3"], "]"}], " ", 
                  SubsuperscriptBox["p", "1", "2"], " ", 
                  SubsuperscriptBox["p", "2", "4"]}], "+", 
                 RowBox[{"4", " ", 
                  RowBox[{"Log", "[", 
                   SubscriptBox["p", "2"], "]"}], " ", 
                  SubsuperscriptBox["p", "2", "6"]}], "-", 
                 RowBox[{"4", " ", 
                  RowBox[{"Log", "[", 
                   SubscriptBox["p", "3"], "]"}], " ", 
                  SubsuperscriptBox["p", "2", "6"]}], "+", 
                 RowBox[{"4", " ", 
                  RowBox[{"Log", "[", 
                   SubscriptBox["p", "3"], "]"}], " ", 
                  SubsuperscriptBox["p", "1", "4"], " ", 
                  SubsuperscriptBox["p", "3", "2"]}], "+", 
                 RowBox[{"4", " ", 
                  RowBox[{"Log", "[", 
                   SubscriptBox["p", "2"], "]"}], " ", 
                  SubsuperscriptBox["p", "1", "2"], " ", 
                  SubsuperscriptBox["p", "2", "2"], " ", 
                  SubsuperscriptBox["p", "3", "2"]}], "-", 
                 RowBox[{"12", " ", 
                  RowBox[{"Log", "[", 
                   SubscriptBox["p", "3"], "]"}], " ", 
                  SubsuperscriptBox["p", "1", "2"], " ", 
                  SubsuperscriptBox["p", "2", "2"], " ", 
                  SubsuperscriptBox["p", "3", "2"]}], "-", 
                 RowBox[{"8", " ", 
                  RowBox[{"Log", "[", 
                   SubscriptBox["p", "2"], "]"}], " ", 
                  SubsuperscriptBox["p", "2", "4"], " ", 
                  SubsuperscriptBox["p", "3", "2"]}], "+", 
                 RowBox[{"8", " ", 
                  RowBox[{"Log", "[", 
                   SubscriptBox["p", "3"], "]"}], " ", 
                  SubsuperscriptBox["p", "2", "4"], " ", 
                  SubsuperscriptBox["p", "3", "2"]}], "-", 
                 RowBox[{"2", " ", 
                  RowBox[{"Log", "[", 
                   SubscriptBox["p", "3"], "]"}], " ", 
                  SubsuperscriptBox["p", "1", "2"], " ", 
                  SubsuperscriptBox["p", "3", "4"]}], "+", 
                 RowBox[{"4", " ", 
                  RowBox[{"Log", "[", 
                   SubscriptBox["p", "2"], "]"}], " ", 
                  SubsuperscriptBox["p", "2", "2"], " ", 
                  SubsuperscriptBox["p", "3", "4"]}], "-", 
                 RowBox[{"4", " ", 
                  RowBox[{"Log", "[", 
                   SubscriptBox["p", "3"], "]"}], " ", 
                  SubsuperscriptBox["p", "2", "2"], " ", 
                  SubsuperscriptBox["p", "3", "4"]}], "+", 
                 RowBox[{"2", " ", 
                  RowBox[{"Log", "[", 
                   SubscriptBox["p", "1"], "]"}], " ", 
                  SubsuperscriptBox["p", "1", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    SubsuperscriptBox["p", "1", "4"], "-", 
                    RowBox[{"5", " ", 
                    SubsuperscriptBox["p", "2", "4"]}], "+", 
                    RowBox[{"4", " ", 
                    SubsuperscriptBox["p", "2", "2"], " ", 
                    SubsuperscriptBox["p", "3", "2"]}], "+", 
                    SubsuperscriptBox["p", "3", "4"], "+", 
                    RowBox[{
                    SubsuperscriptBox["p", "1", "2"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4", " ", 
                    SubsuperscriptBox["p", "2", "2"]}], "-", 
                    RowBox[{"2", " ", 
                    SubsuperscriptBox["p", "3", "2"]}]}], ")"}]}]}], ")"}]}], 
                 "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    SubsuperscriptBox["p", "1", "2"]}], "+", 
                    RowBox[{"4", " ", 
                    RowBox[{"Log", "[", 
                    SubscriptBox["p", "1"], "]"}], " ", 
                    SubsuperscriptBox["p", "1", "2"]}], "-", 
                    RowBox[{"2", " ", 
                    RowBox[{"Log", "[", 
                    SubscriptBox["p", "3"], "]"}], " ", 
                    SubsuperscriptBox["p", "1", "2"]}], "-", 
                    SubsuperscriptBox["p", "2", "2"], "+", 
                    RowBox[{"4", " ", 
                    RowBox[{"Log", "[", 
                    SubscriptBox["p", "3"], "]"}], " ", 
                    SubsuperscriptBox["p", "2", "2"]}], "+", 
                    SubsuperscriptBox["p", "3", "2"], "-", 
                    RowBox[{"2", " ", 
                    RowBox[{"Log", "[", 
                    SubscriptBox["p", "3"], "]"}], " ", 
                    SubsuperscriptBox["p", "3", "2"]}], "-", 
                    RowBox[{"2", " ", 
                    RowBox[{"Log", "[", 
                    SubscriptBox["p", "2"], "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SubsuperscriptBox["p", "1", "2"], "+", 
                    RowBox[{"2", " ", 
                    SubsuperscriptBox["p", "2", "2"]}], "-", 
                    SubsuperscriptBox["p", "3", "2"]}], ")"}]}]}], ")"}], " ",
                   "\[Lambda]"}]}], ")"}], " ", 
               TemplateBox[{"p","1","\[Nu]"},
                "Subsuperscript"]}], "+", 
              RowBox[{"2", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"3", " ", 
                  SubsuperscriptBox["p", "1", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    SubsuperscriptBox["p", "1", "2"], "-", 
                    SubsuperscriptBox["p", "2", "2"], "-", 
                    SubsuperscriptBox["p", "3", "2"]}], ")"}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"2", " ", 
                    RowBox[{"Log", "[", 
                    SubscriptBox["p", "1"], "]"}], " ", 
                    SubsuperscriptBox["p", "1", "2"]}], "-", 
                    RowBox[{
                    RowBox[{"Log", "[", 
                    SubscriptBox["p", "2"], "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SubsuperscriptBox["p", "1", "2"], "+", 
                    SubsuperscriptBox["p", "2", "2"], "-", 
                    SubsuperscriptBox["p", "3", "2"]}], ")"}]}], "-", 
                    RowBox[{
                    RowBox[{"Log", "[", 
                    SubscriptBox["p", "3"], "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SubsuperscriptBox["p", "1", "2"], "-", 
                    SubsuperscriptBox["p", "2", "2"], "+", 
                    SubsuperscriptBox["p", "3", "2"]}], ")"}]}]}], ")"}]}], 
                 "-", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    SubsuperscriptBox["p", "1", "2"], "+", 
                    RowBox[{
                    RowBox[{"Log", "[", 
                    SubscriptBox["p", "2"], "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SubsuperscriptBox["p", "2", "2"], "-", 
                    SubsuperscriptBox["p", "3", "2"]}], ")"}]}], "+", 
                    RowBox[{
                    RowBox[{"Log", "[", 
                    SubscriptBox["p", "3"], "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SubsuperscriptBox["p", "2", "2"]}], "+", 
                    SubsuperscriptBox["p", "3", "2"]}], ")"}]}]}], ")"}], " ",
                   "\[Lambda]"}]}], ")"}], " ", 
               TemplateBox[{"p","2","\[Nu]"},
                "Subsuperscript"]}]}], ")"}]}]}], ")"}]}]}], ")"}]}]}], 
    ")"}]}]}]], "Output",
 CellChangeTimes->{
  3.781714068225324*^9, 3.781714157285055*^9, 3.7817156216330156`*^9, 
   3.781715869029044*^9, 3.7817164292433467`*^9, 3.7817176116128855`*^9, 
   3.7817182717917676`*^9, 3.781718487421713*^9, 3.781718530111083*^9, {
   3.7817191092165103`*^9, 3.781719120697719*^9}, 3.781719166997359*^9, 
   3.7817212587209206`*^9, 3.7817213057067103`*^9, 3.781721573627496*^9, {
   3.781721835608621*^9, 3.7817218676002254`*^9}, 3.7817220257802925`*^9, {
   3.781789954394083*^9, 3.781790005872068*^9}, {3.781790044177047*^9, 
   3.7817900900055428`*^9}, 3.794556353806403*^9, {3.794556557126513*^9, 
   3.794556579054214*^9}, {3.794557820833263*^9, 3.794557831366025*^9}, 
   3.7945579601486607`*^9, 3.797200111063048*^9, 3.7972001664911385`*^9, 
   3.798253587254828*^9, 3.7986858276774178`*^9, 
   3.7990376519668083`*^9},ExpressionUUID->"01288c0a-9980-497f-8e0a-\
83e369eab2e3"]
}, Open  ]],

Cell["Let\[CloseCurlyQuote]s check Ward identities", "Text",
 CellChangeTimes->{{3.781790105946459*^9, 
  3.781790110530978*^9}},ExpressionUUID->"f4a7e1db-2e24-4562-a7b6-\
a7bf5928bc5b"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Contract", "[", 
    RowBox[{"TOO3", "*", 
     RowBox[{
      RowBox[{"p", "[", "1", "]"}], "[", "\[Mu]", "]"}]}], "]"}], "/.", 
   RowBox[{"{", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"p", "[", "1", "]"}], "[", "\[Nu]", "]"}], "\[Rule]", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
        RowBox[{"p", "[", "2", "]"}], "[", "\[Nu]", "]"}]}], "-", 
      RowBox[{
       RowBox[{"p", "[", "3", "]"}], "[", "\[Nu]", "]"}]}]}], " ", "}"}]}], "//",
   "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"TransverseWI", "/.", 
   RowBox[{"d", "\[Rule]", "3"}]}], "//", "Simplify"}]}], "Input",
 CellChangeTimes->{{3.781714316464763*^9, 3.781714374550537*^9}, {
  3.7817188083969364`*^9, 3.7817188349993773`*^9}, {3.7817901119144907`*^9, 
  3.7817901642270107`*^9}},ExpressionUUID->"7f62f848-abfc-4fb8-8cab-\
c373ecc17bc3"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "4"], " ", 
  RowBox[{"(", 
   RowBox[{
    FractionBox[
     TemplateBox[{"p","2","\[Nu]"},
      "Subsuperscript"], 
     SubscriptBox["p", "2"]], "+", 
    FractionBox[
     TemplateBox[{"p","3","\[Nu]"},
      "Subsuperscript"], 
     SubscriptBox["p", "3"]]}], ")"}]}]], "Output",
 CellChangeTimes->{{3.781714320704838*^9, 3.781714332121024*^9}, 
   3.781714374985562*^9, 3.78171562500004*^9, 3.781716432328374*^9, 
   3.7817176216501255`*^9, 3.7817183443187633`*^9, 3.781718497608746*^9, 
   3.7817185432921724`*^9, {3.781718822852131*^9, 3.781718835304395*^9}, 
   3.781719125199836*^9, 3.7817191706684027`*^9, 3.781721265382077*^9, 
   3.781721312612775*^9, 3.7817215766265554`*^9, 3.7817218726362333`*^9, 
   3.7817220305773473`*^9, {3.781790124496839*^9, 3.7817901645378304`*^9}, 
   3.794556363188313*^9, 3.794556592382606*^9, 3.7945579697047997`*^9, 
   3.7972001716011457`*^9, 3.7982535953232927`*^9, 3.7986858324316854`*^9, 
   3.799037652024884*^9},ExpressionUUID->"6d3530eb-100a-42f5-b7be-\
583983220d3a"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "4"], " ", 
  RowBox[{"(", 
   RowBox[{
    FractionBox[
     TemplateBox[{"p","2","\[Nu]"},
      "Subsuperscript"], 
     SubscriptBox["p", "2"]], "+", 
    FractionBox[
     TemplateBox[{"p","3","\[Nu]"},
      "Subsuperscript"], 
     SubscriptBox["p", "3"]]}], ")"}]}]], "Output",
 CellChangeTimes->{{3.781714320704838*^9, 3.781714332121024*^9}, 
   3.781714374985562*^9, 3.78171562500004*^9, 3.781716432328374*^9, 
   3.7817176216501255`*^9, 3.7817183443187633`*^9, 3.781718497608746*^9, 
   3.7817185432921724`*^9, {3.781718822852131*^9, 3.781718835304395*^9}, 
   3.781719125199836*^9, 3.7817191706684027`*^9, 3.781721265382077*^9, 
   3.781721312612775*^9, 3.7817215766265554`*^9, 3.7817218726362333`*^9, 
   3.7817220305773473`*^9, {3.781790124496839*^9, 3.7817901645378304`*^9}, 
   3.794556363188313*^9, 3.794556592382606*^9, 3.7945579697047997`*^9, 
   3.7972001716011457`*^9, 3.7982535953232927`*^9, 3.7986858324316854`*^9, 
   3.799037652027667*^9},ExpressionUUID->"f2ecb655-61c0-4230-ad6d-\
f21afd8b9fd7"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Contract", "[", 
   RowBox[{"TOO3", ",", "\[Mu]", ",", "\[Nu]", ",", 
    RowBox[{"Dimension", "\[Rule]", "3"}]}], "]"}], "//", 
  "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"TraceWI", "/.", 
   RowBox[{"d", "\[Rule]", "3"}]}], "//", "Simplify"}]}], "Input",
 CellChangeTimes->{{3.781790173187004*^9, 
  3.781790191282301*^9}},ExpressionUUID->"be172a4c-42e2-45a4-850b-\
7f58eaa45eba"],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{
    SubscriptBox["p", "2"], "+", 
    SubscriptBox["p", "3"]}], 
   RowBox[{"4", " ", 
    SubscriptBox["p", "2"], " ", 
    SubscriptBox["p", "3"]}]]}]], "Output",
 CellChangeTimes->{{3.781790183797432*^9, 3.7817901918845253`*^9}, 
   3.7945563650543547`*^9, 3.794556593197332*^9, 3.7945579708487787`*^9, 
   3.7972001741471496`*^9, 3.7982535991219873`*^9, 3.798685832454687*^9, 
   3.799037652062805*^9},ExpressionUUID->"787b780d-bc70-46f4-bbe3-\
9c6eee97d7b7"],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{
    SubscriptBox["p", "2"], "+", 
    SubscriptBox["p", "3"]}], 
   RowBox[{"4", " ", 
    SubscriptBox["p", "2"], " ", 
    SubscriptBox["p", "3"]}]]}]], "Output",
 CellChangeTimes->{{3.781790183797432*^9, 3.7817901918845253`*^9}, 
   3.7945563650543547`*^9, 3.794556593197332*^9, 3.7945579708487787`*^9, 
   3.7972001741471496`*^9, 3.7982535991219873`*^9, 3.798685832454687*^9, 
   3.79903765206528*^9},ExpressionUUID->"76e70fc9-c9d6-4c3f-a970-\
4d73dbcfebb9"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Collect", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Contract", "[", 
      RowBox[{"TOO4", "*", 
       RowBox[{
        RowBox[{"p", "[", "1", "]"}], "[", "\[Mu]", "]"}]}], "]"}], "/.", 
     RowBox[{"{", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"p", "[", "1", "]"}], "[", "\[Nu]", "]"}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{
          RowBox[{"p", "[", "2", "]"}], "[", "\[Nu]", "]"}]}], "-", 
        RowBox[{
         RowBox[{"p", "[", "3", "]"}], "[", "\[Nu]", "]"}]}]}], " ", "}"}]}], 
    "//", " ", 
    RowBox[{
     RowBox[{"KExpand", "[", 
      RowBox[{"#", ",", 
       RowBox[{"Level", "\[Rule]", "\[Lambda]"}]}], "]"}], "&"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Epsilon]", ",", "NL"}], "}"}], ",", "Simplify"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Series", "[", 
   RowBox[{
    RowBox[{"TransverseWI", "/.", 
     RowBox[{"d", "\[Rule]", 
      RowBox[{"4", "-", 
       RowBox[{"2", "\[Epsilon]"}]}]}]}], ",", 
    RowBox[{"{", 
     RowBox[{"\[Epsilon]", ",", "0", ",", "0"}], "}"}]}], "]"}], "//", 
  "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%%", "-", "%"}], "//", "FullSimplify"}]}], "Input",
 CellChangeTimes->{{3.78179020437854*^9, 3.7817902542672358`*^9}, {
   3.781790290070882*^9, 3.7817903162684917`*^9}, {3.781790374043825*^9, 
   3.7817903806627197`*^9}, 3.7945566558663054`*^9, {3.794557395965158*^9, 
   3.794557413510792*^9}, {3.798253608826775*^9, 
   3.798253643080763*^9}},ExpressionUUID->"c139233e-404f-481a-94b7-\
54033568f2f8"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{
    TemplateBox[{"p","2","\[Nu]"},
     "Subsuperscript"], "+", 
    TemplateBox[{"p","3","\[Nu]"},
     "Subsuperscript"]}], 
   RowBox[{"8", " ", 
    SuperscriptBox["\[Pi]", "2"], " ", "\[Epsilon]"}]], "+", 
  RowBox[{
   FractionBox["1", 
    RowBox[{"24", " ", 
     SuperscriptBox["\[Pi]", "2"]}]], 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"6", "-", 
        RowBox[{"3", " ", "EulerGamma"}], "+", 
        RowBox[{"Log", "[", "64", "]"}], "+", 
        RowBox[{"3", " ", 
         RowBox[{"Log", "[", "\[Pi]", "]"}]}], "-", 
        RowBox[{"6", " ", 
         RowBox[{"Log", "[", 
          SubscriptBox["p", "2"], "]"}]}]}], ")"}], " ", 
      TemplateBox[{"p","2","\[Nu]"},
       "Subsuperscript"]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"6", "-", 
        RowBox[{"3", " ", "EulerGamma"}], "+", 
        RowBox[{"Log", "[", "64", "]"}], "+", 
        RowBox[{"3", " ", 
         RowBox[{"Log", "[", "\[Pi]", "]"}]}], "-", 
        RowBox[{"6", " ", 
         RowBox[{"Log", "[", 
          SubscriptBox["p", "3"], "]"}]}]}], ")"}], " ", 
      TemplateBox[{"p","3","\[Nu]"},
       "Subsuperscript"]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{{3.781790210172229*^9, 3.781790232292643*^9}, {
   3.781790285654456*^9, 3.781790317885762*^9}, {3.781790356309252*^9, 
   3.781790381494076*^9}, 3.794556377653063*^9, 3.794557379559668*^9, 
   3.794558023020337*^9, 3.794558787199451*^9, 3.7972001776021547`*^9, {
   3.79825360271875*^9, 3.798253643999229*^9}, 3.798685832629697*^9, 
   3.799037652278967*^9},ExpressionUUID->"2e24d0b0-2219-44ce-8f6a-\
5b4191a87384"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   FractionBox[
    RowBox[{
     TemplateBox[{"p","2","\[Nu]"},
      "Subsuperscript"], "+", 
     TemplateBox[{"p","3","\[Nu]"},
      "Subsuperscript"]}], 
    RowBox[{"8", " ", 
     SuperscriptBox["\[Pi]", "2"], " ", "\[Epsilon]"}]], "+", 
   RowBox[{
    FractionBox["1", 
     RowBox[{"8", " ", 
      SuperscriptBox["\[Pi]", "2"]}]], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Log", "[", 
          RowBox[{"16", " ", "\[Pi]"}], "]"}], "-", 
         RowBox[{"2", " ", 
          RowBox[{"Log", "[", 
           SubscriptBox["p", "2"], "]"}]}], "+", 
         RowBox[{"PolyGamma", "[", 
          RowBox[{"0", ",", 
           FractionBox["3", "2"]}], "]"}]}], ")"}], " ", 
       TemplateBox[{"p","2","\[Nu]"},
        "Subsuperscript"]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Log", "[", 
          RowBox[{"16", " ", "\[Pi]"}], "]"}], "-", 
         RowBox[{"2", " ", 
          RowBox[{"Log", "[", 
           SubscriptBox["p", "3"], "]"}]}], "+", 
         RowBox[{"PolyGamma", "[", 
          RowBox[{"0", ",", 
           FractionBox["3", "2"]}], "]"}]}], ")"}], " ", 
       TemplateBox[{"p","3","\[Nu]"},
        "Subsuperscript"]}]}], ")"}]}], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "\[Epsilon]", "]"}], "1"],
    SeriesData[TripleK`\[Epsilon], 0, {}, -1, 1, 1],
    Editable->False]}],
  SeriesData[
  TripleK`\[Epsilon], 0, {
   Rational[1, 8] 
    Pi^(-2) (TripleK`p[2][$CellContext`\[Nu]] + 
     TripleK`p[3][$CellContext`\[Nu]]), Rational[1, 8] 
    Pi^(-2) ((Log[16 Pi] - 2 Log[
         TripleK`p[2]] + PolyGamma[0, 
         Rational[3, 2]]) 
      TripleK`p[2][$CellContext`\[Nu]] + (Log[16 Pi] - 2 Log[
         TripleK`p[3]] + PolyGamma[0, 
         Rational[3, 2]]) TripleK`p[3][$CellContext`\[Nu]])}, -1, 1, 1],
  Editable->False]], "Output",
 CellChangeTimes->{{3.781790210172229*^9, 3.781790232292643*^9}, {
   3.781790285654456*^9, 3.781790317885762*^9}, {3.781790356309252*^9, 
   3.781790381494076*^9}, 3.794556377653063*^9, 3.794557379559668*^9, 
   3.794558023020337*^9, 3.794558787199451*^9, 3.7972001776021547`*^9, {
   3.79825360271875*^9, 3.798253643999229*^9}, 3.798685832629697*^9, 
   3.799037652368352*^9},ExpressionUUID->"e9e88ee2-0cf2-46b8-805d-\
2bc3b3a71c76"],

Cell[BoxData[
 InterpretationBox[
  SuperscriptBox[
   RowBox[{"O", "[", "\[Epsilon]", "]"}], "1"],
  SeriesData[TripleK`\[Epsilon], 0, {}, 1, 1, 1],
  Editable->False]], "Output",
 CellChangeTimes->{{3.781790210172229*^9, 3.781790232292643*^9}, {
   3.781790285654456*^9, 3.781790317885762*^9}, {3.781790356309252*^9, 
   3.781790381494076*^9}, 3.794556377653063*^9, 3.794557379559668*^9, 
   3.794558023020337*^9, 3.794558787199451*^9, 3.7972001776021547`*^9, {
   3.79825360271875*^9, 3.798253643999229*^9}, 3.798685832629697*^9, 
   3.7990376523898478`*^9},ExpressionUUID->"d40f7e09-117e-4422-9124-\
ee62c4677e1c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Collect", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Series", "[", 
      RowBox[{
       RowBox[{"Contract", "[", 
        RowBox[{"TOO4", ",", "\[Mu]", ",", "\[Nu]", ",", 
         RowBox[{"Dimension", "\[Rule]", 
          RowBox[{"4", "-", 
           RowBox[{"2", "\[Epsilon]"}]}]}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"\[Epsilon]", ",", "0", ",", "0"}], "}"}]}], "]"}], "/.", 
     RowBox[{"{", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"p", "[", "1", "]"}], "[", "\[Nu]", "]"}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{
          RowBox[{"p", "[", "2", "]"}], "[", "\[Nu]", "]"}]}], "-", 
        RowBox[{
         RowBox[{"p", "[", "3", "]"}], "[", "\[Nu]", "]"}]}]}], " ", "}"}]}], 
    "//", " ", 
    RowBox[{
     RowBox[{"KExpand", "[", 
      RowBox[{"#", ",", 
       RowBox[{"Level", "\[Rule]", "\[Lambda]"}]}], "]"}], "&"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Epsilon]", ",", "NL"}], "}"}], ",", "Simplify"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Series", "[", 
   RowBox[{
    RowBox[{"TraceWI", "/.", 
     RowBox[{"d", "\[Rule]", 
      RowBox[{"4", "-", 
       RowBox[{"2", "\[Epsilon]"}]}]}]}], ",", 
    RowBox[{"{", 
     RowBox[{"\[Epsilon]", ",", "0", ",", "0"}], "}"}]}], "]"}], "//", 
  "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%%", "-", "%"}], "//", "FullSimplify"}]}], "Input",
 CellChangeTimes->{{3.781790391322927*^9, 3.7817904865515633`*^9}, 
   3.794558032120697*^9, {3.798253667425356*^9, 
   3.7982536675632553`*^9}},ExpressionUUID->"11b6b74e-48fe-4968-ae87-\
23f2d4278ce4"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox["1", 
    RowBox[{"2", " ", 
     SuperscriptBox["\[Pi]", "2"], " ", "\[Epsilon]"}]]}], "-", 
  FractionBox[
   RowBox[{"3", "-", 
    RowBox[{"3", " ", "EulerGamma"}], "+", 
    RowBox[{"Log", "[", "64", "]"}], "+", 
    RowBox[{"3", " ", 
     RowBox[{"Log", "[", "\[Pi]", "]"}]}], "-", 
    RowBox[{"3", " ", 
     RowBox[{"Log", "[", 
      SubscriptBox["p", "2"], "]"}]}], "-", 
    RowBox[{"3", " ", 
     RowBox[{"Log", "[", 
      SubscriptBox["p", "3"], "]"}]}]}], 
   RowBox[{"6", " ", 
    SuperscriptBox["\[Pi]", "2"]}]]}]], "Output",
 CellChangeTimes->{{3.781790419705102*^9, 3.781790456211854*^9}, 
   3.781790487775218*^9, 3.794558033758473*^9, 3.794558790572699*^9, 
   3.7972001795731573`*^9, 3.798253669028758*^9, 3.7986858330587215`*^9, 
   3.79903765253964*^9},ExpressionUUID->"8a0726ef-81dc-4593-a372-\
520de200aca3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{"-", 
    FractionBox["1", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[Pi]", "2"], " ", "\[Epsilon]"}]]}], "+", 
   FractionBox[
    RowBox[{"1", "+", 
     RowBox[{"Log", "[", 
      FractionBox[
       RowBox[{
        SubscriptBox["p", "2"], " ", 
        SubscriptBox["p", "3"]}], 
       RowBox[{"16", " ", "\[Pi]"}]], "]"}], "-", 
     RowBox[{"PolyGamma", "[", 
      RowBox[{"0", ",", 
       FractionBox["3", "2"]}], "]"}]}], 
    RowBox[{"2", " ", 
     SuperscriptBox["\[Pi]", "2"]}]], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "\[Epsilon]", "]"}], "1"],
    SeriesData[TripleK`\[Epsilon], 0, {}, -1, 1, 1],
    Editable->False]}],
  SeriesData[
  TripleK`\[Epsilon], 0, {
   Rational[-1, 2] Pi^(-2), Rational[1, 2] 
    Pi^(-2) (1 + Log[Rational[1, 16] Pi^(-1) TripleK`p[2] TripleK`p[3]] - 
     PolyGamma[0, 
      Rational[3, 2]])}, -1, 1, 1],
  Editable->False]], "Output",
 CellChangeTimes->{{3.781790419705102*^9, 3.781790456211854*^9}, 
   3.781790487775218*^9, 3.794558033758473*^9, 3.794558790572699*^9, 
   3.7972001795731573`*^9, 3.798253669028758*^9, 3.7986858330587215`*^9, 
   3.799037652567189*^9},ExpressionUUID->"7a1293d1-6d4c-458c-b6ce-\
211fd816eef1"],

Cell[BoxData[
 InterpretationBox[
  SuperscriptBox[
   RowBox[{"O", "[", "\[Epsilon]", "]"}], "1"],
  SeriesData[TripleK`\[Epsilon], 0, {}, 1, 1, 1],
  Editable->False]], "Output",
 CellChangeTimes->{{3.781790419705102*^9, 3.781790456211854*^9}, 
   3.781790487775218*^9, 3.794558033758473*^9, 3.794558790572699*^9, 
   3.7972001795731573`*^9, 3.798253669028758*^9, 3.7986858330587215`*^9, 
   3.799037652589099*^9},ExpressionUUID->"3a2612da-b9cf-4801-aea3-\
e06183eec529"]
}, Open  ]],

Cell[TextData[{
 "So we\[CloseCurlyQuote]re doing great. We can also read the ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["A", "1"], TraditionalForm]],ExpressionUUID->
  "c05f69e2-b826-4d6f-b423-1f8039d7c48a"],
 " form factor. This is defined in (R.6.4) of [",
 ButtonBox["1304.7760",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://arxiv.org/pdf/1304.7760.pdf"], None},
  ButtonNote->"https://arxiv.org/pdf/1304.7760.pdf"],
 "] and calculated using (R.6.6)."
}], "Text",
 CellChangeTimes->{{3.781790365315333*^9, 3.7817903789792957`*^9}, {
  3.781790500534822*^9, 3.781790507586796*^9}, {3.797200183158162*^9, 
  3.797200207211196*^9}, {3.797200301693329*^9, 
  3.797200324510361*^9}},ExpressionUUID->"eb5f3744-39e8-4503-82e2-\
68b082d3d605"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Coefficient", "[", 
  RowBox[{"TOO3", ",", 
   RowBox[{
    RowBox[{
     RowBox[{"p", "[", "2", "]"}], "[", "\[Mu]", "]"}], 
    RowBox[{
     RowBox[{"p", "[", "2", "]"}], "[", "\[Nu]", "]"}]}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Coefficient", "[", 
  RowBox[{"TOO4", ",", 
   RowBox[{
    RowBox[{
     RowBox[{"p", "[", "2", "]"}], "[", "\[Mu]", "]"}], 
    RowBox[{
     RowBox[{"p", "[", "2", "]"}], "[", "\[Nu]", "]"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.781790510372363*^9, 3.7817905682295647`*^9}, {
   3.798253693269582*^9, 3.798253703232088*^9}, 
   3.798253900979245*^9},ExpressionUUID->"e64668a0-b364-41fe-9ec5-\
303a90a295cb"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"2", " ", 
    SubscriptBox["p", "1"]}], "+", 
   SubscriptBox["p", "2"], "+", 
   SubscriptBox["p", "3"]}], 
  RowBox[{"2", " ", 
   SubscriptBox["p", "2"], " ", 
   SubscriptBox["p", "3"], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["p", "1"], "+", 
      SubscriptBox["p", "2"], "+", 
      SubscriptBox["p", "3"]}], ")"}], "2"]}]]], "Output",
 CellChangeTimes->{{3.781790521202136*^9, 3.7817905686615477`*^9}, 
   3.794558037360408*^9, 3.79455879389639*^9, 3.797200326726364*^9, {
   3.798253694128168*^9, 3.7982537036939297`*^9}, 3.7982539014341373`*^9, 
   3.7986858331157246`*^9, 
   3.799037652604068*^9},ExpressionUUID->"a6445c10-a3da-4628-88ff-\
7aad7f979dbc"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{"24", " ", 
    SuperscriptBox["\[Pi]", "2"], " ", 
    SuperscriptBox["\[Lambda]", 
     RowBox[{"5", "/", "2"}]]}]], 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"12", " ", "NL", " ", 
     SubsuperscriptBox["p", "1", "4"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"3", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            SubsuperscriptBox["p", "1", "2"]}], "+", 
           SubsuperscriptBox["p", "2", "2"], "+", 
           SubsuperscriptBox["p", "3", "2"]}], ")"}], "2"]}], "-", 
       "\[Lambda]"}], ")"}]}], "-", 
    RowBox[{"12", " ", 
     SqrtBox["\[Lambda]"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"3", " ", 
        SubsuperscriptBox["p", "1", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          SubsuperscriptBox["p", "1", "2"], "-", 
          SubsuperscriptBox["p", "2", "2"], "-", 
          SubsuperscriptBox["p", "3", "2"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", 
           RowBox[{"Log", "[", 
            SubscriptBox["p", "1"], "]"}], " ", 
           SubsuperscriptBox["p", "1", "2"]}], "-", 
          RowBox[{
           RowBox[{"Log", "[", 
            SubscriptBox["p", "2"], "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             SubsuperscriptBox["p", "1", "2"], "+", 
             SubsuperscriptBox["p", "2", "2"], "-", 
             SubsuperscriptBox["p", "3", "2"]}], ")"}]}], "-", 
          RowBox[{
           RowBox[{"Log", "[", 
            SubscriptBox["p", "3"], "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             SubsuperscriptBox["p", "1", "2"], "-", 
             SubsuperscriptBox["p", "2", "2"], "+", 
             SubsuperscriptBox["p", "3", "2"]}], ")"}]}]}], ")"}]}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SubsuperscriptBox["p", "1", "2"], "+", 
          RowBox[{
           RowBox[{"Log", "[", 
            SubscriptBox["p", "2"], "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             SubsuperscriptBox["p", "2", "2"], "-", 
             SubsuperscriptBox["p", "3", "2"]}], ")"}]}], "+", 
          RowBox[{
           RowBox[{"Log", "[", 
            SubscriptBox["p", "3"], "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              SubsuperscriptBox["p", "2", "2"]}], "+", 
             SubsuperscriptBox["p", "3", "2"]}], ")"}]}]}], ")"}], " ", 
        "\[Lambda]"}]}], ")"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{{3.781790521202136*^9, 3.7817905686615477`*^9}, 
   3.794558037360408*^9, 3.79455879389639*^9, 3.797200326726364*^9, {
   3.798253694128168*^9, 3.7982537036939297`*^9}, 3.7982539014341373`*^9, 
   3.7986858331157246`*^9, 
   3.7990376526070347`*^9},ExpressionUUID->"f50474fe-fe1e-4e76-94c3-\
f7e9511b6f75"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Chiral anomaly", "Section",
 CellChangeTimes->{
  3.794882252526905*^9},ExpressionUUID->"9d6cf142-2004-423c-a544-\
54fc6939e5cf"],

Cell["\<\
By implementing the algebra of the Levi-Civita tensor one can recover the \
famous ABJ (chiral) anomaly. Notice, however, that now have access to the \
full expression for the 3-point function. Therefore we can check the ABJ \
calculations explicitly, without using any `tricks\[CloseCurlyQuote].\
\>", "Text",
 CellChangeTimes->{{3.79488686636104*^9, 3.794886931369855*^9}, {
  3.7972003781794367`*^9, 
  3.797200391654456*^9}},ExpressionUUID->"605dd233-f16a-47ac-8c52-\
0688c8a3c088"],

Cell[TextData[{
 "We will work with a single free Weyl fermion \[Psi] and the axial current\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["j", "\[Mu]"], "=", 
    RowBox[{
     SubscriptBox[
      OverscriptBox["\[Psi]", "_"], 
      OverscriptBox["\[Alpha]", "."]], 
     SuperscriptBox[
      OverscriptBox["\[Sigma]", "_"], 
      RowBox[{"\[Mu]", 
       OverscriptBox["\[Alpha]", "."], "\[Alpha]"}]], 
     SubscriptBox["\[Psi]", "\[Alpha]"]}]}], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "bf7ac359-3d50-43e4-abdc-958327ecd047"],
 ".\nUnlike in previous sections, we work in ",
 StyleBox["Lorentzian",
  FontSlant->"Italic"],
 " signature here."
}], "Text",
 CellChangeTimes->{{3.798519283211924*^9, 
  3.798519440228569*^9}},ExpressionUUID->"e9114555-0a9a-4b1a-a845-\
0c1495db0bf9"],

Cell[TextData[{
 "The 3-point function of 3 chiral currents equals\n< ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       SuperscriptBox["j", "\[Mu]"], "(", 
       SubscriptBox["p", "1"], ")"}], " ", 
      RowBox[{
       SuperscriptBox["j", "\[Nu]"], "(", 
       SubscriptBox["p", "1"], ")"}], " ", 
      RowBox[{
       SuperscriptBox["j", "\[Rho]"], "(", 
       SubscriptBox["p", "1"], ")"}]}], " ", ">"}], " ", "=", " ", 
    RowBox[{
     SuperscriptBox["tensor", 
      RowBox[{"\[Mu]\[Nu]\[Rho]", " ", "\[Alpha]\[Beta]\[Gamma]"}]], " ", "*",
      " ", 
     SubscriptBox["integral", "\[Alpha]\[Beta]\[Gamma]"]}]}], 
   TraditionalForm]],ExpressionUUID->"1b92a08e-40b8-4425-9d0b-b9aa402e6a4c"],
 "\nwhere ",
 StyleBox["tensor",
  FontSlant->"Italic"],
 " and ",
 StyleBox["integral",
  FontSlant->"Italic"],
 " are as follows"
}], "Text",
 CellChangeTimes->{{3.794886034728403*^9, 3.794886135058158*^9}, {
  3.7948862040731564`*^9, 
  3.794886204824849*^9}},ExpressionUUID->"fb772569-90a9-4284-9317-\
85796cfd5371"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"integral", "=", 
  RowBox[{
   RowBox[{"LoopIntegral", "[", 
    RowBox[{
     RowBox[{"4", "-", 
      RowBox[{"2", "\[Epsilon]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "1", ",", "1"}], "}"}]}], "]"}], "[", 
   RowBox[{
    RowBox[{
     RowBox[{"k", "[", "\[Alpha]", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"k", "[", "\[Beta]", "]"}], "-", 
       RowBox[{
        RowBox[{"p", "[", "1", "]"}], "[", "\[Beta]", "]"}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"k", "[", "\[Gamma]", "]"}], "+", 
       RowBox[{
        RowBox[{"p", "[", "2", "]"}], "[", "\[Gamma]", "]"}]}], ")"}]}], ",", 
    "k"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.7843021644021444`*^9, 3.784302187167446*^9}, {
  3.7843024003347125`*^9, 3.7843024525977015`*^9}, {3.7843031948819947`*^9, 
  3.784303207065692*^9}, {3.784308812251122*^9, 3.7843088224507055`*^9}, {
  3.784309225279746*^9, 3.7843092265508184`*^9}, {3.784313902622141*^9, 
  3.784313906461361*^9}, {3.792766954829946*^9, 3.792766954938506*^9}, {
  3.794824018125185*^9, 3.794824027957396*^9}, {3.7948822637825623`*^9, 
  3.7948822772311277`*^9}, {3.794886138484761*^9, 
  3.79488614082491*^9}},ExpressionUUID->"7e9cb068-ad3d-44e9-8062-\
9bc5987e3a3b"],

Cell[BoxData[
 TagBox[
  RowBox[{"\<\"\\!\\(\\*StyleBox[\\\"\[Integral]\\\",FontSize->18]\\)\"\>", 
   " ", 
   TagBox[
    FractionBox[
     RowBox[{
      SuperscriptBox["\<\"\[DifferentialD]\"\>", 
       RowBox[{"4", "-", 
        RowBox[{"2", " ", "\[Epsilon]"}]}]], " ", "k"}], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"2", " ", "\[Pi]"}], ")"}], 
      RowBox[{"4", "-", 
       RowBox[{"2", " ", "\[Epsilon]"}]}]]],
    HoldForm], " ", 
   TagBox[
    FractionBox[
     RowBox[{
      TemplateBox[{"k","\[Alpha]"},
       "Superscript"], " ", 
      RowBox[{"(", 
       RowBox[{
        TemplateBox[{"k","\[Beta]"},
         "Superscript"], "-", 
        TemplateBox[{"p","1","\[Beta]"},
         "Subsuperscript"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        TemplateBox[{"k","\[Gamma]"},
         "Superscript"], "+", 
        TemplateBox[{"p","2","\[Gamma]"},
         "Subsuperscript"]}], ")"}]}], 
     RowBox[{
      SuperscriptBox["k", "2"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"k", "-", 
         SubscriptBox["p", "1"]}], ")"}], "2"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"k", "+", 
         SubscriptBox["p", "2"]}], ")"}], "2"]}]],
    HoldForm]}],
  HoldForm]], "Output",
 CellChangeTimes->{{3.784302172563611*^9, 3.7843021874204607`*^9}, {
   3.784302398340598*^9, 3.784302452863717*^9}, 3.7843027893445287`*^9, {
   3.784303199974286*^9, 3.784303207431713*^9}, 3.784303306107592*^9, 
   3.7843045353548307`*^9, 3.7843081947288017`*^9, 3.78430883092819*^9, {
   3.7843092206824827`*^9, 3.7843092270538473`*^9}, 3.7843124606386642`*^9, 
   3.784313906708375*^9, 3.784353719143322*^9, 3.7845362059226294`*^9, 
   3.7847213958669033`*^9, 3.784727244338068*^9, 3.78472738977829*^9, {
   3.7851272815638723`*^9, 3.7851272891278543`*^9}, 3.792402632315062*^9, 
   3.792762953390876*^9, 3.792766955370564*^9, 3.794824038107909*^9, 
   3.7948822782184067`*^9, 3.794886142974065*^9, 3.7972003985754657`*^9, 
   3.798253942858508*^9, 3.7986858331287255`*^9, 
   3.799037652644726*^9},ExpressionUUID->"4715f997-9b80-4a5c-bc7a-\
11bb86cc1f5e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"tensor", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "\[ImaginaryI]"}], "/", "2"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       RowBox[{"e", "[", 
        RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Rho]", ",", "\[Gamma]"}], 
        "]"}]}], " ", 
      RowBox[{"\[Delta]", "[", 
       RowBox[{"\[Alpha]", ",", "\[Beta]"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"e", "[", 
       RowBox[{"\[Beta]", ",", "\[Nu]", ",", "\[Rho]", ",", "\[Gamma]"}], 
       "]"}], " ", 
      RowBox[{"\[Delta]", "[", 
       RowBox[{"\[Alpha]", ",", "\[Mu]"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"e", "[", 
       RowBox[{"\[Alpha]", ",", "\[Nu]", ",", "\[Rho]", ",", "\[Gamma]"}], 
       "]"}], " ", 
      RowBox[{"\[Delta]", "[", 
       RowBox[{"\[Beta]", ",", "\[Mu]"}], "]"}]}], "-", 
     RowBox[{
      RowBox[{"e", "[", 
       RowBox[{"\[Beta]", ",", "\[Alpha]", ",", "\[Mu]", ",", "\[Gamma]"}], 
       "]"}], " ", 
      RowBox[{"\[Delta]", "[", 
       RowBox[{"\[Nu]", ",", "\[Rho]"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"e", "[", 
       RowBox[{"\[Beta]", ",", "\[Alpha]", ",", "\[Mu]", ",", "\[Rho]"}], 
       "]"}], " ", 
      RowBox[{"\[Delta]", "[", 
       RowBox[{"\[Nu]", ",", "\[Gamma]"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"e", "[", 
       RowBox[{"\[Beta]", ",", "\[Alpha]", ",", "\[Mu]", ",", "\[Nu]"}], 
       "]"}], " ", 
      RowBox[{"\[Delta]", "[", 
       RowBox[{"\[Rho]", ",", "\[Gamma]"}], "]"}]}]}], ")"}]}]}]], "Input",
 CellChangeTimes->{{3.794824062741788*^9, 3.794824083661758*^9}, {
  3.794824323024248*^9, 3.794824335974557*^9}, {3.794882282654409*^9, 
  3.7948823427894917`*^9}, {3.7948826515263157`*^9, 
  3.794882680389989*^9}},ExpressionUUID->"e4327b37-8987-4b67-aaa8-\
1c9fa6fdd7ab"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox["1", "2"]}], " ", "\[ImaginaryI]", " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      RowBox[{"e", "[", 
       RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Rho]", ",", "\[Gamma]"}], 
       "]"}]}], " ", 
     SubscriptBox["\[Delta]", 
      RowBox[{"\[Alpha]", ",", "\[Beta]"}]]}], "+", 
    RowBox[{
     RowBox[{"e", "[", 
      RowBox[{"\[Beta]", ",", "\[Nu]", ",", "\[Rho]", ",", "\[Gamma]"}], 
      "]"}], " ", 
     SubscriptBox["\[Delta]", 
      RowBox[{"\[Alpha]", ",", "\[Mu]"}]]}], "+", 
    RowBox[{
     RowBox[{"e", "[", 
      RowBox[{"\[Alpha]", ",", "\[Nu]", ",", "\[Rho]", ",", "\[Gamma]"}], 
      "]"}], " ", 
     SubscriptBox["\[Delta]", 
      RowBox[{"\[Beta]", ",", "\[Mu]"}]]}], "+", 
    RowBox[{
     RowBox[{"e", "[", 
      RowBox[{"\[Beta]", ",", "\[Alpha]", ",", "\[Mu]", ",", "\[Rho]"}], 
      "]"}], " ", 
     SubscriptBox["\[Delta]", 
      RowBox[{"\[Gamma]", ",", "\[Nu]"}]]}], "+", 
    RowBox[{
     RowBox[{"e", "[", 
      RowBox[{"\[Beta]", ",", "\[Alpha]", ",", "\[Mu]", ",", "\[Nu]"}], "]"}],
      " ", 
     SubscriptBox["\[Delta]", 
      RowBox[{"\[Gamma]", ",", "\[Rho]"}]]}], "-", 
    RowBox[{
     RowBox[{"e", "[", 
      RowBox[{"\[Beta]", ",", "\[Alpha]", ",", "\[Mu]", ",", "\[Gamma]"}], 
      "]"}], " ", 
     SubscriptBox["\[Delta]", 
      RowBox[{"\[Nu]", ",", "\[Rho]"}]]}]}], ")"}]}]], "Output",
 CellChangeTimes->{{3.794824068834798*^9, 3.7948240838966017`*^9}, 
   3.7948243363311157`*^9, 3.794882343332131*^9, {3.794882680909157*^9, 
   3.7948826881519127`*^9}, 3.794886144641946*^9, 3.797200399740467*^9, 
   3.798253945081451*^9, 3.7986858331397266`*^9, 
   3.799037652691462*^9},ExpressionUUID->"7a0656d4-983b-410c-9cca-\
cfe0bc41eac3"]
}, Open  ]],

Cell[TextData[{
 "We evaluate the integral in 4-2\[Epsilon] dimensions and split the result \
into 3 pieces:\n- ",
 StyleBox["divergenceInt",
  FontSlant->"Italic"],
 " contains the divergent 1/\[Epsilon] piece\n- ",
 StyleBox["nonlocalInt",
  FontSlant->"Italic"],
 " is the coefficient of NL, the non-local part of the integral\n- ",
 StyleBox["restInt",
  FontSlant->"Italic"],
 " contains the remaining part.\nWe also work in Lorentzian signature in this \
section."
}], "Text",
 CellChangeTimes->{{3.794886163680125*^9, 3.79488624244809*^9}, {
  3.797200495354602*^9, 3.7972004988456063`*^9}, {3.7972007641639814`*^9, 
  3.797200790227018*^9}},ExpressionUUID->"9e808f49-2304-421c-a889-\
8c880fbfa368"],

Cell["This may take a moment.", "Text",
 CellChangeTimes->{
  3.7972007795610027`*^9},ExpressionUUID->"a7c70a36-9f10-4276-8899-\
df4061e8d100"],

Cell[BoxData[
 RowBox[{
  RowBox[{"int", "=", 
   RowBox[{
    RowBox[{"LoopEvaluate", "[", "integral", "]"}], "//", "Normal"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.784313840511588*^9, 3.7843139116376567`*^9}, {
   3.794824114236927*^9, 3.794824136213047*^9}, 3.7948861553224487`*^9, {
   3.7972004638765574`*^9, 3.797200470051566*^9}, {3.798253960314878*^9, 
   3.798253964536199*^9}},ExpressionUUID->"b9bdf744-6d0a-408a-91e1-\
f29b58551e12"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"divergenceInt", "=", 
  RowBox[{
   RowBox[{"Coefficient", "[", 
    RowBox[{"int", ",", "\[Epsilon]", ",", 
     RowBox[{"-", "1"}]}], "]"}], "//", "Simplify"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nonlocalInt", "=", 
   RowBox[{
    RowBox[{"Coefficient", "[", 
     RowBox[{"int", ",", 
      RowBox[{"NL", "[", 
       RowBox[{
        RowBox[{"p", "[", "1", "]"}], ",", 
        RowBox[{"p", "[", "2", "]"}], ",", 
        RowBox[{"p", "[", "3", "]"}]}], "]"}]}], "]"}], "//", "Simplify"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"restInt", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Expand", "[", 
     RowBox[{
      RowBox[{"Coefficient", "[", 
       RowBox[{"int", ",", "\[Epsilon]", ",", "0"}], "]"}], "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"NL", "[", 
         RowBox[{
          RowBox[{"p", "[", "1", "]"}], ",", 
          RowBox[{"p", "[", "2", "]"}], ",", 
          RowBox[{"p", "[", "3", "]"}]}], "]"}], "\[Rule]", "0"}], "}"}]}], 
     "]"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.784313954463106*^9, 3.7843139626525745`*^9}, {
   3.7843140453653054`*^9, 3.784314182451146*^9}, {3.78472524925521*^9, 
   3.784725283890686*^9}, {3.794824154917482*^9, 3.7948241731972637`*^9}, {
   3.794824207477434*^9, 3.794824216844486*^9}, {3.794882777589864*^9, 
   3.794882785771873*^9}, {3.794883132175521*^9, 3.794883133333603*^9}, {
   3.794883231752521*^9, 3.7948832322302856`*^9}, {3.7948834519210978`*^9, 
   3.794883454142787*^9}, 
   3.794886250065288*^9},ExpressionUUID->"7dc8daa7-7294-477a-8bcf-\
20b06a6ff0ba"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{
    SubscriptBox["\[Delta]", 
     RowBox[{"\[Beta]", ",", "\[Gamma]"}]], " ", 
    RowBox[{"(", 
     RowBox[{
      TemplateBox[{"p","1","\[Alpha]"},
       "Subsuperscript"], "-", 
      TemplateBox[{"p","2","\[Alpha]"},
       "Subsuperscript"]}], ")"}]}], "-", 
   RowBox[{
    SubscriptBox["\[Delta]", 
     RowBox[{"\[Alpha]", ",", "\[Gamma]"}]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", 
       TemplateBox[{"p","1","\[Beta]"},
        "Subsuperscript"]}], "+", 
      TemplateBox[{"p","2","\[Beta]"},
       "Subsuperscript"]}], ")"}]}], "+", 
   RowBox[{
    SubscriptBox["\[Delta]", 
     RowBox[{"\[Alpha]", ",", "\[Beta]"}]], " ", 
    RowBox[{"(", 
     RowBox[{
      TemplateBox[{"p","1","\[Gamma]"},
       "Subsuperscript"], "+", 
      RowBox[{"2", " ", 
       TemplateBox[{"p","2","\[Gamma]"},
        "Subsuperscript"]}]}], ")"}]}]}], 
  RowBox[{"192", " ", 
   SuperscriptBox["\[Pi]", "2"]}]]], "Output",
 CellChangeTimes->{{3.794886250883353*^9, 3.794886251912361*^9}, 
   3.7972004114404836`*^9, {3.7972004492235365`*^9, 3.797200472447569*^9}, 
   3.798253970755453*^9, 3.79868583658892*^9, 
   3.799037656492756*^9},ExpressionUUID->"3c8682e1-8a96-4d7a-b0a0-\
3cb6466a9011"]
}, Open  ]],

Cell[TextData[{
 "As we can see the integral itself is divergent. However, the contraction of \
the divergence with the ",
 StyleBox["tensor",
  FontSlant->"Italic"],
 " factor vanishes. To see it, we have to implement the algebra of the \
Levi-Civita tensor."
}], "Text",
 CellChangeTimes->{{3.794886255479553*^9, 
  3.7948863158732767`*^9}},ExpressionUUID->"0908cb63-fe6a-470c-b887-\
0c4348579e09"],

Cell[TextData[{
 "The Levi-Civita tensor is denoted by ",
 Cell[BoxData[
  FormBox[
   RowBox[{"e", "[", 
    RowBox[{
     SubscriptBox["\[Mu]", "1"], ",", "...", ",", 
     SubscriptBox["\[Mu]", "d"]}], "]"}], TraditionalForm]],ExpressionUUID->
  "e00644a6-e00f-4311-a049-d825156f9540"],
 " where ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[Mu]", "1"], ",", "...", ",", 
    SubscriptBox["\[Mu]", "d"]}], TraditionalForm]],ExpressionUUID->
  "d3f0a51a-fb70-4149-989e-38d003112b0b"],
 " is the sequence of indices.\nFurthermore, we define ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"e", "[", 
     RowBox[{
      SubscriptBox["x", "1"], ",", "...", ",", 
      SubscriptBox["x", "n"]}], "]"}], "[", 
    RowBox[{
     SubscriptBox["\[Mu]", "1"], ",", "...", ",", 
     SubscriptBox["\[Mu]", "d"]}], "]"}], TraditionalForm]],ExpressionUUID->
  "6f6685c8-43bc-4585-99b1-14e679ef55b9"],
 " as the Levi-Civita tensor contracted with ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["x", "1"], ",", "...", ",", 
    SubscriptBox["x", "n"]}], TraditionalForm]],ExpressionUUID->
  "b0c25b82-df75-4c87-b6b3-ef5415f3d84e"],
 ", i.e., ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{"e", "[", 
      RowBox[{
       SubscriptBox["x", "1"], ",", "...", ",", 
       SubscriptBox["x", "n"]}], "]"}], "[", 
     RowBox[{
      SubscriptBox["\[Mu]", "1"], ",", "...", ",", 
      SubscriptBox["\[Mu]", "d"]}], "]"}], "=", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"e", "[", 
        RowBox[{
         SubscriptBox["\[Alpha]", "1"], ",", "...", ",", 
         SubscriptBox["\[Alpha]", "n"], ",", 
         SubscriptBox["\[Mu]", "1"], ",", "...", ",", 
         SubscriptBox["\[Mu]", "d"]}], "]"}], 
       SuperscriptBox[
        SubscriptBox["x", "1"], 
        SubscriptBox["\[Alpha]", "1"]]}], "..."}], 
     RowBox[{
      SuperscriptBox[
       SubscriptBox["x", "n"], 
       SubscriptBox["\[Alpha]", "n"]], "."}]}]}], TraditionalForm]],
  ExpressionUUID->"08cfb66a-24be-414c-ad96-9b3a9a788677"]
}], "Text",
 CellChangeTimes->{{3.79488632076062*^9, 
  3.7948865669790277`*^9}},ExpressionUUID->"6a472fe2-537f-475e-bc5e-\
3398ea8d9107"],

Cell[BoxData[
 RowBox[{
  RowBox[{"suEpsilonContract", "=", 
   RowBox[{"{", " ", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"e", "[", 
        RowBox[{"i___", ",", "j_", ",", "k___", ",", "l_", ",", "m___"}], 
        "]"}], 
       RowBox[{"y_", "[", "j_", "]"}], 
       RowBox[{"y_", "[", "l_", "]"}]}], "\[RuleDelayed]", "0"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"e", "[", 
        RowBox[{"i___", ",", "j_", ",", "k___", ",", "l_", ",", "m___"}], 
        "]"}], 
       RowBox[{"\[Delta]", "[", 
        RowBox[{"j_", ",", "l_"}], "]"}]}], "\[RuleDelayed]", "0"}], ",", 
     RowBox[{
      RowBox[{"e", "[", 
       RowBox[{"i___", ",", "j_", ",", "k___", ",", "j_", ",", "l___"}], 
       "]"}], "\[RuleDelayed]", "0"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"e", "[", 
        RowBox[{"i___", ",", "j_", ",", "k___"}], "]"}], 
       RowBox[{"\[Delta]", "[", 
        RowBox[{"j_", ",", "l_"}], "]"}]}], "\[RuleDelayed]", 
      RowBox[{"e", "[", 
       RowBox[{"i", ",", "l", ",", "k"}], "]"}]}]}], " ", "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.794884775663389*^9, 3.794884810600203*^9}, {
  3.7948853017869797`*^9, 3.794885350588367*^9}, {3.794885523932558*^9, 
  3.794885524216628*^9}},ExpressionUUID->"2eabfe3a-ca93-4a3d-9902-\
16eb9903bcb2"],

Cell[BoxData[
 RowBox[{
  RowBox[{"suEpsilonSort", "=", 
   RowBox[{"{", " ", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"e", "[", "y___", "]"}], "[", 
        RowBox[{"i___", ",", "j_", ",", "k___"}], "]"}], 
       RowBox[{"x_", "[", "j_", "]"}]}], "\[RuleDelayed]", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"-", "1"}], ")"}], "^", 
        RowBox[{"Length", "[", 
         RowBox[{"{", "i", "}"}], "]"}]}], 
       RowBox[{
        RowBox[{"e", "[", 
         RowBox[{"y", ",", "x"}], "]"}], "[", 
        RowBox[{"i", ",", "k"}], "]"}]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"e", "[", "x___", "]"}], "[", "i___", "]"}], "\[RuleDelayed]", 
      RowBox[{
       RowBox[{"Signature", "[", 
        RowBox[{"{", "x", "}"}], "]"}], 
       RowBox[{"Signature", "[", 
        RowBox[{"{", "i", "}"}], "]"}], "*", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"e", "@@", 
          RowBox[{"Sort", "[", 
           RowBox[{"{", "x", "}"}], "]"}]}], ")"}], "@@", 
        RowBox[{"Sort", "[", 
         RowBox[{"{", "i", "}"}], "]"}]}]}]}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.794884850011795*^9, 
  3.794884880280087*^9}},ExpressionUUID->"1f97dead-2e3e-4510-829c-\
12a78a5c50a3"],

Cell[BoxData[
 RowBox[{
  RowBox[{"suUncontractEpsilon", "[", "\[Mu]_", "]"}], ":=", " ", 
  RowBox[{"{", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"e", "[", 
       RowBox[{"x___", ",", "y_"}], "]"}], "[", "i___", "]"}], 
     "\[RuleDelayed]", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"e", "[", "x", "]"}], "[", 
         RowBox[{"j", ",", "i"}], "]"}], "*", 
        RowBox[{"y", "[", "j", "]"}]}], "/.", 
       RowBox[{"{", 
        RowBox[{"j", "\[Rule]", 
         RowBox[{"Unique", "[", "\[Mu]", "]"}]}], "}"}]}], ")"}]}], ",", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"e", "[", "]"}], "[", "i___", "]"}], "\[RuleDelayed]", 
     RowBox[{"e", "[", "i", "]"}]}]}], " ", "}"}]}]], "Input",
 CellChangeTimes->{{3.794885540032823*^9, 3.7948855536817703`*^9}, {
  3.794885653859125*^9, 3.7948857459527082`*^9}, {3.794885795523715*^9, 
  3.7948858022887278`*^9}},ExpressionUUID->"1a10e53a-1507-4861-a8f6-\
67ec6b0ed006"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ContractEpsilon", "[", 
    RowBox[{"exp_", ",", 
     RowBox[{"opts___", "?", "OptionQ"}]}], "]"}], " ", ":=", " ", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "tmp", "}"}], ",", 
     RowBox[{"Contract", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"Expand", "[", "exp", "]"}], "//.", 
           RowBox[{"suUncontractEpsilon", "[", "tmp", "]"}]}], "//.", 
          "suEpsilonContract"}], "/.", 
         RowBox[{"{", 
          RowBox[{"e", "\[Rule]", 
           RowBox[{"e", "[", "]"}]}], "}"}]}], "//.", "suEpsilonSort"}], ",", 
       "opts"}], "]"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7948849994577303`*^9, 3.7948851435121393`*^9}, {
  3.794885287275696*^9, 3.794885289576725*^9}, {3.7948855777846823`*^9, 
  3.7948855781949263`*^9}, {3.7948858110361633`*^9, 
  3.794885847649748*^9}},ExpressionUUID->"26067ccf-b69e-409f-97ee-\
28407a9096bc"],

Cell[TextData[{
 "The divergence of the entire 3-point function vanishes. Note that it is \
important to use ",
 StyleBox["d",
  FontSlant->"Italic"],
 "=4 dimensions for the external momental and the Levi-Civita tensor."
}], "Text",
 CellChangeTimes->{{3.794886587328231*^9, 3.794886600784667*^9}, {
  3.7948866833853407`*^9, 
  3.794886704737564*^9}},ExpressionUUID->"815c0566-e7b3-4c5a-b5bd-\
5fdf495eb950"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"divergence", "=", 
  RowBox[{"ContractEpsilon", "[", 
   RowBox[{
    RowBox[{"divergenceInt", "*", "tensor"}], ",", 
    RowBox[{"Dimension", "\[Rule]", "4"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.794824219532267*^9, 3.794824229092169*^9}, {
  3.7948244615645113`*^9, 3.7948245035321217`*^9}, {3.794882532375696*^9, 
  3.7948825739499598`*^9}, {3.7948826375586567`*^9, 3.794882638053738*^9}, {
  3.7948827042637243`*^9, 3.794882707277725*^9}, {3.7948827492234898`*^9, 
  3.794882758133131*^9}, {3.794882788898932*^9, 3.79488281425445*^9}, {
  3.794882875168557*^9, 3.7948828859734993`*^9}, {3.794882979016*^9, 
  3.794883009903974*^9}, {3.794885151622776*^9, 
  3.794885162031865*^9}},ExpressionUUID->"c53c4370-367d-407d-9da0-\
026b887bc108"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.794882994288704*^9, 3.7948830176417*^9}, 
   3.79488323635181*^9, 3.794883520514752*^9, 3.7948851629202623`*^9, {
   3.794885327488744*^9, 3.7948853545887947`*^9}, 3.794885815173423*^9, 
   3.7948858504871407`*^9, 3.79720057945372*^9, 3.798254002330102*^9, 
   3.79868585874918*^9, 
   3.799037680109787*^9},ExpressionUUID->"2739a735-2979-4961-be3e-\
c77599c701a6"]
}, Open  ]],

Cell[TextData[{
 "The full 3-point function is then stored in ",
 StyleBox["jjjChiral",
  FontSlant->"Italic"],
 "."
}], "Text",
 CellChangeTimes->{{3.794886587328231*^9, 3.794886629296422*^9}, {
  3.7948867078014593`*^9, 3.794886716239703*^9}, {3.794886759128832*^9, 
  3.794886760296795*^9}},ExpressionUUID->"89441c3f-4e54-4728-bb2a-\
b32dfa5fb5dc"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"nonlocal", "=", 
   RowBox[{"ContractEpsilon", "[", 
    RowBox[{
     RowBox[{"nonlocalInt", "*", "tensor"}], ",", 
     RowBox[{"Dimension", "\[Rule]", "4"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rest", "=", 
   RowBox[{"ContractEpsilon", "[", 
    RowBox[{
     RowBox[{"restInt", "*", "tensor"}], ",", 
     RowBox[{"Dimension", "\[Rule]", "4"}]}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.794883021598091*^9, 3.7948830261529427`*^9}, {
  3.7948851688798523`*^9, 
  3.794885181736148*^9}},ExpressionUUID->"716f91f3-1fb2-4d58-8b3d-\
7a69ddb2cc2b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"jjjChiral", "=", 
   RowBox[{
    RowBox[{"divergence", "/", "\[Epsilon]"}], "+", 
    RowBox[{"nonlocal", " ", 
     RowBox[{"NL", "[", 
      RowBox[{
       RowBox[{"p", "[", "1", "]"}], ",", 
       RowBox[{"p", "[", "2", "]"}], ",", 
       RowBox[{"p", "[", "3", "]"}]}], "]"}]}], "+", "rest"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.79488520469875*^9, 3.794885217304512*^9}, {
  3.794886764027196*^9, 
  3.7948867664652767`*^9}},ExpressionUUID->"f99b20a4-eaed-41e8-b9f1-\
2e9388ccece5"],

Cell["\<\
Now it is time to check if the 3-point function is anomalous.
Contractions of the correlator with the external momenta are:\
\>", "Text",
 CellChangeTimes->{{3.794886587328231*^9, 3.794886676041111*^9}, {
  3.7948867234092503`*^9, 3.794886729801296*^9}, {3.794886775081366*^9, 
  3.7948867833534193`*^9}},ExpressionUUID->"50bc0d52-3a49-4814-9763-\
424cca03fc20"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"p1Nonlocal", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"ContractEpsilon", "[", 
     RowBox[{
      RowBox[{"jjjChiral", "*", 
       RowBox[{
        RowBox[{"p", "[", "1", "]"}], "[", "\[Mu]", "]"}]}], ",", 
      RowBox[{"Dimension", "\[Rule]", "4"}]}], "]"}], "//", 
    RowBox[{
     RowBox[{"KExpand", "[", 
      RowBox[{"#", ",", 
       RowBox[{"Level", "\[Rule]", "\[Lambda]"}]}], "]"}], "&"}]}], "//", 
   "Simplify"}]}], "\[IndentingNewLine]", 
 RowBox[{"p2Nonlocal", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"ContractEpsilon", "[", 
     RowBox[{
      RowBox[{"jjjChiral", "*", 
       RowBox[{
        RowBox[{"p", "[", "2", "]"}], "[", "\[Nu]", "]"}]}], ",", 
      RowBox[{"Dimension", "\[Rule]", "4"}]}], "]"}], "//", 
    RowBox[{
     RowBox[{"KExpand", "[", 
      RowBox[{"#", ",", 
       RowBox[{"Level", "\[Rule]", "\[Lambda]"}]}], "]"}], "&"}]}], "//", 
   "Simplify"}]}], "\[IndentingNewLine]", 
 RowBox[{"p3Nonlocal", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"ContractEpsilon", "[", 
     RowBox[{
      RowBox[{"jjjChiral", "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"p", "[", "1", "]"}], "[", "\[Rho]", "]"}]}], "-", 
         RowBox[{
          RowBox[{"p", "[", "2", "]"}], "[", "\[Rho]", "]"}]}], ")"}]}], ",", 
      RowBox[{"Dimension", "\[Rule]", "4"}]}], "]"}], "//", 
    RowBox[{
     RowBox[{"KExpand", "[", 
      RowBox[{"#", ",", 
       RowBox[{"Level", "\[Rule]", "\[Lambda]"}]}], "]"}], "&"}]}], "//", 
   "Simplify"}]}]}], "Input",
 CellChangeTimes->{
  3.794886751864318*^9, {3.79488678612387*^9, 3.7948867975338583`*^9}, {
   3.798254041674209*^9, 
   3.79825406091477*^9}},ExpressionUUID->"a3f2f9c3-4e24-4f37-8f88-\
e2231053446a"],

Cell[BoxData[
 FractionBox[
  RowBox[{"\[ImaginaryI]", " ", 
   RowBox[{
    RowBox[{"e", "[", 
     RowBox[{
      SubscriptBox["p", "1"], ",", 
      SubscriptBox["p", "2"]}], "]"}], "[", 
    RowBox[{"\[Nu]", ",", "\[Rho]"}], "]"}]}], 
  RowBox[{"96", " ", 
   SuperscriptBox["\[Pi]", "2"]}]]], "Output",
 CellChangeTimes->{3.794886753899539*^9, 3.794886799955275*^9, 
  3.7972005934607396`*^9, 3.798254021140377*^9, 3.798254066972755*^9, 
  3.7986858667626324`*^9, 
  3.799037689097829*^9},ExpressionUUID->"ab72721f-2888-477e-ad79-\
f2ad38f79cd3"],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"\[ImaginaryI]", " ", 
    RowBox[{
     RowBox[{"e", "[", 
      RowBox[{
       SubscriptBox["p", "1"], ",", 
       SubscriptBox["p", "2"]}], "]"}], "[", 
     RowBox[{"\[Mu]", ",", "\[Rho]"}], "]"}]}], 
   RowBox[{"96", " ", 
    SuperscriptBox["\[Pi]", "2"]}]]}]], "Output",
 CellChangeTimes->{3.794886753899539*^9, 3.794886799955275*^9, 
  3.7972005934607396`*^9, 3.798254021140377*^9, 3.798254066972755*^9, 
  3.7986858667626324`*^9, 
  3.7990376898672132`*^9},ExpressionUUID->"6933debc-0b7d-451d-b784-\
c6ab4de5b1f7"],

Cell[BoxData[
 FractionBox[
  RowBox[{"\[ImaginaryI]", " ", 
   RowBox[{
    RowBox[{"e", "[", 
     RowBox[{
      SubscriptBox["p", "1"], ",", 
      SubscriptBox["p", "2"]}], "]"}], "[", 
    RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}]}], 
  RowBox[{"96", " ", 
   SuperscriptBox["\[Pi]", "2"]}]]], "Output",
 CellChangeTimes->{3.794886753899539*^9, 3.794886799955275*^9, 
  3.7972005934607396`*^9, 3.798254021140377*^9, 3.798254066972755*^9, 
  3.7986858667626324`*^9, 
  3.799037691115445*^9},ExpressionUUID->"8264bdf2-08ae-4e89-825d-\
dd2a0bc65c9f"]
}, Open  ]],

Cell[TextData[{
 "We recover the correct ABJ anomaly,\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["p", 
      RowBox[{"3", "\[Rho]"}]], "<", 
     RowBox[{
      RowBox[{
       SuperscriptBox["j", "\[Mu]"], "(", 
       SubscriptBox["p", "1"], ")"}], 
      RowBox[{
       SuperscriptBox["j", "\[Nu]"], "(", 
       SubscriptBox["p", "2"], ")"}], 
      RowBox[{
       SuperscriptBox["j", "\[Rho]"], "(", 
       SubscriptBox["p", "3"], ")"}]}], ">"}], " ", "=", " ", 
    RowBox[{
     FractionBox["i", 
      RowBox[{"96", " ", 
       SuperscriptBox["\[Pi]", "2"]}]], 
     SuperscriptBox["\[Epsilon]", "\[Alpha]\[Beta]\[Mu]\[Nu]"], 
     SubscriptBox["p", 
      RowBox[{"1", "\[Alpha]"}]], 
     SubscriptBox["p", 
      RowBox[{"2", "\[Beta]"}]]}]}], TraditionalForm]],ExpressionUUID->
  "37571223-bea9-47cb-af1f-4ec5c6d40c14"],
 "\ntogether with the symmetric equations."
}], "Text",
 CellChangeTimes->{{3.7948868174004707`*^9, 3.7948868514332113`*^9}, {
  3.797200522172639*^9, 3.79720052254764*^9}, {3.797200609297762*^9, 
  3.7972007513319626`*^9}, {3.7982540764898243`*^9, 
  3.798254093608612*^9}},ExpressionUUID->"4a229772-c0a0-46d4-b0eb-\
d547981332d9"]
}, Closed]]
},
WindowSize->{995, 693},
WindowMargins->{{Automatic, 134}, {64, Automatic}},
ShowSelection->True,
Magnification:>FEPrivate`If[
  FEPrivate`Equal[FEPrivate`$VersionNumber, 6.], 1.25, 1.25 Inherited],
FrontEndVersion->"11.2 for Linux x86 (64-bit) (September 10, 2017)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[557, 20, 302, 7, 39, "Input",ExpressionUUID->"dc453752-83d2-4d0d-9f4c-1a179aba4247"],
Cell[862, 29, 185, 4, 39, "Input",ExpressionUUID->"319af3f1-fcf4-44fc-93fe-2d882d3e0a38"],
Cell[CellGroupData[{
Cell[1072, 37, 177, 3, 84, "Section",ExpressionUUID->"49a7a544-43e6-4966-a5b7-afcc2fd40efe"],
Cell[1252, 42, 2231, 68, 137, "Text",ExpressionUUID->"d93abd0d-e2db-410d-8942-00f2873a61dd"],
Cell[3486, 112, 1255, 41, 108, "Text",ExpressionUUID->"b69c35ca-eda3-4f49-8b78-ebf46ba617f0"],
Cell[4744, 155, 273, 8, 44, "Text",ExpressionUUID->"f5d4e600-9632-4427-ae03-1f545dfc61e4"],
Cell[CellGroupData[{
Cell[5042, 167, 679, 20, 69, "Input",ExpressionUUID->"acd878a6-993e-4d4d-ab29-f3aa0dd216e5"],
Cell[5724, 189, 486, 11, 48, "Output",ExpressionUUID->"e3944857-09a3-435c-a6c4-e2af9470b32e"],
Cell[6213, 202, 495, 11, 48, "Output",ExpressionUUID->"48e907f3-842f-40a2-80c2-b00410db6c65"]
}, Open  ]],
Cell[6723, 216, 841, 25, 73, "Text",ExpressionUUID->"247985cb-d475-4788-b74c-5191783784d8"],
Cell[CellGroupData[{
Cell[7589, 245, 734, 20, 43, "Input",ExpressionUUID->"67200ffc-9223-4cef-8986-5d12adfe9904"],
Cell[8326, 267, 271, 5, 44, "Output",ExpressionUUID->"1f84b12d-e519-48ea-8afb-055e3f041eff"]
}, Open  ]],
Cell[8612, 275, 1086, 30, 131, "Text",ExpressionUUID->"c50a115c-ec58-4fca-9718-4fa58b9f53ef"],
Cell[CellGroupData[{
Cell[9723, 309, 300, 9, 40, "Item",ExpressionUUID->"9a21bc91-1ec3-4b84-b6fa-219db6be256f"],
Cell[10026, 320, 326, 9, 67, "Item",ExpressionUUID->"274637e8-5dd3-41ff-bfc4-9240e48c6577"],
Cell[10355, 331, 306, 9, 40, "Item",ExpressionUUID->"adbb3bff-24da-42bc-b179-28c7107848f9"],
Cell[10664, 342, 2431, 72, 101, "Item",ExpressionUUID->"7058b4cb-e823-45ed-96f3-653534c410dd"]
}, Open  ]],
Cell[13110, 417, 307, 7, 44, "Text",ExpressionUUID->"5c5729b2-fc5a-4431-891f-fc44dbf87dc6"],
Cell[CellGroupData[{
Cell[13442, 428, 807, 18, 69, "Input",ExpressionUUID->"66608a6c-4b9c-4db2-a659-2d179210c9bc"],
Cell[14252, 448, 454, 8, 44, "Output",ExpressionUUID->"4d0d0bc1-587b-4f9a-b2ce-c92e8d4d5db8"],
Cell[14709, 458, 455, 8, 44, "Output",ExpressionUUID->"8182fe33-c710-40a2-9536-1d19cd3a371c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[15201, 471, 165, 3, 68, "Subsection",ExpressionUUID->"3226fdf5-c858-4709-af01-0a2e1aafa4b3"],
Cell[15369, 476, 440, 11, 44, "Text",ExpressionUUID->"55a0cdbb-e785-4fca-9712-d3f52244f2a9"],
Cell[CellGroupData[{
Cell[15834, 491, 497, 12, 39, "Input",ExpressionUUID->"70a893ee-87f6-4783-94b5-f94e657edd5f"],
Cell[16334, 505, 1536, 43, 116, "Output",ExpressionUUID->"953a2304-fa28-4090-8d22-e60c27bdb543"]
}, Open  ]],
Cell[17885, 551, 376, 9, 44, "Text",ExpressionUUID->"8651df40-a0de-4128-9bc5-5a88c10ab305"],
Cell[CellGroupData[{
Cell[18286, 564, 560, 15, 69, "Input",ExpressionUUID->"e8ff13db-0330-4019-bbc6-96af4b63dfb6"],
Cell[18849, 581, 322, 5, 44, "Output",ExpressionUUID->"1769ed37-e2b2-49e1-8360-36da356550c1"],
Cell[19174, 588, 421, 9, 48, "Output",ExpressionUUID->"6092f6a2-7e7d-4aa9-a615-51b10b0bb7c9"]
}, Open  ]],
Cell[19610, 600, 324, 9, 44, "Text",ExpressionUUID->"af344a54-a977-4cc3-b332-4702c7b0936e"],
Cell[CellGroupData[{
Cell[19959, 613, 992, 26, 69, "Input",ExpressionUUID->"1bdd0eae-3834-48e0-8cd3-aa00995272c0"],
Cell[20954, 641, 1350, 33, 75, "Output",ExpressionUUID->"90d90bd0-e41b-460f-b698-7f32eb099982"],
Cell[22307, 676, 2123, 57, 90, "Output",ExpressionUUID->"11502647-f1a5-41d6-beae-b3fa86a50032"]
}, Open  ]],
Cell[24445, 736, 262, 4, 44, "Text",ExpressionUUID->"5604e229-ab24-453e-a9bf-f2c14db3937e"],
Cell[CellGroupData[{
Cell[24732, 744, 845, 16, 39, "Input",ExpressionUUID->"6bb4e652-0333-4e6a-b8c5-4c1fe5ba6c24"],
Cell[25580, 762, 852, 16, 44, "Output",ExpressionUUID->"2551632f-0241-4839-bd4c-dfc4d807b556"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[26481, 784, 314, 5, 68, "Subsection",ExpressionUUID->"90b8d251-9ada-468e-be76-e75e3b8eac05"],
Cell[26798, 791, 1008, 24, 108, "Text",ExpressionUUID->"b8622019-d078-4df3-bb3a-57c7e730de1a"],
Cell[CellGroupData[{
Cell[27831, 819, 164, 3, 39, "Input",ExpressionUUID->"4c6d8e0d-a74e-47e1-806f-8f7b3a9f8e2c"],
Cell[27998, 824, 303, 5, 44, "Output",ExpressionUUID->"8d2d2c10-8f56-4bf5-b36e-41b0777ad0f1"]
}, Open  ]],
Cell[28316, 832, 274, 7, 44, "Text",ExpressionUUID->"9c8d247a-1517-49fd-bb7f-a0fe574daf5c"],
Cell[CellGroupData[{
Cell[28615, 843, 290, 8, 39, "Input",ExpressionUUID->"014eed7f-76a5-4f39-b968-ee56fe5d09d8"],
Cell[28908, 853, 873, 23, 63, "Output",ExpressionUUID->"ec44afa4-7aa3-41ff-97d3-99589a2191c4"]
}, Open  ]],
Cell[29796, 879, 1062, 31, 76, "Text",ExpressionUUID->"a83b1238-8775-4355-8bb4-04977d9a2f2b"],
Cell[CellGroupData[{
Cell[30883, 914, 713, 16, 39, "Input",ExpressionUUID->"254452d4-34e5-47f6-90cc-88c9b9e0d5b7"],
Cell[31599, 932, 1319, 38, 67, "Output",ExpressionUUID->"790fe2bd-73bf-46df-ad3c-0a3c5c91009a"]
}, Open  ]],
Cell[32933, 973, 695, 15, 102, "Text",ExpressionUUID->"20882784-813f-4493-b7b7-780e283703af"],
Cell[CellGroupData[{
Cell[33653, 992, 1834, 52, 214, "Input",ExpressionUUID->"dd471db2-0423-41c7-aa78-1288ad5ecb43"],
Cell[35490, 1046, 1028, 26, 63, "Output",ExpressionUUID->"8c8a31f8-f9b3-4107-88e8-d2feace9ce68"],
Cell[36521, 1074, 470, 8, 44, "Output",ExpressionUUID->"bb4d27e1-608d-47c8-a9e4-95e317931d2a"],
Cell[36994, 1084, 1028, 26, 63, "Output",ExpressionUUID->"15cabe2d-8bf8-4bae-9643-ee87fc40785e"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[38071, 1116, 374, 6, 68, "Subsection",ExpressionUUID->"2ce07684-bb5a-4f02-b428-2cea82fec864"],
Cell[38448, 1124, 346, 9, 44, "Text",ExpressionUUID->"bac7b8f5-4470-4d34-865b-12bfbe083725"],
Cell[CellGroupData[{
Cell[38819, 1137, 759, 22, 98, "Input",ExpressionUUID->"0ae17e62-314e-4dc0-85d5-7b356f04df97"],
Cell[39581, 1161, 306, 5, 44, "Output",ExpressionUUID->"65851794-8ab5-4d4e-94a3-cc24ada058e0"],
Cell[39890, 1168, 306, 5, 44, "Output",ExpressionUUID->"710f4ce1-7d80-47c8-b5e8-55d515450024"],
Cell[40199, 1175, 307, 5, 44, "Output",ExpressionUUID->"92274afe-c524-406f-af2c-85cb3c4419d1"]
}, Open  ]],
Cell[40521, 1183, 587, 15, 102, "Text",ExpressionUUID->"30d753eb-c45a-4ae6-98a2-d0a1a2b61b30"],
Cell[CellGroupData[{
Cell[41133, 1202, 1108, 31, 98, "Input",ExpressionUUID->"638d66c2-1493-480b-9722-441850c76f6a"],
Cell[42244, 1235, 376, 6, 44, "Output",ExpressionUUID->"5c72eaee-cf49-4e60-9fe7-d40c188fa53c"],
Cell[42623, 1243, 903, 26, 44, "Output",ExpressionUUID->"6ee4200d-5961-41da-8852-e75c0f72fe7a"],
Cell[43529, 1271, 376, 6, 44, "Output",ExpressionUUID->"b2b3c2a7-eab6-4b71-bf51-2fd305f3311e"]
}, Open  ]],
Cell[43920, 1280, 668, 17, 73, "Text",ExpressionUUID->"5afdcbd9-626d-48dd-83b5-3632a7a4b713"],
Cell[44591, 1299, 288, 9, 44, "Text",ExpressionUUID->"b001977a-38d3-4492-8c29-99712bdb041b"],
Cell[CellGroupData[{
Cell[44904, 1312, 1225, 36, 98, "Input",ExpressionUUID->"6cd441ec-6249-4a0e-afba-d96370afb0c3"],
Cell[46132, 1350, 660, 16, 63, "Output",ExpressionUUID->"2c6cf54a-8eb7-4f74-931a-6f247af2bcca"],
Cell[46795, 1368, 822, 22, 74, "Output",ExpressionUUID->"2d48966d-638d-4f0f-9b6e-64872f3c447e"],
Cell[47620, 1392, 4268, 106, 179, "Output",ExpressionUUID->"d74e5f9b-0d66-470c-8b42-59e2a27e5459"]
}, Open  ]],
Cell[51903, 1501, 442, 15, 73, "Text",ExpressionUUID->"c3bc55fc-c729-4983-9aaa-f6e666f1ed8d"],
Cell[52348, 1518, 393, 10, 73, "Text",ExpressionUUID->"723b8801-821c-48a5-8274-4facad3a5229"],
Cell[CellGroupData[{
Cell[52766, 1532, 1359, 39, 98, "Input",ExpressionUUID->"16204cf1-4cb7-4e57-a33d-ad20d05c4f89"],
Cell[54128, 1573, 575, 12, 44, "Output",ExpressionUUID->"c1a6cff4-79e6-4a51-a346-53ebaa030f56"],
Cell[54706, 1587, 1571, 43, 79, "Output",ExpressionUUID->"f53338bc-2162-49c7-98f4-353f3791b85e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[56314, 1635, 907, 26, 98, "Input",ExpressionUUID->"7910339e-9638-453f-85ea-37d8e6bf457e"],
Cell[57224, 1663, 444, 7, 44, "Output",ExpressionUUID->"090ba6bf-4251-4964-9e3c-0ee0a0427e01"],
Cell[57671, 1672, 3105, 87, 158, "Output",ExpressionUUID->"8dbc25fb-64c4-41ae-9a21-3ce8486546c5"]
}, Open  ]],
Cell[60791, 1762, 688, 20, 102, "Text",ExpressionUUID->"b5d0bfb4-b7ba-4a24-9946-05b85752a5dc"],
Cell[CellGroupData[{
Cell[61504, 1786, 450, 14, 39, "Input",ExpressionUUID->"12c5d84c-a810-4f38-a937-3d29286f9644"],
Cell[61957, 1802, 1488, 44, 82, "Output",ExpressionUUID->"bbc6f42f-4732-4965-862b-0759c8f71133"]
}, Open  ]],
Cell[63460, 1849, 400, 14, 73, "Text",ExpressionUUID->"9bb570e0-dd63-47c8-a160-fc02f430a81f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[63897, 1868, 224, 4, 68, "Subsection",ExpressionUUID->"9d826c2a-f428-45c3-9fef-af437394b46e"],
Cell[64124, 1874, 778, 22, 102, "Text",ExpressionUUID->"d72e3ecf-616b-42b4-9b46-1468f234eb8c"],
Cell[CellGroupData[{
Cell[64927, 1900, 382, 11, 39, "Input",ExpressionUUID->"fe45192e-4ee7-417d-b215-eb604a028c9a"],
Cell[65312, 1913, 368, 7, 44, "Output",ExpressionUUID->"6db4a227-5f14-4030-ad11-562b723fe323"]
}, Open  ]],
Cell[65695, 1923, 667, 23, 73, "Text",ExpressionUUID->"ead0ff5f-8abc-469f-81ef-f5ba52e0af03"],
Cell[CellGroupData[{
Cell[66387, 1950, 365, 6, 69, "Input",ExpressionUUID->"4e4661ac-cace-4791-b6c0-4a3c3a0bf0bf"],
Cell[66755, 1958, 810, 19, 46, "Output",ExpressionUUID->"80af7246-dccb-4c59-b5ec-55a718727927"],
Cell[67568, 1979, 4097, 111, 315, "Output",ExpressionUUID->"70d9fbf9-9078-4be9-bf64-6337a06e556d"]
}, Open  ]],
Cell[71680, 2093, 448, 15, 44, "Text",ExpressionUUID->"e54e4bfc-3fc7-4cf2-ac7b-aa83d7fb2aad"],
Cell[CellGroupData[{
Cell[72153, 2112, 919, 24, 39, "Input",ExpressionUUID->"61eeec09-8477-4484-968f-70f09bf6f3bb"],
Cell[73075, 2138, 1759, 50, 130, "Output",ExpressionUUID->"4dcf412f-292a-436b-b53b-80a254488578"]
}, Open  ]],
Cell[74849, 2191, 281, 10, 44, "Text",ExpressionUUID->"6798e88a-3819-4f3b-bcc2-3b99dfdc9d8a"],
Cell[CellGroupData[{
Cell[75155, 2205, 572, 18, 67, "Item",ExpressionUUID->"c1f03b33-97d6-49f2-813a-0ae171a92d80"],
Cell[75730, 2225, 311, 8, 40, "Item",ExpressionUUID->"969253ff-6711-454a-99f8-46e6c497caab"],
Cell[76044, 2235, 260, 6, 40, "Item",ExpressionUUID->"17303104-b700-452a-96d2-9eaa5b0c256d"],
Cell[76307, 2243, 476, 17, 67, "Item",ExpressionUUID->"2f7542e4-1c7b-4117-93c4-06f02b94391d"],
Cell[76786, 2262, 145, 3, 40, "Item",ExpressionUUID->"19ff4c1a-5631-48e8-824a-b4a47ad92505"]
}, Open  ]],
Cell[CellGroupData[{
Cell[76968, 2270, 514, 14, 69, "Input",ExpressionUUID->"7117085d-0dbb-4bf1-90b5-be053d17be0e"],
Cell[77485, 2286, 1846, 53, 102, "Output",ExpressionUUID->"f1bfee96-637f-4004-b7d3-149f08b74026"],
Cell[79334, 2341, 2269, 66, 148, "Output",ExpressionUUID->"513b8a56-7ad7-4962-8679-f09580085573"]
}, Open  ]],
Cell[81618, 2410, 341, 11, 44, "Text",ExpressionUUID->"ee939956-5879-4ecf-bc8b-a185a2d83067"]
}, Open  ]],
Cell[CellGroupData[{
Cell[81996, 2426, 192, 3, 68, "Subsection",ExpressionUUID->"451ec262-9a81-4378-b345-3edb27b3057e"],
Cell[82191, 2431, 286, 8, 44, "Text",ExpressionUUID->"ef957067-8dbb-4b2f-9031-1c3d2938560f"],
Cell[CellGroupData[{
Cell[82502, 2443, 480, 11, 39, "Input",ExpressionUUID->"bec38e02-c1b1-4d57-9845-399dd0a23f6e"],
Cell[82985, 2456, 1101, 27, 69, "Output",ExpressionUUID->"83029b0e-4455-4a7c-9388-e7c2960978f9"]
}, Open  ]],
Cell[84101, 2486, 759, 19, 73, "Text",ExpressionUUID->"55fdd9a2-0294-4bd5-b1c0-e3e09d0db5d4"],
Cell[CellGroupData[{
Cell[84885, 2509, 345, 6, 39, "Input",ExpressionUUID->"1d5b2260-c33f-4d52-a3c7-3f4581e4433d"],
Cell[85233, 2517, 7087, 165, 381, "Output",ExpressionUUID->"aa2ab14c-84b1-48b6-b524-736f3fd22c69"]
}, Open  ]],
Cell[92335, 2685, 603, 16, 102, "Text",ExpressionUUID->"cd001cfe-4a34-49fc-9b3c-6f867f3ed3f5"],
Cell[CellGroupData[{
Cell[92963, 2705, 672, 14, 39, "Input",ExpressionUUID->"a12e3683-8896-4f55-a377-938e484db6b8"],
Cell[93638, 2721, 677, 13, 44, "Output",ExpressionUUID->"aef22c9a-b33a-49ef-a600-21e1080b7084"]
}, Open  ]],
Cell[94330, 2737, 515, 13, 73, "Text",ExpressionUUID->"cb42a138-3c5c-400b-accd-d7b3124b429b"],
Cell[CellGroupData[{
Cell[94870, 2754, 702, 16, 39, "Input",ExpressionUUID->"7e613e8c-61dc-4182-921c-2c7b7d7b7720"],
Cell[95575, 2772, 10959, 281, 431, "Output",ExpressionUUID->"30c16beb-d0f1-45e3-aa6c-e76f7dbd342f"]
}, Open  ]],
Cell[106549, 3056, 350, 9, 73, "Text",ExpressionUUID->"80aa21c7-fb18-4c3e-a47f-19049b6e9f6b"],
Cell[CellGroupData[{
Cell[106924, 3069, 555, 16, 39, "Input",ExpressionUUID->"81311d0b-e7ea-4909-a7f2-90280d4e949d"],
Cell[107482, 3087, 477, 10, 44, "Output",ExpressionUUID->"1ea0c2d0-eba8-4b5a-ba42-3d594ffb7a22"]
}, Open  ]],
Cell[107974, 3100, 361, 7, 73, "Text",ExpressionUUID->"403444db-e9eb-4743-8f65-c8b1f03c2a28"],
Cell[CellGroupData[{
Cell[108360, 3111, 1206, 29, 69, "Input",ExpressionUUID->"225fdc60-6239-4872-aba9-268383c0836c"],
Cell[109569, 3142, 655, 13, 44, "Output",ExpressionUUID->"dc037556-bb65-47d3-abef-93c382bb92d2"],
Cell[110227, 3157, 657, 13, 44, "Output",ExpressionUUID->"afa92f7d-ea92-4109-b5cb-cf3b42ae295e"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[110945, 3177, 169, 3, 65, "Section",ExpressionUUID->"8ea2412d-cc6f-4bb0-bf4d-940576ac4526"],
Cell[111117, 3182, 2926, 95, 253, "Text",ExpressionUUID->"0e569706-9359-4e43-b111-a0a977aca93d"],
Cell[114046, 3279, 392, 9, 73, "Text",ExpressionUUID->"cccffcc3-9cd2-450e-b901-0397d673f7a1"],
Cell[CellGroupData[{
Cell[114463, 3292, 400, 10, 39, "Input",ExpressionUUID->"b919e6fb-849c-4190-860d-f73b53728e1c"],
Cell[114866, 3304, 1022, 29, 75, "Output",ExpressionUUID->"364be254-2195-453b-8aba-7a2c4007c8e4"]
}, Open  ]],
Cell[115903, 3336, 580, 15, 44, "Text",ExpressionUUID->"6964230c-52ed-4857-aee1-94872bc6df48"],
Cell[CellGroupData[{
Cell[116508, 3355, 390, 10, 39, "Input",ExpressionUUID->"01aa5b81-766f-43ed-90ef-ccb10a0669d1"],
Cell[116901, 3367, 1153, 34, 75, "Output",ExpressionUUID->"af7f5926-b7f6-410a-ac1e-74540e19678d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[118091, 3406, 221, 4, 68, "Subsection",ExpressionUUID->"e0926b4c-9868-42bb-9d36-4a1d8a6a35e1"],
Cell[118315, 3412, 484, 12, 102, "Text",ExpressionUUID->"8e1ae90e-40f3-4b5b-9963-673bbe1aef23"],
Cell[118802, 3426, 1014, 28, 81, "Text",ExpressionUUID->"deae2631-dd54-4073-a2ea-52100380e07a"],
Cell[CellGroupData[{
Cell[119841, 3458, 254, 7, 39, "Input",ExpressionUUID->"d4519333-3e1e-438b-b90f-2f21f5c9ee26"],
Cell[120098, 3467, 503, 13, 63, "Output",ExpressionUUID->"ebd36192-abe1-493a-a714-bb0bdc4870ef"]
}, Open  ]],
Cell[120616, 3483, 420, 12, 73, "Text",ExpressionUUID->"3174dc97-845b-4790-846d-862c31086ff5"],
Cell[CellGroupData[{
Cell[121061, 3499, 876, 24, 69, "Input",ExpressionUUID->"1bb0f6be-f389-4b1c-8a34-6ab8b6314a41"],
Cell[121940, 3525, 884, 27, 48, "Output",ExpressionUUID->"9d8d5427-9ff2-4c30-b5e6-2b4c53a81467"],
Cell[122827, 3554, 427, 10, 48, "Output",ExpressionUUID->"bff125d8-2c7e-4b1b-9426-82720565902c"]
}, Open  ]],
Cell[123269, 3567, 798, 24, 76, "Text",ExpressionUUID->"9e9a11f0-3e16-4d4d-a3be-f143f1c6dd3d"],
Cell[CellGroupData[{
Cell[124092, 3595, 615, 16, 69, "Input",ExpressionUUID->"eecc1fa3-d0d5-4dfc-b25e-b42616e3a1ed"],
Cell[124710, 3613, 521, 13, 63, "Output",ExpressionUUID->"dd7866a4-7211-46b6-9e40-ae780138f13f"],
Cell[125234, 3628, 403, 9, 46, "Output",ExpressionUUID->"acc122c1-2fe5-4f0f-81b2-ae54fc24ae32"]
}, Open  ]],
Cell[125652, 3640, 352, 9, 44, "Text",ExpressionUUID->"be9d5955-2230-4998-9fc5-a28cdf532368"],
Cell[CellGroupData[{
Cell[126029, 3653, 424, 11, 39, "Input",ExpressionUUID->"6547ad10-5b9f-4424-a93b-db357fc90e05"],
Cell[126456, 3666, 354, 7, 44, "Output",ExpressionUUID->"d0b0e33a-ff89-4b7c-8384-abbccd09bc56"]
}, Open  ]],
Cell[126825, 3676, 413, 13, 73, "Text",ExpressionUUID->"3e73fdae-5149-4396-a18e-45ed3cad79a7"],
Cell[CellGroupData[{
Cell[127263, 3693, 536, 15, 39, "Input",ExpressionUUID->"16d6244e-c4d1-4115-b4a7-f7c9524ce5e4"],
Cell[127802, 3710, 420, 9, 44, "Output",ExpressionUUID->"1aa3e654-1fd9-490e-a33b-d1608c24a255"]
}, Open  ]],
Cell[128237, 3722, 300, 7, 44, "Text",ExpressionUUID->"99b07dc7-84d9-43b8-8c93-1246d70a182e"],
Cell[CellGroupData[{
Cell[128562, 3733, 453, 14, 39, "Input",ExpressionUUID->"6f8a9853-56d6-4e47-958e-4404d92ae176"],
Cell[129018, 3749, 387, 10, 44, "Output",ExpressionUUID->"a225eca5-c18e-46bf-b617-211c9c8b7588"]
}, Open  ]],
Cell[129420, 3762, 338, 9, 44, "Text",ExpressionUUID->"053230b6-7339-4b10-8ecd-575c18a94cef"],
Cell[CellGroupData[{
Cell[129783, 3775, 354, 10, 39, "Input",ExpressionUUID->"2f013a70-a3c6-4c85-96e9-59ec7b8f87be"],
Cell[130140, 3787, 297, 6, 44, "Output",ExpressionUUID->"e69da52f-7bb5-432f-a987-9914415f4b92"]
}, Open  ]],
Cell[130452, 3796, 258, 8, 44, "Text",ExpressionUUID->"431e9a79-c7a0-4b66-be7d-2bb8f8ed3262"],
Cell[CellGroupData[{
Cell[130735, 3808, 605, 14, 69, "Input",ExpressionUUID->"4c886d6f-0cb3-4a80-a4f6-1126972a3f9b"],
Cell[131343, 3824, 240, 4, 44, "Output",ExpressionUUID->"63d78e31-95be-4182-b106-a27ed7229b60"],
Cell[131586, 3830, 242, 4, 44, "Output",ExpressionUUID->"6ecc6fe6-7722-46bb-b872-5220a4296c79"]
}, Open  ]],
Cell[131843, 3837, 462, 13, 73, "Text",ExpressionUUID->"9cc0edd7-c632-46d8-b0f5-f47ead1bd19a"],
Cell[CellGroupData[{
Cell[132330, 3854, 287, 7, 39, "Input",ExpressionUUID->"efa11422-383d-4ddc-bcc1-3b97b86b419b"],
Cell[132620, 3863, 422, 8, 46, "Output",ExpressionUUID->"cbae141c-e736-458f-8ff4-3a926a0e7511"]
}, Open  ]],
Cell[133057, 3874, 1039, 31, 46, "Text",ExpressionUUID->"62f695e2-32c0-4116-9fcd-64dd1bf8c459"],
Cell[CellGroupData[{
Cell[134121, 3909, 495, 12, 39, "Input",ExpressionUUID->"df8f7d9d-b0e5-4166-bd19-c9e296dfc7f3"],
Cell[134619, 3923, 1106, 29, 48, "Output",ExpressionUUID->"cd7ca1cd-01ab-415e-978c-13a7f7c5f079"]
}, Open  ]],
Cell[135740, 3955, 328, 13, 44, "Text",ExpressionUUID->"f178ba43-15e5-45c5-bfb6-99a30c921eb2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[136105, 3973, 183, 3, 68, "Subsection",ExpressionUUID->"0cf24d98-a44f-44d7-8079-bbdfc9ca3f6f"],
Cell[136291, 3978, 357, 8, 44, "Text",ExpressionUUID->"b293b4bf-df53-453e-874b-4ff2a9d80fc6"],
Cell[CellGroupData[{
Cell[136673, 3990, 459, 11, 39, "Input",ExpressionUUID->"d73016d9-20ab-444c-8518-199c74a95ada"],
Cell[137135, 4003, 1426, 37, 75, "Output",ExpressionUUID->"5595b503-3176-41e0-83ea-924a4f98a9ac"]
}, Open  ]],
Cell[CellGroupData[{
Cell[138598, 4045, 314, 6, 39, "Input",ExpressionUUID->"aa0a79f7-c8e0-4575-970b-dd210a15aad2"],
Cell[138915, 4053, 1510, 40, 94, "Output",ExpressionUUID->"149491a4-e844-4ff3-9414-d3009a4dae47"]
}, Open  ]],
Cell[140440, 4096, 460, 12, 73, "Text",ExpressionUUID->"7bf55f78-37c4-4f70-a570-d1d86ce1dbfe"],
Cell[CellGroupData[{
Cell[140925, 4112, 809, 22, 69, "Input",ExpressionUUID->"4771dd85-bf54-400d-bcd1-6043455a673f"],
Cell[141737, 4136, 1734, 44, 68, "Output",ExpressionUUID->"057bc7ce-39c9-4b8f-a6d5-aa4a94f76323"],
Cell[143474, 4182, 1733, 44, 68, "Output",ExpressionUUID->"c4baa201-e079-4739-85e0-8f1b9bb858b2"]
}, Open  ]],
Cell[145222, 4229, 221, 5, 44, "Text",ExpressionUUID->"795999c4-69b4-49b4-b53e-875782d69d68"],
Cell[CellGroupData[{
Cell[145468, 4238, 646, 20, 39, "Input",ExpressionUUID->"84805282-6157-41b7-ad2d-252cbcb1f0a4"],
Cell[146117, 4260, 1603, 46, 75, "Output",ExpressionUUID->"64236c27-fa96-434d-b654-09559f84594d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[147757, 4311, 316, 6, 39, "Input",ExpressionUUID->"0f5df7ea-ff2b-46a2-be59-f7c3cfccf1d7"],
Cell[148076, 4319, 72395, 1606, 3365, "Output",ExpressionUUID->"2246aa49-92c4-4406-87fb-0ec612d353ed"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[220532, 5932, 163, 3, 65, "Section",ExpressionUUID->"fd49f45b-d987-49cc-abd1-a0545e72588e"],
Cell[220698, 5937, 1535, 38, 131, "Text",ExpressionUUID->"0c3d5b31-b0cf-4e50-9af4-dfa1a4c7d99c"],
Cell[CellGroupData[{
Cell[222258, 5979, 472, 14, 68, "Subsection",ExpressionUUID->"c292588b-0fdd-4a5c-bef2-a028d303aa5f"],
Cell[222733, 5995, 1189, 33, 73, "Text",ExpressionUUID->"53bc34e9-5a29-4968-8652-ba552978ba3e"],
Cell[223925, 6030, 625, 17, 73, "Text",ExpressionUUID->"5df6d6a9-49c7-4eee-a0f4-910346731b3f"],
Cell[CellGroupData[{
Cell[224575, 6051, 1216, 35, 127, "Input",ExpressionUUID->"27b39e08-614e-42c9-bb47-cd1d867ddb7a"],
Cell[225794, 6088, 232, 4, 44, "Output",ExpressionUUID->"5e59b870-d3cf-473f-b1cd-f855e9bd3bc9"],
Cell[226029, 6094, 5188, 146, 155, "Output",ExpressionUUID->"88178ec1-fc6e-4ac4-af65-1095b55ce746"]
}, Open  ]],
Cell[231232, 6243, 438, 12, 44, "Text",ExpressionUUID->"2a3730d0-bfd6-40d7-a0b9-54ca3575b095"],
Cell[CellGroupData[{
Cell[231695, 6259, 402, 10, 69, "Input",ExpressionUUID->"d0f2d88e-8972-482e-87eb-0d14c726ff49"],
Cell[232100, 6271, 1035, 31, 88, "Output",ExpressionUUID->"7fa26429-6a76-4bf9-afe8-051b88fe668d"],
Cell[233138, 6304, 396, 10, 71, "Output",ExpressionUUID->"6c70c1d0-524a-45ef-b1f3-c8c1eda86109"]
}, Open  ]],
Cell[233549, 6317, 525, 13, 73, "Text",ExpressionUUID->"226404a7-37a5-4ad2-8d6e-d8dee37be64c"],
Cell[CellGroupData[{
Cell[234099, 6334, 1019, 30, 98, "Input",ExpressionUUID->"bc8f433c-0959-48c1-9631-2b42e940ae1e"],
Cell[235121, 6366, 1844, 59, 91, "Output",ExpressionUUID->"011984b9-0863-4e26-ab55-aabcf010cc03"]
}, Open  ]],
Cell[236980, 6428, 225, 5, 44, "Text",ExpressionUUID->"40000531-41bb-4bcc-9139-032d59bbf4ed"],
Cell[CellGroupData[{
Cell[237230, 6437, 1268, 35, 156, "Input",ExpressionUUID->"ff642a5f-7a24-4536-8054-1c9c5f931db3"],
Cell[238501, 6474, 254, 4, 44, "Output",ExpressionUUID->"e0374a19-9a25-451c-9d08-e52ed64ff0b0"],
Cell[238758, 6480, 7327, 212, 314, "Output",ExpressionUUID->"60b3ef16-37f5-46bb-b4ea-25163724d137"]
}, Open  ]],
Cell[246100, 6695, 291, 9, 44, "Text",ExpressionUUID->"963df61e-7d16-4fee-9c6a-6b9af9108305"],
Cell[CellGroupData[{
Cell[246416, 6708, 240, 5, 39, "Input",ExpressionUUID->"1265e92b-d917-4049-a50a-0fbd10c3b8e7"],
Cell[246659, 6715, 1361, 44, 106, "Output",ExpressionUUID->"d48adfbd-1ee2-43c6-9216-acd24fbf4706"]
}, Open  ]],
Cell[248035, 6762, 421, 8, 73, "Text",ExpressionUUID->"c9e11e6f-2ca8-4c51-9542-6d697da79784"],
Cell[CellGroupData[{
Cell[248481, 6774, 271, 7, 69, "Input",ExpressionUUID->"784af205-3860-48d4-be21-dc0e98ec7515"],
Cell[248755, 6783, 220, 5, 44, "Output",ExpressionUUID->"b1c657ca-3aeb-4c7c-ace1-c8d6dc286625"],
Cell[248978, 6790, 215, 4, 44, "Output",ExpressionUUID->"85fb6e0b-6262-4d74-8a35-a5a0f6052072"]
}, Open  ]],
Cell[249208, 6797, 155, 3, 44, "Text",ExpressionUUID->"87ba0228-c4c5-4c75-af5e-e41817076d0f"],
Cell[CellGroupData[{
Cell[249388, 6804, 360, 9, 39, "Input",ExpressionUUID->"93db7e9c-55a1-41ef-9f28-602c9205305f"],
Cell[249751, 6815, 4996, 124, 233, "Output",ExpressionUUID->"2faa872e-71bf-40e0-9da3-82ee94398792"]
}, Open  ]],
Cell[254762, 6942, 591, 13, 73, "Text",ExpressionUUID->"6da59a45-df9e-4ffd-abd3-4385da9228d2"],
Cell[CellGroupData[{
Cell[255378, 6959, 1937, 52, 156, "Input",ExpressionUUID->"56b643c4-68b4-48d6-bdf3-27bead31b80c"],
Cell[257318, 7013, 6077, 149, 340, "Output",ExpressionUUID->"c274c697-e7ed-4539-a52f-6fc175c34aed"]
}, Open  ]],
Cell[263410, 7165, 255, 4, 44, "Text",ExpressionUUID->"d5450e56-84cd-4768-89f3-0fb49c8b1175"],
Cell[CellGroupData[{
Cell[263690, 7173, 609, 15, 39, "Input",ExpressionUUID->"7f0bcb58-20bb-425e-966e-44d8576066c4"],
Cell[264302, 7190, 3152, 84, 185, "Output",ExpressionUUID->"23670956-3ce7-4b4d-91c1-841dc3264cd6"]
}, Open  ]],
Cell[267469, 7277, 672, 14, 102, "Text",ExpressionUUID->"f2794c09-2596-4033-abb3-c0409dc8ccaf"],
Cell[CellGroupData[{
Cell[268166, 7295, 709, 17, 69, "Input",ExpressionUUID->"cb3b6757-655e-4431-a10b-577e62bf4c95"],
Cell[268878, 7314, 588, 15, 73, "Output",ExpressionUUID->"3558d483-55e2-4a5a-a2ff-515440cce007"],
Cell[269469, 7331, 325, 6, 44, "Output",ExpressionUUID->"7eac238f-f26b-44c5-9ba7-52641e92390d"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[269843, 7343, 556, 16, 68, "Subsection",ExpressionUUID->"319a28d5-226e-4ddc-8b1e-4586a662c196"],
Cell[270402, 7361, 748, 21, 73, "Text",ExpressionUUID->"7c5a7b04-5e3d-40d2-9b14-0e1c47c14e3e"],
Cell[271153, 7384, 584, 17, 44, "Text",ExpressionUUID->"41f6b6e8-0adf-49f6-b7b0-c2a556cf5c14"],
Cell[CellGroupData[{
Cell[271762, 7405, 1483, 38, 98, "Input",ExpressionUUID->"ae87c3a2-dd96-4fbd-994f-e9be3533381f"],
Cell[273248, 7445, 2371, 66, 106, "Output",ExpressionUUID->"1a4fbdb8-625f-4d87-9a24-5cea86b3e5b8"]
}, Open  ]],
Cell[275634, 7514, 181, 3, 44, "Text",ExpressionUUID->"d0f88a61-2df2-4e41-9a3e-a7aff4ffccb6"],
Cell[CellGroupData[{
Cell[275840, 7521, 484, 13, 69, "Input",ExpressionUUID->"8d9820d9-850a-4c4e-af3a-82e7abc70db4"],
Cell[276327, 7536, 929, 27, 72, "Output",ExpressionUUID->"13e7bc45-55eb-445b-899f-2c1a741d8870"],
Cell[277259, 7565, 1349, 38, 71, "Output",ExpressionUUID->"f1af7048-7b42-473e-8994-61f9935cf4d6"]
}, Open  ]],
Cell[278623, 7606, 182, 3, 44, "Text",ExpressionUUID->"6b5dfc5a-3137-4aa1-9742-5c6a475bd430"],
Cell[CellGroupData[{
Cell[278830, 7613, 1659, 42, 156, "Input",ExpressionUUID->"9177c9d3-75b0-490a-9d71-d91eb3310819"],
Cell[280492, 7657, 1299, 35, 74, "Output",ExpressionUUID->"172ee5cd-828e-43ab-9e9c-da6c6be60276"],
Cell[281794, 7694, 3458, 100, 92, "Output",ExpressionUUID->"b0b97aca-6a5f-4e49-ad83-39d0baa9c7d8"]
}, Open  ]],
Cell[285267, 7797, 251, 8, 44, "Text",ExpressionUUID->"c465d17f-f044-4273-91bf-a6ede013140e"],
Cell[CellGroupData[{
Cell[285543, 7809, 335, 6, 39, "Input",ExpressionUUID->"0f100c5c-b836-4a32-be45-08111150848e"],
Cell[285881, 7817, 1299, 38, 76, "Output",ExpressionUUID->"f1642879-b963-46f6-94aa-f9a9c90aa1ef"]
}, Open  ]],
Cell[287195, 7858, 173, 3, 44, "Text",ExpressionUUID->"959c6477-6869-4f26-a1de-edcd83fa37c7"],
Cell[CellGroupData[{
Cell[287393, 7865, 325, 8, 39, "Input",ExpressionUUID->"23f319ec-23e6-4abe-ac7f-9afd2c1a99d7"],
Cell[287721, 7875, 2471, 65, 140, "Output",ExpressionUUID->"e5441522-7187-4f19-9449-4e269b4a299b"]
}, Open  ]],
Cell[290207, 7943, 1096, 29, 102, "Text",ExpressionUUID->"ec60d745-6dd3-4910-bfba-130759644c08"],
Cell[CellGroupData[{
Cell[291328, 7976, 1026, 30, 69, "Input",ExpressionUUID->"88f8d7a9-93b9-4f47-9582-4ba536b036c4"],
Cell[292357, 8008, 304, 8, 48, "Output",ExpressionUUID->"7219f887-96ed-429c-80f2-c77c8d3b5a1e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[292698, 8021, 886, 20, 39, "Input",ExpressionUUID->"2f8284c9-72aa-412f-ae33-1514e5ee12c5"],
Cell[293587, 8043, 15847, 422, 733, "Output",ExpressionUUID->"ff2f603e-d2d1-48e9-904c-a6425ac05a22"]
}, Open  ]],
Cell[309449, 8468, 385, 9, 44, "Text",ExpressionUUID->"4f6ee97f-15fd-4bce-a9ec-8e71ea08f0b1"],
Cell[CellGroupData[{
Cell[309859, 8481, 987, 23, 127, "Input",ExpressionUUID->"be7217a6-6276-401b-b479-3c3d31c68c30"],
Cell[310849, 8506, 3434, 87, 148, "Output",ExpressionUUID->"ae138ef9-6648-4dfc-b6fa-0bb316181074"],
Cell[314286, 8595, 559, 11, 44, "Output",ExpressionUUID->"0407cd50-9f4c-4024-97bf-13165054bdff"]
}, Open  ]],
Cell[314860, 8609, 588, 13, 102, "Text",ExpressionUUID->"f14535b6-a05a-4b55-8e41-daaaaa905efe"],
Cell[CellGroupData[{
Cell[315473, 8626, 2050, 64, 156, "Input",ExpressionUUID->"8b489d85-6940-40df-8c9c-55edb1bc6975"],
Cell[317526, 8692, 1871, 56, 96, "Output",ExpressionUUID->"b9ea5f5e-d882-425b-8c50-241f1d1c3f6a"]
}, Open  ]],
Cell[319412, 8751, 960, 34, 73, "Text",ExpressionUUID->"bc709146-c9b3-4460-bb71-bb4ad40dd382"],
Cell[CellGroupData[{
Cell[320397, 8789, 1333, 38, 98, "Input",ExpressionUUID->"204aa2f3-ce9d-40f3-a8f8-abd7f1ea4f4e"],
Cell[321733, 8829, 6730, 175, 366, "Output",ExpressionUUID->"1791e11e-d15d-4888-a161-5cc1a4073a16"]
}, Open  ]],
Cell[328478, 9007, 2018, 54, 156, "Input",ExpressionUUID->"699a0f47-3c3e-4f8c-863f-15fad1a8c17c"],
Cell[CellGroupData[{
Cell[330521, 9065, 749, 20, 69, "Input",ExpressionUUID->"605ddd1d-a5bb-4af3-97f2-a57e80956642"],
Cell[331273, 9087, 456, 10, 28, "Message",ExpressionUUID->"1cc0590c-9b75-4389-b71d-31fbcf14dabb"],
Cell[331732, 9099, 1771, 53, 119, "Output",ExpressionUUID->"8e97fed1-5279-4148-9135-225a01b14e76"]
}, Open  ]],
Cell[333518, 9155, 251, 4, 44, "Text",ExpressionUUID->"f609131b-45e4-4a4c-b83f-8e3441da9de4"],
Cell[CellGroupData[{
Cell[333794, 9163, 459, 13, 39, "Input",ExpressionUUID->"ada3f711-6803-4636-9cda-e3f409ce6c30"],
Cell[334256, 9178, 18901, 497, 928, "Output",ExpressionUUID->"b80d6769-9ce2-40d9-8324-4e08d279a08c"]
}, Open  ]],
Cell[353172, 9678, 229, 5, 44, "Text",ExpressionUUID->"c32e5082-c4ab-49ac-bca6-6448f9187f52"],
Cell[CellGroupData[{
Cell[353426, 9687, 324, 9, 39, "Input",ExpressionUUID->"e921198d-adf8-41c3-8673-e26e7b4aeea5"],
Cell[353753, 9698, 3285, 88, 166, "Output",ExpressionUUID->"6b8a0306-c963-4f0d-a211-caee82aa29c0"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[357099, 9793, 398, 12, 65, "Section",ExpressionUUID->"2f6d1ec5-a0ce-48b9-aec2-d5222270966d"],
Cell[357500, 9807, 764, 17, 102, "Text",ExpressionUUID->"c7c446fa-ac13-4089-83f1-3b9049214936"],
Cell[CellGroupData[{
Cell[358289, 9828, 1805, 56, 98, "Input",ExpressionUUID->"425c0f68-d53e-46b7-8b27-c88b73fcf1d9"],
Cell[360097, 9886, 468, 12, 48, "Output",ExpressionUUID->"38956383-22c2-4be9-b50b-c797f2fe333e"],
Cell[360568, 9900, 860, 24, 63, "Output",ExpressionUUID->"aa9787b8-11b0-469e-8396-939528532131"],
Cell[361431, 9926, 826, 26, 73, "Output",ExpressionUUID->"9ab2c739-539c-41d9-b4a1-84bb415f7500"]
}, Open  ]],
Cell[362272, 9955, 194, 3, 44, "Text",ExpressionUUID->"b2927a49-ff0a-415e-b94f-fd279215c1f4"],
Cell[CellGroupData[{
Cell[362491, 9962, 510, 12, 98, "Input",ExpressionUUID->"c96d877e-e8ac-42bb-ba99-8ec893da4548"],
Cell[363004, 9976, 2344, 72, 147, "Output",ExpressionUUID->"1d9d49dc-0de1-49f8-aade-6dc8f1870705"]
}, Open  ]],
Cell[CellGroupData[{
Cell[365385, 10053, 168, 3, 57, "Subsubsection",ExpressionUUID->"a87354aa-c6db-4bdd-b601-2c96c630fe15"],
Cell[365556, 10058, 321, 7, 73, "Text",ExpressionUUID->"b19528b8-295c-494c-abbb-d367ee28aba0"],
Cell[CellGroupData[{
Cell[365902, 10069, 470, 12, 39, "Input",ExpressionUUID->"76377155-a343-4cc6-9c8f-1b82d9c489ae"],
Cell[366375, 10083, 949, 28, 75, "Output",ExpressionUUID->"3027ccca-b81a-46c3-bd0b-ba52da20585f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[367361, 10116, 273, 6, 39, "Input",ExpressionUUID->"935e18c3-ba1d-494e-b82c-abb5eb61a956"],
Cell[367637, 10124, 956, 27, 102, "Output",ExpressionUUID->"762b4738-6019-4bc3-b1f8-8b61a8745ee3"]
}, Open  ]],
Cell[368608, 10154, 451, 12, 44, "Text",ExpressionUUID->"6f9f0efc-d343-4e2a-ba9a-0ef82a5df08a"],
Cell[CellGroupData[{
Cell[369084, 10170, 1709, 52, 185, "Input",ExpressionUUID->"5b277083-867e-49f5-8455-1d4456a09a32"],
Cell[370796, 10224, 1685, 52, 102, "Output",ExpressionUUID->"83e74197-0d26-4937-b560-eeea9a2952ba"],
Cell[372484, 10278, 2750, 90, 200, "Output",ExpressionUUID->"5106d475-a12b-42bc-bba7-0c93ce736836"]
}, Open  ]],
Cell[375249, 10371, 171, 3, 44, "Text",ExpressionUUID->"d5e46db6-d771-44da-bb2c-39a565c48b6a"],
Cell[CellGroupData[{
Cell[375445, 10378, 1622, 38, 185, "Input",ExpressionUUID->"ef92b8f7-0e76-4302-b03f-fd40d1dd20fc"],
Cell[377070, 10418, 2507, 68, 75, "Output",ExpressionUUID->"9d1ab604-0723-4e3f-8340-40ef091088a1"],
Cell[379580, 10488, 2424, 65, 75, "Output",ExpressionUUID->"a036177f-cdd8-4972-a9f0-1d768583fc15"]
}, Open  ]],
Cell[CellGroupData[{
Cell[382041, 10558, 691, 16, 69, "Input",ExpressionUUID->"dc05385d-60fe-4ebb-85c0-82e2552886d6"],
Cell[382735, 10576, 1665, 49, 89, "Output",ExpressionUUID->"8ff5e4f9-dd28-4abb-9e50-568a6c36bb9c"],
Cell[384403, 10627, 1499, 44, 89, "Output",ExpressionUUID->"9ce60e3b-cb86-42b8-925b-afea96bc7237"]
}, Open  ]],
Cell[CellGroupData[{
Cell[385939, 10676, 397, 9, 69, "Input",ExpressionUUID->"831962e5-6bf7-4abc-9e8e-e5ac45d7d171"],
Cell[386339, 10687, 253, 4, 44, "Output",ExpressionUUID->"01258b66-6b13-4861-ad3c-73b39f1c06f9"],
Cell[386595, 10693, 252, 4, 44, "Output",ExpressionUUID->"42073e3a-75bf-43e6-b094-3173bd9dca63"]
}, Open  ]],
Cell[386862, 10700, 149, 3, 44, "Text",ExpressionUUID->"a13129be-7277-488c-a178-6b6350a9b698"]
}, Open  ]],
Cell[CellGroupData[{
Cell[387048, 10708, 230, 4, 57, "Subsubsection",ExpressionUUID->"863f88d1-0c2c-46cc-a7c9-ac34ca9458a8"],
Cell[387281, 10714, 338, 5, 44, "Text",ExpressionUUID->"74e912b5-2dbe-421d-8ad0-a4459e118c52"],
Cell[CellGroupData[{
Cell[387644, 10723, 745, 15, 39, "Input",ExpressionUUID->"9726064b-053c-4efb-abc9-ff4ec56944ec"],
Cell[388392, 10740, 3199, 99, 144, "Output",ExpressionUUID->"1ba42c82-5109-4990-a7e9-c80b6b09f66a"]
}, Open  ]],
Cell[391606, 10842, 193, 3, 44, "Text",ExpressionUUID->"03f7db83-7586-41f0-bf3d-67c6947a9ba4"],
Cell[CellGroupData[{
Cell[391824, 10849, 1336, 34, 69, "Input",ExpressionUUID->"4abb0d77-e286-409b-ba12-4f51d8874069"],
Cell[393163, 10885, 3656, 101, 120, "Output",ExpressionUUID->"b6fafe2a-78d3-48cc-962c-5c26f31f5374"],
Cell[396822, 10988, 26338, 592, 879, "Output",ExpressionUUID->"01288c0a-9980-497f-8e0a-83e369eab2e3"]
}, Open  ]],
Cell[423175, 11583, 186, 3, 44, "Text",ExpressionUUID->"f4a7e1db-2e24-4562-a7b6-a7bf5928bc5b"],
Cell[CellGroupData[{
Cell[423386, 11590, 889, 24, 69, "Input",ExpressionUUID->"7f62f848-abfc-4fb8-8cab-c373ecc17bc3"],
Cell[424278, 11616, 1064, 23, 73, "Output",ExpressionUUID->"6d3530eb-100a-42f5-b7be-583983220d3a"],
Cell[425345, 11641, 1064, 23, 73, "Output",ExpressionUUID->"f2ecb655-61c0-4230-ad6d-f21afd8b9fd7"]
}, Open  ]],
Cell[CellGroupData[{
Cell[426446, 11669, 435, 11, 69, "Input",ExpressionUUID->"be172a4c-42e2-45a4-850b-7f58eaa45eba"],
Cell[426884, 11682, 519, 13, 64, "Output",ExpressionUUID->"787b780d-bc70-46f4-bbe3-9c6eee97d7b7"],
Cell[427406, 11697, 518, 13, 64, "Output",ExpressionUUID->"76e70fc9-c9d6-4c3f-a970-4d73dbcfebb9"]
}, Open  ]],
Cell[CellGroupData[{
Cell[427961, 11715, 1588, 44, 127, "Input",ExpressionUUID->"c139233e-404f-481a-94b7-54033568f2f8"],
Cell[429552, 11761, 1682, 46, 105, "Output",ExpressionUUID->"2e24d0b0-2219-44ce-8f6a-5b4191a87384"],
Cell[431237, 11809, 2388, 66, 119, "Output",ExpressionUUID->"e9e88ee2-0cf2-46b8-805d-2bc3b3a71c76"],
Cell[433628, 11877, 618, 12, 44, "Output",ExpressionUUID->"d40f7e09-117e-4422-9124-ee62c4677e1c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[434283, 11894, 1645, 47, 156, "Input",ExpressionUUID->"11b6b74e-48fe-4968-ae87-23f2d4278ce4"],
Cell[435931, 11943, 893, 24, 67, "Output",ExpressionUUID->"8a0726ef-81dc-4593-a372-520de200aca3"],
Cell[436827, 11969, 1271, 36, 82, "Output",ExpressionUUID->"7a1293d1-6d4c-458c-b6ce-211fd816eef1"],
Cell[438101, 12007, 473, 10, 44, "Output",ExpressionUUID->"3a2612da-b9cf-4801-aea3-e06183eec529"]
}, Open  ]],
Cell[438589, 12020, 755, 18, 73, "Text",ExpressionUUID->"eb5f3744-39e8-4503-82e2-68b082d3d605"],
Cell[CellGroupData[{
Cell[439369, 12042, 685, 19, 69, "Input",ExpressionUUID->"e64668a0-b364-41fe-9ec5-303a90a295cb"],
Cell[440057, 12063, 752, 21, 69, "Output",ExpressionUUID->"a6445c10-a3da-4628-88ff-7aad7f979dbc"],
Cell[440812, 12086, 2906, 80, 133, "Output",ExpressionUUID->"f50474fe-fe1e-4e76-94c3-f7e9511b6f75"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[443779, 12173, 135, 3, 65, "Section",ExpressionUUID->"9d6cf142-2004-423c-a544-54fc6939e5cf"],
Cell[443917, 12178, 496, 9, 102, "Text",ExpressionUUID->"605dd233-f16a-47ac-8c52-0688c8a3c088"],
Cell[444416, 12189, 831, 24, 104, "Text",ExpressionUUID->"e9114555-0a9a-4b1a-a845-0c1495db0bf9"],
Cell[445250, 12215, 1065, 33, 106, "Text",ExpressionUUID->"fb772569-90a9-4284-9317-85796cfd5371"],
Cell[CellGroupData[{
Cell[446340, 12252, 1276, 31, 69, "Input",ExpressionUUID->"7e9cb068-ad3d-44e9-8062-9bc5987e3a3b"],
Cell[447619, 12285, 2141, 57, 77, "Output",ExpressionUUID->"4715f997-9b80-4a5c-bc7a-11bb86cc1f5e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[449797, 12347, 1805, 48, 98, "Input",ExpressionUUID->"e4327b37-8987-4b67-aaa8-1c9fa6fdd7ab"],
Cell[451605, 12397, 1781, 48, 97, "Output",ExpressionUUID->"7a0656d4-983b-410c-9cca-cfe0bc41eac3"]
}, Open  ]],
Cell[453401, 12448, 706, 17, 159, "Text",ExpressionUUID->"9e808f49-2304-421c-a889-8c880fbfa368"],
Cell[454110, 12467, 143, 3, 44, "Text",ExpressionUUID->"a7c70a36-9f10-4276-8899-df4061e8d100"],
Cell[454256, 12472, 451, 10, 39, "Input",ExpressionUUID->"b9bdf744-6d0a-408a-91e1-f29b58551e12"],
Cell[CellGroupData[{
Cell[454732, 12486, 1617, 40, 127, "Input",ExpressionUUID->"7dc8daa7-7294-477a-8bcf-20b06a6ff0ba"],
Cell[456352, 12528, 1271, 38, 74, "Output",ExpressionUUID->"3c8682e1-8a96-4d7a-b0a0-3cb6466a9011"]
}, Open  ]],
Cell[457638, 12569, 400, 10, 73, "Text",ExpressionUUID->"0908cb63-fe6a-470c-b887-0c4348579e09"],
Cell[458041, 12581, 2197, 67, 98, "Text",ExpressionUUID->"6a472fe2-537f-475e-bc5e-3398ea8d9107"],
Cell[460241, 12650, 1355, 35, 127, "Input",ExpressionUUID->"2eabfe3a-ca93-4a3d-9902-16eb9903bcb2"],
Cell[461599, 12687, 1279, 38, 69, "Input",ExpressionUUID->"1f97dead-2e3e-4510-829c-12a78a5c50a3"],
Cell[462881, 12727, 989, 27, 69, "Input",ExpressionUUID->"1a10e53a-1507-4861-a8f6-67ec6b0ed006"],
Cell[463873, 12756, 994, 26, 127, "Input",ExpressionUUID->"26067ccf-b69e-409f-97ee-28407a9096bc"],
Cell[464870, 12784, 410, 10, 73, "Text",ExpressionUUID->"815c0566-e7b3-4c5a-b5bd-5fdf495eb950"],
Cell[CellGroupData[{
Cell[465305, 12798, 773, 14, 39, "Input",ExpressionUUID->"c53c4370-367d-407d-9da0-026b887bc108"],
Cell[466081, 12814, 416, 7, 44, "Output",ExpressionUUID->"2739a735-2979-4961-be3e-c77599c701a6"]
}, Open  ]],
Cell[466512, 12824, 351, 9, 44, "Text",ExpressionUUID->"89441c3f-4e54-4728-bb2a-b32dfa5fb5dc"],
Cell[466866, 12835, 623, 17, 69, "Input",ExpressionUUID->"716f91f3-1fb2-4d58-8b3d-7a69ddb2cc2b"],
Cell[467492, 12854, 534, 15, 39, "Input",ExpressionUUID->"f99b20a4-eaed-41e8-b9f1-2e9388ccece5"],
Cell[468029, 12871, 372, 7, 73, "Text",ExpressionUUID->"50bc0d52-3a49-4814-9763-424cca03fc20"],
Cell[CellGroupData[{
Cell[468426, 12882, 1766, 52, 272, "Input",ExpressionUUID->"a3f2f9c3-4e24-4f37-8f88-e2231053446a"],
Cell[470195, 12936, 551, 15, 66, "Output",ExpressionUUID->"ab72721f-2888-477e-ad79-f2ad38f79cd3"],
Cell[470749, 12953, 580, 16, 66, "Output",ExpressionUUID->"6933debc-0b7d-451d-b784-c6ab4de5b1f7"],
Cell[471332, 12971, 550, 15, 66, "Output",ExpressionUUID->"8264bdf2-08ae-4e89-825d-dd2a0bc65c9f"]
}, Open  ]],
Cell[471897, 12989, 1199, 34, 107, "Text",ExpressionUUID->"4a229772-c0a0-46d4-b0eb-d547981332d9"]
}, Closed]]
}
]
*)

